#!/usr/bin/env bash
# Powerline Extra Symbols (40 icons, 3 aliases)
# Codepoints: E0A0-E0A3 E0B0-E0BF E0C0-E0C8 E0CC-E0CF E0D0-E0D2 E0D4 E0D6-E0D7
test -n "$__i_ple_loaded" && return || __i_ple_loaded=1
i='' i_pl_branch=$i
i='' i_pl_line_number=$i
      i_pl_current_line=$i_pl_line_number
i='' i_pl_hostname=$i
      i_pl_readonly=$i_pl_hostname
i='' i_ple_column_number=$i
      i_ple_current_column=$i_ple_column_number
i='' i_pl_left_hard_divider=$i
i='' i_pl_left_soft_divider=$i
i='' i_pl_right_hard_divider=$i
i='' i_pl_right_soft_divider=$i
i='' i_ple_right_half_circle_thick=$i
i='' i_ple_right_half_circle_thin=$i
i='' i_ple_left_half_circle_thick=$i
i='' i_ple_left_half_circle_thin=$i
i='' i_ple_lower_left_triangle=$i
i='' i_ple_backslash_separator=$i
i='' i_ple_lower_right_triangle=$i
i='' i_ple_forwardslash_separator=$i
i='' i_ple_upper_left_triangle=$i
i='' i_ple_forwardslash_separator_redundant=$i
i='' i_ple_upper_right_triangle=$i
i='' i_ple_backslash_separator_redundant=$i
i='' i_ple_flame_thick=$i
i='' i_ple_flame_thin=$i
i='' i_ple_flame_thick_mirrored=$i
i='' i_ple_flame_thin_mirrored=$i
i='' i_ple_pixelated_squares_small=$i
i='' i_ple_pixelated_squares_small_mirrored=$i
i='' i_ple_pixelated_squares_big=$i
i='' i_ple_pixelated_squares_big_mirrored=$i
i='' i_ple_ice_waveform=$i
i='' i_ple_ice_waveform_mirrored=$i
i='' i_ple_honeycomb=$i
i='' i_ple_honeycomb_outline=$i
i='' i_ple_lego_separator=$i
i='' i_ple_lego_separator_thin=$i
i='' i_ple_lego_block_facing=$i
i='' i_ple_lego_block_sideways=$i
i='' i_ple_trapezoid_top_bottom=$i
i='' i_ple_trapezoid_top_bottom_mirrored=$i
i='' i_ple_right_hard_divider_inverse=$i
i='' i_ple_left_hard_divider_inverse=$i
unset i
