#!/usr/bin/env bash
# Font Awesome Extension (170 icons)
# Codepoints: Nerd Fonts moved E000-E0A9 → E200-E2A9
test -n "$__i_fae_loaded" && return || __i_fae_loaded=1
i='' i_fae_smaller=$i
i='' i_fae_snowing=$i
i='' i_fae_soda=$i
i='' i_fae_sofa=$i
i='' i_fae_soup=$i
i='' i_fae_spermatozoon=$i
i='' i_fae_spin_double=$i
i='' i_fae_stomach=$i
i='' i_fae_storm=$i
i='' i_fae_telescope=$i
i='' i_fae_thermometer=$i
i='' i_fae_thermometer_high=$i
i='' i_fae_thermometer_low=$i
i='' i_fae_thin_close=$i
i='' i_fae_toilet=$i
i='' i_fae_tools=$i
i='' i_fae_tooth=$i
i='' i_fae_uterus=$i
i='' i_fae_w3c=$i
i='' i_fae_walking=$i
i='' i_fae_virus=$i
i='' i_fae_telegram_circle=$i
i='' i_fae_slash=$i
i='' i_fae_telegram=$i
i='' i_fae_shirt=$i
i='' i_fae_tacos=$i
i='' i_fae_sushi=$i
i='' i_fae_triangle_ruler=$i
i='' i_fae_tree=$i
i='' i_fae_sun_cloud=$i
i='' i_fae_ruby_o=$i
i='' i_fae_ruler=$i
i='' i_fae_umbrella=$i
i='' i_fae_medicine=$i
i='' i_fae_microscope=$i
i='' i_fae_milk_bottle=$i
i='' i_fae_minimize=$i
i='' i_fae_molecule=$i
i='' i_fae_moon_cloud=$i
i='' i_fae_mushroom=$i
i='' i_fae_mustache=$i
i='' i_fae_mysql=$i
i='' i_fae_nintendo=$i
i='' i_fae_palette_color=$i
i='' i_fae_pi=$i
i='' i_fae_pizza=$i
i='' i_fae_planet=$i
i='' i_fae_plant=$i
i='' i_fae_playstation=$i
i='' i_fae_poison=$i
i='' i_fae_popcorn=$i
i='' i_fae_popsicle=$i
i='' i_fae_pulse=$i
i='' i_fae_python=$i
i='' i_fae_quora_circle=$i
i='' i_fae_quora_square=$i
i='' i_fae_radioactive=$i
i='' i_fae_raining=$i
i='' i_fae_real_heart=$i
i='' i_fae_refrigerator=$i
i='' i_fae_restore=$i
i='' i_fae_ring=$i
i='' i_fae_ruby=$i
i='' i_fae_fingerprint=$i
i='' i_fae_floppy=$i
i='' i_fae_footprint=$i
i='' i_fae_freecodecamp=$i
i='' i_fae_galaxy=$i
i='' i_fae_galery=$i
i='' i_fae_glass=$i
i='' i_fae_google_drive=$i
i='' i_fae_google_play=$i
i='' i_fae_gps=$i
i='' i_fae_grav=$i
i='' i_fae_guitar=$i
i='' i_fae_gut=$i
i='' i_fae_halter=$i
i='' i_fae_hamburger=$i
i='' i_fae_hat=$i
i='' i_fae_hexagon=$i
i='' i_fae_high_heel=$i
i='' i_fae_hotdog=$i
i='' i_fae_ice_cream=$i
i='' i_fae_id_card=$i
i='' i_fae_imdb=$i
i='' i_fae_infinity=$i
i='' i_fae_java=$i
i='' i_fae_layers=$i
i='' i_fae_lips=$i
i='' i_fae_lipstick=$i
i='' i_fae_liver=$i
i='' i_fae_lung=$i
i='' i_fae_makeup_brushes=$i
i='' i_fae_maximize=$i
i='' i_fae_wallet=$i
i='' i_fae_chess_horse=$i
i='' i_fae_chess_king=$i
i='' i_fae_chess_pawn=$i
i='' i_fae_chess_queen=$i
i='' i_fae_chess_tower=$i
i='' i_fae_cheese=$i
i='' i_fae_chilli=$i
i='' i_fae_chip=$i
i='' i_fae_cicling=$i
i='' i_fae_cloud=$i
i='' i_fae_cockroach=$i
i='' i_fae_coffe_beans=$i
i='' i_fae_coins=$i
i='' i_fae_comb=$i
i='' i_fae_comet=$i
i='' i_fae_crown=$i
i='' i_fae_cup_coffe=$i
i='' i_fae_dice=$i
i='' i_fae_disco=$i
i='' i_fae_dna=$i
i='' i_fae_donut=$i
i='' i_fae_dress=$i
i='' i_fae_drop=$i
i='' i_fae_ello=$i
i='' i_fae_envelope_open=$i
i='' i_fae_envelope_open_o=$i
i='' i_fae_equal=$i
i='' i_fae_equal_bigger=$i
i='' i_fae_feedly=$i
i='' i_fae_file_export=$i
i='' i_fae_file_import=$i
i='' i_fae_wind=$i
i='' i_fae_atom=$i
i='' i_fae_bacteria=$i
i='' i_fae_banana=$i
i='' i_fae_bath=$i
i='' i_fae_bed=$i
i='' i_fae_benzene=$i
i='' i_fae_bigger=$i
i='' i_fae_biohazard=$i
i='' i_fae_blogger_circle=$i
i='' i_fae_blogger_square=$i
i='' i_fae_bones=$i
i='' i_fae_book_open=$i
i='' i_fae_book_open_o=$i
i='' i_fae_brain=$i
i='' i_fae_bread=$i
i='' i_fae_butterfly=$i
i='' i_fae_carot=$i
i='' i_fae_cc_by=$i
i='' i_fae_cc_cc=$i
i='' i_fae_cc_nc=$i
i='' i_fae_cc_nc_eu=$i
i='' i_fae_cc_nc_jp=$i
i='' i_fae_cc_nd=$i
i='' i_fae_cc_remix=$i
i='' i_fae_cc_sa=$i
i='' i_fae_cc_share=$i
i='' i_fae_cc_zero=$i
i='' i_fae_checklist_o=$i
i='' i_fae_cherry=$i
i='' i_fae_chess_bishop=$i
i='' i_fae_xbox=$i
i='' i_fae_apple_fruit=$i
i='' i_fae_chicken_thigh=$i
i='' i_fae_gift_card=$i
i='' i_fae_injection=$i
i='' i_fae_isle=$i
i='' i_fae_lollipop=$i
i='' i_fae_loyalty_card=$i
i='' i_fae_meat=$i
i='' i_fae_mountains=$i
i='' i_fae_orange=$i
i='' i_fae_peach=$i
i='' i_fae_pear=$i
unset i
