#!/usr/bin/env bash
# Devicons (198 icons, 7 do not have an established name)
# Codepoints: Nerd moved E600-E6C5 → E700-E7C5
test -n "$__i_dev_loaded" && return || __i_dev_loaded=1
i='' i_dev_bing_small=$i
i='' i_dev_css_tricks=$i
i='' i_dev_git=$i
i='' i_dev_bitbucket=$i
i='' i_dev_mysql=$i
i='' i_dev_streamline=$i
i='' i_dev_database=$i
i='' i_dev_dropbox=$i
i='' i_dev_github_alt=$i
i='' i_dev_github_badge=$i
i='' i_dev_github=$i
i='' i_dev_wordpress=$i
i='' i_dev_visualstudio=$i
i='' i_dev_jekyll_small=$i
i='' i_dev_android=$i
i='' i_dev_windows=$i
i='' i_dev_stackoverflow=$i
i='' i_dev_apple=$i
i='' i_dev_linux=$i
i='' i_dev_appstore=$i
i='' i_dev_ghost_small=$i
i='' i_dev_yahoo=$i
i='' i_dev_codepen=$i
i='' i_dev_github_full=$i
i='' i_dev_nodejs_small=$i
i='' i_dev_nodejs=$i
i='' i_dev_hackernews=$i
i='' i_dev_ember=$i
i='' i_dev_dojo=$i
i='' i_dev_django=$i
i='' i_dev_npm=$i
i='' i_dev_ghost=$i
i='' i_dev_modernizr=$i
i='' i_dev_unity_small=$i
i='' i_dev_rasberry_pi=$i
i='' i_dev_blackberry=$i
i='' i_dev_go=$i
i='' i_dev_git_branch=$i
i='' i_dev_git_pull_request=$i
i='' i_dev_git_merge=$i
i='' i_dev_git_compare=$i
i='' i_dev_git_commit=$i
i='' i_dev_cssdeck=$i
i='' i_dev_yahoo_small=$i
i='' i_dev_techcrunch=$i
i='' i_dev_smashing_magazine=$i
i='' i_dev_netmagazine=$i
i='' i_dev_codrops=$i
i='' i_dev_phonegap=$i
i='' i_dev_google_drive=$i
i='' i_dev_html5_multimedia=$i
i='' i_dev_html5_device_access=$i
i='' i_dev_html5_connectivity=$i
i='' i_dev_html5_3d_effects=$i
i='' i_dev_html5=$i
i='' i_dev_scala=$i
i='' i_dev_java=$i
i='' i_dev_ruby=$i
i='' i_dev_ubuntu=$i
i='' i_dev_ruby_on_rails=$i
i='' i_dev_python=$i
i='' i_dev_php=$i
i='' i_dev_markdown=$i
i='' i_dev_laravel=$i
i='' i_dev_magento=$i
i='' i_dev_joomla=$i
i='' i_dev_drupal=$i
i='' i_dev_chrome=$i
i='' i_dev_ie=$i
i='' i_dev_firefox=$i
i='' i_dev_opera=$i
i='' i_dev_bootstrap=$i
i='' i_dev_safari=$i
i='' i_dev_css3=$i
i='' i_dev_css3_full=$i
i='' i_dev_sass=$i
i='' i_dev_grunt=$i
i='' i_dev_bower=$i
i='' i_dev_javascript=$i
i='' i_dev_javascript_shield=$i
i='' i_dev_jquery=$i
i='' i_dev_coffeescript=$i
i='' i_dev_backbone=$i
i='' i_dev_angular=$i
i='' i_dev_jquery_ui=$i
i='' i_dev_swift=$i
i='' i_dev_symfony=$i
i='' i_dev_symfony_badge=$i
i='' i_dev_less=$i
i='' i_dev_stylus=$i
i='' i_dev_trello=$i
i='' i_dev_atlassian=$i
i='' i_dev_jira=$i
i='' i_dev_envato=$i
i='' i_dev_snap_svg=$i
i='' i_dev_raphael=$i
i='' i_dev_chart=$i
i='' i_dev_compass=$i
i='' i_dev_onedrive=$i
i='' i_dev_gulp=$i
i='' i_dev_atom=$i
i='' i_dev_cisco=$i
i='' i_dev_nancy=$i
i='' i_dev_jenkins=$i
i='' i_dev_clojure=$i
i='' i_dev_perl=$i
i='' i_dev_clojure_alt=$i
i='' i_dev_celluloid=$i
i='' i_dev_w3c=$i
i='' i_dev_redis=$i
i='' i_dev_postgresql=$i
i='' i_dev_webplatform=$i
i='' i_dev_requirejs=$i
i='' i_dev_opensource=$i
i='' i_dev_typo3=$i
i='' i_dev_uikit=$i
i='' i_dev_doctrine=$i
i='' i_dev_groovy=$i
i='' i_dev_nginx=$i
i='' i_dev_haskell=$i
i='' i_dev_zend=$i
i='' i_dev_gnu=$i
i='' i_dev_yeoman=$i
i='' i_dev_heroku=$i
i='' i_dev_msql_server=$i
i='' i_dev_debian=$i
i='' i_dev_travis=$i
i='' i_dev_dotnet=$i
i='' i_dev_codeigniter=$i
i='' i_dev_javascript_badge=$i
i='' i_dev_yii=$i
i='' i_dev_composer=$i
i='' i_dev_krakenjs_badge=$i
i='' i_dev_krakenjs=$i
i='' i_dev_mozilla=$i
i='' i_dev_firebase=$i
i='' i_dev_sizzlejs=$i
i='' i_dev_creativecommons=$i
i='' i_dev_creativecommons_badge=$i
i='' i_dev_mitlicence=$i
i='' i_dev_senchatouch=$i
i='' i_dev_bugsense=$i
i='' i_dev_extjs=$i
i='' i_dev_mootools_badge=$i
i='' i_dev_mootools=$i
i='' i_dev_ruby_rough=$i
i='' i_dev_komodo=$i
i='' i_dev_coda=$i
i='' i_dev_bintray=$i
i='' i_dev_terminal=$i
i='' i_dev_code=$i
i='' i_dev_responsive=$i
i='' i_dev_dart=$i
i='' i_dev_aptana=$i
i='' i_dev_mailchimp=$i
i='' i_dev_netbeans=$i
i='' i_dev_dreamweaver=$i
i='' i_dev_brackets=$i
i='' i_dev_eclipse=$i
i='' i_dev_cloud9=$i
i='' i_dev_scrum=$i
i='' i_dev_prolog=$i
i='' i_dev_terminal_badge=$i
i='' i_dev_code_badge=$i
i='' i_dev_mongodb=$i
i='' i_dev_meteor=$i
i='' i_dev_meteorfull=$i
i='' i_dev_fsharp=$i
i='' i_dev_rust=$i
i='' i_dev_ionic=$i
i='' i_dev_sublime=$i
i='' i_dev_appcelerator=$i
i='' i_dev_asterisk=$i
i='' i_dev_aws=$i
i='' i_dev_digital_ocean=$i
i='' i_dev_dlang=$i
i='' i_dev_docker=$i
i='' i_dev_erlang=$i
i='' i_dev_google_cloud_platform=$i
i='' i_dev_grails=$i
i='' i_dev_illustrator=$i
i='' i_dev_intellij=$i
i='' i_dev_materializecss=$i
i='' i_dev_openshift=$i
i='' i_dev_photoshop=$i
i='' i_dev_rackspace=$i
i='' i_dev_react=$i
i='' i_dev_redhat=$i
i='' i_dev_scriptcs=$i
i=''
i=''
i=''
i=''
i=''
i=''
i=''
i='' i_dev_sqllite=$i
i='' i_dev_vim=$i
unset i
