#!/usr/bin/env bash
# Font Logos (Font Linux) 1.1.1 (118 icons)
# Codepoints: F300-F375
# Nerd Fonts Version: 3.2.1
# Script Version: 1.2.0
# We keep the name 'linux' in the metadata for continuity reasons
test -n "$__i_linux_loaded" && return || __i_linux_loaded=1
i='' i_linux_alpine=$i
i='' i_linux_aosc=$i
i='' i_linux_apple=$i
i='' i_linux_archlinux=$i
i='' i_linux_centos=$i
i='' i_linux_coreos=$i
i='' i_linux_debian=$i
i='' i_linux_devuan=$i
i='' i_linux_docker=$i
i='' i_linux_elementary=$i
i='' i_linux_fedora=$i
i='' i_linux_fedora_inverse=$i
i='' i_linux_freebsd=$i
i='' i_linux_gentoo=$i
i='' i_linux_linuxmint=$i
i='' i_linux_linuxmint_inverse=$i
i='' i_linux_mageia=$i
i='' i_linux_mandriva=$i
i='' i_linux_manjaro=$i
i='' i_linux_nixos=$i
i='' i_linux_opensuse=$i
i='' i_linux_raspberry_pi=$i
i='' i_linux_redhat=$i
i='' i_linux_sabayon=$i
i='' i_linux_slackware=$i
i='' i_linux_slackware_inverse=$i
i='' i_linux_tux=$i
i='' i_linux_ubuntu=$i
i='' i_linux_ubuntu_inverse=$i
i='' i_linux_almalinux=$i
i='' i_linux_archlabs=$i
i='' i_linux_artix=$i
i='' i_linux_budgie=$i
i='' i_linux_deepin=$i
i='' i_linux_endeavour=$i
i='' i_linux_ferris=$i
i='' i_linux_flathub=$i
i='' i_linux_gnu_guix=$i
i='' i_linux_illumos=$i
i='' i_linux_kali_linux=$i
i='' i_linux_openbsd=$i
i='' i_linux_parrot=$i
i='' i_linux_pop_os=$i
i='' i_linux_rocky_linux=$i
i='' i_linux_snappy=$i
i='' i_linux_solus=$i
i='' i_linux_void=$i
i='' i_linux_zorin=$i
i='' i_linux_codeberg=$i
i='' i_linux_kde_neon=$i
i='' i_linux_kde_plasma=$i
i='' i_linux_kubuntu=$i
i='' i_linux_kubuntu_inverse=$i
i='' i_linux_forgejo=$i
i='' i_linux_freecad=$i
i='' i_linux_garuda=$i
i='' i_linux_gimp=$i
i='' i_linux_gitea=$i
i='' i_linux_hyperbola=$i
i='' i_linux_inkscape=$i
i='' i_linux_kdenlive=$i
i='' i_linux_krita=$i
i='' i_linux_lxle=$i
i='' i_linux_mxlinux=$i
i='' i_linux_parabola=$i
i='' i_linux_puppy=$i
i='' i_linux_qubesos=$i
i='' i_linux_tails=$i
i='' i_linux_trisquel=$i
i='' i_linux_archcraft=$i
i='' i_linux_arcolinux=$i
i='' i_linux_biglinux=$i
i='' i_linux_crystal=$i
i='' i_linux_locos=$i
i='' i_linux_xerolinux=$i
i='' i_linux_arduino=$i
i='' i_linux_kicad=$i
i='' i_linux_octoprint=$i
i='' i_linux_openscad=$i
i='' i_linux_osh=$i
i='' i_linux_oshwa=$i
i='' i_linux_prusaslicer=$i
i='' i_linux_reprap=$i
i='' i_linux_riscv=$i
i='' i_linux_awesome=$i
i='' i_linux_bspwm=$i
i='' i_linux_dwm=$i
i='' i_linux_enlightenment=$i
i='' i_linux_fluxbox=$i
i='' i_linux_hyprland=$i
i='' i_linux_i3=$i
i='' i_linux_jwm=$i
i='' i_linux_qtile=$i
i='' i_linux_sway=$i
i='' i_linux_xmonad=$i
i='' i_linux_cinnamon=$i
i='' i_linux_freedesktop=$i
i='' i_linux_gnome=$i
i='' i_linux_gtk=$i
i='' i_linux_lxde=$i
i='' i_linux_lxqt=$i
i='' i_linux_mate=$i
i='' i_linux_vanilla=$i
i='' i_linux_wayland=$i
i='' i_linux_xfce=$i
i='' i_linux_xorg=$i
i='' i_linux_fdroid=$i
i='' i_linux_fosdem=$i
i='' i_linux_osi=$i
i='' i_linux_wikimedia=$i
i='' i_linux_mpv=$i
i='' i_linux_neovim=$i
i='' i_linux_thunderbird=$i
i='' i_linux_tor=$i
i='' i_linux_vscodium=$i
i='' i_linux_kde=$i
i='' i_linux_postmarketos=$i
i='' i_linux_qt=$i
unset i
