#!/usr/bin/env bash
# Octicons (310 icons)
# Codepoints: 2665-F533 with gaps
# Nerd Fonts Version: 3.2.1
# Script Version: (autogenerated)
test -n "$__i_oct_loaded" && return || __i_oct_loaded=1
i='♥' i_oct_heart=$i
i='⚡' i_oct_zap=$i
i='' i_oct_light_bulb=$i
i='' i_oct_repo=$i
i='' i_oct_repo_forked=$i
i='' i_oct_repo_push=$i
i='' i_oct_repo_pull=$i
i='' i_oct_book=$i
i='' i_oct_accessibility=$i
i='' i_oct_git_pull_request=$i
i='' i_oct_mark_github=$i
i='' i_oct_download=$i
i='' i_oct_upload=$i
i='' i_oct_accessibility_inset=$i
i='' i_oct_alert_fill=$i
i='' i_oct_file_code=$i
i='' i_oct_apps=$i
i='' i_oct_file_media=$i
i='' i_oct_file_zip=$i
i='' i_oct_archive=$i
i='' i_oct_tag=$i
i='' i_oct_file_directory=$i
i='' i_oct_file_submodule=$i
i='' i_oct_person=$i
i='' i_oct_arrow_both=$i
i='' i_oct_git_commit=$i
i='' i_oct_git_branch=$i
i='' i_oct_git_merge=$i
i='' i_oct_mirror=$i
i='' i_oct_issue_opened=$i
i='' i_oct_issue_reopened=$i
i='' i_oct_issue_closed=$i
i='' i_oct_star=$i
i='' i_oct_comment=$i
i='' i_oct_question=$i
i='' i_oct_alert=$i
i='' i_oct_search=$i
i='' i_oct_gear=$i
i='' i_oct_arrow_down_left=$i
i='' i_oct_tools=$i
i='' i_oct_sign_out=$i
i='' i_oct_rocket=$i
i='' i_oct_rss=$i
i='' i_oct_paste=$i
i='' i_oct_sign_in=$i
i='' i_oct_organization=$i
i='' i_oct_device_mobile=$i
i='' i_oct_unfold=$i
i='' i_oct_check=$i
i='' i_oct_mail=$i
i='' i_oct_read=$i
i='' i_oct_arrow_up=$i
i='' i_oct_arrow_right=$i
i='' i_oct_arrow_down=$i
i='' i_oct_arrow_left=$i
i='' i_oct_pin=$i
i='' i_oct_gift=$i
i='' i_oct_graph=$i
i='' i_oct_triangle_left=$i
i='' i_oct_credit_card=$i
i='' i_oct_clock=$i
i='' i_oct_ruby=$i
i='' i_oct_broadcast=$i
i='' i_oct_key=$i
i='' i_oct_arrow_down_right=$i
i='' i_oct_repo_clone=$i
i='' i_oct_diff=$i
i='' i_oct_eye=$i
i='' i_oct_comment_discussion=$i
i='' i_oct_arrow_switch=$i
i='' i_oct_dot_fill=$i
i='' i_oct_square_fill=$i
i='' i_oct_device_camera=$i
i='' i_oct_device_camera_video=$i
i='' i_oct_pencil=$i
i='' i_oct_info=$i
i='' i_oct_triangle_right=$i
i='' i_oct_triangle_down=$i
i='' i_oct_link=$i
i='' i_oct_plus=$i
i='' i_oct_three_bars=$i
i='' i_oct_code=$i
i='' i_oct_location=$i
i='' i_oct_list_unordered=$i
i='' i_oct_list_ordered=$i
i='' i_oct_quote=$i
i='' i_oct_versions=$i
i='' i_oct_calendar=$i
i='' i_oct_lock=$i
i='' i_oct_diff_added=$i
i='' i_oct_diff_removed=$i
i='' i_oct_diff_modified=$i
i='' i_oct_diff_renamed=$i
i='' i_oct_horizontal_rule=$i
i='' i_oct_arrow_up_left=$i
i='' i_oct_milestone=$i
i='' i_oct_checklist=$i
i='' i_oct_megaphone=$i
i='' i_oct_chevron_right=$i
i='' i_oct_bookmark=$i
i='' i_oct_sliders=$i
i='' i_oct_meter=$i
i='' i_oct_history=$i
i='' i_oct_link_external=$i
i='' i_oct_mute=$i
i='' i_oct_x=$i
i='' i_oct_circle_slash=$i
i='' i_oct_pulse=$i
i='' i_oct_sync=$i
i='' i_oct_telescope=$i
i='' i_oct_arrow_up_right=$i
i='' i_oct_home=$i
i='' i_oct_stop=$i
i='' i_oct_bug=$i
i='' i_oct_logo_github=$i
i='' i_oct_file_binary=$i
i='' i_oct_database=$i
i='' i_oct_server=$i
i='' i_oct_diff_ignored=$i
i='' i_oct_ellipsis=$i
i='' i_oct_bell_fill=$i
i='' i_oct_hubot=$i
i='' i_oct_bell_slash=$i
i='' i_oct_blocked=$i
i='' i_oct_bookmark_fill=$i
i='' i_oct_chevron_up=$i
i='' i_oct_chevron_down=$i
i='' i_oct_chevron_left=$i
i='' i_oct_triangle_up=$i
i='' i_oct_git_compare=$i
i='' i_oct_logo_gist=$i
i='' i_oct_file_symlink_file=$i
i='' i_oct_file_symlink_directory=$i
i='' i_oct_squirrel=$i
i='' i_oct_globe=$i
i='' i_oct_unmute=$i
i='' i_oct_mention=$i
i='' i_oct_package=$i
i='' i_oct_browser=$i
i='' i_oct_terminal=$i
i='' i_oct_markdown=$i
i='' i_oct_dash=$i
i='' i_oct_fold=$i
i='' i_oct_inbox=$i
i='' i_oct_trash=$i
i='' i_oct_paintbrush=$i
i='' i_oct_flame=$i
i='' i_oct_briefcase=$i
i='' i_oct_plug=$i
i='' i_oct_bookmark_slash_fill=$i
i='' i_oct_mortar_board=$i
i='' i_oct_law=$i
i='' i_oct_thumbsup=$i
i='' i_oct_thumbsdown=$i
i='' i_oct_desktop_download=$i
i='' i_oct_beaker=$i
i='' i_oct_bell=$i
i='' i_oct_cache=$i
i='' i_oct_shield=$i
i='' i_oct_bold=$i
i='' i_oct_check_circle=$i
i='' i_oct_italic=$i
i='' i_oct_tasklist=$i
i='' i_oct_verified=$i
i='' i_oct_smiley=$i
i='' i_oct_unverified=$i
i='' i_oct_check_circle_fill=$i
i='' i_oct_file=$i
i='' i_oct_grabber=$i
i='' i_oct_checkbox=$i
i='' i_oct_reply=$i
i='' i_oct_device_desktop=$i
i='' i_oct_circle=$i
i='' i_oct_clock_fill=$i
i='' i_oct_cloud=$i
i='' i_oct_cloud_offline=$i
i='' i_oct_code_of_conduct=$i
i='' i_oct_code_review=$i
i='' i_oct_code_square=$i
i='' i_oct_codescan=$i
i='' i_oct_codescan_checkmark=$i
i='' i_oct_codespaces=$i
i='' i_oct_columns=$i
i='' i_oct_command_palette=$i
i='' i_oct_commit=$i
i='' i_oct_container=$i
i='' i_oct_copilot=$i
i='' i_oct_copilot_error=$i
i='' i_oct_copilot_warning=$i
i='' i_oct_copy=$i
i='' i_oct_cpu=$i
i='' i_oct_cross_reference=$i
i='' i_oct_dependabot=$i
i='' i_oct_diamond=$i
i='' i_oct_discussion_closed=$i
i='' i_oct_discussion_duplicate=$i
i='' i_oct_discussion_outdated=$i
i='' i_oct_dot=$i
i='' i_oct_duplicate=$i
i='' i_oct_eye_closed=$i
i='' i_oct_feed_discussion=$i
i='' i_oct_feed_forked=$i
i='' i_oct_feed_heart=$i
i='' i_oct_feed_merged=$i
i='' i_oct_feed_person=$i
i='' i_oct_feed_repo=$i
i='' i_oct_feed_rocket=$i
i='' i_oct_feed_star=$i
i='' i_oct_feed_tag=$i
i='' i_oct_feed_trophy=$i
i='' i_oct_file_added=$i
i='' i_oct_file_badge=$i
i='' i_oct_file_diff=$i
i='' i_oct_file_directory_fill=$i
i='' i_oct_file_directory_open_fill=$i
i='' i_oct_file_moved=$i
i='' i_oct_file_removed=$i
i='' i_oct_filter=$i
i='' i_oct_fiscal_host=$i
i='' i_oct_fold_down=$i
i='' i_oct_fold_up=$i
i='' i_oct_git_merge_queue=$i
i='' i_oct_git_pull_request_closed=$i
i='' i_oct_git_pull_request_draft=$i
i='' i_oct_goal=$i
i='' i_oct_hash=$i
i='' i_oct_heading=$i
i='' i_oct_heart_fill=$i
i='' i_oct_home_fill=$i
i='' i_oct_hourglass=$i
i='' i_oct_id_badge=$i
i='' i_oct_image=$i
i='' i_oct_infinity=$i
i='' i_oct_issue_draft=$i
i='' i_oct_issue_tracked_by=$i
i='' i_oct_issue_tracks=$i
i='' i_oct_iterations=$i
i='' i_oct_kebab_horizontal=$i
i='' i_oct_key_asterisk=$i
i='' i_oct_log=$i
i='' i_oct_moon=$i
i='' i_oct_move_to_bottom=$i
i='' i_oct_move_to_end=$i
i='' i_oct_move_to_start=$i
i='' i_oct_move_to_top=$i
i='' i_oct_multi_select=$i
i='' i_oct_no_entry=$i
i='' i_oct_north_star=$i
i='' i_oct_note=$i
i='' i_oct_number=$i
i='' i_oct_package_dependencies=$i
i='' i_oct_package_dependents=$i
i='' i_oct_paper_airplane=$i
i='' i_oct_paperclip=$i
i='' i_oct_passkey_fill=$i
i='' i_oct_people=$i
i='' i_oct_person_add=$i
i='' i_oct_person_fill=$i
i='' i_oct_play=$i
i='' i_oct_plus_circle=$i
i='' i_oct_project=$i
i='' i_oct_project_roadmap=$i
i='' i_oct_project_symlink=$i
i='' i_oct_project_template=$i
i='' i_oct_rel_file_path=$i
i='' i_oct_repo_deleted=$i
i='' i_oct_repo_locked=$i
i='' i_oct_repo_template=$i
i='' i_oct_report=$i
i='' i_oct_rows=$i
i='' i_oct_screen_full=$i
i='' i_oct_screen_normal=$i
i='' i_oct_share=$i
i='' i_oct_share_android=$i
i='' i_oct_shield_check=$i
i='' i_oct_shield_lock=$i
i='' i_oct_shield_slash=$i
i='' i_oct_shield_x=$i
i='' i_oct_sidebar_collapse=$i
i='' i_oct_sidebar_expand=$i
i='' i_oct_single_select=$i
i='' i_oct_skip=$i
i='' i_oct_skip_fill=$i
i='' i_oct_sort_asc=$i
i='' i_oct_sort_desc=$i
i='' i_oct_sparkle_fill=$i
i='' i_oct_sponsor_tiers=$i
i='' i_oct_square=$i
i='' i_oct_stack=$i
i='' i_oct_star_fill=$i
i='' i_oct_stopwatch=$i
i='' i_oct_strikethrough=$i
i='' i_oct_sun=$i
i='' i_oct_tab=$i
i='' i_oct_tab_external=$i
i='' i_oct_table=$i
i='' i_oct_telescope_fill=$i
i='' i_oct_trophy=$i
i='' i_oct_typography=$i
i='' i_oct_unlink=$i
i='' i_oct_unlock=$i
i='' i_oct_unread=$i
i='' i_oct_video=$i
i='' i_oct_webhook=$i
i='' i_oct_workflow=$i
i='' i_oct_x_circle=$i
i='' i_oct_x_circle_fill=$i
i='' i_oct_zoom_in=$i
i='' i_oct_zoom_out=$i
i='' i_oct_bookmark_slash=$i
unset i
