#!/usr/bin/env bash
# Seti-UI + Custom (188 icons, 21 aliases)
# Codepoints: E5FA-E6B5
# Nerd Fonts Version: 3.2.1
# Script Version: (autogenerated)
test -n "$__i_seti_loaded" && return || __i_seti_loaded=1
i='' i_custom_folder_npm=$i
i='' i_custom_folder_git=$i
      i_custom_folder_git_branch=$i_custom_folder_git
i='' i_custom_folder_config=$i
i='' i_custom_folder_github=$i
i='' i_custom_folder_open=$i
i='' i_custom_folder=$i
i='' i_seti_stylus=$i
i='' i_seti_project=$i
i='' i_custom_play_arrow=$i
      i_seti_play_arrow=$i_custom_play_arrow
i='' i_seti_sass=$i
i='' i_seti_rails=$i
i='' i_custom_ruby=$i
      i_seti_ruby=$i_custom_ruby
i='' i_seti_python=$i
i='' i_seti_heroku=$i
i='' i_seti_php=$i
i='' i_seti_markdown=$i
i='' i_seti_license=$i
i='' i_seti_json=$i
      i_seti_less=$i_seti_json
i='' i_seti_javascript=$i
i='' i_seti_image=$i
i='' i_seti_html=$i
i='' i_seti_mustache=$i
i='' i_seti_gulp=$i
i='' i_seti_grunt=$i
i='' i_custom_default=$i
i='' i_seti_folder=$i
i='' i_seti_css=$i
i='' i_seti_config=$i
i='' i_seti_npm=$i
      i_seti_npm_ignored=$i_seti_npm
i='' i_custom_home=$i
      i_seti_home=$i_custom_home
i='' i_seti_ejs=$i
i='' i_seti_xml=$i
i='' i_seti_bower=$i
i='' i_seti_coffee=$i
      i_seti_cjsx=$i_seti_coffee
i='' i_seti_twig=$i
i='' i_custom_cpp=$i
i='' i_custom_c=$i
i='' i_seti_haskell=$i
i='' i_seti_lua=$i
i='' i_indent_line=$i
      i_indentation_line=$i_indent_line
      i_indent_dotted_guide=$i_indent_line
i='' i_seti_karma=$i
i='' i_seti_favicon=$i
i='' i_seti_julia=$i
i='' i_seti_react=$i
i='' i_custom_go=$i
i='' i_seti_go=$i
i='' i_seti_typescript=$i
i='' i_custom_msdos=$i
i='' i_custom_windows=$i
i='' i_custom_vim=$i
i='' i_custom_elm=$i
      i_seti_elm=$i_custom_elm
i='' i_custom_elixir=$i
      i_seti_elixir=$i_custom_elixir
i='' i_custom_electron=$i
i='' i_custom_crystal=$i
      i_seti_crystal=$i_custom_crystal
i='' i_custom_purescript=$i
      i_seti_purescript=$i_custom_purescript
i='' i_seti_puppet=$i
      i_custom_puppet=$i_seti_puppet
i='' i_custom_emacs=$i
i='' i_custom_orgmode=$i
i='' i_custom_kotlin=$i
      i_seti_kotlin=$i_custom_kotlin
i='' i_seti_apple=$i
i='' i_seti_argdown=$i
i='' i_seti_asm=$i
i='' i_seti_audio=$i
i='' i_seti_babel=$i
i='' i_custom_bazel=$i
      i_seti_bazel=$i_custom_bazel
i='' i_seti_bicep=$i
i='' i_seti_bsl=$i
i='' i_seti_cake_php=$i
i='' i_seti_cake=$i
i='' i_seti_checkbox=$i
i='' i_seti_checkbox_unchecked=$i
i='' i_seti_clock=$i
      i_seti_time_cop=$i_seti_clock
i='' i_seti_clojure=$i
i='' i_seti_code_climate=$i
i='' i_seti_code_search=$i
i='' i_seti_coldfusion=$i
i='' i_seti_cpp=$i
i='' i_seti_crystal_embedded=$i
i='' i_seti_c_sharp=$i
i='' i_seti_c=$i
i='' i_seti_csv=$i
i='' i_seti_cu=$i
i='' i_seti_dart=$i
i='' i_seti_db=$i
i='' i_seti_default=$i
      i_seti_text=$i_seti_default
i='' i_seti_deprecation_cop=$i
i='' i_seti_docker=$i
i='' i_seti_d=$i
i='' i_seti_editorconfig=$i
i='' i_seti_elixir_script=$i
i='' i_seti_error=$i
i='' i_seti_eslint=$i
i='' i_seti_ethereum=$i
i='' i_custom_firebase=$i
      i_seti_firebase=$i_custom_firebase
i='' i_seti_firefox=$i
i='' i_seti_font=$i
i='' i_seti_f_sharp=$i
i='' i_seti_github=$i
i='' i_seti_gitlab=$i
i='' i_seti_git=$i
      i_seti_git_folder=$i_seti_git
      i_seti_git_ignore=$i_seti_git
i='' i_seti_go2=$i
i='' i_seti_godot=$i
i='' i_seti_gradle=$i
i='' i_seti_grails=$i
i='' i_seti_graphql=$i
i='' i_seti_hacklang=$i
i='' i_seti_haml=$i
i='' i_seti_happenings=$i
i='' i_seti_haxe=$i
i='' i_seti_hex=$i
i='' i_seti_ignored=$i
i='' i_seti_illustrator=$i
i='' i_seti_info=$i
i='' i_seti_ionic=$i
i='' i_seti_jade=$i
i='' i_seti_java=$i
i='' i_seti_jenkins=$i
i='' i_seti_jinja=$i
i='' i_seti_liquid=$i
i='' i_seti_livescript=$i
i='' i_seti_lock=$i
i='' i_seti_makefile=$i
i='' i_seti_maven=$i
i='' i_seti_mdo=$i
i='' i_seti_new_file=$i
i='' i_seti_nim=$i
i='' i_seti_notebook=$i
i='' i_seti_nunjucks=$i
i='' i_seti_ocaml=$i
i='' i_seti_odata=$i
i='' i_seti_pddl=$i
i='' i_seti_pdf=$i
i='' i_seti_perl=$i
i='' i_seti_photoshop=$i
i='' i_seti_pipeline=$i
i='' i_seti_plan=$i
i='' i_seti_platformio=$i
i='' i_seti_powershell=$i
i='' i_seti_prisma=$i
i='' i_seti_prolog=$i
i='' i_seti_pug=$i
i='' i_seti_reasonml=$i
i='' i_seti_rescript=$i
i='' i_seti_rollup=$i
i='' i_seti_r=$i
i='' i_seti_rust=$i
i='' i_seti_salesforce=$i
i='' i_seti_sbt=$i
i='' i_seti_scala=$i
i='' i_seti_search=$i
i='' i_seti_settings=$i
i='' i_seti_shell=$i
i='' i_seti_slim=$i
i='' i_seti_smarty=$i
i='' i_seti_spring=$i
i='' i_seti_stylelint=$i
i='' i_seti_sublime=$i
i='' i_seti_svelte=$i
i='' i_seti_svg=$i
i='' i_seti_swift=$i
i='' i_seti_terraform=$i
i='' i_seti_tex=$i
i='' i_seti_todo=$i
i='' i_seti_tsconfig=$i
i='' i_seti_vala=$i
i='' i_seti_video=$i
i='' i_seti_vue=$i
i='' i_seti_wasm=$i
i='' i_seti_wat=$i
i='' i_seti_webpack=$i
i='' i_seti_wgt=$i
i='' i_seti_word=$i
i='' i_seti_xls=$i
i='' i_seti_yarn=$i
i='' i_seti_yml=$i
i='' i_seti_zig=$i
i='' i_seti_zip=$i
i='' i_custom_asm=$i
i='' i_custom_v_lang=$i
i='' i_custom_folder_oct=$i
i='' i_custom_neovim=$i
i='' i_custom_fennel=$i
i='' i_custom_common_lisp=$i
i='' i_custom_scheme=$i
i='' i_custom_toml=$i
i='' i_custom_astro=$i
i='' i_custom_prettier=$i
i='' i_custom_ada=$i
unset i
