#!/usr/bin/env bash
# Codicons (439 icons)
# Codepoints: EA60-EC1E with holes
test -n "$__i_cod_loaded" && return || __i_cod_loaded=1
i='' i_cod_add=$i
i='' i_cod_lightbulb=$i
i='' i_cod_repo=$i
i='' i_cod_repo_forked=$i
i='' i_cod_git_pull_request=$i
i='' i_cod_record_keys=$i
i='' i_cod_tag=$i
i='' i_cod_person=$i
i='' i_cod_source_control=$i
i='' i_cod_mirror=$i
i='' i_cod_star_empty=$i
i='' i_cod_comment=$i
i='' i_cod_warning=$i
i='' i_cod_search=$i
i='' i_cod_sign_out=$i
i='' i_cod_sign_in=$i
i='' i_cod_eye=$i
i='' i_cod_circle_filled=$i
i='' i_cod_primitive_square=$i
i='' i_cod_edit=$i
i='' i_cod_info=$i
i='' i_cod_lock=$i
i='' i_cod_close=$i
i='' i_cod_sync=$i
i='' i_cod_desktop_download=$i
i='' i_cod_beaker=$i
i='' i_cod_vm=$i
i='' i_cod_file=$i
i='' i_cod_ellipsis=$i
i='' i_cod_reply=$i
i='' i_cod_organization=$i
i='' i_cod_new_file=$i
i='' i_cod_new_folder=$i
i='' i_cod_trash=$i
i='' i_cod_history=$i
i='' i_cod_folder=$i
i='' i_cod_github=$i
i='' i_cod_terminal=$i
i='' i_cod_symbol_event=$i
i='' i_cod_error=$i
i='' i_cod_symbol_variable=$i
i='' i_cod_symbol_array=$i
i='' i_cod_symbol_namespace=$i
i='' i_cod_symbol_method=$i
i='' i_cod_symbol_boolean=$i
i='' i_cod_symbol_numeric=$i
i='' i_cod_symbol_structure=$i
i='' i_cod_symbol_parameter=$i
i='' i_cod_symbol_key=$i
i='' i_cod_go_to_file=$i
i='' i_cod_symbol_enum=$i
i='' i_cod_symbol_ruler=$i
i='' i_cod_activate_breakpoints=$i
i='' i_cod_archive=$i
i='' i_cod_arrow_both=$i
i='' i_cod_arrow_down=$i
i='' i_cod_arrow_left=$i
i='' i_cod_arrow_right=$i
i='' i_cod_arrow_small_down=$i
i='' i_cod_arrow_small_left=$i
i='' i_cod_arrow_small_right=$i
i='' i_cod_arrow_small_up=$i
i='' i_cod_arrow_up=$i
i='' i_cod_bell=$i
i='' i_cod_bold=$i
i='' i_cod_book=$i
i='' i_cod_bookmark=$i
i='' i_cod_debug_breakpoint_conditional_unverified=$i
i='' i_cod_debug_breakpoint_conditional=$i
i='' i_cod_debug_breakpoint_data_unverified=$i
i='' i_cod_debug_breakpoint_data=$i
i='' i_cod_debug_breakpoint_log_unverified=$i
i='' i_cod_debug_breakpoint_log=$i
i='' i_cod_briefcase=$i
i='' i_cod_broadcast=$i
i='' i_cod_browser=$i
i='' i_cod_bug=$i
i='' i_cod_calendar=$i
i='' i_cod_case_sensitive=$i
i='' i_cod_check=$i
i='' i_cod_checklist=$i
i='' i_cod_chevron_down=$i
i='' i_cod_chevron_left=$i
i='' i_cod_chevron_right=$i
i='' i_cod_chevron_up=$i
i='' i_cod_chrome_close=$i
i='' i_cod_chrome_maximize=$i
i='' i_cod_chrome_minimize=$i
i='' i_cod_chrome_restore=$i
i='' i_cod_circle=$i
i='' i_cod_circle_slash=$i
i='' i_cod_circuit_board=$i
i='' i_cod_clear_all=$i
i='' i_cod_clippy=$i
i='' i_cod_close_all=$i
i='' i_cod_cloud_download=$i
i='' i_cod_cloud_upload=$i
i='' i_cod_code=$i
i='' i_cod_collapse_all=$i
i='' i_cod_color_mode=$i
i='' i_cod_comment_discussion=$i
i='' i_cod_credit_card=$i
i='' i_cod_dash=$i
i='' i_cod_dashboard=$i
i='' i_cod_database=$i
i='' i_cod_debug_continue=$i
i='' i_cod_debug_disconnect=$i
i='' i_cod_debug_pause=$i
i='' i_cod_debug_restart=$i
i='' i_cod_debug_start=$i
i='' i_cod_debug_step_into=$i
i='' i_cod_debug_step_out=$i
i='' i_cod_debug_step_over=$i
i='' i_cod_debug_stop=$i
i='' i_cod_debug=$i
i='' i_cod_device_camera_video=$i
i='' i_cod_device_camera=$i
i='' i_cod_device_mobile=$i
i='' i_cod_diff_added=$i
i='' i_cod_diff_ignored=$i
i='' i_cod_diff_modified=$i
i='' i_cod_diff_removed=$i
i='' i_cod_diff_renamed=$i
i='' i_cod_diff=$i
i='' i_cod_discard=$i
i='' i_cod_editor_layout=$i
i='' i_cod_empty_window=$i
i='' i_cod_exclude=$i
i='' i_cod_extensions=$i
i='' i_cod_eye_closed=$i
i='' i_cod_file_binary=$i
i='' i_cod_file_code=$i
i='' i_cod_file_media=$i
i='' i_cod_file_pdf=$i
i='' i_cod_file_submodule=$i
i='' i_cod_file_symlink_directory=$i
i='' i_cod_file_symlink_file=$i
i='' i_cod_file_zip=$i
i='' i_cod_files=$i
i='' i_cod_filter=$i
i='' i_cod_flame=$i
i='' i_cod_fold_down=$i
i='' i_cod_fold_up=$i
i='' i_cod_fold=$i
i='' i_cod_folder_active=$i
i='' i_cod_folder_opened=$i
i='' i_cod_gear=$i
i='' i_cod_gift=$i
i='' i_cod_gist_secret=$i
i='' i_cod_git_commit=$i
i='' i_cod_git_compare=$i
i='' i_cod_git_merge=$i
i='' i_cod_github_action=$i
i='' i_cod_github_alt=$i
i='' i_cod_globe=$i
i='' i_cod_grabber=$i
i='' i_cod_graph=$i
i='' i_cod_gripper=$i
i='' i_cod_heart=$i
i='' i_cod_home=$i
i='' i_cod_horizontal_rule=$i
i='' i_cod_hubot=$i
i='' i_cod_inbox=$i
i='' i_cod_issue_reopened=$i
i='' i_cod_issues=$i
i='' i_cod_italic=$i
i='' i_cod_jersey=$i
i='' i_cod_json=$i
i='' i_cod_kebab_vertical=$i
i='' i_cod_key=$i
i='' i_cod_law=$i
i='' i_cod_lightbulb_autofix=$i
i='' i_cod_link_external=$i
i='' i_cod_link=$i
i='' i_cod_list_ordered=$i
i='' i_cod_list_unordered=$i
i='' i_cod_live_share=$i
i='' i_cod_loading=$i
i='' i_cod_location=$i
i='' i_cod_mail_read=$i
i='' i_cod_mail=$i
i='' i_cod_markdown=$i
i='' i_cod_megaphone=$i
i='' i_cod_mention=$i
i='' i_cod_milestone=$i
i='' i_cod_mortar_board=$i
i='' i_cod_move=$i
i='' i_cod_multiple_windows=$i
i='' i_cod_mute=$i
i='' i_cod_no_newline=$i
i='' i_cod_note=$i
i='' i_cod_octoface=$i
i='' i_cod_open_preview=$i
i='' i_cod_package=$i
i='' i_cod_paintcan=$i
i='' i_cod_pin=$i
i='' i_cod_play=$i
i='' i_cod_plug=$i
i='' i_cod_preserve_case=$i
i='' i_cod_preview=$i
i='' i_cod_project=$i
i='' i_cod_pulse=$i
i='' i_cod_question=$i
i='' i_cod_quote=$i
i='' i_cod_radio_tower=$i
i='' i_cod_reactions=$i
i='' i_cod_references=$i
i='' i_cod_refresh=$i
i='' i_cod_regex=$i
i='' i_cod_remote_explorer=$i
i='' i_cod_remote=$i
i='' i_cod_remove=$i
i='' i_cod_replace_all=$i
i='' i_cod_replace=$i
i='' i_cod_repo_clone=$i
i='' i_cod_repo_force_push=$i
i='' i_cod_repo_pull=$i
i='' i_cod_repo_push=$i
i='' i_cod_report=$i
i='' i_cod_request_changes=$i
i='' i_cod_rocket=$i
i='' i_cod_root_folder_opened=$i
i='' i_cod_root_folder=$i
i='' i_cod_rss=$i
i='' i_cod_ruby=$i
i='' i_cod_save_all=$i
i='' i_cod_save_as=$i
i='' i_cod_save=$i
i='' i_cod_screen_full=$i
i='' i_cod_screen_normal=$i
i='' i_cod_search_stop=$i
i='' i_cod_server=$i
i='' i_cod_settings_gear=$i
i='' i_cod_settings=$i
i='' i_cod_shield=$i
i='' i_cod_smiley=$i
i='' i_cod_sort_precedence=$i
i='' i_cod_split_horizontal=$i
i='' i_cod_split_vertical=$i
i='' i_cod_squirrel=$i
i='' i_cod_star_full=$i
i='' i_cod_star_half=$i
i='' i_cod_symbol_class=$i
i='' i_cod_symbol_color=$i
i='' i_cod_symbol_constant=$i
i='' i_cod_symbol_enum_member=$i
i='' i_cod_symbol_field=$i
i='' i_cod_symbol_file=$i
i='' i_cod_symbol_interface=$i
i='' i_cod_symbol_keyword=$i
i='' i_cod_symbol_misc=$i
i='' i_cod_symbol_operator=$i
i='' i_cod_symbol_property=$i
i='' i_cod_symbol_snippet=$i
i='' i_cod_tasklist=$i
i='' i_cod_telescope=$i
i='' i_cod_text_size=$i
i='' i_cod_three_bars=$i
i='' i_cod_thumbsdown=$i
i='' i_cod_thumbsup=$i
i='' i_cod_tools=$i
i='' i_cod_triangle_down=$i
i='' i_cod_triangle_left=$i
i='' i_cod_triangle_right=$i
i='' i_cod_triangle_up=$i
i='' i_cod_twitter=$i
i='' i_cod_unfold=$i
i='' i_cod_unlock=$i
i='' i_cod_unmute=$i
i='' i_cod_unverified=$i
i='' i_cod_verified=$i
i='' i_cod_versions=$i
i='' i_cod_vm_active=$i
i='' i_cod_vm_outline=$i
i='' i_cod_vm_running=$i
i='' i_cod_watch=$i
i='' i_cod_whitespace=$i
i='' i_cod_whole_word=$i
i='' i_cod_window=$i
i='' i_cod_word_wrap=$i
i='' i_cod_zoom_in=$i
i='' i_cod_zoom_out=$i
i='' i_cod_list_filter=$i
i='' i_cod_list_flat=$i
i='' i_cod_list_selection=$i
i='' i_cod_list_tree=$i
i='' i_cod_debug_breakpoint_function_unverified=$i
i='' i_cod_debug_breakpoint_function=$i
i='' i_cod_debug_stackframe_active=$i
i='' i_cod_circle_small_filled=$i
i='' i_cod_debug_stackframe=$i
i='' i_cod_debug_breakpoint_unsupported=$i
i='' i_cod_symbol_string=$i
i='' i_cod_debug_reverse_continue=$i
i='' i_cod_debug_step_back=$i
i='' i_cod_debug_restart_frame=$i
i='' i_cod_debug_alt=$i
i='' i_cod_call_incoming=$i
i='' i_cod_call_outgoing=$i
i='' i_cod_menu=$i
i='' i_cod_expand_all=$i
i='' i_cod_feedback=$i
i='' i_cod_group_by_ref_type=$i
i='' i_cod_ungroup_by_ref_type=$i
i='' i_cod_account=$i
i='' i_cod_bell_dot=$i
i='' i_cod_debug_console=$i
i='' i_cod_library=$i
i='' i_cod_output=$i
i='' i_cod_run_all=$i
i='' i_cod_sync_ignored=$i
i='' i_cod_pinned=$i
i='' i_cod_github_inverted=$i
i='' i_cod_server_process=$i
i='' i_cod_server_environment=$i
i='' i_cod_pass=$i
i='' i_cod_stop_circle=$i
i='' i_cod_play_circle=$i
i='' i_cod_record=$i
i='' i_cod_debug_alt_small=$i
i='' i_cod_vm_connect=$i
i='' i_cod_cloud=$i
i='' i_cod_merge=$i
i='' i_cod_export=$i
i='' i_cod_graph_left=$i
i='' i_cod_magnet=$i
i='' i_cod_notebook=$i
i='' i_cod_redo=$i
i='' i_cod_check_all=$i
i='' i_cod_pinned_dirty=$i
i='' i_cod_pass_filled=$i
i='' i_cod_circle_large_filled=$i
i='' i_cod_circle_large=$i
i='' i_cod_combine=$i
i='' i_cod_table=$i
i='' i_cod_variable_group=$i
i='' i_cod_type_hierarchy=$i
i='' i_cod_type_hierarchy_sub=$i
i='' i_cod_type_hierarchy_super=$i
i='' i_cod_git_pull_request_create=$i
i='' i_cod_run_above=$i
i='' i_cod_run_below=$i
i='' i_cod_notebook_template=$i
i='' i_cod_debug_rerun=$i
i='' i_cod_workspace_trusted=$i
i='' i_cod_workspace_untrusted=$i
i='' i_cod_workspace_unknown=$i
i='' i_cod_terminal_cmd=$i
i='' i_cod_terminal_debian=$i
i='' i_cod_terminal_linux=$i
i='' i_cod_terminal_powershell=$i
i='' i_cod_terminal_tmux=$i
i='' i_cod_terminal_ubuntu=$i
i='' i_cod_terminal_bash=$i
i='' i_cod_arrow_swap=$i
i='' i_cod_copy=$i
i='' i_cod_person_add=$i
i='' i_cod_filter_filled=$i
i='' i_cod_wand=$i
i='' i_cod_debug_line_by_line=$i
i='' i_cod_inspect=$i
i='' i_cod_layers=$i
i='' i_cod_layers_dot=$i
i='' i_cod_layers_active=$i
i='' i_cod_compass=$i
i='' i_cod_compass_dot=$i
i='' i_cod_compass_active=$i
i='' i_cod_azure=$i
i='' i_cod_issue_draft=$i
i='' i_cod_git_pull_request_closed=$i
i='' i_cod_git_pull_request_draft=$i
i='' i_cod_debug_all=$i
i='' i_cod_debug_coverage=$i
i='' i_cod_run_errors=$i
i='' i_cod_folder_library=$i
i='' i_cod_debug_continue_small=$i
i='' i_cod_beaker_stop=$i
i='' i_cod_graph_line=$i
i='' i_cod_graph_scatter=$i
i='' i_cod_pie_chart=$i
i='' i_cod_bracket_dot=$i
i='' i_cod_bracket_error=$i
i='' i_cod_lock_small=$i
i='' i_cod_azure_devops=$i
i='' i_cod_verified_filled=$i
i='' i_cod_newline=$i
i='' i_cod_layout=$i
i='' i_cod_layout_activitybar_left=$i
i='' i_cod_layout_activitybar_right=$i
i='' i_cod_layout_panel_left=$i
i='' i_cod_layout_panel_center=$i
i='' i_cod_layout_panel_justify=$i
i='' i_cod_layout_panel_right=$i
i='' i_cod_layout_panel=$i
i='' i_cod_layout_sidebar_left=$i
i='' i_cod_layout_sidebar_right=$i
i='' i_cod_layout_statusbar=$i
i='' i_cod_layout_menubar=$i
i='' i_cod_layout_centered=$i
i='' i_cod_target=$i
i='' i_cod_indent=$i
i='' i_cod_record_small=$i
i='' i_cod_error_small=$i
i='' i_cod_arrow_circle_down=$i
i='' i_cod_arrow_circle_left=$i
i='' i_cod_arrow_circle_right=$i
i='' i_cod_arrow_circle_up=$i
i='' i_cod_layout_sidebar_right_off=$i
i='' i_cod_layout_panel_off=$i
i='' i_cod_layout_sidebar_left_off=$i
i='' i_cod_blank=$i
i='' i_cod_heart_filled=$i
i='' i_cod_map=$i
i='' i_cod_map_filled=$i
i='' i_cod_circle_small=$i
i='' i_cod_bell_slash=$i
i='' i_cod_bell_slash_dot=$i
i='' i_cod_comment_unresolved=$i
i='' i_cod_git_pull_request_go_to_changes=$i
i='' i_cod_git_pull_request_new_changes=$i
i='' i_cod_search_fuzzy=$i
i='' i_cod_comment_draft=$i
i='' i_cod_send=$i
i='' i_cod_sparkle=$i
i='' i_cod_insert=$i
i='' i_cod_mic=$i
i='' i_cod_thumbsdown_filled=$i
i='' i_cod_thumbsup_filled=$i
i='' i_cod_coffee=$i
i='' i_cod_snake=$i
i='' i_cod_game=$i
i='' i_cod_vr=$i
i='' i_cod_chip=$i
i='' i_cod_piano=$i
i='' i_cod_music=$i
i='' i_cod_mic_filled=$i
i='' i_cod_git_fetch=$i
i='' i_cod_copilot=$i
unset i
