#!/usr/bin/env bash
# Pomicons (11 icons)
# Codepoints: E000-E00A
test -n "$__i_pom_loaded" && return || __i_pom_loaded=1
i='' i_pom_clean_code=$i
i='' i_pom_pomodoro_done=$i
i='' i_pom_pomodoro_estimated=$i
i='' i_pom_pomodoro_ticking=$i
i='' i_pom_pomodoro_squashed=$i
i='' i_pom_short_pause=$i
i='' i_pom_long_pause=$i
i='' i_pom_away=$i
i='' i_pom_pair_programming=$i
i='' i_pom_internal_interruption=$i
i='' i_pom_external_interruption=$i
unset i
