#!/usr/bin/env bash
# Material Design Icons (6,896 icons)
# Codepoints: F0001-F1AF0
# Nerd Fonts Version: 3.2.1
# Script Version 1.0.1
test -n "$__i_md_loaded" && return || __i_md_loaded=1
i='󰀁' i_md_vector_square=$i
i='󰀂' i_md_access_point_network=$i
i='󰀃' i_md_access_point=$i
i='󰀄' i_md_account=$i
i='󰀅' i_md_account_alert=$i
i='󰀆' i_md_account_box=$i
i='󰀇' i_md_account_box_outline=$i
i='󰀈' i_md_account_check=$i
i='󰀉' i_md_account_circle=$i
i='󰀊' i_md_account_convert=$i
i='󰀋' i_md_account_key=$i
i='󰀌' i_md_tooltip_account=$i
i='󰀍' i_md_account_minus=$i
i='󰀎' i_md_account_multiple=$i
i='󰀏' i_md_account_multiple_outline=$i
i='󰀐' i_md_account_multiple_plus=$i
i='󰀑' i_md_account_network=$i
i='󰀒' i_md_account_off=$i
i='󰀓' i_md_account_outline=$i
i='󰀔' i_md_account_plus=$i
i='󰀕' i_md_account_remove=$i
i='󰀖' i_md_account_search=$i
i='󰀗' i_md_account_star=$i
i='󰀘' i_md_orbit=$i
i='󰀙' i_md_account_switch=$i
i='󰀚' i_md_adjust=$i
i='󰀛' i_md_air_conditioner=$i
i='󰀜' i_md_airballoon=$i
i='󰀝' i_md_airplane=$i
i='󰀞' i_md_airplane_off=$i
i='󰀟' i_md_cast_variant=$i
i='󰀠' i_md_alarm=$i
i='󰀡' i_md_alarm_check=$i
i='󰀢' i_md_alarm_multiple=$i
i='󰀣' i_md_alarm_off=$i
i='󰀤' i_md_alarm_plus=$i
i='󰀥' i_md_album=$i
i='󰀦' i_md_alert=$i
i='󰀧' i_md_alert_box=$i
i='󰀨' i_md_alert_circle=$i
i='󰀩' i_md_alert_octagon=$i
i='󰀪' i_md_alert_outline=$i
i='󰀫' i_md_alpha=$i
i='󰀬' i_md_alphabetical=$i
i='󰀭' i_md_greenhouse=$i
i='󰀮' i_md_rollerblade_off=$i
i='󰀯' i_md_ambulance=$i
i='󰀰' i_md_amplifier=$i
i='󰀱' i_md_anchor=$i
i='󰀲' i_md_android=$i
i='󰀳' i_md_web_plus=$i
i='󰀴' i_md_android_studio=$i
i='󰀵' i_md_apple=$i
i='󰀶' i_md_apple_finder=$i
i='󰀷' i_md_apple_ios=$i
i='󰀸' i_md_apple_icloud=$i
i='󰀹' i_md_apple_safari=$i
i='󰀺' i_md_font_awesome=$i
i='󰀻' i_md_apps=$i
i='󰀼' i_md_archive=$i
i='󰀽' i_md_arrange_bring_forward=$i
i='󰀾' i_md_arrange_bring_to_front=$i
i='󰀿' i_md_arrange_send_backward=$i
i='󰁀' i_md_arrange_send_to_back=$i
i='󰁁' i_md_arrow_all=$i
i='󰁂' i_md_arrow_bottom_left=$i
i='󰁃' i_md_arrow_bottom_right=$i
i='󰁄' i_md_arrow_collapse_all=$i
i='󰁅' i_md_arrow_down=$i
i='󰁆' i_md_arrow_down_thick=$i
i='󰁇' i_md_arrow_down_bold_circle=$i
i='󰁈' i_md_arrow_down_bold_circle_outline=$i
i='󰁉' i_md_arrow_down_bold_hexagon_outline=$i
i='󰁊' i_md_arrow_down_drop_circle=$i
i='󰁋' i_md_arrow_down_drop_circle_outline=$i
i='󰁌' i_md_arrow_expand_all=$i
i='󰁍' i_md_arrow_left=$i
i='󰁎' i_md_arrow_left_thick=$i
i='󰁏' i_md_arrow_left_bold_circle=$i
i='󰁐' i_md_arrow_left_bold_circle_outline=$i
i='󰁑' i_md_arrow_left_bold_hexagon_outline=$i
i='󰁒' i_md_arrow_left_drop_circle=$i
i='󰁓' i_md_arrow_left_drop_circle_outline=$i
i='󰁔' i_md_arrow_right=$i
i='󰁕' i_md_arrow_right_thick=$i
i='󰁖' i_md_arrow_right_bold_circle=$i
i='󰁗' i_md_arrow_right_bold_circle_outline=$i
i='󰁘' i_md_arrow_right_bold_hexagon_outline=$i
i='󰁙' i_md_arrow_right_drop_circle=$i
i='󰁚' i_md_arrow_right_drop_circle_outline=$i
i='󰁛' i_md_arrow_top_left=$i
i='󰁜' i_md_arrow_top_right=$i
i='󰁝' i_md_arrow_up=$i
i='󰁞' i_md_arrow_up_thick=$i
i='󰁟' i_md_arrow_up_bold_circle=$i
i='󰁠' i_md_arrow_up_bold_circle_outline=$i
i='󰁡' i_md_arrow_up_bold_hexagon_outline=$i
i='󰁢' i_md_arrow_up_drop_circle=$i
i='󰁣' i_md_arrow_up_drop_circle_outline=$i
i='󰁤' i_md_assistant=$i
i='󰁥' i_md_at=$i
i='󰁦' i_md_attachment=$i
i='󰁧' i_md_book_music=$i
i='󰁨' i_md_auto_fix=$i
i='󰁩' i_md_auto_upload=$i
i='󰁪' i_md_autorenew=$i
i='󰁫' i_md_av_timer=$i
i='󰁬' i_md_baby=$i
i='󰁭' i_md_backburger=$i
i='󰁮' i_md_backspace=$i
i='󰁯' i_md_backup_restore=$i
i='󰁰' i_md_bank=$i
i='󰁱' i_md_barcode=$i
i='󰁲' i_md_barcode_scan=$i
i='󰁳' i_md_barley=$i
i='󰁴' i_md_barrel=$i
i='󰁵' i_md_incognito_off=$i
i='󰁶' i_md_basket=$i
i='󰁷' i_md_basket_fill=$i
i='󰁸' i_md_basket_unfill=$i
i='󰁹' i_md_battery=$i
i='󰁺' i_md_battery_10=$i
i='󰁻' i_md_battery_20=$i
i='󰁼' i_md_battery_30=$i
i='󰁽' i_md_battery_40=$i
i='󰁾' i_md_battery_50=$i
i='󰁿' i_md_battery_60=$i
i='󰂀' i_md_battery_70=$i
i='󰂁' i_md_battery_80=$i
i='󰂂' i_md_battery_90=$i
i='󰂃' i_md_battery_alert=$i
i='󰂄' i_md_battery_charging=$i
i='󰂅' i_md_battery_charging_100=$i
i='󰂆' i_md_battery_charging_20=$i
i='󰂇' i_md_battery_charging_30=$i
i='󰂈' i_md_battery_charging_40=$i
i='󰂉' i_md_battery_charging_60=$i
i='󰂊' i_md_battery_charging_80=$i
i='󰂋' i_md_battery_charging_90=$i
i='󰂌' i_md_battery_minus_variant=$i
i='󰂍' i_md_battery_negative=$i
i='󰂎' i_md_battery_outline=$i
i='󰂏' i_md_battery_plus_variant=$i
i='󰂐' i_md_battery_positive=$i
i='󰂑' i_md_battery_unknown=$i
i='󰂒' i_md_beach=$i
i='󰂓' i_md_flask=$i
i='󰂔' i_md_flask_empty=$i
i='󰂕' i_md_flask_empty_outline=$i
i='󰂖' i_md_flask_outline=$i
i='󰂗' i_md_bunk_bed_outline=$i
i='󰂘' i_md_beer=$i
i='󰂙' i_md_bed_outline=$i
i='󰂚' i_md_bell=$i
i='󰂛' i_md_bell_off=$i
i='󰂜' i_md_bell_outline=$i
i='󰂝' i_md_bell_plus=$i
i='󰂞' i_md_bell_ring=$i
i='󰂟' i_md_bell_ring_outline=$i
i='󰂠' i_md_bell_sleep=$i
i='󰂡' i_md_beta=$i
i='󰂢' i_md_book_cross=$i
i='󰂣' i_md_bike=$i
i='󰂤' i_md_microsoft_bing=$i
i='󰂥' i_md_binoculars=$i
i='󰂦' i_md_bio=$i
i='󰂧' i_md_biohazard=$i
i='󰂨' i_md_bitbucket=$i
i='󰂩' i_md_black_mesa=$i
i='󰂪' i_md_shield_refresh=$i
i='󰂫' i_md_blender_software=$i
i='󰂬' i_md_blinds=$i
i='󰂭' i_md_block_helper=$i
i='󰂮' i_md_application_edit=$i
i='󰂯' i_md_bluetooth=$i
i='󰂰' i_md_bluetooth_audio=$i
i='󰂱' i_md_bluetooth_connect=$i
i='󰂲' i_md_bluetooth_off=$i
i='󰂳' i_md_bluetooth_settings=$i
i='󰂴' i_md_bluetooth_transfer=$i
i='󰂵' i_md_blur=$i
i='󰂶' i_md_blur_linear=$i
i='󰂷' i_md_blur_off=$i
i='󰂸' i_md_blur_radial=$i
i='󰂹' i_md_bone=$i
i='󰂺' i_md_book=$i
i='󰂻' i_md_book_multiple=$i
i='󰂼' i_md_book_variant_multiple=$i
i='󰂽' i_md_book_open=$i
i='󰂾' i_md_book_open_blank_variant=$i
i='󰂿' i_md_book_variant=$i
i='󰃀' i_md_bookmark=$i
i='󰃁' i_md_bookmark_check=$i
i='󰃂' i_md_bookmark_music=$i
i='󰃃' i_md_bookmark_outline=$i
i='󰃄' i_md_bookmark_plus_outline=$i
i='󰃅' i_md_bookmark_plus=$i
i='󰃆' i_md_bookmark_remove=$i
i='󰃇' i_md_border_all=$i
i='󰃈' i_md_border_bottom=$i
i='󰃉' i_md_border_color=$i
i='󰃊' i_md_border_horizontal=$i
i='󰃋' i_md_border_inside=$i
i='󰃌' i_md_border_left=$i
i='󰃍' i_md_border_none=$i
i='󰃎' i_md_border_outside=$i
i='󰃏' i_md_border_right=$i
i='󰃐' i_md_border_style=$i
i='󰃑' i_md_border_top=$i
i='󰃒' i_md_border_vertical=$i
i='󰃓' i_md_bowling=$i
i='󰃔' i_md_box=$i
i='󰃕' i_md_box_cutter=$i
i='󰃖' i_md_briefcase=$i
i='󰃗' i_md_briefcase_check=$i
i='󰃘' i_md_briefcase_download=$i
i='󰃙' i_md_briefcase_upload=$i
i='󰃚' i_md_brightness_1=$i
i='󰃛' i_md_brightness_2=$i
i='󰃜' i_md_brightness_3=$i
i='󰃝' i_md_brightness_4=$i
i='󰃞' i_md_brightness_5=$i
i='󰃟' i_md_brightness_6=$i
i='󰃠' i_md_brightness_7=$i
i='󰃡' i_md_brightness_auto=$i
i='󰃢' i_md_broom=$i
i='󰃣' i_md_brush=$i
i='󰃤' i_md_bug=$i
i='󰃥' i_md_bulletin_board=$i
i='󰃦' i_md_bullhorn=$i
i='󰃧' i_md_bus=$i
i='󰃨' i_md_cached=$i
i='󰃩' i_md_cake=$i
i='󰃪' i_md_cake_layered=$i
i='󰃫' i_md_cake_variant=$i
i='󰃬' i_md_calculator=$i
i='󰃭' i_md_calendar=$i
i='󰃮' i_md_calendar_blank=$i
i='󰃯' i_md_calendar_check=$i
i='󰃰' i_md_calendar_clock=$i
i='󰃱' i_md_calendar_multiple=$i
i='󰃲' i_md_calendar_multiple_check=$i
i='󰃳' i_md_calendar_plus=$i
i='󰃴' i_md_calendar_remove=$i
i='󰃵' i_md_calendar_text=$i
i='󰃶' i_md_calendar_today=$i
i='󰃷' i_md_call_made=$i
i='󰃸' i_md_call_merge=$i
i='󰃹' i_md_call_missed=$i
i='󰃺' i_md_call_received=$i
i='󰃻' i_md_call_split=$i
i='󰃼' i_md_camcorder=$i
i='󰃽' i_md_video_box=$i
i='󰃾' i_md_video_box_off=$i
i='󰃿' i_md_camcorder_off=$i
i='󰄀' i_md_camera=$i
i='󰄁' i_md_camera_enhance=$i
i='󰄂' i_md_camera_front=$i
i='󰄃' i_md_camera_front_variant=$i
i='󰄄' i_md_camera_iris=$i
i='󰄅' i_md_camera_party_mode=$i
i='󰄆' i_md_camera_rear=$i
i='󰄇' i_md_camera_rear_variant=$i
i='󰄈' i_md_camera_switch=$i
i='󰄉' i_md_camera_timer=$i
i='󰄊' i_md_candycane=$i
i='󰄋' i_md_car=$i
i='󰄌' i_md_car_battery=$i
i='󰄍' i_md_car_connected=$i
i='󰄎' i_md_car_wash=$i
i='󰄏' i_md_carrot=$i
i='󰄐' i_md_cart=$i
i='󰄑' i_md_cart_outline=$i
i='󰄒' i_md_cart_plus=$i
i='󰄓' i_md_case_sensitive_alt=$i
i='󰄔' i_md_cash=$i
i='󰄕' i_md_cash_100=$i
i='󰄖' i_md_cash_multiple=$i
i='󰄗' i_md_checkbox_blank_badge_outline=$i
i='󰄘' i_md_cast=$i
i='󰄙' i_md_cast_connected=$i
i='󰄚' i_md_castle=$i
i='󰄛' i_md_cat=$i
i='󰄜' i_md_cellphone=$i
i='󰄝' i_md_tray_arrow_up=$i
i='󰄞' i_md_cellphone_basic=$i
i='󰄟' i_md_cellphone_dock=$i
i='󰄠' i_md_tray_arrow_down=$i
i='󰄡' i_md_cellphone_link=$i
i='󰄢' i_md_cellphone_link_off=$i
i='󰄣' i_md_cellphone_settings=$i
i='󰄤' i_md_certificate=$i
i='󰄥' i_md_chair_school=$i
i='󰄦' i_md_chart_arc=$i
i='󰄧' i_md_chart_areaspline=$i
i='󰄨' i_md_chart_bar=$i
i='󰄩' i_md_chart_histogram=$i
i='󰄪' i_md_chart_line=$i
i='󰄫' i_md_chart_pie=$i
i='󰄬' i_md_check=$i
i='󰄭' i_md_check_all=$i
i='󰄮' i_md_checkbox_blank=$i
i='󰄯' i_md_checkbox_blank_circle=$i
i='󰄰' i_md_checkbox_blank_circle_outline=$i
i='󰄱' i_md_checkbox_blank_outline=$i
i='󰄲' i_md_checkbox_marked=$i
i='󰄳' i_md_checkbox_marked_circle=$i
i='󰄴' i_md_checkbox_marked_circle_outline=$i
i='󰄵' i_md_checkbox_marked_outline=$i
i='󰄶' i_md_checkbox_multiple_blank=$i
i='󰄷' i_md_checkbox_multiple_blank_outline=$i
i='󰄸' i_md_checkbox_multiple_marked=$i
i='󰄹' i_md_checkbox_multiple_marked_outline=$i
i='󰄺' i_md_checkerboard=$i
i='󰄻' i_md_chemical_weapon=$i
i='󰄼' i_md_chevron_double_down=$i
i='󰄽' i_md_chevron_double_left=$i
i='󰄾' i_md_chevron_double_right=$i
i='󰄿' i_md_chevron_double_up=$i
i='󰅀' i_md_chevron_down=$i
i='󰅁' i_md_chevron_left=$i
i='󰅂' i_md_chevron_right=$i
i='󰅃' i_md_chevron_up=$i
i='󰅄' i_md_church=$i
i='󰅅' i_md_roller_skate_off=$i
i='󰅆' i_md_city=$i
i='󰅇' i_md_clipboard=$i
i='󰅈' i_md_clipboard_account=$i
i='󰅉' i_md_clipboard_alert=$i
i='󰅊' i_md_clipboard_arrow_down=$i
i='󰅋' i_md_clipboard_arrow_left=$i
i='󰅌' i_md_clipboard_outline=$i
i='󰅍' i_md_clipboard_text=$i
i='󰅎' i_md_clipboard_check=$i
i='󰅏' i_md_clippy=$i
i='󰅐' i_md_clock_outline=$i
i='󰅑' i_md_clock_end=$i
i='󰅒' i_md_clock_fast=$i
i='󰅓' i_md_clock_in=$i
i='󰅔' i_md_clock_out=$i
i='󰅕' i_md_clock_start=$i
i='󰅖' i_md_close=$i
i='󰅗' i_md_close_box=$i
i='󰅘' i_md_close_box_outline=$i
i='󰅙' i_md_close_circle=$i
i='󰅚' i_md_close_circle_outline=$i
i='󰅛' i_md_close_network=$i
i='󰅜' i_md_close_octagon=$i
i='󰅝' i_md_close_octagon_outline=$i
i='󰅞' i_md_closed_caption=$i
i='󰅟' i_md_cloud=$i
i='󰅠' i_md_cloud_check=$i
i='󰅡' i_md_cloud_circle=$i
i='󰅢' i_md_cloud_download=$i
i='󰅣' i_md_cloud_outline=$i
i='󰅤' i_md_cloud_off_outline=$i
i='󰅥' i_md_cloud_print=$i
i='󰅦' i_md_cloud_print_outline=$i
i='󰅧' i_md_cloud_upload=$i
i='󰅨' i_md_code_array=$i
i='󰅩' i_md_code_braces=$i
i='󰅪' i_md_code_brackets=$i
i='󰅫' i_md_code_equal=$i
i='󰅬' i_md_code_greater_than=$i
i='󰅭' i_md_code_greater_than_or_equal=$i
i='󰅮' i_md_code_less_than=$i
i='󰅯' i_md_code_less_than_or_equal=$i
i='󰅰' i_md_code_not_equal=$i
i='󰅱' i_md_code_not_equal_variant=$i
i='󰅲' i_md_code_parentheses=$i
i='󰅳' i_md_code_string=$i
i='󰅴' i_md_code_tags=$i
i='󰅵' i_md_codepen=$i
i='󰅶' i_md_coffee=$i
i='󰅷' i_md_coffee_to_go=$i
i='󰅸' i_md_bell_badge_outline=$i
i='󰅹' i_md_color_helper=$i
i='󰅺' i_md_comment=$i
i='󰅻' i_md_comment_account=$i
i='󰅼' i_md_comment_account_outline=$i
i='󰅽' i_md_comment_alert=$i
i='󰅾' i_md_comment_alert_outline=$i
i='󰅿' i_md_comment_check=$i
i='󰆀' i_md_comment_check_outline=$i
i='󰆁' i_md_comment_multiple_outline=$i
i='󰆂' i_md_comment_outline=$i
i='󰆃' i_md_comment_plus_outline=$i
i='󰆄' i_md_comment_processing=$i
i='󰆅' i_md_comment_processing_outline=$i
i='󰆆' i_md_comment_question_outline=$i
i='󰆇' i_md_comment_remove_outline=$i
i='󰆈' i_md_comment_text=$i
i='󰆉' i_md_comment_text_outline=$i
i='󰆊' i_md_compare=$i
i='󰆋' i_md_compass=$i
i='󰆌' i_md_compass_outline=$i
i='󰆍' i_md_console=$i
i='󰆎' i_md_card_account_mail=$i
i='󰆏' i_md_content_copy=$i
i='󰆐' i_md_content_cut=$i
i='󰆑' i_md_content_duplicate=$i
i='󰆒' i_md_content_paste=$i
i='󰆓' i_md_content_save=$i
i='󰆔' i_md_content_save_all=$i
i='󰆕' i_md_contrast=$i
i='󰆖' i_md_contrast_box=$i
i='󰆗' i_md_contrast_circle=$i
i='󰆘' i_md_cookie=$i
i='󰆙' i_md_counter=$i
i='󰆚' i_md_cow=$i
i='󰆛' i_md_credit_card_outline=$i
i='󰆜' i_md_credit_card_multiple_outline=$i
i='󰆝' i_md_credit_card_scan_outline=$i
i='󰆞' i_md_crop=$i
i='󰆟' i_md_crop_free=$i
i='󰆠' i_md_crop_landscape=$i
i='󰆡' i_md_crop_portrait=$i
i='󰆢' i_md_crop_square=$i
i='󰆣' i_md_crosshairs=$i
i='󰆤' i_md_crosshairs_gps=$i
i='󰆥' i_md_crown=$i
i='󰆦' i_md_cube=$i
i='󰆧' i_md_cube_outline=$i
i='󰆨' i_md_cube_send=$i
i='󰆩' i_md_cube_unfolded=$i
i='󰆪' i_md_cup=$i
i='󰆫' i_md_cup_water=$i
i='󰆬' i_md_currency_btc=$i
i='󰆭' i_md_currency_eur=$i
i='󰆮' i_md_currency_gbp=$i
i='󰆯' i_md_currency_inr=$i
i='󰆰' i_md_currency_ngn=$i
i='󰆱' i_md_currency_rub=$i
i='󰆲' i_md_currency_try=$i
i='󰆳' i_md_delete_variant=$i
i='󰆴' i_md_delete=$i
i='󰆵' i_md_decimal_increase=$i
i='󰆶' i_md_decimal_decrease=$i
i='󰆷' i_md_debug_step_over=$i
i='󰆸' i_md_debug_step_out=$i
i='󰆹' i_md_debug_step_into=$i
i='󰆺' i_md_database_plus=$i
i='󰆻' i_md_database_minus=$i
i='󰆼' i_md_database=$i
i='󰆽' i_md_cursor_pointer=$i
i='󰆾' i_md_cursor_move=$i
i='󰆿' i_md_cursor_default_outline=$i
i='󰇀' i_md_cursor_default=$i
i='󰇁' i_md_currency_usd=$i
i='󰇂' i_md_delta=$i
i='󰇃' i_md_deskphone=$i
i='󰇄' i_md_desktop_mac=$i
i='󰇅' i_md_desktop_tower=$i
i='󰇆' i_md_details=$i
i='󰇇' i_md_deviantart=$i
i='󰇈' i_md_diamond_stone=$i
i='󰇉' i_md_ab_testing=$i
i='󰇊' i_md_dice_1=$i
i='󰇋' i_md_dice_2=$i
i='󰇌' i_md_dice_3=$i
i='󰇍' i_md_dice_4=$i
i='󰇎' i_md_dice_5=$i
i='󰇏' i_md_dice_6=$i
i='󰇐' i_md_directions=$i
i='󰇑' i_md_disc_alert=$i
i='󰇒' i_md_disqus=$i
i='󰇓' i_md_video_plus_outline=$i
i='󰇔' i_md_division=$i
i='󰇕' i_md_division_box=$i
i='󰇖' i_md_dns=$i
i='󰇗' i_md_domain=$i
i='󰇘' i_md_dots_horizontal=$i
i='󰇙' i_md_dots_vertical=$i
i='󰇚' i_md_download=$i
i='󰇛' i_md_drag=$i
i='󰇜' i_md_drag_horizontal=$i
i='󰇝' i_md_drag_vertical=$i
i='󰇞' i_md_drawing=$i
i='󰇟' i_md_drawing_box=$i
i='󰇠' i_md_shield_refresh_outline=$i
i='󰇡' i_md_calendar_refresh=$i
i='󰇢' i_md_drone=$i
i='󰇣' i_md_dropbox=$i
i='󰇤' i_md_drupal=$i
i='󰇥' i_md_duck=$i
i='󰇦' i_md_dumbbell=$i
i='󰇧' i_md_earth=$i
i='󰇨' i_md_earth_off=$i
i='󰇩' i_md_microsoft_edge=$i
i='󰇪' i_md_eject=$i
i='󰇫' i_md_elevation_decline=$i
i='󰇬' i_md_elevation_rise=$i
i='󰇭' i_md_elevator=$i
i='󰇮' i_md_email=$i
i='󰇯' i_md_email_open=$i
i='󰇰' i_md_email_outline=$i
i='󰇱' i_md_email_lock=$i
i='󰇲' i_md_emoticon_outline=$i
i='󰇳' i_md_emoticon_cool_outline=$i
i='󰇴' i_md_emoticon_devil_outline=$i
i='󰇵' i_md_emoticon_happy_outline=$i
i='󰇶' i_md_emoticon_neutral_outline=$i
i='󰇷' i_md_emoticon_poop=$i
i='󰇸' i_md_emoticon_sad_outline=$i
i='󰇹' i_md_emoticon_tongue=$i
i='󰇺' i_md_engine=$i
i='󰇻' i_md_engine_outline=$i
i='󰇼' i_md_equal=$i
i='󰇽' i_md_equal_box=$i
i='󰇾' i_md_eraser=$i
i='󰇿' i_md_escalator=$i
i='󰈀' i_md_ethernet=$i
i='󰈁' i_md_ethernet_cable=$i
i='󰈂' i_md_ethernet_cable_off=$i
i='󰈃' i_md_calendar_refresh_outline=$i
i='󰈄' i_md_evernote=$i
i='󰈅' i_md_exclamation=$i
i='󰈆' i_md_exit_to_app=$i
i='󰈇' i_md_export=$i
i='󰈈' i_md_eye=$i
i='󰈉' i_md_eye_off=$i
i='󰈊' i_md_eyedropper=$i
i='󰈋' i_md_eyedropper_variant=$i
i='󰈌' i_md_facebook=$i
i='󰈍' i_md_order_alphabetical_ascending=$i
i='󰈎' i_md_facebook_messenger=$i
i='󰈏' i_md_factory=$i
i='󰈐' i_md_fan=$i
i='󰈑' i_md_fast_forward=$i
i='󰈒' i_md_fax=$i
i='󰈓' i_md_ferry=$i
i='󰈔' i_md_file=$i
i='󰈕' i_md_file_chart=$i
i='󰈖' i_md_file_check=$i
i='󰈗' i_md_file_cloud=$i
i='󰈘' i_md_file_delimited=$i
i='󰈙' i_md_file_document=$i
i='󰈚' i_md_text_box=$i
i='󰈛' i_md_file_excel=$i
i='󰈜' i_md_file_excel_box=$i
i='󰈝' i_md_file_export=$i
i='󰈞' i_md_file_find=$i
i='󰈟' i_md_file_image=$i
i='󰈠' i_md_file_import=$i
i='󰈡' i_md_file_lock=$i
i='󰈢' i_md_file_multiple=$i
i='󰈣' i_md_file_music=$i
i='󰈤' i_md_file_outline=$i
i='󰈥' i_md_file_jpg_box=$i
i='󰈦' i_md_file_pdf_box=$i
i='󰈧' i_md_file_powerpoint=$i
i='󰈨' i_md_file_powerpoint_box=$i
i='󰈩' i_md_file_presentation_box=$i
i='󰈪' i_md_file_send=$i
i='󰈫' i_md_file_video=$i
i='󰈬' i_md_file_word=$i
i='󰈭' i_md_file_word_box=$i
i='󰈮' i_md_file_code=$i
i='󰈯' i_md_film=$i
i='󰈰' i_md_filmstrip=$i
i='󰈱' i_md_filmstrip_off=$i
i='󰈲' i_md_filter=$i
i='󰈳' i_md_filter_outline=$i
i='󰈴' i_md_filter_remove=$i
i='󰈵' i_md_filter_remove_outline=$i
i='󰈶' i_md_filter_variant=$i
i='󰈷' i_md_fingerprint=$i
i='󰈸' i_md_fire=$i
i='󰈹' i_md_firefox=$i
i='󰈺' i_md_fish=$i
i='󰈻' i_md_flag=$i
i='󰈼' i_md_flag_checkered=$i
i='󰈽' i_md_flag_outline=$i
i='󰈾' i_md_flag_variant_outline=$i
i='󰈿' i_md_flag_triangle=$i
i='󰉀' i_md_flag_variant=$i
i='󰉁' i_md_flash=$i
i='󰉂' i_md_flash_auto=$i
i='󰉃' i_md_flash_off=$i
i='󰉄' i_md_flashlight=$i
i='󰉅' i_md_flashlight_off=$i
i='󰉆' i_md_star_half=$i
i='󰉇' i_md_flip_to_back=$i
i='󰉈' i_md_flip_to_front=$i
i='󰉉' i_md_floppy=$i
i='󰉊' i_md_flower=$i
i='󰉋' i_md_folder=$i
i='󰉌' i_md_folder_account=$i
i='󰉍' i_md_folder_download=$i
i='󰉎' i_md_folder_google_drive=$i
i='󰉏' i_md_folder_image=$i
i='󰉐' i_md_folder_lock=$i
i='󰉑' i_md_folder_lock_open=$i
i='󰉒' i_md_folder_move=$i
i='󰉓' i_md_folder_multiple=$i
i='󰉔' i_md_folder_multiple_image=$i
i='󰉕' i_md_folder_multiple_outline=$i
i='󰉖' i_md_folder_outline=$i
i='󰉗' i_md_folder_plus=$i
i='󰉘' i_md_folder_remove=$i
i='󰉙' i_md_folder_upload=$i
i='󰉚' i_md_food=$i
i='󰉛' i_md_food_apple=$i
i='󰉜' i_md_food_variant=$i
i='󰉝' i_md_football=$i
i='󰉞' i_md_football_australian=$i
i='󰉟' i_md_football_helmet=$i
i='󰉠' i_md_format_align_center=$i
i='󰉡' i_md_format_align_justify=$i
i='󰉢' i_md_format_align_left=$i
i='󰉣' i_md_format_align_right=$i
i='󰉤' i_md_format_bold=$i
i='󰉥' i_md_format_clear=$i
i='󰉦' i_md_format_color_fill=$i
i='󰉧' i_md_format_float_center=$i
i='󰉨' i_md_format_float_left=$i
i='󰉩' i_md_format_float_none=$i
i='󰉪' i_md_format_float_right=$i
i='󰉫' i_md_format_header_1=$i
i='󰉬' i_md_format_header_2=$i
i='󰉭' i_md_format_header_3=$i
i='󰉮' i_md_format_header_4=$i
i='󰉯' i_md_format_header_5=$i
i='󰉰' i_md_format_header_6=$i
i='󰉱' i_md_format_header_decrease=$i
i='󰉲' i_md_format_header_equal=$i
i='󰉳' i_md_format_header_increase=$i
i='󰉴' i_md_format_header_pound=$i
i='󰉵' i_md_format_indent_decrease=$i
i='󰉶' i_md_format_indent_increase=$i
i='󰉷' i_md_format_italic=$i
i='󰉸' i_md_format_line_spacing=$i
i='󰉹' i_md_format_list_bulleted=$i
i='󰉺' i_md_format_list_bulleted_type=$i
i='󰉻' i_md_format_list_numbered=$i
i='󰉼' i_md_format_paint=$i
i='󰉽' i_md_format_paragraph=$i
i='󰉾' i_md_format_quote_close=$i
i='󰉿' i_md_format_size=$i
i='󰊀' i_md_format_strikethrough=$i
i='󰊁' i_md_format_strikethrough_variant=$i
i='󰊂' i_md_format_subscript=$i
i='󰊃' i_md_format_superscript=$i
i='󰊄' i_md_format_text=$i
i='󰊅' i_md_format_textdirection_l_to_r=$i
i='󰊆' i_md_format_textdirection_r_to_l=$i
i='󰊇' i_md_format_underline=$i
i='󰊈' i_md_format_wrap_inline=$i
i='󰊉' i_md_format_wrap_square=$i
i='󰊊' i_md_format_wrap_tight=$i
i='󰊋' i_md_format_wrap_top_bottom=$i
i='󰊌' i_md_forum=$i
i='󰊍' i_md_forward=$i
i='󰊎' i_md_bowl=$i
i='󰊏' i_md_fridge_outline=$i
i='󰊐' i_md_fridge=$i
i='󰊑' i_md_fridge_top=$i
i='󰊒' i_md_fridge_bottom=$i
i='󰊓' i_md_fullscreen=$i
i='󰊔' i_md_fullscreen_exit=$i
i='󰊕' i_md_function=$i
i='󰊖' i_md_gamepad=$i
i='󰊗' i_md_gamepad_variant=$i
i='󰊘' i_md_gas_station=$i
i='󰊙' i_md_gate=$i
i='󰊚' i_md_gauge=$i
i='󰊛' i_md_gavel=$i
i='󰊜' i_md_gender_female=$i
i='󰊝' i_md_gender_male=$i
i='󰊞' i_md_gender_male_female=$i
i='󰊟' i_md_gender_transgender=$i
i='󰊠' i_md_ghost=$i
i='󰊡' i_md_gift_outline=$i
i='󰊢' i_md_git=$i
i='󰊣' i_md_card_account_details_star=$i
i='󰊤' i_md_github=$i
i='󰊥' i_md_glass_flute=$i
i='󰊦' i_md_glass_mug=$i
i='󰊧' i_md_glass_stange=$i
i='󰊨' i_md_glass_tulip=$i
i='󰊩' i_md_bowl_outline=$i
i='󰊪' i_md_glasses=$i
i='󰊫' i_md_gmail=$i
i='󰊬' i_md_gnome=$i
i='󰊭' i_md_google=$i
i='󰊮' i_md_google_cardboard=$i
i='󰊯' i_md_google_chrome=$i
i='󰊰' i_md_google_circles=$i
i='󰊱' i_md_google_circles_communities=$i
i='󰊲' i_md_google_circles_extended=$i
i='󰊳' i_md_google_circles_group=$i
i='󰊴' i_md_google_controller=$i
i='󰊵' i_md_google_controller_off=$i
i='󰊶' i_md_google_drive=$i
i='󰊷' i_md_google_earth=$i
i='󰊸' i_md_google_glass=$i
i='󰊹' i_md_google_nearby=$i
i='󰊺' i_md_video_minus_outline=$i
i='󰊻' i_md_microsoft_teams=$i
i='󰊼' i_md_google_play=$i
i='󰊽' i_md_google_plus=$i
i='󰊾' i_md_order_bool_ascending=$i
i='󰊿' i_md_google_translate=$i
i='󰋀' i_md_google_classroom=$i
i='󰋁' i_md_grid=$i
i='󰋂' i_md_grid_off=$i
i='󰋃' i_md_group=$i
i='󰋄' i_md_guitar_electric=$i
i='󰋅' i_md_guitar_pick=$i
i='󰋆' i_md_guitar_pick_outline=$i
i='󰋇' i_md_hand_pointing_right=$i
i='󰋈' i_md_hanger=$i
i='󰋉' i_md_google_hangouts=$i
i='󰋊' i_md_harddisk=$i
i='󰋋' i_md_headphones=$i
i='󰋌' i_md_headphones_box=$i
i='󰋍' i_md_headphones_settings=$i
i='󰋎' i_md_headset=$i
i='󰋏' i_md_headset_dock=$i
i='󰋐' i_md_headset_off=$i
i='󰋑' i_md_heart=$i
i='󰋒' i_md_heart_box=$i
i='󰋓' i_md_heart_box_outline=$i
i='󰋔' i_md_heart_broken=$i
i='󰋕' i_md_heart_outline=$i
i='󰋖' i_md_help=$i
i='󰋗' i_md_help_circle=$i
i='󰋘' i_md_hexagon=$i
i='󰋙' i_md_hexagon_outline=$i
i='󰋚' i_md_history=$i
i='󰋛' i_md_hololens=$i
i='󰋜' i_md_home=$i
i='󰋝' i_md_home_modern=$i
i='󰋞' i_md_home_variant=$i
i='󰋟' i_md_hops=$i
i='󰋠' i_md_hospital_box=$i
i='󰋡' i_md_hospital_building=$i
i='󰋢' i_md_hospital_marker=$i
i='󰋣' i_md_bed=$i
i='󰋤' i_md_bowl_mix_outline=$i
i='󰋥' i_md_pot=$i
i='󰋦' i_md_human=$i
i='󰋧' i_md_human_child=$i
i='󰋨' i_md_human_male_female=$i
i='󰋩' i_md_image=$i
i='󰋪' i_md_image_album=$i
i='󰋫' i_md_image_area=$i
i='󰋬' i_md_image_area_close=$i
i='󰋭' i_md_image_broken=$i
i='󰋮' i_md_image_broken_variant=$i
i='󰋯' i_md_image_multiple_outline=$i
i='󰋰' i_md_image_filter_black_white=$i
i='󰋱' i_md_image_filter_center_focus=$i
i='󰋲' i_md_image_filter_center_focus_weak=$i
i='󰋳' i_md_image_filter_drama=$i
i='󰋴' i_md_image_filter_frames=$i
i='󰋵' i_md_image_filter_hdr=$i
i='󰋶' i_md_image_filter_none=$i
i='󰋷' i_md_image_filter_tilt_shift=$i
i='󰋸' i_md_image_filter_vintage=$i
i='󰋹' i_md_image_multiple=$i
i='󰋺' i_md_import=$i
i='󰋻' i_md_inbox_arrow_down=$i
i='󰋼' i_md_information=$i
i='󰋽' i_md_information_outline=$i
i='󰋾' i_md_instagram=$i
i='󰋿' i_md_pot_outline=$i
i='󰌀' i_md_microsoft_internet_explorer=$i
i='󰌁' i_md_invert_colors=$i
i='󰌂' i_md_jeepney=$i
i='󰌃' i_md_jira=$i
i='󰌄' i_md_jsfiddle=$i
i='󰌅' i_md_keg=$i
i='󰌆' i_md_key=$i
i='󰌇' i_md_key_change=$i
i='󰌈' i_md_key_minus=$i
i='󰌉' i_md_key_plus=$i
i='󰌊' i_md_key_remove=$i
i='󰌋' i_md_key_variant=$i
i='󰌌' i_md_keyboard=$i
i='󰌍' i_md_keyboard_backspace=$i
i='󰌎' i_md_keyboard_caps=$i
i='󰌏' i_md_keyboard_close=$i
i='󰌐' i_md_keyboard_off=$i
i='󰌑' i_md_keyboard_return=$i
i='󰌒' i_md_keyboard_tab=$i
i='󰌓' i_md_keyboard_variant=$i
i='󰌔' i_md_kodi=$i
i='󰌕' i_md_label=$i
i='󰌖' i_md_label_outline=$i
i='󰌗' i_md_lan=$i
i='󰌘' i_md_lan_connect=$i
i='󰌙' i_md_lan_disconnect=$i
i='󰌚' i_md_lan_pending=$i
i='󰌛' i_md_language_csharp=$i
i='󰌜' i_md_language_css3=$i
i='󰌝' i_md_language_html5=$i
i='󰌞' i_md_language_javascript=$i
i='󰌟' i_md_language_php=$i
i='󰌠' i_md_language_python=$i
i='󰌡' i_md_contactless_payment_circle=$i
i='󰌢' i_md_laptop=$i
i='󰌣' i_md_magazine_rifle=$i
i='󰌤' i_md_magazine_pistol=$i
i='󰌥' i_md_keyboard_tab_reverse=$i
i='󰌦' i_md_pot_steam_outline=$i
i='󰌧' i_md_launch=$i
i='󰌨' i_md_layers=$i
i='󰌩' i_md_layers_off=$i
i='󰌪' i_md_leaf=$i
i='󰌫' i_md_led_off=$i
i='󰌬' i_md_led_on=$i
i='󰌭' i_md_led_outline=$i
i='󰌮' i_md_led_variant_off=$i
i='󰌯' i_md_led_variant_on=$i
i='󰌰' i_md_led_variant_outline=$i
i='󰌱' i_md_library=$i
i='󰌲' i_md_filmstrip_box=$i
i='󰌳' i_md_music_box_multiple=$i
i='󰌴' i_md_plus_box_multiple=$i
i='󰌵' i_md_lightbulb=$i
i='󰌶' i_md_lightbulb_outline=$i
i='󰌷' i_md_link=$i
i='󰌸' i_md_link_off=$i
i='󰌹' i_md_link_variant=$i
i='󰌺' i_md_link_variant_off=$i
i='󰌻' i_md_linkedin=$i
i='󰌼' i_md_sort_reverse_variant=$i
i='󰌽' i_md_linux=$i
i='󰌾' i_md_lock=$i
i='󰌿' i_md_lock_open=$i
i='󰍀' i_md_lock_open_outline=$i
i='󰍁' i_md_lock_outline=$i
i='󰍂' i_md_login=$i
i='󰍃' i_md_logout=$i
i='󰍄' i_md_looks=$i
i='󰍅' i_md_loupe=$i
i='󰍆' i_md_lumx=$i
i='󰍇' i_md_magnet=$i
i='󰍈' i_md_magnet_on=$i
i='󰍉' i_md_magnify=$i
i='󰍊' i_md_magnify_minus=$i
i='󰍋' i_md_magnify_plus=$i
i='󰍌' i_md_plus_circle_multiple=$i
i='󰍍' i_md_map=$i
i='󰍎' i_md_map_marker=$i
i='󰍏' i_md_map_marker_circle=$i
i='󰍐' i_md_map_marker_multiple=$i
i='󰍑' i_md_map_marker_off=$i
i='󰍒' i_md_map_marker_radius=$i
i='󰍓' i_md_margin=$i
i='󰍔' i_md_language_markdown=$i
i='󰍕' i_md_marker_check=$i
i='󰍖' i_md_glass_cocktail=$i
i='󰍗' i_md_material_ui=$i
i='󰍘' i_md_math_compass=$i
i='󰍙' i_md_stackpath=$i
i='󰍚' i_md_minus_circle_multiple=$i
i='󰍛' i_md_memory=$i
i='󰍜' i_md_menu=$i
i='󰍝' i_md_menu_down=$i
i='󰍞' i_md_menu_left=$i
i='󰍟' i_md_menu_right=$i
i='󰍠' i_md_menu_up=$i
i='󰍡' i_md_message=$i
i='󰍢' i_md_message_alert=$i
i='󰍣' i_md_message_draw=$i
i='󰍤' i_md_message_image=$i
i='󰍥' i_md_message_outline=$i
i='󰍦' i_md_message_processing=$i
i='󰍧' i_md_message_reply=$i
i='󰍨' i_md_message_reply_text=$i
i='󰍩' i_md_message_text=$i
i='󰍪' i_md_message_text_outline=$i
i='󰍫' i_md_message_video=$i
i='󰍬' i_md_microphone=$i
i='󰍭' i_md_microphone_off=$i
i='󰍮' i_md_microphone_outline=$i
i='󰍯' i_md_microphone_settings=$i
i='󰍰' i_md_microphone_variant=$i
i='󰍱' i_md_microphone_variant_off=$i
i='󰍲' i_md_microsoft=$i
i='󰍳' i_md_minecraft=$i
i='󰍴' i_md_minus=$i
i='󰍵' i_md_minus_box=$i
i='󰍶' i_md_minus_circle=$i
i='󰍷' i_md_minus_circle_outline=$i
i='󰍸' i_md_minus_network=$i
i='󰍹' i_md_monitor=$i
i='󰍺' i_md_monitor_multiple=$i
i='󰍻' i_md_more=$i
i='󰍼' i_md_motorbike=$i
i='󰍽' i_md_mouse=$i
i='󰍾' i_md_mouse_off=$i
i='󰍿' i_md_mouse_variant=$i
i='󰎀' i_md_mouse_variant_off=$i
i='󰎁' i_md_movie=$i
i='󰎂' i_md_multiplication=$i
i='󰎃' i_md_multiplication_box=$i
i='󰎄' i_md_music_box=$i
i='󰎅' i_md_music_box_outline=$i
i='󰎆' i_md_music_circle=$i
i='󰎇' i_md_music_note=$i
i='󰎉' i_md_music_note_half=$i
i='󰎊' i_md_music_note_off=$i
i='󰎋' i_md_music_note_quarter=$i
i='󰎌' i_md_music_note_sixteenth=$i
i='󰎍' i_md_music_note_whole=$i
i='󰎎' i_md_nature=$i
i='󰎏' i_md_nature_people=$i
i='󰎐' i_md_navigation=$i
i='󰎑' i_md_needle=$i
i='󰎒' i_md_smoke_detector=$i
i='󰎓' i_md_thermostat=$i
i='󰎔' i_md_new_box=$i
i='󰎕' i_md_newspaper=$i
i='󰎖' i_md_nfc=$i
i='󰎗' i_md_nfc_tap=$i
i='󰎘' i_md_nfc_variant=$i
i='󰎙' i_md_nodejs=$i
i='󰎚' i_md_note=$i
i='󰎛' i_md_note_outline=$i
i='󰎜' i_md_note_plus=$i
i='󰎝' i_md_note_plus_outline=$i
i='󰎞' i_md_note_text=$i
i='󰎟' i_md_notification_clear_all=$i
i='󰎠' i_md_numeric=$i
i='󰎡' i_md_numeric_0_box=$i
i='󰎢' i_md_numeric_0_box_multiple_outline=$i
i='󰎣' i_md_numeric_0_box_outline=$i
i='󰎤' i_md_numeric_1_box=$i
i='󰎥' i_md_numeric_1_box_multiple_outline=$i
i='󰎦' i_md_numeric_1_box_outline=$i
i='󰎧' i_md_numeric_2_box=$i
i='󰎨' i_md_numeric_2_box_multiple_outline=$i
i='󰎩' i_md_numeric_2_box_outline=$i
i='󰎪' i_md_numeric_3_box=$i
i='󰎫' i_md_numeric_3_box_multiple_outline=$i
i='󰎬' i_md_numeric_3_box_outline=$i
i='󰎭' i_md_numeric_4_box=$i
i='󰎮' i_md_numeric_4_box_outline=$i
i='󰎯' i_md_numeric_5_box_multiple_outline=$i
i='󰎰' i_md_numeric_5_box_outline=$i
i='󰎱' i_md_numeric_5_box=$i
i='󰎲' i_md_numeric_4_box_multiple_outline=$i
i='󰎳' i_md_numeric_6_box=$i
i='󰎴' i_md_numeric_6_box_multiple_outline=$i
i='󰎵' i_md_numeric_6_box_outline=$i
i='󰎶' i_md_numeric_7_box=$i
i='󰎷' i_md_numeric_7_box_multiple_outline=$i
i='󰎸' i_md_numeric_7_box_outline=$i
i='󰎹' i_md_numeric_8_box=$i
i='󰎺' i_md_numeric_8_box_multiple_outline=$i
i='󰎻' i_md_numeric_8_box_outline=$i
i='󰎼' i_md_numeric_9_box=$i
i='󰎽' i_md_numeric_9_box_multiple_outline=$i
i='󰎾' i_md_numeric_9_box_outline=$i
i='󰎿' i_md_numeric_9_plus_box=$i
i='󰏀' i_md_numeric_9_plus_box_multiple_outline=$i
i='󰏁' i_md_numeric_9_plus_box_outline=$i
i='󰏂' i_md_nutrition=$i
i='󰏃' i_md_octagon=$i
i='󰏄' i_md_octagon_outline=$i
i='󰏅' i_md_odnoklassniki=$i
i='󰏆' i_md_microsoft_office=$i
i='󰏇' i_md_oil=$i
i='󰏈' i_md_coolant_temperature=$i
i='󰏉' i_md_omega=$i
i='󰏊' i_md_microsoft_onedrive=$i
i='󰏋' i_md_open_in_app=$i
i='󰏌' i_md_open_in_new=$i
i='󰏍' i_md_openid=$i
i='󰏎' i_md_opera=$i
i='󰏏' i_md_ornament=$i
i='󰏐' i_md_ornament_variant=$i
i='󰏑' i_md_inbox_arrow_up=$i
i='󰏒' i_md_owl=$i
i='󰏓' i_md_package=$i
i='󰏔' i_md_package_down=$i
i='󰏕' i_md_package_up=$i
i='󰏖' i_md_package_variant=$i
i='󰏗' i_md_package_variant_closed=$i
i='󰏘' i_md_palette=$i
i='󰏙' i_md_palette_advanced=$i
i='󰏚' i_md_panda=$i
i='󰏛' i_md_pandora=$i
i='󰏜' i_md_panorama=$i
i='󰏝' i_md_panorama_fisheye=$i
i='󰏞' i_md_panorama_horizontal_outline=$i
i='󰏟' i_md_panorama_vertical_outline=$i
i='󰏠' i_md_panorama_wide_angle_outline=$i
i='󰏡' i_md_paper_cut_vertical=$i
i='󰏢' i_md_paperclip=$i
i='󰏣' i_md_parking=$i
i='󰏤' i_md_pause=$i
i='󰏥' i_md_pause_circle=$i
i='󰏦' i_md_pause_circle_outline=$i
i='󰏧' i_md_pause_octagon=$i
i='󰏨' i_md_pause_octagon_outline=$i
i='󰏩' i_md_paw=$i
i='󰏪' i_md_pen=$i
i='󰏫' i_md_pencil=$i
i='󰏬' i_md_pencil_box=$i
i='󰏭' i_md_pencil_box_outline=$i
i='󰏮' i_md_pencil_lock=$i
i='󰏯' i_md_pencil_off=$i
i='󰏰' i_md_percent=$i
i='󰏱' i_md_mortar_pestle_plus=$i
i='󰏲' i_md_phone=$i
i='󰏳' i_md_phone_bluetooth=$i
i='󰏴' i_md_phone_forward=$i
i='󰏵' i_md_phone_hangup=$i
i='󰏶' i_md_phone_in_talk=$i
i='󰏷' i_md_phone_incoming=$i
i='󰏸' i_md_phone_lock=$i
i='󰏹' i_md_phone_log=$i
i='󰏺' i_md_phone_missed=$i
i='󰏻' i_md_phone_outgoing=$i
i='󰏼' i_md_phone_paused=$i
i='󰏽' i_md_phone_settings=$i
i='󰏾' i_md_phone_voip=$i
i='󰏿' i_md_pi=$i
i='󰐀' i_md_pi_box=$i
i='󰐁' i_md_pig=$i
i='󰐂' i_md_pill=$i
i='󰐃' i_md_pin=$i
i='󰐄' i_md_pin_off=$i
i='󰐅' i_md_pine_tree=$i
i='󰐆' i_md_pine_tree_box=$i
i='󰐇' i_md_pinterest=$i
i='󰐈' i_md_contactless_payment_circle_outline=$i
i='󰐉' i_md_pizza=$i
i='󰐊' i_md_play=$i
i='󰐋' i_md_play_box_outline=$i
i='󰐌' i_md_play_circle=$i
i='󰐍' i_md_play_circle_outline=$i
i='󰐎' i_md_play_pause=$i
i='󰐏' i_md_play_protected_content=$i
i='󰐐' i_md_playlist_minus=$i
i='󰐑' i_md_playlist_play=$i
i='󰐒' i_md_playlist_plus=$i
i='󰐓' i_md_playlist_remove=$i
i='󰐔' i_md_sony_playstation=$i
i='󰐕' i_md_plus=$i
i='󰐖' i_md_plus_box=$i
i='󰐗' i_md_plus_circle=$i
i='󰐘' i_md_plus_circle_multiple_outline=$i
i='󰐙' i_md_plus_circle_outline=$i
i='󰐚' i_md_plus_network=$i
i='󰐛' i_md_sledding=$i
i='󰐜' i_md_wall_sconce_flat_variant=$i
i='󰐝' i_md_pokeball=$i
i='󰐞' i_md_polaroid=$i
i='󰐟' i_md_poll=$i
i='󰐠' i_md_account_eye=$i
i='󰐡' i_md_polymer=$i
i='󰐢' i_md_popcorn=$i
i='󰐣' i_md_pound=$i
i='󰐤' i_md_pound_box=$i
i='󰐥' i_md_power=$i
i='󰐦' i_md_power_settings=$i
i='󰐧' i_md_power_socket=$i
i='󰐨' i_md_presentation=$i
i='󰐩' i_md_presentation_play=$i
i='󰐪' i_md_printer=$i
i='󰐫' i_md_printer_3d=$i
i='󰐬' i_md_printer_alert=$i
i='󰐭' i_md_professional_hexagon=$i
i='󰐮' i_md_projector=$i
i='󰐯' i_md_projector_screen=$i
i='󰐰' i_md_pulse=$i
i='󰐱' i_md_puzzle=$i
i='󰐲' i_md_qrcode=$i
i='󰐳' i_md_qrcode_scan=$i
i='󰐴' i_md_quadcopter=$i
i='󰐵' i_md_quality_high=$i
i='󰐶' i_md_book_multiple_outline=$i
i='󰐷' i_md_radar=$i
i='󰐸' i_md_radiator=$i
i='󰐹' i_md_radio=$i
i='󰐺' i_md_radio_handheld=$i
i='󰐻' i_md_radio_tower=$i
i='󰐼' i_md_radioactive=$i
i='󰐾' i_md_radiobox_marked=$i
i='󰐿' i_md_raspberry_pi=$i
i='󰑀' i_md_ray_end=$i
i='󰑁' i_md_ray_end_arrow=$i
i='󰑂' i_md_ray_start=$i
i='󰑃' i_md_ray_start_arrow=$i
i='󰑄' i_md_ray_start_end=$i
i='󰑅' i_md_ray_vertex=$i
i='󰑆' i_md_lastpass=$i
i='󰑇' i_md_read=$i
i='󰑈' i_md_youtube_tv=$i
i='󰑉' i_md_receipt=$i
i='󰑊' i_md_record=$i
i='󰑋' i_md_record_rec=$i
i='󰑌' i_md_recycle=$i
i='󰑍' i_md_reddit=$i
i='󰑎' i_md_redo=$i
i='󰑏' i_md_redo_variant=$i
i='󰑐' i_md_refresh=$i
i='󰑑' i_md_regex=$i
i='󰑒' i_md_relative_scale=$i
i='󰑓' i_md_reload=$i
i='󰑔' i_md_remote=$i
i='󰑕' i_md_rename_box=$i
i='󰑖' i_md_repeat=$i
i='󰑗' i_md_repeat_off=$i
i='󰑘' i_md_repeat_once=$i
i='󰑙' i_md_replay=$i
i='󰑚' i_md_reply=$i
i='󰑛' i_md_reply_all=$i
i='󰑜' i_md_reproduction=$i
i='󰑝' i_md_resize_bottom_right=$i
i='󰑞' i_md_responsive=$i
i='󰑟' i_md_rewind=$i
i='󰑠' i_md_ribbon=$i
i='󰑡' i_md_road=$i
i='󰑢' i_md_road_variant=$i
i='󰑣' i_md_rocket=$i
i='󰑤' i_md_rotate_3d_variant=$i
i='󰑥' i_md_rotate_left=$i
i='󰑦' i_md_rotate_left_variant=$i
i='󰑧' i_md_rotate_right=$i
i='󰑨' i_md_rotate_right_variant=$i
i='󰑩' i_md_router_wireless=$i
i='󰑪' i_md_routes=$i
i='󰑫' i_md_rss=$i
i='󰑬' i_md_rss_box=$i
i='󰑭' i_md_ruler=$i
i='󰑮' i_md_run_fast=$i
i='󰑯' i_md_sale=$i
i='󰑰' i_md_satellite=$i
i='󰑱' i_md_satellite_variant=$i
i='󰑲' i_md_scale=$i
i='󰑳' i_md_scale_bathroom=$i
i='󰑴' i_md_school=$i
i='󰑵' i_md_screen_rotation=$i
i='󰑶' i_md_screwdriver=$i
i='󰑷' i_md_script_outline=$i
i='󰑸' i_md_screen_rotation_lock=$i
i='󰑹' i_md_sd=$i
i='󰑺' i_md_seal=$i
i='󰑻' i_md_seat_flat=$i
i='󰑼' i_md_seat_flat_angled=$i
i='󰑽' i_md_seat_individual_suite=$i
i='󰑾' i_md_seat_legroom_extra=$i
i='󰑿' i_md_seat_legroom_normal=$i
i='󰒀' i_md_seat_legroom_reduced=$i
i='󰒁' i_md_seat_recline_extra=$i
i='󰒂' i_md_seat_recline_normal=$i
i='󰒃' i_md_security=$i
i='󰒄' i_md_security_network=$i
i='󰒅' i_md_select=$i
i='󰒆' i_md_select_all=$i
i='󰒇' i_md_select_inverse=$i
i='󰒈' i_md_select_off=$i
i='󰒉' i_md_selection=$i
i='󰒊' i_md_send=$i
i='󰒋' i_md_server=$i
i='󰒌' i_md_server_minus=$i
i='󰒍' i_md_server_network=$i
i='󰒎' i_md_server_network_off=$i
i='󰒏' i_md_server_off=$i
i='󰒐' i_md_server_plus=$i
i='󰒑' i_md_server_remove=$i
i='󰒒' i_md_server_security=$i
i='󰒓' i_md_cog=$i
i='󰒔' i_md_cog_box=$i
i='󰒕' i_md_shape_plus=$i
i='󰒖' i_md_share=$i
i='󰒗' i_md_share_variant=$i
i='󰒘' i_md_shield=$i
i='󰒙' i_md_shield_outline=$i
i='󰒚' i_md_shopping=$i
i='󰒛' i_md_shopping_music=$i
i='󰒜' i_md_shredder=$i
i='󰒝' i_md_shuffle=$i
i='󰒞' i_md_shuffle_disabled=$i
i='󰒟' i_md_shuffle_variant=$i
i='󰒠' i_md_sigma=$i
i='󰒡' i_md_sign_caution=$i
i='󰒢' i_md_signal=$i
i='󰒣' i_md_silverware=$i
i='󰒤' i_md_silverware_fork=$i
i='󰒥' i_md_silverware_spoon=$i
i='󰒦' i_md_silverware_variant=$i
i='󰒧' i_md_sim=$i
i='󰒨' i_md_sim_alert=$i
i='󰒩' i_md_sim_off=$i
i='󰒪' i_md_sitemap=$i
i='󰒫' i_md_skip_backward=$i
i='󰒬' i_md_skip_forward=$i
i='󰒭' i_md_skip_next=$i
i='󰒮' i_md_skip_previous=$i
i='󰒯' i_md_skype=$i
i='󰒰' i_md_skype_business=$i
i='󰒱' i_md_slack=$i
i='󰒲' i_md_sleep=$i
i='󰒳' i_md_sleep_off=$i
i='󰒴' i_md_smoking=$i
i='󰒵' i_md_smoking_off=$i
i='󰒶' i_md_snapchat=$i
i='󰒷' i_md_snowman=$i
i='󰒸' i_md_soccer=$i
i='󰒹' i_md_sofa=$i
i='󰒺' i_md_sort=$i
i='󰒻' i_md_sort_alphabetical_variant=$i
i='󰒼' i_md_sort_ascending=$i
i='󰒽' i_md_sort_descending=$i
i='󰒾' i_md_sort_numeric_variant=$i
i='󰒿' i_md_sort_variant=$i
i='󰓀' i_md_soundcloud=$i
i='󰓁' i_md_source_fork=$i
i='󰓂' i_md_source_pull=$i
i='󰓃' i_md_speaker=$i
i='󰓄' i_md_speaker_off=$i
i='󰓅' i_md_speedometer=$i
i='󰓆' i_md_spellcheck=$i
i='󰓇' i_md_spotify=$i
i='󰓈' i_md_spotlight=$i
i='󰓉' i_md_spotlight_beam=$i
i='󰓊' i_md_book_remove_multiple_outline=$i
i='󰓋' i_md_account_switch_outline=$i
i='󰓌' i_md_stack_overflow=$i
i='󰓍' i_md_stairs=$i
i='󰓎' i_md_star=$i
i='󰓏' i_md_star_circle=$i
i='󰓐' i_md_star_half_full=$i
i='󰓑' i_md_star_off=$i
i='󰓒' i_md_star_outline=$i
i='󰓓' i_md_steam=$i
i='󰓔' i_md_steering=$i
i='󰓕' i_md_step_backward=$i
i='󰓖' i_md_step_backward_2=$i
i='󰓗' i_md_step_forward=$i
i='󰓘' i_md_step_forward_2=$i
i='󰓙' i_md_stethoscope=$i
i='󰓚' i_md_stocking=$i
i='󰓛' i_md_stop=$i
i='󰓜' i_md_store=$i
i='󰓝' i_md_store_24_hour=$i
i='󰓞' i_md_stove=$i
i='󰓟' i_md_subway_variant=$i
i='󰓠' i_md_sunglasses=$i
i='󰓡' i_md_swap_horizontal=$i
i='󰓢' i_md_swap_vertical=$i
i='󰓣' i_md_swim=$i
i='󰓤' i_md_switch=$i
i='󰓥' i_md_sword=$i
i='󰓦' i_md_sync=$i
i='󰓧' i_md_sync_alert=$i
i='󰓨' i_md_sync_off=$i
i='󰓩' i_md_tab=$i
i='󰓪' i_md_tab_unselected=$i
i='󰓫' i_md_table=$i
i='󰓬' i_md_table_column_plus_after=$i
i='󰓭' i_md_table_column_plus_before=$i
i='󰓮' i_md_table_column_remove=$i
i='󰓯' i_md_table_column_width=$i
i='󰓰' i_md_table_edit=$i
i='󰓱' i_md_table_large=$i
i='󰓲' i_md_table_row_height=$i
i='󰓳' i_md_table_row_plus_after=$i
i='󰓴' i_md_table_row_plus_before=$i
i='󰓵' i_md_table_row_remove=$i
i='󰓶' i_md_tablet=$i
i='󰓷' i_md_tablet_android=$i
i='󰓸' i_md_tangram=$i
i='󰓹' i_md_tag=$i
i='󰓺' i_md_tag_faces=$i
i='󰓻' i_md_tag_multiple=$i
i='󰓼' i_md_tag_outline=$i
i='󰓽' i_md_tag_text_outline=$i
i='󰓾' i_md_target=$i
i='󰓿' i_md_taxi=$i
i='󰔀' i_md_teamviewer=$i
i='󰔁' i_md_skateboarding=$i
i='󰔂' i_md_television=$i
i='󰔃' i_md_television_guide=$i
i='󰔄' i_md_temperature_celsius=$i
i='󰔅' i_md_temperature_fahrenheit=$i
i='󰔆' i_md_temperature_kelvin=$i
i='󰔇' i_md_tennis_ball=$i
i='󰔈' i_md_tent=$i
i='󰔊' i_md_text_to_speech=$i
i='󰔋' i_md_text_to_speech_off=$i
i='󰔌' i_md_texture=$i
i='󰔍' i_md_theater=$i
i='󰔎' i_md_theme_light_dark=$i
i='󰔏' i_md_thermometer=$i
i='󰔐' i_md_thermometer_lines=$i
i='󰔑' i_md_thumb_down=$i
i='󰔒' i_md_thumb_down_outline=$i
i='󰔓' i_md_thumb_up=$i
i='󰔔' i_md_thumb_up_outline=$i
i='󰔕' i_md_thumbs_up_down=$i
i='󰔖' i_md_ticket=$i
i='󰔗' i_md_ticket_account=$i
i='󰔘' i_md_ticket_confirmation=$i
i='󰔙' i_md_tie=$i
i='󰔚' i_md_timelapse=$i
i='󰔛' i_md_timer_outline=$i
i='󰔜' i_md_timer_10=$i
i='󰔝' i_md_timer_3=$i
i='󰔞' i_md_timer_off_outline=$i
i='󰔟' i_md_timer_sand=$i
i='󰔠' i_md_timetable=$i
i='󰔡' i_md_toggle_switch=$i
i='󰔢' i_md_toggle_switch_off=$i
i='󰔣' i_md_tooltip=$i
i='󰔤' i_md_tooltip_edit=$i
i='󰔥' i_md_tooltip_image=$i
i='󰔦' i_md_tooltip_outline=$i
i='󰔧' i_md_tooltip_plus_outline=$i
i='󰔨' i_md_tooltip_text=$i
i='󰔩' i_md_tooth_outline=$i
i='󰔪' i_md_cloud_refresh=$i
i='󰔫' i_md_traffic_light=$i
i='󰔬' i_md_train=$i
i='󰔭' i_md_tram=$i
i='󰔮' i_md_transcribe=$i
i='󰔯' i_md_transcribe_close=$i
i='󰔰' i_md_transfer_right=$i
i='󰔱' i_md_tree=$i
i='󰔲' i_md_trello=$i
i='󰔳' i_md_trending_down=$i
i='󰔴' i_md_trending_neutral=$i
i='󰔵' i_md_trending_up=$i
i='󰔶' i_md_triangle=$i
i='󰔷' i_md_triangle_outline=$i
i='󰔸' i_md_trophy=$i
i='󰔹' i_md_trophy_award=$i
i='󰔺' i_md_trophy_outline=$i
i='󰔻' i_md_trophy_variant=$i
i='󰔼' i_md_trophy_variant_outline=$i
i='󰔽' i_md_truck=$i
i='󰔾' i_md_truck_delivery=$i
i='󰔿' i_md_tshirt_crew_outline=$i
i='󰕀' i_md_tshirt_v_outline=$i
i='󰕁' i_md_file_refresh_outline=$i
i='󰕂' i_md_folder_refresh_outline=$i
i='󰕃' i_md_twitch=$i
i='󰕄' i_md_twitter=$i
i='󰕅' i_md_order_numeric_ascending=$i
i='󰕆' i_md_order_numeric_descending=$i
i='󰕇' i_md_repeat_variant=$i
i='󰕈' i_md_ubuntu=$i
i='󰕉' i_md_umbraco=$i
i='󰕊' i_md_umbrella=$i
i='󰕋' i_md_umbrella_outline=$i
i='󰕌' i_md_undo=$i
i='󰕍' i_md_undo_variant=$i
i='󰕎' i_md_unfold_less_horizontal=$i
i='󰕏' i_md_unfold_more_horizontal=$i
i='󰕐' i_md_ungroup=$i
i='󰕑' i_md_web_remove=$i
i='󰕒' i_md_upload=$i
i='󰕓' i_md_usb=$i
i='󰕔' i_md_vector_arrange_above=$i
i='󰕕' i_md_vector_arrange_below=$i
i='󰕖' i_md_vector_circle=$i
i='󰕗' i_md_vector_circle_variant=$i
i='󰕘' i_md_vector_combine=$i
i='󰕙' i_md_vector_curve=$i
i='󰕚' i_md_vector_difference=$i
i='󰕛' i_md_vector_difference_ab=$i
i='󰕜' i_md_vector_difference_ba=$i
i='󰕝' i_md_vector_intersection=$i
i='󰕞' i_md_vector_line=$i
i='󰕟' i_md_vector_point=$i
i='󰕠' i_md_vector_polygon=$i
i='󰕡' i_md_vector_polyline=$i
i='󰕢' i_md_vector_selection=$i
i='󰕣' i_md_vector_triangle=$i
i='󰕤' i_md_vector_union=$i
i='󰕥' i_md_shield_check=$i
i='󰕦' i_md_vibrate=$i
i='󰕧' i_md_video=$i
i='󰕨' i_md_video_off=$i
i='󰕩' i_md_video_switch=$i
i='󰕪' i_md_view_agenda=$i
i='󰕫' i_md_view_array=$i
i='󰕬' i_md_view_carousel=$i
i='󰕭' i_md_view_column=$i
i='󰕮' i_md_view_dashboard=$i
i='󰕯' i_md_view_day=$i
i='󰕰' i_md_view_grid=$i
i='󰕱' i_md_view_headline=$i
i='󰕲' i_md_view_list=$i
i='󰕳' i_md_view_module=$i
i='󰕴' i_md_view_quilt=$i
i='󰕵' i_md_view_stream=$i
i='󰕶' i_md_view_week=$i
i='󰕷' i_md_vimeo=$i
i='󰕸' i_md_buffet=$i
i='󰕹' i_md_hands_pray=$i
i='󰕺' i_md_credit_card_wireless_off=$i
i='󰕻' i_md_credit_card_wireless_off_outline=$i
i='󰕼' i_md_vlc=$i
i='󰕽' i_md_voicemail=$i
i='󰕾' i_md_volume_high=$i
i='󰕿' i_md_volume_low=$i
i='󰖀' i_md_volume_medium=$i
i='󰖁' i_md_volume_off=$i
i='󰖂' i_md_vpn=$i
i='󰖃' i_md_walk=$i
i='󰖄' i_md_wallet=$i
i='󰖅' i_md_wallet_giftcard=$i
i='󰖆' i_md_wallet_membership=$i
i='󰖇' i_md_wallet_travel=$i
i='󰖈' i_md_wan=$i
i='󰖉' i_md_watch=$i
i='󰖊' i_md_watch_export=$i
i='󰖋' i_md_watch_import=$i
i='󰖌' i_md_water=$i
i='󰖍' i_md_water_off=$i
i='󰖎' i_md_water_percent=$i
i='󰖏' i_md_water_pump=$i
i='󰖐' i_md_weather_cloudy=$i
i='󰖑' i_md_weather_fog=$i
i='󰖒' i_md_weather_hail=$i
i='󰖓' i_md_weather_lightning=$i
i='󰖔' i_md_weather_night=$i
i='󰖕' i_md_weather_partly_cloudy=$i
i='󰖖' i_md_weather_pouring=$i
i='󰖗' i_md_weather_rainy=$i
i='󰖘' i_md_weather_snowy=$i
i='󰖙' i_md_weather_sunny=$i
i='󰖚' i_md_weather_sunset=$i
i='󰖛' i_md_weather_sunset_down=$i
i='󰖜' i_md_weather_sunset_up=$i
i='󰖝' i_md_weather_windy=$i
i='󰖞' i_md_weather_windy_variant=$i
i='󰖟' i_md_web=$i
i='󰖠' i_md_webcam=$i
i='󰖡' i_md_weight=$i
i='󰖢' i_md_weight_kilogram=$i
i='󰖣' i_md_whatsapp=$i
i='󰖤' i_md_wheelchair_accessibility=$i
i='󰖥' i_md_white_balance_auto=$i
i='󰖦' i_md_white_balance_incandescent=$i
i='󰖧' i_md_white_balance_iridescent=$i
i='󰖨' i_md_white_balance_sunny=$i
i='󰖩' i_md_wifi=$i
i='󰖪' i_md_wifi_off=$i
i='󰖫' i_md_nintendo_wii=$i
i='󰖬' i_md_wikipedia=$i
i='󰖭' i_md_window_close=$i
i='󰖮' i_md_window_closed=$i
i='󰖯' i_md_window_maximize=$i
i='󰖰' i_md_window_minimize=$i
i='󰖱' i_md_window_open=$i
i='󰖲' i_md_window_restore=$i
i='󰖳' i_md_microsoft_windows=$i
i='󰖴' i_md_wordpress=$i
i='󰖵' i_md_account_hard_hat=$i
i='󰖶' i_md_wrap=$i
i='󰖷' i_md_wrench=$i
i='󰖸' i_md_contacts_outline=$i
i='󰖹' i_md_microsoft_xbox=$i
i='󰖺' i_md_microsoft_xbox_controller=$i
i='󰖻' i_md_microsoft_xbox_controller_off=$i
i='󰖼' i_md_table_furniture=$i
i='󰖽' i_md_sort_alphabetical_ascending=$i
i='󰖾' i_md_firewire=$i
i='󰖿' i_md_sort_alphabetical_descending=$i
i='󰗀' i_md_xml=$i
i='󰗁' i_md_yeast=$i
i='󰗂' i_md_database_refresh=$i
i='󰗃' i_md_youtube=$i
i='󰗄' i_md_zip_box=$i
i='󰗅' i_md_surround_sound=$i
i='󰗆' i_md_vector_rectangle=$i
i='󰗇' i_md_playlist_check=$i
i='󰗈' i_md_format_line_style=$i
i='󰗉' i_md_format_line_weight=$i
i='󰗊' i_md_translate=$i
i='󰗋' i_md_account_voice=$i
i='󰗌' i_md_opacity=$i
i='󰗍' i_md_near_me=$i
i='󰗎' i_md_clock_alert_outline=$i
i='󰗏' i_md_human_pregnant=$i
i='󰗐' i_md_sticker_circle_outline=$i
i='󰗑' i_md_scale_balance=$i
i='󰗒' i_md_card_account_details=$i
i='󰗓' i_md_account_multiple_minus=$i
i='󰗔' i_md_airplane_landing=$i
i='󰗕' i_md_airplane_takeoff=$i
i='󰗖' i_md_alert_circle_outline=$i
i='󰗗' i_md_altimeter=$i
i='󰗘' i_md_animation=$i
i='󰗙' i_md_book_minus=$i
i='󰗚' i_md_book_open_page_variant=$i
i='󰗛' i_md_book_plus=$i
i='󰗜' i_md_boombox=$i
i='󰗝' i_md_bullseye=$i
i='󰗞' i_md_comment_remove=$i
i='󰗟' i_md_camera_off=$i
i='󰗠' i_md_check_circle=$i
i='󰗡' i_md_check_circle_outline=$i
i='󰗢' i_md_candle=$i
i='󰗣' i_md_chart_bubble=$i
i='󰗤' i_md_credit_card_off_outline=$i
i='󰗥' i_md_cup_off=$i
i='󰗦' i_md_copyright=$i
i='󰗧' i_md_cursor_text=$i
i='󰗨' i_md_delete_forever=$i
i='󰗩' i_md_delete_sweep=$i
i='󰗪' i_md_dice_d20_outline=$i
i='󰗫' i_md_dice_d4_outline=$i
i='󰗬' i_md_dice_d8_outline=$i
i='󰗭' i_md_dice_d6_outline=$i
i='󰗮' i_md_disc=$i
i='󰗯' i_md_email_open_outline=$i
i='󰗰' i_md_email_variant=$i
i='󰗱' i_md_ev_station=$i
i='󰗲' i_md_food_fork_drink=$i
i='󰗳' i_md_food_off=$i
i='󰗴' i_md_format_title=$i
i='󰗵' i_md_google_maps=$i
i='󰗶' i_md_heart_pulse=$i
i='󰗷' i_md_highway=$i
i='󰗸' i_md_home_map_marker=$i
i='󰗹' i_md_incognito=$i
i='󰗺' i_md_kettle=$i
i='󰗻' i_md_lock_plus=$i
i='󰗽' i_md_logout_variant=$i
i='󰗾' i_md_music_note_bluetooth=$i
i='󰗿' i_md_music_note_bluetooth_off=$i
i='󰘀' i_md_page_first=$i
i='󰘁' i_md_page_last=$i
i='󰘂' i_md_phone_classic=$i
i='󰘃' i_md_priority_high=$i
i='󰘄' i_md_priority_low=$i
i='󰘅' i_md_qqchat=$i
i='󰘆' i_md_pool=$i
i='󰘇' i_md_rounded_corner=$i
i='󰘈' i_md_rowing=$i
i='󰘉' i_md_saxophone=$i
i='󰘊' i_md_signal_variant=$i
i='󰘋' i_md_stack_exchange=$i
i='󰘌' i_md_subdirectory_arrow_left=$i
i='󰘍' i_md_subdirectory_arrow_right=$i
i='󰘎' i_md_form_textbox=$i
i='󰘏' i_md_violin=$i
i='󰘐' i_md_microsoft_visual_studio=$i
i='󰘑' i_md_wechat=$i
i='󰘒' i_md_watermark=$i
i='󰘓' i_md_file_hidden=$i
i='󰘔' i_md_application_outline=$i
i='󰘕' i_md_arrow_collapse=$i
i='󰘖' i_md_arrow_expand=$i
i='󰘗' i_md_bowl_mix=$i
i='󰘘' i_md_bridge=$i
i='󰘙' i_md_application_edit_outline=$i
i='󰘚' i_md_chip=$i
i='󰘛' i_md_content_save_settings=$i
i='󰘜' i_md_dialpad=$i
i='󰘝' i_md_book_alphabet=$i
i='󰘞' i_md_format_horizontal_align_center=$i
i='󰘟' i_md_format_horizontal_align_left=$i
i='󰘠' i_md_format_horizontal_align_right=$i
i='󰘡' i_md_format_vertical_align_bottom=$i
i='󰘢' i_md_format_vertical_align_center=$i
i='󰘣' i_md_format_vertical_align_top=$i
i='󰘤' i_md_line_scan=$i
i='󰘥' i_md_help_circle_outline=$i
i='󰘦' i_md_code_json=$i
i='󰘧' i_md_lambda=$i
i='󰘨' i_md_matrix=$i
i='󰘩' i_md_meteor=$i
i='󰘪' i_md_close_circle_multiple=$i
i='󰘫' i_md_sigma_lower=$i
i='󰘬' i_md_source_branch=$i
i='󰘭' i_md_source_merge=$i
i='󰘮' i_md_tune=$i
i='󰘯' i_md_webhook=$i
i='󰘰' i_md_account_settings=$i
i='󰘱' i_md_account_details=$i
i='󰘲' i_md_apple_keyboard_caps=$i
i='󰘳' i_md_apple_keyboard_command=$i
i='󰘴' i_md_apple_keyboard_control=$i
i='󰘵' i_md_apple_keyboard_option=$i
i='󰘶' i_md_apple_keyboard_shift=$i
i='󰘷' i_md_box_shadow=$i
i='󰘸' i_md_cards=$i
i='󰘹' i_md_cards_outline=$i
i='󰘺' i_md_cards_playing_outline=$i
i='󰘻' i_md_checkbox_multiple_blank_circle=$i
i='󰘼' i_md_checkbox_multiple_blank_circle_outline=$i
i='󰘽' i_md_checkbox_multiple_marked_circle=$i
i='󰘾' i_md_checkbox_multiple_marked_circle_outline=$i
i='󰘿' i_md_cloud_sync=$i
i='󰙀' i_md_collage=$i
i='󰙁' i_md_directions_fork=$i
i='󰙂' i_md_eraser_variant=$i
i='󰙃' i_md_face_man=$i
i='󰙄' i_md_face_man_profile=$i
i='󰙅' i_md_file_tree=$i
i='󰙆' i_md_format_annotation_plus=$i
i='󰙇' i_md_gas_cylinder=$i
i='󰙈' i_md_grease_pencil=$i
i='󰙉' i_md_human_female=$i
i='󰙊' i_md_human_greeting_variant=$i
i='󰙋' i_md_human_handsdown=$i
i='󰙌' i_md_human_handsup=$i
i='󰙍' i_md_human_male=$i
i='󰙎' i_md_information_variant=$i
i='󰙏' i_md_lead_pencil=$i
i='󰙐' i_md_map_marker_minus=$i
i='󰙑' i_md_map_marker_plus=$i
i='󰙒' i_md_marker=$i
i='󰙓' i_md_message_plus=$i
i='󰙔' i_md_microscope=$i
i='󰙕' i_md_move_resize=$i
i='󰙖' i_md_move_resize_variant=$i
i='󰙗' i_md_paw_off=$i
i='󰙘' i_md_phone_minus=$i
i='󰙙' i_md_phone_plus=$i
i='󰙚' i_md_pot_steam=$i
i='󰙛' i_md_pot_mix=$i
i='󰙜' i_md_serial_port=$i
i='󰙝' i_md_shape_circle_plus=$i
i='󰙞' i_md_shape_polygon_plus=$i
i='󰙟' i_md_shape_rectangle_plus=$i
i='󰙠' i_md_shape_square_plus=$i
i='󰙡' i_md_skip_next_circle=$i
i='󰙢' i_md_skip_next_circle_outline=$i
i='󰙣' i_md_skip_previous_circle=$i
i='󰙤' i_md_skip_previous_circle_outline=$i
i='󰙥' i_md_spray=$i
i='󰙦' i_md_stop_circle=$i
i='󰙧' i_md_stop_circle_outline=$i
i='󰙨' i_md_test_tube=$i
i='󰙩' i_md_text_shadow=$i
i='󰙪' i_md_tune_vertical=$i
i='󰙫' i_md_cart_off=$i
i='󰙬' i_md_chart_gantt=$i
i='󰙭' i_md_chart_scatter_plot_hexbin=$i
i='󰙮' i_md_chart_timeline=$i
i='󰙯' i_md_discord=$i
i='󰙰' i_md_file_restore=$i
i='󰙱' i_md_language_c=$i
i='󰙲' i_md_language_cpp=$i
i='󰙳' i_md_language_xaml=$i
i='󰙴' i_md_creation=$i
i='󰙵' i_md_application_cog=$i
i='󰙶' i_md_credit_card_plus_outline=$i
i='󰙷' i_md_pot_mix_outline=$i
i='󰙸' i_md_bow_tie=$i
i='󰙹' i_md_calendar_range=$i
i='󰙺' i_md_currency_usd_off=$i
i='󰙻' i_md_flash_red_eye=$i
i='󰙼' i_md_oar=$i
i='󰙽' i_md_piano=$i
i='󰙾' i_md_weather_lightning_rainy=$i
i='󰙿' i_md_weather_snowy_rainy=$i
i='󰚀' i_md_yin_yang=$i
i='󰚁' i_md_tower_beach=$i
i='󰚂' i_md_tower_fire=$i
i='󰚃' i_md_delete_circle=$i
i='󰚄' i_md_dna=$i
i='󰚅' i_md_hamburger=$i
i='󰚆' i_md_gondola=$i
i='󰚇' i_md_inbox=$i
i='󰚈' i_md_reorder_horizontal=$i
i='󰚉' i_md_reorder_vertical=$i
i='󰚊' i_md_shield_home=$i
i='󰚋' i_md_tag_heart=$i
i='󰚌' i_md_skull=$i
i='󰚍' i_md_solid=$i
i='󰚎' i_md_alarm_snooze=$i
i='󰚏' i_md_baby_carriage=$i
i='󰚐' i_md_beaker_outline=$i
i='󰚑' i_md_bomb=$i
i='󰚒' i_md_calendar_question=$i
i='󰚓' i_md_camera_burst=$i
i='󰚔' i_md_code_tags_check=$i
i='󰚕' i_md_circle_multiple_outline=$i
i='󰚖' i_md_crop_rotate=$i
i='󰚗' i_md_developer_board=$i
i='󰚘' i_md_piano_off=$i
i='󰚙' i_md_skate_off=$i
i='󰚚' i_md_message_star=$i
i='󰚛' i_md_emoticon_dead_outline=$i
i='󰚜' i_md_emoticon_excited_outline=$i
i='󰚝' i_md_folder_star=$i
i='󰚞' i_md_format_color_text=$i
i='󰚟' i_md_format_section=$i
i='󰚠' i_md_gradient_vertical=$i
i='󰚡' i_md_home_outline=$i
i='󰚢' i_md_message_bulleted=$i
i='󰚣' i_md_message_bulleted_off=$i
i='󰚤' i_md_nuke=$i
i='󰚥' i_md_power_plug=$i
i='󰚦' i_md_power_plug_off=$i
i='󰚧' i_md_publish=$i
i='󰚨' i_md_credit_card_marker=$i
i='󰚩' i_md_robot=$i
i='󰚪' i_md_format_rotate_90=$i
i='󰚫' i_md_scanner=$i
i='󰚬' i_md_subway=$i
i='󰚭' i_md_timer_sand_empty=$i
i='󰚮' i_md_transit_transfer=$i
i='󰚯' i_md_unity=$i
i='󰚰' i_md_update=$i
i='󰚱' i_md_watch_vibrate=$i
i='󰚲' i_md_angular=$i
i='󰚳' i_md_dolby=$i
i='󰚴' i_md_emby=$i
i='󰚵' i_md_lamp=$i
i='󰚶' i_md_menu_down_outline=$i
i='󰚷' i_md_menu_up_outline=$i
i='󰚸' i_md_note_multiple=$i
i='󰚹' i_md_note_multiple_outline=$i
i='󰚺' i_md_plex=$i
i='󰚻' i_md_shield_airplane=$i
i='󰚼' i_md_account_edit=$i
i='󰚽' i_md_alert_decagram=$i
i='󰚾' i_md_all_inclusive=$i
i='󰚿' i_md_angularjs=$i
i='󰛀' i_md_arrow_down_box=$i
i='󰛁' i_md_arrow_left_box=$i
i='󰛂' i_md_arrow_right_box=$i
i='󰛃' i_md_arrow_up_box=$i
i='󰛄' i_md_asterisk=$i
i='󰛅' i_md_bomb_off=$i
i='󰛆' i_md_bootstrap=$i
i='󰛇' i_md_cards_variant=$i
i='󰛈' i_md_clipboard_flow=$i
i='󰛉' i_md_close_outline=$i
i='󰛊' i_md_coffee_outline=$i
i='󰛋' i_md_contacts=$i
i='󰛌' i_md_delete_empty=$i
i='󰛍' i_md_earth_box=$i
i='󰛎' i_md_earth_box_off=$i
i='󰛏' i_md_email_alert=$i
i='󰛐' i_md_eye_outline=$i
i='󰛑' i_md_eye_off_outline=$i
i='󰛒' i_md_fast_forward_outline=$i
i='󰛓' i_md_feather=$i
i='󰛔' i_md_find_replace=$i
i='󰛕' i_md_flash_outline=$i
i='󰛖' i_md_format_font=$i
i='󰛗' i_md_format_page_break=$i
i='󰛘' i_md_format_pilcrow=$i
i='󰛙' i_md_garage=$i
i='󰛚' i_md_garage_open=$i
i='󰛛' i_md_card_account_details_star_outline=$i
i='󰛜' i_md_google_keep=$i
i='󰛝' i_md_snowmobile=$i
i='󰛞' i_md_heart_half_full=$i
i='󰛟' i_md_heart_half=$i
i='󰛠' i_md_heart_half_outline=$i
i='󰛡' i_md_hexagon_multiple=$i
i='󰛢' i_md_hook=$i
i='󰛣' i_md_hook_off=$i
i='󰛤' i_md_infinity=$i
i='󰛥' i_md_language_swift=$i
i='󰛦' i_md_language_typescript=$i
i='󰛧' i_md_laptop_off=$i
i='󰛨' i_md_lightbulb_on=$i
i='󰛩' i_md_lightbulb_on_outline=$i
i='󰛪' i_md_lock_pattern=$i
i='󰛫' i_md_folder_zip=$i
i='󰛬' i_md_magnify_minus_outline=$i
i='󰛭' i_md_magnify_plus_outline=$i
i='󰛮' i_md_mailbox=$i
i='󰛯' i_md_medical_bag=$i
i='󰛰' i_md_message_settings=$i
i='󰛱' i_md_message_cog=$i
i='󰛲' i_md_minus_box_outline=$i
i='󰛳' i_md_network=$i
i='󰛴' i_md_download_network=$i
i='󰛵' i_md_help_network=$i
i='󰛶' i_md_upload_network=$i
i='󰛷' i_md_npm=$i
i='󰛸' i_md_nut=$i
i='󰛹' i_md_octagram=$i
i='󰛺' i_md_page_layout_body=$i
i='󰛻' i_md_page_layout_footer=$i
i='󰛼' i_md_page_layout_header=$i
i='󰛽' i_md_page_layout_sidebar_left=$i
i='󰛾' i_md_page_layout_sidebar_right=$i
i='󰛿' i_md_pencil_circle=$i
i='󰜀' i_md_pentagon_outline=$i
i='󰜁' i_md_pentagon=$i
i='󰜂' i_md_pillar=$i
i='󰜃' i_md_pistol=$i
i='󰜄' i_md_plus_box_outline=$i
i='󰜅' i_md_plus_outline=$i
i='󰜆' i_md_prescription=$i
i='󰜇' i_md_printer_settings=$i
i='󰜈' i_md_react=$i
i='󰜉' i_md_restart=$i
i='󰜊' i_md_rewind_outline=$i
i='󰜋' i_md_rhombus=$i
i='󰜌' i_md_rhombus_outline=$i
i='󰜍' i_md_robot_vacuum=$i
i='󰜎' i_md_run=$i
i='󰜏' i_md_search_web=$i
i='󰜐' i_md_shovel=$i
i='󰜑' i_md_shovel_off=$i
i='󰜒' i_md_signal_2g=$i
i='󰜓' i_md_signal_3g=$i
i='󰜔' i_md_signal_4g=$i
i='󰜕' i_md_signal_hspa=$i
i='󰜖' i_md_signal_hspa_plus=$i
i='󰜗' i_md_snowflake=$i
i='󰜘' i_md_source_commit=$i
i='󰜙' i_md_source_commit_end=$i
i='󰜚' i_md_source_commit_end_local=$i
i='󰜛' i_md_source_commit_local=$i
i='󰜜' i_md_source_commit_next_local=$i
i='󰜝' i_md_source_commit_start=$i
i='󰜞' i_md_source_commit_start_next_local=$i
i='󰜟' i_md_speaker_wireless=$i
i='󰜠' i_md_stadium_variant=$i
i='󰜡' i_md_svg=$i
i='󰜢' i_md_tag_plus=$i
i='󰜣' i_md_tag_remove=$i
i='󰜤' i_md_ticket_percent=$i
i='󰜥' i_md_tilde=$i
i='󰜦' i_md_treasure_chest=$i
i='󰜧' i_md_truck_trailer=$i
i='󰜨' i_md_view_parallel=$i
i='󰜩' i_md_view_sequential=$i
i='󰜪' i_md_washing_machine=$i
i='󰜫' i_md_webpack=$i
i='󰜬' i_md_widgets=$i
i='󰜭' i_md_nintendo_wiiu=$i
i='󰜮' i_md_arrow_down_bold=$i
i='󰜯' i_md_arrow_down_bold_box=$i
i='󰜰' i_md_arrow_down_bold_box_outline=$i
i='󰜱' i_md_arrow_left_bold=$i
i='󰜲' i_md_arrow_left_bold_box=$i
i='󰜳' i_md_arrow_left_bold_box_outline=$i
i='󰜴' i_md_arrow_right_bold=$i
i='󰜵' i_md_arrow_right_bold_box=$i
i='󰜶' i_md_arrow_right_bold_box_outline=$i
i='󰜷' i_md_arrow_up_bold=$i
i='󰜸' i_md_arrow_up_bold_box=$i
i='󰜹' i_md_arrow_up_bold_box_outline=$i
i='󰜺' i_md_cancel=$i
i='󰜻' i_md_file_account=$i
i='󰜼' i_md_gesture_double_tap=$i
i='󰜽' i_md_gesture_swipe_down=$i
i='󰜾' i_md_gesture_swipe_left=$i
i='󰜿' i_md_gesture_swipe_right=$i
i='󰝀' i_md_gesture_swipe_up=$i
i='󰝁' i_md_gesture_tap=$i
i='󰝂' i_md_gesture_two_double_tap=$i
i='󰝃' i_md_gesture_two_tap=$i
i='󰝄' i_md_humble_bundle=$i
i='󰝅' i_md_kickstarter=$i
i='󰝆' i_md_netflix=$i
i='󰝇' i_md_microsoft_onenote=$i
i='󰝈' i_md_wall_sconce_round=$i
i='󰝉' i_md_folder_refresh=$i
i='󰝊' i_md_vector_radius=$i
i='󰝋' i_md_microsoft_xbox_controller_battery_alert=$i
i='󰝌' i_md_microsoft_xbox_controller_battery_empty=$i
i='󰝍' i_md_microsoft_xbox_controller_battery_full=$i
i='󰝎' i_md_microsoft_xbox_controller_battery_low=$i
i='󰝏' i_md_microsoft_xbox_controller_battery_medium=$i
i='󰝐' i_md_microsoft_xbox_controller_battery_unknown=$i
i='󰝑' i_md_clipboard_plus=$i
i='󰝒' i_md_file_plus=$i
i='󰝓' i_md_format_align_bottom=$i
i='󰝔' i_md_format_align_middle=$i
i='󰝕' i_md_format_align_top=$i
i='󰝖' i_md_format_list_checks=$i
i='󰝗' i_md_format_quote_open=$i
i='󰝘' i_md_grid_large=$i
i='󰝙' i_md_heart_off=$i
i='󰝚' i_md_music=$i
i='󰝛' i_md_music_off=$i
i='󰝜' i_md_tab_plus=$i
i='󰝝' i_md_volume_plus=$i
i='󰝞' i_md_volume_minus=$i
i='󰝟' i_md_volume_mute=$i
i='󰝠' i_md_unfold_less_vertical=$i
i='󰝡' i_md_unfold_more_vertical=$i
i='󰝢' i_md_taco=$i
i='󰝣' i_md_square_outline=$i
i='󰝤' i_md_square=$i
i='󰝧' i_md_alert_octagram=$i
i='󰝨' i_md_atom=$i
i='󰝩' i_md_ceiling_light=$i
i='󰝪' i_md_chart_bar_stacked=$i
i='󰝫' i_md_chart_line_stacked=$i
i='󰝬' i_md_decagram=$i
i='󰝭' i_md_decagram_outline=$i
i='󰝮' i_md_dice_multiple=$i
i='󰝯' i_md_dice_d10_outline=$i
i='󰝰' i_md_folder_open=$i
i='󰝱' i_md_guitar_acoustic=$i
i='󰝲' i_md_loading=$i
i='󰝳' i_md_lock_reset=$i
i='󰝴' i_md_ninja=$i
i='󰝵' i_md_octagram_outline=$i
i='󰝶' i_md_pencil_circle_outline=$i
i='󰝷' i_md_selection_off=$i
i='󰝸' i_md_set_all=$i
i='󰝹' i_md_set_center=$i
i='󰝺' i_md_set_center_right=$i
i='󰝻' i_md_set_left=$i
i='󰝼' i_md_set_left_center=$i
i='󰝽' i_md_set_left_right=$i
i='󰝾' i_md_set_none=$i
i='󰝿' i_md_set_right=$i
i='󰞀' i_md_shield_half_full=$i
i='󰞁' i_md_sign_direction=$i
i='󰞂' i_md_sign_text=$i
i='󰞃' i_md_signal_off=$i
i='󰞄' i_md_square_root=$i
i='󰞅' i_md_sticker_emoji=$i
i='󰞆' i_md_summit=$i
i='󰞇' i_md_sword_cross=$i
i='󰞈' i_md_truck_fast=$i
i='󰞉' i_md_web_check=$i
i='󰞊' i_md_cast_off=$i
i='󰞋' i_md_help_box=$i
i='󰞌' i_md_timer_sand_full=$i
i='󰞍' i_md_waves=$i
i='󰞎' i_md_alarm_bell=$i
i='󰞏' i_md_alarm_light=$i
i='󰞐' i_md_video_switch_outline=$i
i='󰞑' i_md_check_decagram=$i
i='󰞒' i_md_arrow_collapse_down=$i
i='󰞓' i_md_arrow_collapse_left=$i
i='󰞔' i_md_arrow_collapse_right=$i
i='󰞕' i_md_arrow_collapse_up=$i
i='󰞖' i_md_arrow_expand_down=$i
i='󰞗' i_md_arrow_expand_left=$i
i='󰞘' i_md_arrow_expand_right=$i
i='󰞙' i_md_arrow_expand_up=$i
i='󰞚' i_md_book_lock=$i
i='󰞛' i_md_book_lock_open=$i
i='󰞜' i_md_bus_articulated_end=$i
i='󰞝' i_md_bus_articulated_front=$i
i='󰞞' i_md_bus_double_decker=$i
i='󰞟' i_md_bus_school=$i
i='󰞠' i_md_bus_side=$i
i='󰞡' i_md_camera_gopro=$i
i='󰞢' i_md_camera_metering_center=$i
i='󰞣' i_md_camera_metering_matrix=$i
i='󰞤' i_md_camera_metering_partial=$i
i='󰞥' i_md_camera_metering_spot=$i
i='󰞦' i_md_cannabis=$i
i='󰞧' i_md_car_convertible=$i
i='󰞨' i_md_car_estate=$i
i='󰞩' i_md_car_hatchback=$i
i='󰞪' i_md_car_pickup=$i
i='󰞫' i_md_car_side=$i
i='󰞬' i_md_car_sports=$i
i='󰞭' i_md_caravan=$i
i='󰞮' i_md_cctv=$i
i='󰞯' i_md_chart_donut=$i
i='󰞰' i_md_chart_donut_variant=$i
i='󰞱' i_md_chart_line_variant=$i
i='󰞲' i_md_chili_hot=$i
i='󰞳' i_md_chili_medium=$i
i='󰞴' i_md_chili_mild=$i
i='󰞵' i_md_cloud_braces=$i
i='󰞶' i_md_cloud_tags=$i
i='󰞷' i_md_console_line=$i
i='󰞸' i_md_corn=$i
i='󰞹' i_md_folder_zip_outline=$i
i='󰞺' i_md_currency_cny=$i
i='󰞻' i_md_currency_eth=$i
i='󰞼' i_md_currency_jpy=$i
i='󰞽' i_md_currency_krw=$i
i='󰞾' i_md_currency_sign=$i
i='󰞿' i_md_currency_twd=$i
i='󰟀' i_md_desktop_classic=$i
i='󰟁' i_md_dip_switch=$i
i='󰟂' i_md_donkey=$i
i='󰟃' i_md_dots_horizontal_circle=$i
i='󰟄' i_md_dots_vertical_circle=$i
i='󰟅' i_md_ear_hearing=$i
i='󰟆' i_md_elephant=$i
i='󰟇' i_md_storefront=$i
i='󰟈' i_md_food_croissant=$i
i='󰟉' i_md_forklift=$i
i='󰟊' i_md_fuel=$i
i='󰟋' i_md_gesture=$i
i='󰟌' i_md_google_analytics=$i
i='󰟍' i_md_google_assistant=$i
i='󰟎' i_md_headphones_off=$i
i='󰟏' i_md_high_definition=$i
i='󰟐' i_md_home_assistant=$i
i='󰟑' i_md_home_automation=$i
i='󰟒' i_md_home_circle=$i
i='󰟓' i_md_language_go=$i
i='󰟔' i_md_language_r=$i
i='󰟕' i_md_lava_lamp=$i
i='󰟖' i_md_led_strip=$i
i='󰟗' i_md_locker=$i
i='󰟘' i_md_locker_multiple=$i
i='󰟙' i_md_map_marker_outline=$i
i='󰟚' i_md_metronome=$i
i='󰟛' i_md_metronome_tick=$i
i='󰟜' i_md_micro_sd=$i
i='󰟝' i_md_facebook_gaming=$i
i='󰟞' i_md_movie_roll=$i
i='󰟟' i_md_mushroom=$i
i='󰟠' i_md_mushroom_outline=$i
i='󰟡' i_md_nintendo_switch=$i
i='󰟢' i_md_null=$i
i='󰟣' i_md_passport=$i
i='󰟤' i_md_molecule_co2=$i
i='󰟥' i_md_pipe=$i
i='󰟦' i_md_pipe_disconnected=$i
i='󰟧' i_md_power_socket_eu=$i
i='󰟨' i_md_power_socket_uk=$i
i='󰟩' i_md_power_socket_us=$i
i='󰟪' i_md_rice=$i
i='󰟫' i_md_ring=$i
i='󰟬' i_md_sass=$i
i='󰟭' i_md_send_lock=$i
i='󰟮' i_md_soy_sauce=$i
i='󰟯' i_md_standard_definition=$i
i='󰟰' i_md_surround_sound_2_0=$i
i='󰟱' i_md_surround_sound_3_1=$i
i='󰟲' i_md_surround_sound_5_1=$i
i='󰟳' i_md_surround_sound_7_1=$i
i='󰟴' i_md_television_classic=$i
i='󰟵' i_md_form_textbox_password=$i
i='󰟶' i_md_thought_bubble=$i
i='󰟷' i_md_thought_bubble_outline=$i
i='󰟸' i_md_trackpad=$i
i='󰟹' i_md_ultra_high_definition=$i
i='󰟺' i_md_van_passenger=$i
i='󰟻' i_md_van_utility=$i
i='󰟼' i_md_vanish=$i
i='󰟽' i_md_video_3d=$i
i='󰟾' i_md_wall=$i
i='󰟿' i_md_xmpp=$i
i='󰠀' i_md_account_multiple_plus_outline=$i
i='󰠁' i_md_account_plus_outline=$i
i='󰠂' i_md_credit_card_wireless=$i
i='󰠃' i_md_account_music=$i
i='󰠄' i_md_atlassian=$i
i='󰠅' i_md_microsoft_azure=$i
i='󰠆' i_md_basketball=$i
i='󰠇' i_md_battery_charging_wireless=$i
i='󰠈' i_md_battery_charging_wireless_10=$i
i='󰠉' i_md_battery_charging_wireless_20=$i
i='󰠊' i_md_battery_charging_wireless_30=$i
i='󰠋' i_md_battery_charging_wireless_40=$i
i='󰠌' i_md_battery_charging_wireless_50=$i
i='󰠍' i_md_battery_charging_wireless_60=$i
i='󰠎' i_md_battery_charging_wireless_70=$i
i='󰠏' i_md_battery_charging_wireless_80=$i
i='󰠐' i_md_battery_charging_wireless_90=$i
i='󰠑' i_md_battery_charging_wireless_alert=$i
i='󰠒' i_md_battery_charging_wireless_outline=$i
i='󰠓' i_md_bitcoin=$i
i='󰠔' i_md_briefcase_outline=$i
i='󰠕' i_md_cellphone_wireless=$i
i='󰠖' i_md_clover=$i
i='󰠗' i_md_comment_question=$i
i='󰠘' i_md_content_save_outline=$i
i='󰠙' i_md_delete_restore=$i
i='󰠚' i_md_door=$i
i='󰠛' i_md_door_closed=$i
i='󰠜' i_md_door_open=$i
i='󰠝' i_md_fan_off=$i
i='󰠞' i_md_file_percent=$i
i='󰠟' i_md_finance=$i
i='󰠠' i_md_lightning_bolt_circle=$i
i='󰠡' i_md_floor_plan=$i
i='󰠢' i_md_forum_outline=$i
i='󰠣' i_md_golf=$i
i='󰠤' i_md_google_home=$i
i='󰠥' i_md_guy_fawkes_mask=$i
i='󰠦' i_md_home_account=$i
i='󰠧' i_md_home_heart=$i
i='󰠨' i_md_hot_tub=$i
i='󰠩' i_md_hulu=$i
i='󰠪' i_md_ice_cream=$i
i='󰠫' i_md_image_off=$i
i='󰠬' i_md_karate=$i
i='󰠭' i_md_ladybug=$i
i='󰠮' i_md_notebook=$i
i='󰠯' i_md_phone_return=$i
i='󰠰' i_md_poker_chip=$i
i='󰠱' i_md_shape=$i
i='󰠲' i_md_shape_outline=$i
i='󰠳' i_md_ship_wheel=$i
i='󰠴' i_md_soccer_field=$i
i='󰠵' i_md_table_column=$i
i='󰠶' i_md_table_of_contents=$i
i='󰠷' i_md_table_row=$i
i='󰠸' i_md_table_settings=$i
i='󰠹' i_md_television_box=$i
i='󰠺' i_md_television_classic_off=$i
i='󰠻' i_md_television_off=$i
i='󰠼' i_md_tow_truck=$i
i='󰠽' i_md_upload_multiple=$i
i='󰠾' i_md_video_4k_box=$i
i='󰠿' i_md_video_input_antenna=$i
i='󰡀' i_md_video_input_component=$i
i='󰡁' i_md_video_input_hdmi=$i
i='󰡂' i_md_video_input_svideo=$i
i='󰡃' i_md_view_dashboard_variant=$i
i='󰡄' i_md_vuejs=$i
i='󰡅' i_md_xamarin=$i
i='󰡆' i_md_human_male_board_poll=$i
i='󰡇' i_md_youtube_studio=$i
i='󰡈' i_md_youtube_gaming=$i
i='󰡉' i_md_account_group=$i
i='󰡊' i_md_camera_switch_outline=$i
i='󰡋' i_md_airport=$i
i='󰡌' i_md_arrow_collapse_horizontal=$i
i='󰡍' i_md_arrow_collapse_vertical=$i
i='󰡎' i_md_arrow_expand_horizontal=$i
i='󰡏' i_md_arrow_expand_vertical=$i
i='󰡐' i_md_augmented_reality=$i
i='󰡑' i_md_badminton=$i
i='󰡒' i_md_baseball=$i
i='󰡓' i_md_baseball_bat=$i
i='󰡔' i_md_bottle_wine=$i
i='󰡕' i_md_check_outline=$i
i='󰡖' i_md_checkbox_intermediate=$i
i='󰡗' i_md_chess_king=$i
i='󰡘' i_md_chess_knight=$i
i='󰡙' i_md_chess_pawn=$i
i='󰡚' i_md_chess_queen=$i
i='󰡛' i_md_chess_rook=$i
i='󰡜' i_md_chess_bishop=$i
i='󰡝' i_md_clipboard_pulse=$i
i='󰡞' i_md_clipboard_pulse_outline=$i
i='󰡟' i_md_comment_multiple=$i
i='󰡠' i_md_comment_text_multiple=$i
i='󰡡' i_md_comment_text_multiple_outline=$i
i='󰡢' i_md_crane=$i
i='󰡣' i_md_curling=$i
i='󰡤' i_md_currency_bdt=$i
i='󰡥' i_md_currency_kzt=$i
i='󰡦' i_md_database_search=$i
i='󰡧' i_md_dice_d12_outline=$i
i='󰡨' i_md_docker=$i
i='󰡩' i_md_doorbell_video=$i
i='󰡪' i_md_ethereum=$i
i='󰡫' i_md_eye_plus=$i
i='󰡬' i_md_eye_plus_outline=$i
i='󰡭' i_md_eye_settings=$i
i='󰡮' i_md_eye_settings_outline=$i
i='󰡯' i_md_file_question=$i
i='󰡰' i_md_folder_network=$i
i='󰡱' i_md_function_variant=$i
i='󰡲' i_md_garage_alert=$i
i='󰡳' i_md_gauge_empty=$i
i='󰡴' i_md_gauge_full=$i
i='󰡵' i_md_gauge_low=$i
i='󰡶' i_md_glass_wine=$i
i='󰡷' i_md_graphql=$i
i='󰡸' i_md_high_definition_box=$i
i='󰡹' i_md_hockey_puck=$i
i='󰡺' i_md_hockey_sticks=$i
i='󰡻' i_md_home_alert=$i
i='󰡼' i_md_image_plus=$i
i='󰡽' i_md_jquery=$i
i='󰡾' i_md_lifebuoy=$i
i='󰡿' i_md_mixed_reality=$i
i='󰢀' i_md_nativescript=$i
i='󰢁' i_md_onepassword=$i
i='󰢂' i_md_patreon=$i
i='󰢃' i_md_close_circle_multiple_outline=$i
i='󰢄' i_md_peace=$i
i='󰢅' i_md_phone_rotate_landscape=$i
i='󰢆' i_md_phone_rotate_portrait=$i
i='󰢇' i_md_pier=$i
i='󰢈' i_md_pier_crane=$i
i='󰢉' i_md_pipe_leak=$i
i='󰢊' i_md_piston=$i
i='󰢋' i_md_play_network=$i
i='󰢌' i_md_reminder=$i
i='󰢍' i_md_room_service=$i
i='󰢎' i_md_salesforce=$i
i='󰢏' i_md_shield_account=$i
i='󰢐' i_md_human_male_board=$i
i='󰢑' i_md_thermostat_box=$i
i='󰢒' i_md_tractor=$i
i='󰢓' i_md_vector_ellipse=$i
i='󰢔' i_md_virtual_reality=$i
i='󰢕' i_md_watch_export_variant=$i
i='󰢖' i_md_watch_import_variant=$i
i='󰢗' i_md_watch_variant=$i
i='󰢘' i_md_weather_hurricane=$i
i='󰢙' i_md_account_heart=$i
i='󰢚' i_md_alien=$i
i='󰢛' i_md_anvil=$i
i='󰢜' i_md_battery_charging_10=$i
i='󰢝' i_md_battery_charging_50=$i
i='󰢞' i_md_battery_charging_70=$i
i='󰢟' i_md_battery_charging_outline=$i
i='󰢠' i_md_bed_empty=$i
i='󰢡' i_md_border_all_variant=$i
i='󰢢' i_md_border_bottom_variant=$i
i='󰢣' i_md_border_left_variant=$i
i='󰢤' i_md_border_none_variant=$i
i='󰢥' i_md_border_right_variant=$i
i='󰢦' i_md_border_top_variant=$i
i='󰢧' i_md_calendar_edit=$i
i='󰢨' i_md_clipboard_check_outline=$i
i='󰢩' i_md_console_network=$i
i='󰢪' i_md_file_compare=$i
i='󰢫' i_md_fire_truck=$i
i='󰢬' i_md_folder_key=$i
i='󰢭' i_md_folder_key_network=$i
i='󰢮' i_md_expansion_card=$i
i='󰢯' i_md_kayaking=$i
i='󰢰' i_md_inbox_multiple=$i
i='󰢱' i_md_language_lua=$i
i='󰢲' i_md_lock_smart=$i
i='󰢳' i_md_microphone_minus=$i
i='󰢴' i_md_microphone_plus=$i
i='󰢵' i_md_palette_swatch=$i
i='󰢶' i_md_periodic_table=$i
i='󰢷' i_md_pickaxe=$i
i='󰢸' i_md_qrcode_edit=$i
i='󰢹' i_md_remote_desktop=$i
i='󰢺' i_md_sausage=$i
i='󰢻' i_md_cog_outline=$i
i='󰢼' i_md_signal_cellular_1=$i
i='󰢽' i_md_signal_cellular_2=$i
i='󰢾' i_md_signal_cellular_3=$i
i='󰢿' i_md_signal_cellular_outline=$i
i='󰣀' i_md_ssh=$i
i='󰣁' i_md_swap_horizontal_variant=$i
i='󰣂' i_md_swap_vertical_variant=$i
i='󰣃' i_md_tooth=$i
i='󰣄' i_md_train_variant=$i
i='󰣅' i_md_account_multiple_check=$i
i='󰣆' i_md_application=$i
i='󰣇' i_md_arch=$i
i='󰣈' i_md_axe=$i
i='󰣉' i_md_bullseye_arrow=$i
i='󰣊' i_md_bus_clock=$i
i='󰣋' i_md_camera_account=$i
i='󰣌' i_md_camera_image=$i
i='󰣍' i_md_car_limousine=$i
i='󰣎' i_md_cards_club=$i
i='󰣏' i_md_cards_diamond=$i
i='󰣑' i_md_cards_spade=$i
i='󰣒' i_md_cellphone_text=$i
i='󰣓' i_md_cellphone_message=$i
i='󰣔' i_md_chart_multiline=$i
i='󰣕' i_md_circle_edit_outline=$i
i='󰣖' i_md_cogs=$i
i='󰣗' i_md_credit_card_settings_outline=$i
i='󰣘' i_md_death_star=$i
i='󰣙' i_md_death_star_variant=$i
i='󰣚' i_md_debian=$i
i='󰣛' i_md_fedora=$i
i='󰣜' i_md_file_undo=$i
i='󰣝' i_md_floor_lamp=$i
i='󰣞' i_md_folder_edit=$i
i='󰣟' i_md_format_columns=$i
i='󰣠' i_md_freebsd=$i
i='󰣡' i_md_gate_and=$i
i='󰣢' i_md_gate_nand=$i
i='󰣣' i_md_gate_nor=$i
i='󰣤' i_md_gate_not=$i
i='󰣥' i_md_gate_or=$i
i='󰣦' i_md_gate_xnor=$i
i='󰣧' i_md_gate_xor=$i
i='󰣨' i_md_gentoo=$i
i='󰣩' i_md_globe_model=$i
i='󰣪' i_md_hammer=$i
i='󰣫' i_md_home_lock=$i
i='󰣬' i_md_home_lock_open=$i
i='󰣭' i_md_linux_mint=$i
i='󰣮' i_md_lock_alert=$i
i='󰣯' i_md_lock_question=$i
i='󰣰' i_md_map_marker_distance=$i
i='󰣱' i_md_midi=$i
i='󰣲' i_md_midi_port=$i
i='󰣳' i_md_nas=$i
i='󰣴' i_md_network_strength_1=$i
i='󰣵' i_md_network_strength_1_alert=$i
i='󰣶' i_md_network_strength_2=$i
i='󰣷' i_md_network_strength_2_alert=$i
i='󰣸' i_md_network_strength_3=$i
i='󰣹' i_md_network_strength_3_alert=$i
i='󰣺' i_md_network_strength_4=$i
i='󰣻' i_md_network_strength_4_alert=$i
i='󰣼' i_md_network_strength_off=$i
i='󰣽' i_md_network_strength_off_outline=$i
i='󰣾' i_md_network_strength_outline=$i
i='󰣿' i_md_play_speed=$i
i='󰤀' i_md_playlist_edit=$i
i='󰤁' i_md_power_cycle=$i
i='󰤂' i_md_power_off=$i
i='󰤃' i_md_power_on=$i
i='󰤄' i_md_power_sleep=$i
i='󰤅' i_md_power_socket_au=$i
i='󰤆' i_md_power_standby=$i
i='󰤇' i_md_rabbit=$i
i='󰤈' i_md_robot_vacuum_variant=$i
i='󰤉' i_md_satellite_uplink=$i
i='󰤊' i_md_scanner_off=$i
i='󰤋' i_md_book_minus_multiple_outline=$i
i='󰤌' i_md_square_edit_outline=$i
i='󰤍' i_md_sort_numeric_ascending_variant=$i
i='󰤎' i_md_steering_off=$i
i='󰤏' i_md_table_search=$i
i='󰤐' i_md_tag_minus=$i
i='󰤑' i_md_test_tube_empty=$i
i='󰤒' i_md_test_tube_off=$i
i='󰤓' i_md_ticket_outline=$i
i='󰤔' i_md_track_light=$i
i='󰤕' i_md_transition=$i
i='󰤖' i_md_transition_masked=$i
i='󰤗' i_md_tumble_dryer=$i
i='󰤘' i_md_file_refresh=$i
i='󰤙' i_md_video_account=$i
i='󰤚' i_md_video_image=$i
i='󰤛' i_md_video_stabilization=$i
i='󰤜' i_md_wall_sconce=$i
i='󰤝' i_md_wall_sconce_flat=$i
i='󰤞' i_md_wall_sconce_round_variant=$i
i='󰤟' i_md_wifi_strength_1=$i
i='󰤠' i_md_wifi_strength_1_alert=$i
i='󰤡' i_md_wifi_strength_1_lock=$i
i='󰤢' i_md_wifi_strength_2=$i
i='󰤣' i_md_wifi_strength_2_alert=$i
i='󰤤' i_md_wifi_strength_2_lock=$i
i='󰤥' i_md_wifi_strength_3=$i
i='󰤦' i_md_wifi_strength_3_alert=$i
i='󰤧' i_md_wifi_strength_3_lock=$i
i='󰤨' i_md_wifi_strength_4=$i
i='󰤩' i_md_wifi_strength_4_alert=$i
i='󰤪' i_md_wifi_strength_4_lock=$i
i='󰤫' i_md_wifi_strength_alert_outline=$i
i='󰤬' i_md_wifi_strength_lock_outline=$i
i='󰤭' i_md_wifi_strength_off=$i
i='󰤮' i_md_wifi_strength_off_outline=$i
i='󰤯' i_md_wifi_strength_outline=$i
i='󰤰' i_md_pin_off_outline=$i
i='󰤱' i_md_pin_outline=$i
i='󰤲' i_md_share_outline=$i
i='󰤳' i_md_trackpad_lock=$i
i='󰤴' i_md_account_box_multiple=$i
i='󰤵' i_md_account_search_outline=$i
i='󰤶' i_md_account_filter=$i
i='󰤷' i_md_angle_acute=$i
i='󰤸' i_md_angle_obtuse=$i
i='󰤹' i_md_angle_right=$i
i='󰤺' i_md_animation_play=$i
i='󰤻' i_md_arrow_split_horizontal=$i
i='󰤼' i_md_arrow_split_vertical=$i
i='󰤽' i_md_audio_video=$i
i='󰤾' i_md_battery_10_bluetooth=$i
i='󰤿' i_md_battery_20_bluetooth=$i
i='󰥀' i_md_battery_30_bluetooth=$i
i='󰥁' i_md_battery_40_bluetooth=$i
i='󰥂' i_md_battery_50_bluetooth=$i
i='󰥃' i_md_battery_60_bluetooth=$i
i='󰥄' i_md_battery_70_bluetooth=$i
i='󰥅' i_md_battery_80_bluetooth=$i
i='󰥆' i_md_battery_90_bluetooth=$i
i='󰥇' i_md_battery_alert_bluetooth=$i
i='󰥈' i_md_battery_bluetooth=$i
i='󰥉' i_md_battery_bluetooth_variant=$i
i='󰥊' i_md_battery_unknown_bluetooth=$i
i='󰥋' i_md_dharmachakra=$i
i='󰥌' i_md_calendar_search=$i
i='󰥍' i_md_cellphone_remove=$i
i='󰥎' i_md_cellphone_key=$i
i='󰥏' i_md_cellphone_lock=$i
i='󰥐' i_md_cellphone_off=$i
i='󰥑' i_md_cellphone_cog=$i
i='󰥒' i_md_cellphone_sound=$i
i='󰥓' i_md_cross=$i
i='󰥔' i_md_clock=$i
i='󰥕' i_md_clock_alert=$i
i='󰥖' i_md_cloud_search=$i
i='󰥗' i_md_cloud_search_outline=$i
i='󰥘' i_md_cordova=$i
i='󰥙' i_md_cryengine=$i
i='󰥚' i_md_cupcake=$i
i='󰥛' i_md_sine_wave=$i
i='󰥜' i_md_current_dc=$i
i='󰥝' i_md_database_import=$i
i='󰥞' i_md_database_export=$i
i='󰥟' i_md_desk_lamp=$i
i='󰥠' i_md_disc_player=$i
i='󰥡' i_md_email_search=$i
i='󰥢' i_md_email_search_outline=$i
i='󰥣' i_md_exponent=$i
i='󰥤' i_md_exponent_box=$i
i='󰥥' i_md_file_download=$i
i='󰥦' i_md_file_download_outline=$i
i='󰥧' i_md_firebase=$i
i='󰥨' i_md_folder_search=$i
i='󰥩' i_md_folder_search_outline=$i
i='󰥪' i_md_format_list_checkbox=$i
i='󰥫' i_md_fountain=$i
i='󰥬' i_md_google_fit=$i
i='󰥭' i_md_greater_than=$i
i='󰥮' i_md_greater_than_or_equal=$i
i='󰥯' i_md_hard_hat=$i
i='󰥰' i_md_headphones_bluetooth=$i
i='󰥱' i_md_heart_circle=$i
i='󰥲' i_md_heart_circle_outline=$i
i='󰥳' i_md_om=$i
i='󰥴' i_md_home_minus=$i
i='󰥵' i_md_home_plus=$i
i='󰥶' i_md_image_outline=$i
i='󰥷' i_md_image_search=$i
i='󰥸' i_md_image_search_outline=$i
i='󰥹' i_md_star_crescent=$i
i='󰥺' i_md_star_david=$i
i='󰥻' i_md_keyboard_outline=$i
i='󰥼' i_md_less_than=$i
i='󰥽' i_md_less_than_or_equal=$i
i='󰥾' i_md_light_switch=$i
i='󰥿' i_md_lock_clock=$i
i='󰦀' i_md_magnify_close=$i
i='󰦁' i_md_map_minus=$i
i='󰦂' i_md_map_outline=$i
i='󰦃' i_md_map_plus=$i
i='󰦄' i_md_map_search=$i
i='󰦅' i_md_map_search_outline=$i
i='󰦆' i_md_material_design=$i
i='󰦇' i_md_medal=$i
i='󰦈' i_md_microsoft_dynamics_365=$i
i='󰦉' i_md_monitor_cellphone=$i
i='󰦊' i_md_monitor_cellphone_star=$i
i='󰦋' i_md_mouse_bluetooth=$i
i='󰦌' i_md_muffin=$i
i='󰦍' i_md_not_equal=$i
i='󰦎' i_md_not_equal_variant=$i
i='󰦏' i_md_order_bool_ascending_variant=$i
i='󰦐' i_md_order_bool_descending_variant=$i
i='󰦑' i_md_office_building=$i
i='󰦒' i_md_plus_minus=$i
i='󰦓' i_md_plus_minus_box=$i
i='󰦔' i_md_podcast=$i
i='󰦕' i_md_progress_check=$i
i='󰦖' i_md_progress_clock=$i
i='󰦗' i_md_progress_download=$i
i='󰦘' i_md_progress_upload=$i
i='󰦙' i_md_qi=$i
i='󰦚' i_md_record_player=$i
i='󰦛' i_md_restore=$i
i='󰦜' i_md_shield_off_outline=$i
i='󰦝' i_md_shield_lock=$i
i='󰦞' i_md_shield_off=$i
i='󰦟' i_md_set_top_box=$i
i='󰦠' i_md_shower=$i
i='󰦡' i_md_shower_head=$i
i='󰦢' i_md_speaker_bluetooth=$i
i='󰦣' i_md_square_root_box=$i
i='󰦤' i_md_star_circle_outline=$i
i='󰦥' i_md_star_face=$i
i='󰦦' i_md_table_merge_cells=$i
i='󰦧' i_md_tablet_cellphone=$i
i='󰦨' i_md_text=$i
i='󰦩' i_md_text_short=$i
i='󰦪' i_md_text_long=$i
i='󰦫' i_md_toilet=$i
i='󰦬' i_md_toolbox=$i
i='󰦭' i_md_toolbox_outline=$i
i='󰦮' i_md_tournament=$i
i='󰦯' i_md_two_factor_authentication=$i
i='󰦰' i_md_umbrella_closed=$i
i='󰦱' i_md_unreal=$i
i='󰦲' i_md_video_minus=$i
i='󰦳' i_md_video_plus=$i
i='󰦴' i_md_volleyball=$i
i='󰦵' i_md_weight_pound=$i
i='󰦶' i_md_whistle=$i
i='󰦷' i_md_arrow_bottom_left_bold_outline=$i
i='󰦸' i_md_arrow_bottom_left_thick=$i
i='󰦹' i_md_arrow_bottom_right_bold_outline=$i
i='󰦺' i_md_arrow_bottom_right_thick=$i
i='󰦻' i_md_arrow_decision=$i
i='󰦼' i_md_arrow_decision_auto=$i
i='󰦽' i_md_arrow_decision_auto_outline=$i
i='󰦾' i_md_arrow_decision_outline=$i
i='󰦿' i_md_arrow_down_bold_outline=$i
i='󰧀' i_md_arrow_left_bold_outline=$i
i='󰧁' i_md_arrow_left_right_bold_outline=$i
i='󰧂' i_md_arrow_right_bold_outline=$i
i='󰧃' i_md_arrow_top_left_bold_outline=$i
i='󰧄' i_md_arrow_top_left_thick=$i
i='󰧅' i_md_arrow_top_right_bold_outline=$i
i='󰧆' i_md_arrow_top_right_thick=$i
i='󰧇' i_md_arrow_up_bold_outline=$i
i='󰧈' i_md_arrow_up_down_bold_outline=$i
i='󰧉' i_md_ballot=$i
i='󰧊' i_md_ballot_outline=$i
i='󰧋' i_md_betamax=$i
i='󰧌' i_md_bookmark_minus=$i
i='󰧍' i_md_bookmark_minus_outline=$i
i='󰧎' i_md_bookmark_off=$i
i='󰧏' i_md_bookmark_off_outline=$i
i='󰧐' i_md_braille=$i
i='󰧑' i_md_brain=$i
i='󰧒' i_md_calendar_heart=$i
i='󰧓' i_md_calendar_star=$i
i='󰧔' i_md_cassette=$i
i='󰧕' i_md_cellphone_arrow_down=$i
i='󰧖' i_md_chevron_down_box=$i
i='󰧗' i_md_chevron_down_box_outline=$i
i='󰧘' i_md_chevron_left_box=$i
i='󰧙' i_md_chevron_left_box_outline=$i
i='󰧚' i_md_chevron_right_box=$i
i='󰧛' i_md_chevron_right_box_outline=$i
i='󰧜' i_md_chevron_up_box=$i
i='󰧝' i_md_chevron_up_box_outline=$i
i='󰧞' i_md_circle_medium=$i
i='󰧟' i_md_circle_small=$i
i='󰧠' i_md_cloud_alert=$i
i='󰧡' i_md_comment_arrow_left=$i
i='󰧢' i_md_comment_arrow_left_outline=$i
i='󰧣' i_md_comment_arrow_right=$i
i='󰧤' i_md_comment_arrow_right_outline=$i
i='󰧥' i_md_comment_plus=$i
i='󰧦' i_md_currency_php=$i
i='󰧧' i_md_delete_outline=$i
i='󰧨' i_md_desktop_mac_dashboard=$i
i='󰧩' i_md_download_multiple=$i
i='󰧪' i_md_eight_track=$i
i='󰧫' i_md_email_plus=$i
i='󰧬' i_md_email_plus_outline=$i
i='󰧭' i_md_text_box_outline=$i
i='󰧮' i_md_file_document_outline=$i
i='󰧯' i_md_floppy_variant=$i
i='󰧰' i_md_flower_outline=$i
i='󰧱' i_md_flower_tulip=$i
i='󰧲' i_md_flower_tulip_outline=$i
i='󰧳' i_md_format_font_size_decrease=$i
i='󰧴' i_md_format_font_size_increase=$i
i='󰧵' i_md_ghost_off=$i
i='󰧶' i_md_google_lens=$i
i='󰧷' i_md_google_spreadsheet=$i
i='󰧸' i_md_image_move=$i
i='󰧹' i_md_keyboard_settings=$i
i='󰧺' i_md_keyboard_settings_outline=$i
i='󰧻' i_md_knife=$i
i='󰧼' i_md_knife_military=$i
i='󰧽' i_md_layers_off_outline=$i
i='󰧾' i_md_layers_outline=$i
i='󰧿' i_md_lighthouse=$i
i='󰨀' i_md_lighthouse_on=$i
i='󰨁' i_md_map_legend=$i
i='󰨂' i_md_menu_left_outline=$i
i='󰨃' i_md_menu_right_outline=$i
i='󰨄' i_md_message_alert_outline=$i
i='󰨅' i_md_mini_sd=$i
i='󰨆' i_md_minidisc=$i
i='󰨇' i_md_monitor_dashboard=$i
i='󰨈' i_md_pirate=$i
i='󰨉' i_md_pokemon_go=$i
i='󰨊' i_md_powershell=$i
i='󰨋' i_md_printer_wireless=$i
i='󰨌' i_md_quality_low=$i
i='󰨍' i_md_quality_medium=$i
i='󰨎' i_md_reflect_horizontal=$i
i='󰨏' i_md_reflect_vertical=$i
i='󰨐' i_md_rhombus_medium=$i
i='󰨑' i_md_rhombus_split=$i
i='󰨒' i_md_shield_account_outline=$i
i='󰨓' i_md_square_medium=$i
i='󰨔' i_md_square_medium_outline=$i
i='󰨕' i_md_square_small=$i
i='󰨖' i_md_subtitles=$i
i='󰨗' i_md_subtitles_outline=$i
i='󰨘' i_md_table_border=$i
i='󰨙' i_md_toggle_switch_off_outline=$i
i='󰨚' i_md_toggle_switch_outline=$i
i='󰨛' i_md_vhs=$i
i='󰨜' i_md_video_vintage=$i
i='󰨝' i_md_view_dashboard_outline=$i
i='󰨞' i_md_microsoft_visual_studio_code=$i
i='󰨟' i_md_vote=$i
i='󰨠' i_md_vote_outline=$i
i='󰨡' i_md_microsoft_windows_classic=$i
i='󰨢' i_md_microsoft_xbox_controller_battery_charging=$i
i='󰨣' i_md_zip_disk=$i
i='󰨤' i_md_aspect_ratio=$i
i='󰨥' i_md_babel=$i
i='󰨦' i_md_balloon=$i
i='󰨧' i_md_bank_transfer=$i
i='󰨨' i_md_bank_transfer_in=$i
i='󰨩' i_md_bank_transfer_out=$i
i='󰨪' i_md_briefcase_minus=$i
i='󰨫' i_md_briefcase_plus=$i
i='󰨬' i_md_briefcase_remove=$i
i='󰨭' i_md_briefcase_search=$i
i='󰨮' i_md_bug_check=$i
i='󰨯' i_md_bug_check_outline=$i
i='󰨰' i_md_bug_outline=$i
i='󰨱' i_md_calendar_alert=$i
i='󰨲' i_md_calendar_multiselect=$i
i='󰨳' i_md_calendar_week=$i
i='󰨴' i_md_calendar_week_begin=$i
i='󰨵' i_md_cellphone_screenshot=$i
i='󰨶' i_md_city_variant=$i
i='󰨷' i_md_city_variant_outline=$i
i='󰨸' i_md_clipboard_text_outline=$i
i='󰨹' i_md_cloud_question=$i
i='󰨺' i_md_comment_eye=$i
i='󰨻' i_md_comment_eye_outline=$i
i='󰨼' i_md_comment_search=$i
i='󰨽' i_md_comment_search_outline=$i
i='󰨾' i_md_contain=$i
i='󰨿' i_md_contain_end=$i
i='󰩀' i_md_contain_start=$i
i='󰩁' i_md_dlna=$i
i='󰩂' i_md_doctor=$i
i='󰩃' i_md_dog=$i
i='󰩄' i_md_dog_side=$i
i='󰩅' i_md_ear_hearing_off=$i
i='󰩆' i_md_engine_off=$i
i='󰩇' i_md_engine_off_outline=$i
i='󰩈' i_md_exit_run=$i
i='󰩉' i_md_feature_search=$i
i='󰩊' i_md_feature_search_outline=$i
i='󰩋' i_md_file_alert=$i
i='󰩌' i_md_file_alert_outline=$i
i='󰩍' i_md_file_upload=$i
i='󰩎' i_md_file_upload_outline=$i
i='󰩏' i_md_hand_front_right=$i
i='󰩐' i_md_hand_okay=$i
i='󰩑' i_md_hand_peace=$i
i='󰩒' i_md_hand_peace_variant=$i
i='󰩓' i_md_hand_pointing_down=$i
i='󰩔' i_md_hand_pointing_left=$i
i='󰩕' i_md_hand_pointing_up=$i
i='󰩖' i_md_heart_multiple=$i
i='󰩗' i_md_heart_multiple_outline=$i
i='󰩘' i_md_horseshoe=$i
i='󰩙' i_md_human_female_boy=$i
i='󰩚' i_md_human_female_female=$i
i='󰩛' i_md_human_female_girl=$i
i='󰩜' i_md_human_male_boy=$i
i='󰩝' i_md_human_male_girl=$i
i='󰩞' i_md_human_male_male=$i
i='󰩟' i_md_ip=$i
i='󰩠' i_md_ip_network=$i
i='󰩡' i_md_litecoin=$i
i='󰩢' i_md_magnify_minus_cursor=$i
i='󰩣' i_md_magnify_plus_cursor=$i
i='󰩤' i_md_menu_swap=$i
i='󰩥' i_md_menu_swap_outline=$i
i='󰩦' i_md_puzzle_outline=$i
i='󰩧' i_md_registered_trademark=$i
i='󰩨' i_md_resize=$i
i='󰩩' i_md_router_wireless_settings=$i
i='󰩪' i_md_safe=$i
i='󰩫' i_md_scissors_cutting=$i
i='󰩬' i_md_select_drag=$i
i='󰩭' i_md_selection_drag=$i
i='󰩮' i_md_settings_helper=$i
i='󰩯' i_md_signal_5g=$i
i='󰩰' i_md_silverware_fork_knife=$i
i='󰩱' i_md_smog=$i
i='󰩲' i_md_solar_power=$i
i='󰩳' i_md_star_box=$i
i='󰩴' i_md_star_box_outline=$i
i='󰩵' i_md_table_plus=$i
i='󰩶' i_md_table_remove=$i
i='󰩷' i_md_target_variant=$i
i='󰩸' i_md_trademark=$i
i='󰩹' i_md_trash_can=$i
i='󰩺' i_md_trash_can_outline=$i
i='󰩻' i_md_tshirt_crew=$i
i='󰩼' i_md_tshirt_v=$i
i='󰩽' i_md_zodiac_aquarius=$i
i='󰩾' i_md_zodiac_aries=$i
i='󰩿' i_md_zodiac_cancer=$i
i='󰪀' i_md_zodiac_capricorn=$i
i='󰪁' i_md_zodiac_gemini=$i
i='󰪂' i_md_zodiac_leo=$i
i='󰪃' i_md_zodiac_libra=$i
i='󰪄' i_md_zodiac_pisces=$i
i='󰪅' i_md_zodiac_sagittarius=$i
i='󰪆' i_md_zodiac_scorpio=$i
i='󰪇' i_md_zodiac_taurus=$i
i='󰪈' i_md_zodiac_virgo=$i
i='󰪉' i_md_account_child=$i
i='󰪊' i_md_account_child_circle=$i
i='󰪋' i_md_account_supervisor=$i
i='󰪌' i_md_account_supervisor_circle=$i
i='󰪍' i_md_ampersand=$i
i='󰪎' i_md_web_off=$i
i='󰪏' i_md_animation_outline=$i
i='󰪐' i_md_animation_play_outline=$i
i='󰪑' i_md_bell_off_outline=$i
i='󰪒' i_md_bell_plus_outline=$i
i='󰪓' i_md_bell_sleep_outline=$i
i='󰪔' i_md_book_minus_multiple=$i
i='󰪕' i_md_book_plus_multiple=$i
i='󰪖' i_md_book_remove_multiple=$i
i='󰪗' i_md_book_remove=$i
i='󰪘' i_md_briefcase_edit=$i
i='󰪙' i_md_bus_alert=$i
i='󰪚' i_md_calculator_variant=$i
i='󰪛' i_md_caps_lock=$i
i='󰪜' i_md_cash_refund=$i
i='󰪝' i_md_checkbook=$i
i='󰪞' i_md_circle_slice_1=$i
i='󰪟' i_md_circle_slice_2=$i
i='󰪠' i_md_circle_slice_3=$i
i='󰪡' i_md_circle_slice_4=$i
i='󰪢' i_md_circle_slice_5=$i
i='󰪣' i_md_circle_slice_6=$i
i='󰪤' i_md_circle_slice_7=$i
i='󰪥' i_md_circle_slice_8=$i
i='󰪦' i_md_collapse_all=$i
i='󰪧' i_md_collapse_all_outline=$i
i='󰪨' i_md_credit_card_refund_outline=$i
i='󰪩' i_md_database_check=$i
i='󰪪' i_md_database_lock=$i
i='󰪫' i_md_desktop_tower_monitor=$i
i='󰪬' i_md_dishwasher=$i
i='󰪭' i_md_dog_service=$i
i='󰪮' i_md_dot_net=$i
i='󰪯' i_md_egg=$i
i='󰪰' i_md_egg_easter=$i
i='󰪱' i_md_email_check=$i
i='󰪲' i_md_email_check_outline=$i
i='󰪳' i_md_et=$i
i='󰪴' i_md_expand_all=$i
i='󰪵' i_md_expand_all_outline=$i
i='󰪶' i_md_file_cabinet=$i
i='󰪷' i_md_text_box_multiple=$i
i='󰪸' i_md_text_box_multiple_outline=$i
i='󰪹' i_md_file_move=$i
i='󰪺' i_md_folder_clock=$i
i='󰪻' i_md_folder_clock_outline=$i
i='󰪼' i_md_format_annotation_minus=$i
i='󰪽' i_md_gesture_pinch=$i
i='󰪾' i_md_gesture_spread=$i
i='󰪿' i_md_gesture_swipe_horizontal=$i
i='󰫀' i_md_gesture_swipe_vertical=$i
i='󰫁' i_md_hail=$i
i='󰫂' i_md_helicopter=$i
i='󰫃' i_md_hexagon_slice_1=$i
i='󰫄' i_md_hexagon_slice_2=$i
i='󰫅' i_md_hexagon_slice_3=$i
i='󰫆' i_md_hexagon_slice_4=$i
i='󰫇' i_md_hexagon_slice_5=$i
i='󰫈' i_md_hexagon_slice_6=$i
i='󰫉' i_md_hexagram=$i
i='󰫊' i_md_hexagram_outline=$i
i='󰫋' i_md_label_off=$i
i='󰫌' i_md_label_off_outline=$i
i='󰫍' i_md_label_variant=$i
i='󰫎' i_md_label_variant_outline=$i
i='󰫏' i_md_language_ruby_on_rails=$i
i='󰫐' i_md_laravel=$i
i='󰫑' i_md_mastodon=$i
i='󰫒' i_md_sort_numeric_descending_variant=$i
i='󰫓' i_md_minus_circle_multiple_outline=$i
i='󰫔' i_md_music_circle_outline=$i
i='󰫕' i_md_pinwheel=$i
i='󰫖' i_md_pinwheel_outline=$i
i='󰫗' i_md_radiator_disabled=$i
i='󰫘' i_md_radiator_off=$i
i='󰫙' i_md_select_compare=$i
i='󰫚' i_md_shield_plus=$i
i='󰫛' i_md_shield_plus_outline=$i
i='󰫜' i_md_shield_remove=$i
i='󰫝' i_md_shield_remove_outline=$i
i='󰫞' i_md_book_plus_multiple_outline=$i
i='󰫟' i_md_sina_weibo=$i
i='󰫠' i_md_spray_bottle=$i
i='󰫡' i_md_squeegee=$i
i='󰫢' i_md_star_four_points=$i
i='󰫣' i_md_star_four_points_outline=$i
i='󰫤' i_md_star_three_points=$i
i='󰫥' i_md_star_three_points_outline=$i
i='󰫦' i_md_symfony=$i
i='󰫧' i_md_variable=$i
i='󰫨' i_md_vector_bezier=$i
i='󰫩' i_md_wiper=$i
i='󰫪' i_md_z_wave=$i
i='󰫫' i_md_zend=$i
i='󰫬' i_md_account_minus_outline=$i
i='󰫭' i_md_account_remove_outline=$i
i='󰫮' i_md_alpha_a=$i
i='󰫯' i_md_alpha_b=$i
i='󰫰' i_md_alpha_c=$i
i='󰫱' i_md_alpha_d=$i
i='󰫲' i_md_alpha_e=$i
i='󰫳' i_md_alpha_f=$i
i='󰫴' i_md_alpha_g=$i
i='󰫵' i_md_alpha_h=$i
i='󰫶' i_md_alpha_i=$i
i='󰫷' i_md_alpha_j=$i
i='󰫸' i_md_alpha_k=$i
i='󰫹' i_md_alpha_l=$i
i='󰫺' i_md_alpha_m=$i
i='󰫻' i_md_alpha_n=$i
i='󰫼' i_md_alpha_o=$i
i='󰫽' i_md_alpha_p=$i
i='󰫾' i_md_alpha_q=$i
i='󰫿' i_md_alpha_r=$i
i='󰬀' i_md_alpha_s=$i
i='󰬁' i_md_alpha_t=$i
i='󰬂' i_md_alpha_u=$i
i='󰬃' i_md_alpha_v=$i
i='󰬄' i_md_alpha_w=$i
i='󰬅' i_md_alpha_x=$i
i='󰬆' i_md_alpha_y=$i
i='󰬇' i_md_alpha_z=$i
i='󰬈' i_md_alpha_a_box=$i
i='󰬉' i_md_alpha_b_box=$i
i='󰬊' i_md_alpha_c_box=$i
i='󰬋' i_md_alpha_d_box=$i
i='󰬌' i_md_alpha_e_box=$i
i='󰬍' i_md_alpha_f_box=$i
i='󰬎' i_md_alpha_g_box=$i
i='󰬏' i_md_alpha_h_box=$i
i='󰬐' i_md_alpha_i_box=$i
i='󰬑' i_md_alpha_j_box=$i
i='󰬒' i_md_alpha_k_box=$i
i='󰬓' i_md_alpha_l_box=$i
i='󰬔' i_md_alpha_m_box=$i
i='󰬕' i_md_alpha_n_box=$i
i='󰬖' i_md_alpha_o_box=$i
i='󰬗' i_md_alpha_p_box=$i
i='󰬘' i_md_alpha_q_box=$i
i='󰬙' i_md_alpha_r_box=$i
i='󰬚' i_md_alpha_s_box=$i
i='󰬛' i_md_alpha_t_box=$i
i='󰬜' i_md_alpha_u_box=$i
i='󰬝' i_md_alpha_v_box=$i
i='󰬞' i_md_alpha_w_box=$i
i='󰬟' i_md_alpha_x_box=$i
i='󰬠' i_md_alpha_y_box=$i
i='󰬡' i_md_alpha_z_box=$i
i='󰬢' i_md_bulldozer=$i
i='󰬣' i_md_bullhorn_outline=$i
i='󰬤' i_md_calendar_export=$i
i='󰬥' i_md_calendar_import=$i
i='󰬦' i_md_chevron_down_circle=$i
i='󰬧' i_md_chevron_down_circle_outline=$i
i='󰬨' i_md_chevron_left_circle=$i
i='󰬩' i_md_chevron_left_circle_outline=$i
i='󰬪' i_md_chevron_right_circle=$i
i='󰬫' i_md_chevron_right_circle_outline=$i
i='󰬬' i_md_chevron_up_circle=$i
i='󰬭' i_md_chevron_up_circle_outline=$i
i='󰬮' i_md_content_save_settings_outline=$i
i='󰬯' i_md_crystal_ball=$i
i='󰬰' i_md_ember=$i
i='󰬱' i_md_facebook_workplace=$i
i='󰬲' i_md_file_replace=$i
i='󰬳' i_md_file_replace_outline=$i
i='󰬴' i_md_format_letter_case=$i
i='󰬵' i_md_format_letter_case_lower=$i
i='󰬶' i_md_format_letter_case_upper=$i
i='󰬷' i_md_language_java=$i
i='󰬸' i_md_circle_multiple=$i
i='󰬺' i_md_numeric_1=$i
i='󰬻' i_md_numeric_2=$i
i='󰬼' i_md_numeric_3=$i
i='󰬽' i_md_numeric_4=$i
i='󰬾' i_md_numeric_5=$i
i='󰬿' i_md_numeric_6=$i
i='󰭀' i_md_numeric_7=$i
i='󰭁' i_md_numeric_8=$i
i='󰭂' i_md_numeric_9=$i
i='󰭃' i_md_origin=$i
i='󰭄' i_md_resistor=$i
i='󰭅' i_md_resistor_nodes=$i
i='󰭆' i_md_robot_industrial=$i
i='󰭇' i_md_shoe_formal=$i
i='󰭈' i_md_shoe_heel=$i
i='󰭉' i_md_silo=$i
i='󰭊' i_md_box_cutter_off=$i
i='󰭋' i_md_tab_minus=$i
i='󰭌' i_md_tab_remove=$i
i='󰭍' i_md_tape_measure=$i
i='󰭎' i_md_telescope=$i
i='󰭏' i_md_yahoo=$i
i='󰭐' i_md_account_alert_outline=$i
i='󰭑' i_md_account_arrow_left=$i
i='󰭒' i_md_account_arrow_left_outline=$i
i='󰭓' i_md_account_arrow_right=$i
i='󰭔' i_md_account_arrow_right_outline=$i
i='󰭕' i_md_account_circle_outline=$i
i='󰭖' i_md_account_clock=$i
i='󰭗' i_md_account_clock_outline=$i
i='󰭘' i_md_account_group_outline=$i
i='󰭙' i_md_account_question=$i
i='󰭚' i_md_account_question_outline=$i
i='󰭛' i_md_artstation=$i
i='󰭜' i_md_backspace_outline=$i
i='󰭝' i_md_barley_off=$i
i='󰭞' i_md_barn=$i
i='󰭟' i_md_bat=$i
i='󰭠' i_md_application_settings=$i
i='󰭡' i_md_billiards=$i
i='󰭢' i_md_billiards_rack=$i
i='󰭣' i_md_book_open_outline=$i
i='󰭤' i_md_book_outline=$i
i='󰭥' i_md_boxing_glove=$i
i='󰭦' i_md_calendar_blank_outline=$i
i='󰭧' i_md_calendar_outline=$i
i='󰭨' i_md_calendar_range_outline=$i
i='󰭩' i_md_camera_control=$i
i='󰭪' i_md_camera_enhance_outline=$i
i='󰭫' i_md_car_door=$i
i='󰭬' i_md_car_electric=$i
i='󰭭' i_md_car_key=$i
i='󰭮' i_md_car_multiple=$i
i='󰭯' i_md_card=$i
i='󰭰' i_md_card_bulleted=$i
i='󰭱' i_md_card_bulleted_off=$i
i='󰭲' i_md_card_bulleted_off_outline=$i
i='󰭳' i_md_card_bulleted_outline=$i
i='󰭴' i_md_card_bulleted_settings=$i
i='󰭵' i_md_card_bulleted_settings_outline=$i
i='󰭶' i_md_card_outline=$i
i='󰭷' i_md_card_text=$i
i='󰭸' i_md_card_text_outline=$i
i='󰭹' i_md_chat=$i
i='󰭺' i_md_chat_alert=$i
i='󰭻' i_md_chat_processing=$i
i='󰭼' i_md_chef_hat=$i
i='󰭽' i_md_cloud_download_outline=$i
i='󰭾' i_md_cloud_upload_outline=$i
i='󰭿' i_md_coffin=$i
i='󰮀' i_md_compass_off=$i
i='󰮁' i_md_compass_off_outline=$i
i='󰮂' i_md_controller_classic=$i
i='󰮃' i_md_controller_classic_outline=$i
i='󰮄' i_md_cube_scan=$i
i='󰮅' i_md_currency_brl=$i
i='󰮆' i_md_database_edit=$i
i='󰮇' i_md_deathly_hallows=$i
i='󰮈' i_md_delete_circle_outline=$i
i='󰮉' i_md_delete_forever_outline=$i
i='󰮊' i_md_diamond=$i
i='󰮋' i_md_diamond_outline=$i
i='󰮌' i_md_dns_outline=$i
i='󰮍' i_md_dots_horizontal_circle_outline=$i
i='󰮎' i_md_dots_vertical_circle_outline=$i
i='󰮏' i_md_download_outline=$i
i='󰮐' i_md_drag_variant=$i
i='󰮑' i_md_eject_outline=$i
i='󰮒' i_md_email_mark_as_unread=$i
i='󰮓' i_md_export_variant=$i
i='󰮔' i_md_eye_circle=$i
i='󰮕' i_md_eye_circle_outline=$i
i='󰮖' i_md_face_man_outline=$i
i='󰮗' i_md_file_find_outline=$i
i='󰮘' i_md_file_remove=$i
i='󰮙' i_md_flag_minus=$i
i='󰮚' i_md_flag_plus=$i
i='󰮛' i_md_flag_remove=$i
i='󰮜' i_md_folder_account_outline=$i
i='󰮝' i_md_folder_plus_outline=$i
i='󰮞' i_md_folder_remove_outline=$i
i='󰮟' i_md_folder_star_outline=$i
i='󰮠' i_md_gitlab=$i
i='󰮡' i_md_gog=$i
i='󰮢' i_md_grave_stone=$i
i='󰮣' i_md_halloween=$i
i='󰮤' i_md_hat_fedora=$i
i='󰮥' i_md_help_rhombus=$i
i='󰮦' i_md_help_rhombus_outline=$i
i='󰮧' i_md_home_variant_outline=$i
i='󰮨' i_md_inbox_multiple_outline=$i
i='󰮩' i_md_library_shelves=$i
i='󰮪' i_md_mapbox=$i
i='󰮫' i_md_menu_open=$i
i='󰮬' i_md_molecule=$i
i='󰮭' i_md_one_up=$i
i='󰮮' i_md_open_source_initiative=$i
i='󰮯' i_md_pac_man=$i
i='󰮰' i_md_page_next=$i
i='󰮱' i_md_page_next_outline=$i
i='󰮲' i_md_page_previous=$i
i='󰮳' i_md_page_previous_outline=$i
i='󰮴' i_md_pan=$i
i='󰮵' i_md_pan_bottom_left=$i
i='󰮶' i_md_pan_bottom_right=$i
i='󰮷' i_md_pan_down=$i
i='󰮸' i_md_pan_horizontal=$i
i='󰮹' i_md_pan_left=$i
i='󰮺' i_md_pan_right=$i
i='󰮻' i_md_pan_top_left=$i
i='󰮼' i_md_pan_top_right=$i
i='󰮽' i_md_pan_up=$i
i='󰮾' i_md_pan_vertical=$i
i='󰮿' i_md_pumpkin=$i
i='󰯀' i_md_rollupjs=$i
i='󰯁' i_md_script=$i
i='󰯂' i_md_script_text=$i
i='󰯃' i_md_script_text_outline=$i
i='󰯄' i_md_shield_key=$i
i='󰯅' i_md_shield_key_outline=$i
i='󰯆' i_md_skull_crossbones=$i
i='󰯇' i_md_skull_crossbones_outline=$i
i='󰯈' i_md_skull_outline=$i
i='󰯉' i_md_space_invaders=$i
i='󰯊' i_md_spider_web=$i
i='󰯋' i_md_view_split_horizontal=$i
i='󰯌' i_md_view_split_vertical=$i
i='󰯍' i_md_swap_horizontal_bold=$i
i='󰯎' i_md_swap_vertical_bold=$i
i='󰯏' i_md_tag_heart_outline=$i
i='󰯐' i_md_target_account=$i
i='󰯑' i_md_timeline=$i
i='󰯒' i_md_timeline_outline=$i
i='󰯓' i_md_timeline_text=$i
i='󰯔' i_md_timeline_text_outline=$i
i='󰯕' i_md_tooltip_image_outline=$i
i='󰯖' i_md_tooltip_plus=$i
i='󰯗' i_md_tooltip_text_outline=$i
i='󰯘' i_md_train_car=$i
i='󰯙' i_md_triforce=$i
i='󰯚' i_md_ubisoft=$i
i='󰯛' i_md_video_off_outline=$i
i='󰯜' i_md_video_outline=$i
i='󰯝' i_md_wallet_outline=$i
i='󰯞' i_md_waze=$i
i='󰯟' i_md_wrap_disabled=$i
i='󰯠' i_md_wrench_outline=$i
i='󰯡' i_md_access_point_network_off=$i
i='󰯢' i_md_account_check_outline=$i
i='󰯣' i_md_account_heart_outline=$i
i='󰯤' i_md_account_key_outline=$i
i='󰯥' i_md_account_multiple_minus_outline=$i
i='󰯦' i_md_account_network_outline=$i
i='󰯧' i_md_account_off_outline=$i
i='󰯨' i_md_account_star_outline=$i
i='󰯩' i_md_airbag=$i
i='󰯪' i_md_alarm_light_outline=$i
i='󰯫' i_md_alpha_a_box_outline=$i
i='󰯬' i_md_alpha_a_circle=$i
i='󰯭' i_md_alpha_a_circle_outline=$i
i='󰯮' i_md_alpha_b_box_outline=$i
i='󰯯' i_md_alpha_b_circle=$i
i='󰯰' i_md_alpha_b_circle_outline=$i
i='󰯱' i_md_alpha_c_box_outline=$i
i='󰯲' i_md_alpha_c_circle=$i
i='󰯳' i_md_alpha_c_circle_outline=$i
i='󰯴' i_md_alpha_d_box_outline=$i
i='󰯵' i_md_alpha_d_circle=$i
i='󰯶' i_md_alpha_d_circle_outline=$i
i='󰯷' i_md_alpha_e_box_outline=$i
i='󰯸' i_md_alpha_e_circle=$i
i='󰯹' i_md_alpha_e_circle_outline=$i
i='󰯺' i_md_alpha_f_box_outline=$i
i='󰯻' i_md_alpha_f_circle=$i
i='󰯼' i_md_alpha_f_circle_outline=$i
i='󰯽' i_md_alpha_g_box_outline=$i
i='󰯾' i_md_alpha_g_circle=$i
i='󰯿' i_md_alpha_g_circle_outline=$i
i='󰰀' i_md_alpha_h_box_outline=$i
i='󰰁' i_md_alpha_h_circle=$i
i='󰰂' i_md_alpha_h_circle_outline=$i
i='󰰃' i_md_alpha_i_box_outline=$i
i='󰰄' i_md_alpha_i_circle=$i
i='󰰅' i_md_alpha_i_circle_outline=$i
i='󰰆' i_md_alpha_j_box_outline=$i
i='󰰇' i_md_alpha_j_circle=$i
i='󰰈' i_md_alpha_j_circle_outline=$i
i='󰰉' i_md_alpha_k_box_outline=$i
i='󰰊' i_md_alpha_k_circle=$i
i='󰰋' i_md_alpha_k_circle_outline=$i
i='󰰌' i_md_alpha_l_box_outline=$i
i='󰰍' i_md_alpha_l_circle=$i
i='󰰎' i_md_alpha_l_circle_outline=$i
i='󰰏' i_md_alpha_m_box_outline=$i
i='󰰐' i_md_alpha_m_circle=$i
i='󰰑' i_md_alpha_m_circle_outline=$i
i='󰰒' i_md_alpha_n_box_outline=$i
i='󰰓' i_md_alpha_n_circle=$i
i='󰰔' i_md_alpha_n_circle_outline=$i
i='󰰕' i_md_alpha_o_box_outline=$i
i='󰰖' i_md_alpha_o_circle=$i
i='󰰗' i_md_alpha_o_circle_outline=$i
i='󰰘' i_md_alpha_p_box_outline=$i
i='󰰙' i_md_alpha_p_circle=$i
i='󰰚' i_md_alpha_p_circle_outline=$i
i='󰰛' i_md_alpha_q_box_outline=$i
i='󰰜' i_md_alpha_q_circle=$i
i='󰰝' i_md_alpha_q_circle_outline=$i
i='󰰞' i_md_alpha_r_box_outline=$i
i='󰰟' i_md_alpha_r_circle=$i
i='󰰠' i_md_alpha_r_circle_outline=$i
i='󰰡' i_md_alpha_s_box_outline=$i
i='󰰢' i_md_alpha_s_circle=$i
i='󰰣' i_md_alpha_s_circle_outline=$i
i='󰰤' i_md_alpha_t_box_outline=$i
i='󰰥' i_md_alpha_t_circle=$i
i='󰰦' i_md_alpha_t_circle_outline=$i
i='󰰧' i_md_alpha_u_box_outline=$i
i='󰰨' i_md_alpha_u_circle=$i
i='󰰩' i_md_alpha_u_circle_outline=$i
i='󰰪' i_md_alpha_v_box_outline=$i
i='󰰫' i_md_alpha_v_circle=$i
i='󰰬' i_md_alpha_v_circle_outline=$i
i='󰰭' i_md_alpha_w_box_outline=$i
i='󰰮' i_md_alpha_w_circle=$i
i='󰰯' i_md_alpha_w_circle_outline=$i
i='󰰰' i_md_alpha_x_box_outline=$i
i='󰰱' i_md_alpha_x_circle=$i
i='󰰲' i_md_alpha_x_circle_outline=$i
i='󰰳' i_md_alpha_y_box_outline=$i
i='󰰴' i_md_alpha_y_circle=$i
i='󰰵' i_md_alpha_y_circle_outline=$i
i='󰰶' i_md_alpha_z_box_outline=$i
i='󰰷' i_md_alpha_z_circle=$i
i='󰰸' i_md_alpha_z_circle_outline=$i
i='󰰹' i_md_ballot_recount=$i
i='󰰺' i_md_ballot_recount_outline=$i
i='󰰻' i_md_basketball_hoop=$i
i='󰰼' i_md_basketball_hoop_outline=$i
i='󰰽' i_md_briefcase_download_outline=$i
i='󰰾' i_md_briefcase_edit_outline=$i
i='󰰿' i_md_briefcase_minus_outline=$i
i='󰱀' i_md_briefcase_plus_outline=$i
i='󰱁' i_md_briefcase_remove_outline=$i
i='󰱂' i_md_briefcase_search_outline=$i
i='󰱃' i_md_briefcase_upload_outline=$i
i='󰱄' i_md_calendar_check_outline=$i
i='󰱅' i_md_calendar_remove_outline=$i
i='󰱆' i_md_calendar_text_outline=$i
i='󰱇' i_md_car_brake_abs=$i
i='󰱈' i_md_car_brake_alert=$i
i='󰱉' i_md_car_esp=$i
i='󰱊' i_md_car_light_dimmed=$i
i='󰱋' i_md_car_light_fog=$i
i='󰱌' i_md_car_light_high=$i
i='󰱍' i_md_car_tire_alert=$i
i='󰱎' i_md_cart_arrow_right=$i
i='󰱏' i_md_charity=$i
i='󰱐' i_md_chart_bell_curve=$i
i='󰱑' i_md_checkbox_multiple_outline=$i
i='󰱒' i_md_checkbox_outline=$i
i='󰱓' i_md_check_network=$i
i='󰱔' i_md_check_network_outline=$i
i='󰱕' i_md_clipboard_account_outline=$i
i='󰱖' i_md_clipboard_arrow_down_outline=$i
i='󰱗' i_md_clipboard_arrow_up=$i
i='󰱘' i_md_clipboard_arrow_up_outline=$i
i='󰱙' i_md_clipboard_play=$i
i='󰱚' i_md_clipboard_play_outline=$i
i='󰱛' i_md_clipboard_text_play=$i
i='󰱜' i_md_clipboard_text_play_outline=$i
i='󰱝' i_md_close_box_multiple=$i
i='󰱞' i_md_close_box_multiple_outline=$i
i='󰱟' i_md_close_network_outline=$i
i='󰱠' i_md_console_network_outline=$i
i='󰱡' i_md_currency_ils=$i
i='󰱢' i_md_delete_sweep_outline=$i
i='󰱣' i_md_diameter=$i
i='󰱤' i_md_diameter_outline=$i
i='󰱥' i_md_diameter_variant=$i
i='󰱦' i_md_download_network_outline=$i
i='󰱧' i_md_dump_truck=$i
i='󰱨' i_md_emoticon=$i
i='󰱩' i_md_emoticon_angry=$i
i='󰱪' i_md_emoticon_angry_outline=$i
i='󰱫' i_md_emoticon_cool=$i
i='󰱬' i_md_emoticon_cry=$i
i='󰱭' i_md_emoticon_cry_outline=$i
i='󰱮' i_md_emoticon_dead=$i
i='󰱯' i_md_emoticon_devil=$i
i='󰱰' i_md_emoticon_excited=$i
i='󰱱' i_md_emoticon_happy=$i
i='󰱲' i_md_emoticon_kiss=$i
i='󰱳' i_md_emoticon_kiss_outline=$i
i='󰱴' i_md_emoticon_neutral=$i
i='󰱵' i_md_emoticon_poop_outline=$i
i='󰱶' i_md_emoticon_sad=$i
i='󰱷' i_md_emoticon_tongue_outline=$i
i='󰱸' i_md_emoticon_wink=$i
i='󰱹' i_md_emoticon_wink_outline=$i
i='󰱺' i_md_eslint=$i
i='󰱻' i_md_face_recognition=$i
i='󰱼' i_md_file_search=$i
i='󰱽' i_md_file_search_outline=$i
i='󰱾' i_md_file_table=$i
i='󰱿' i_md_file_table_outline=$i
i='󰲀' i_md_folder_key_network_outline=$i
i='󰲁' i_md_folder_network_outline=$i
i='󰲂' i_md_folder_text=$i
i='󰲃' i_md_folder_text_outline=$i
i='󰲄' i_md_food_apple_outline=$i
i='󰲅' i_md_fuse=$i
i='󰲆' i_md_fuse_blade=$i
i='󰲇' i_md_google_ads=$i
i='󰲈' i_md_google_street_view=$i
i='󰲉' i_md_hazard_lights=$i
i='󰲊' i_md_help_network_outline=$i
i='󰲋' i_md_application_brackets=$i
i='󰲌' i_md_application_brackets_outline=$i
i='󰲍' i_md_image_size_select_actual=$i
i='󰲎' i_md_image_size_select_large=$i
i='󰲏' i_md_image_size_select_small=$i
i='󰲐' i_md_ip_network_outline=$i
i='󰲑' i_md_ipod=$i
i='󰲒' i_md_language_haskell=$i
i='󰲓' i_md_leaf_maple=$i
i='󰲔' i_md_link_plus=$i
i='󰲕' i_md_map_marker_check=$i
i='󰲖' i_md_math_cos=$i
i='󰲗' i_md_math_sin=$i
i='󰲘' i_md_math_tan=$i
i='󰲙' i_md_microwave=$i
i='󰲚' i_md_minus_network_outline=$i
i='󰲛' i_md_network_off=$i
i='󰲜' i_md_network_off_outline=$i
i='󰲝' i_md_network_outline=$i
i='󰲠' i_md_numeric_1_circle=$i
i='󰲡' i_md_numeric_1_circle_outline=$i
i='󰲢' i_md_numeric_2_circle=$i
i='󰲣' i_md_numeric_2_circle_outline=$i
i='󰲤' i_md_numeric_3_circle=$i
i='󰲥' i_md_numeric_3_circle_outline=$i
i='󰲦' i_md_numeric_4_circle=$i
i='󰲧' i_md_numeric_4_circle_outline=$i
i='󰲨' i_md_numeric_5_circle=$i
i='󰲩' i_md_numeric_5_circle_outline=$i
i='󰲪' i_md_numeric_6_circle=$i
i='󰲫' i_md_numeric_6_circle_outline=$i
i='󰲬' i_md_numeric_7_circle=$i
i='󰲭' i_md_numeric_7_circle_outline=$i
i='󰲮' i_md_numeric_8_circle=$i
i='󰲯' i_md_numeric_8_circle_outline=$i
i='󰲰' i_md_numeric_9_circle=$i
i='󰲱' i_md_numeric_9_circle_outline=$i
i='󰲲' i_md_numeric_9_plus_circle=$i
i='󰲳' i_md_numeric_9_plus_circle_outline=$i
i='󰲴' i_md_parachute=$i
i='󰲵' i_md_parachute_outline=$i
i='󰲶' i_md_pencil_outline=$i
i='󰲷' i_md_play_network_outline=$i
i='󰲸' i_md_playlist_music=$i
i='󰲹' i_md_playlist_music_outline=$i
i='󰲺' i_md_plus_network_outline=$i
i='󰲻' i_md_postage_stamp=$i
i='󰲼' i_md_progress_alert=$i
i='󰲽' i_md_progress_wrench=$i
i='󰲾' i_md_radio_am=$i
i='󰲿' i_md_radio_fm=$i
i='󰳀' i_md_radius=$i
i='󰳁' i_md_radius_outline=$i
i='󰳂' i_md_ruler_square=$i
i='󰳃' i_md_seat=$i
i='󰳄' i_md_seat_outline=$i
i='󰳅' i_md_seatbelt=$i
i='󰳆' i_md_sheep=$i
i='󰳇' i_md_shield_airplane_outline=$i
i='󰳈' i_md_shield_check_outline=$i
i='󰳉' i_md_shield_cross=$i
i='󰳊' i_md_shield_cross_outline=$i
i='󰳋' i_md_shield_home_outline=$i
i='󰳌' i_md_shield_lock_outline=$i
i='󰳍' i_md_sort_variant_lock=$i
i='󰳎' i_md_sort_variant_lock_open=$i
i='󰳏' i_md_source_repository=$i
i='󰳐' i_md_source_repository_multiple=$i
i='󰳑' i_md_spa=$i
i='󰳒' i_md_spa_outline=$i
i='󰳓' i_md_toaster_oven=$i
i='󰳔' i_md_truck_check=$i
i='󰳕' i_md_turnstile=$i
i='󰳖' i_md_turnstile_outline=$i
i='󰳗' i_md_turtle=$i
i='󰳘' i_md_upload_network_outline=$i
i='󰳙' i_md_vibrate_off=$i
i='󰳚' i_md_watch_vibrate_off=$i
i='󰳛' i_md_arrow_down_circle=$i
i='󰳜' i_md_arrow_down_circle_outline=$i
i='󰳝' i_md_arrow_left_circle=$i
i='󰳞' i_md_arrow_left_circle_outline=$i
i='󰳟' i_md_arrow_right_circle=$i
i='󰳠' i_md_arrow_right_circle_outline=$i
i='󰳡' i_md_arrow_up_circle=$i
i='󰳢' i_md_arrow_up_circle_outline=$i
i='󰳣' i_md_account_tie=$i
i='󰳤' i_md_alert_box_outline=$i
i='󰳥' i_md_alert_decagram_outline=$i
i='󰳦' i_md_alert_octagon_outline=$i
i='󰳧' i_md_alert_octagram_outline=$i
i='󰳨' i_md_ammunition=$i
i='󰳩' i_md_account_music_outline=$i
i='󰳪' i_md_beaker=$i
i='󰳫' i_md_blender=$i
i='󰳬' i_md_blood_bag=$i
i='󰳭' i_md_cross_bolnisi=$i
i='󰳮' i_md_bread_slice=$i
i='󰳯' i_md_bread_slice_outline=$i
i='󰳰' i_md_briefcase_account=$i
i='󰳱' i_md_briefcase_account_outline=$i
i='󰳲' i_md_brightness_percent=$i
i='󰳳' i_md_bullet=$i
i='󰳴' i_md_cash_register=$i
i='󰳵' i_md_cross_celtic=$i
i='󰳶' i_md_cross_outline=$i
i='󰳷' i_md_clipboard_alert_outline=$i
i='󰳸' i_md_clipboard_arrow_left_outline=$i
i='󰳹' i_md_clipboard_arrow_right=$i
i='󰳺' i_md_clipboard_arrow_right_outline=$i
i='󰳻' i_md_content_save_edit=$i
i='󰳼' i_md_content_save_edit_outline=$i
i='󰳽' i_md_cursor_default_click=$i
i='󰳾' i_md_cursor_default_click_outline=$i
i='󰳿' i_md_database_sync=$i
i='󰴀' i_md_database_remove=$i
i='󰴁' i_md_database_settings=$i
i='󰴂' i_md_drama_masks=$i
i='󰴃' i_md_email_box=$i
i='󰴄' i_md_eye_check=$i
i='󰴅' i_md_eye_check_outline=$i
i='󰴆' i_md_fast_forward_30=$i
i='󰴇' i_md_order_alphabetical_descending=$i
i='󰴈' i_md_flower_poppy=$i
i='󰴉' i_md_folder_pound=$i
i='󰴊' i_md_folder_pound_outline=$i
i='󰴋' i_md_folder_sync=$i
i='󰴌' i_md_folder_sync_outline=$i
i='󰴍' i_md_format_list_numbered_rtl=$i
i='󰴎' i_md_format_text_wrapping_clip=$i
i='󰴏' i_md_format_text_wrapping_overflow=$i
i='󰴐' i_md_format_text_wrapping_wrap=$i
i='󰴑' i_md_format_textbox=$i
i='󰴒' i_md_fountain_pen=$i
i='󰴓' i_md_fountain_pen_tip=$i
i='󰴔' i_md_heart_broken_outline=$i
i='󰴕' i_md_home_city=$i
i='󰴖' i_md_home_city_outline=$i
i='󰴗' i_md_hubspot=$i
i='󰴘' i_md_filmstrip_box_multiple=$i
i='󰴙' i_md_play_box_multiple=$i
i='󰴚' i_md_link_box=$i
i='󰴛' i_md_link_box_outline=$i
i='󰴜' i_md_link_box_variant=$i
i='󰴝' i_md_link_box_variant_outline=$i
i='󰴞' i_md_map_clock=$i
i='󰴟' i_md_map_clock_outline=$i
i='󰴠' i_md_map_marker_path=$i
i='󰴡' i_md_mother_nurse=$i
i='󰴢' i_md_microsoft_outlook=$i
i='󰴣' i_md_perspective_less=$i
i='󰴤' i_md_perspective_more=$i
i='󰴥' i_md_podium=$i
i='󰴦' i_md_podium_bronze=$i
i='󰴧' i_md_podium_gold=$i
i='󰴨' i_md_podium_silver=$i
i='󰴩' i_md_quora=$i
i='󰴪' i_md_rewind_10=$i
i='󰴫' i_md_roller_skate=$i
i='󰴬' i_md_rollerblade=$i
i='󰴭' i_md_language_ruby=$i
i='󰴮' i_md_sack=$i
i='󰴯' i_md_sack_percent=$i
i='󰴰' i_md_safety_goggles=$i
i='󰴱' i_md_select_color=$i
i='󰴲' i_md_selection_ellipse=$i
i='󰴳' i_md_shield_link_variant=$i
i='󰴴' i_md_shield_link_variant_outline=$i
i='󰴵' i_md_skate=$i
i='󰴶' i_md_skew_less=$i
i='󰴷' i_md_skew_more=$i
i='󰴸' i_md_speaker_multiple=$i
i='󰴹' i_md_stamper=$i
i='󰴺' i_md_tank=$i
i='󰴻' i_md_tortoise=$i
i='󰴼' i_md_transit_connection=$i
i='󰴽' i_md_transit_connection_variant=$i
i='󰴾' i_md_transmission_tower=$i
i='󰴿' i_md_weight_gram=$i
i='󰵀' i_md_youtube_subscription=$i
i='󰵁' i_md_zigbee=$i
i='󰵂' i_md_email_alert_outline=$i
i='󰵃' i_md_air_filter=$i
i='󰵄' i_md_air_purifier=$i
i='󰵅' i_md_android_messages=$i
i='󰵆' i_md_apps_box=$i
i='󰵇' i_md_atm=$i
i='󰵈' i_md_axis=$i
i='󰵉' i_md_axis_arrow=$i
i='󰵊' i_md_axis_arrow_lock=$i
i='󰵋' i_md_axis_lock=$i
i='󰵌' i_md_axis_x_arrow=$i
i='󰵍' i_md_axis_x_arrow_lock=$i
i='󰵎' i_md_axis_x_rotate_clockwise=$i
i='󰵏' i_md_axis_x_rotate_counterclockwise=$i
i='󰵐' i_md_axis_x_y_arrow_lock=$i
i='󰵑' i_md_axis_y_arrow=$i
i='󰵒' i_md_axis_y_arrow_lock=$i
i='󰵓' i_md_axis_y_rotate_clockwise=$i
i='󰵔' i_md_axis_y_rotate_counterclockwise=$i
i='󰵕' i_md_axis_z_arrow=$i
i='󰵖' i_md_axis_z_arrow_lock=$i
i='󰵗' i_md_axis_z_rotate_clockwise=$i
i='󰵘' i_md_axis_z_rotate_counterclockwise=$i
i='󰵙' i_md_bell_alert=$i
i='󰵚' i_md_bell_circle=$i
i='󰵛' i_md_bell_circle_outline=$i
i='󰵜' i_md_calendar_minus=$i
i='󰵝' i_md_camera_outline=$i
i='󰵞' i_md_car_brake_hold=$i
i='󰵟' i_md_car_brake_parking=$i
i='󰵠' i_md_car_cruise_control=$i
i='󰵡' i_md_car_defrost_front=$i
i='󰵢' i_md_car_defrost_rear=$i
i='󰵣' i_md_car_parking_lights=$i
i='󰵤' i_md_car_traction_control=$i
i='󰵥' i_md_bag_carry_on_check=$i
i='󰵦' i_md_cart_arrow_down=$i
i='󰵧' i_md_cart_arrow_up=$i
i='󰵨' i_md_cart_minus=$i
i='󰵩' i_md_cart_remove=$i
i='󰵪' i_md_contactless_payment=$i
i='󰵫' i_md_creative_commons=$i
i='󰵬' i_md_credit_card_wireless_outline=$i
i='󰵭' i_md_cricket=$i
i='󰵮' i_md_dev_to=$i
i='󰵯' i_md_domain_off=$i
i='󰵰' i_md_face_agent=$i
i='󰵱' i_md_fast_forward_10=$i
i='󰵲' i_md_flare=$i
i='󰵳' i_md_format_text_rotation_down=$i
i='󰵴' i_md_format_text_rotation_none=$i
i='󰵵' i_md_forwardburger=$i
i='󰵶' i_md_gesture_swipe=$i
i='󰵷' i_md_gesture_tap_hold=$i
i='󰵸' i_md_file_gif_box=$i
i='󰵹' i_md_go_kart=$i
i='󰵺' i_md_go_kart_track=$i
i='󰵻' i_md_goodreads=$i
i='󰵼' i_md_grain=$i
i='󰵽' i_md_hdr=$i
i='󰵾' i_md_hdr_off=$i
i='󰵿' i_md_hiking=$i
i='󰶀' i_md_home_floor_1=$i
i='󰶁' i_md_home_floor_2=$i
i='󰶂' i_md_home_floor_3=$i
i='󰶃' i_md_home_floor_a=$i
i='󰶄' i_md_home_floor_b=$i
i='󰶅' i_md_home_floor_g=$i
i='󰶆' i_md_home_floor_l=$i
i='󰶇' i_md_kabaddi=$i
i='󰶈' i_md_mailbox_open=$i
i='󰶉' i_md_mailbox_open_outline=$i
i='󰶊' i_md_mailbox_open_up=$i
i='󰶋' i_md_mailbox_open_up_outline=$i
i='󰶌' i_md_mailbox_outline=$i
i='󰶍' i_md_mailbox_up=$i
i='󰶎' i_md_mailbox_up_outline=$i
i='󰶏' i_md_mixed_martial_arts=$i
i='󰶐' i_md_monitor_off=$i
i='󰶑' i_md_motion_sensor=$i
i='󰶒' i_md_point_of_sale=$i
i='󰶓' i_md_racing_helmet=$i
i='󰶔' i_md_racquetball=$i
i='󰶕' i_md_restart_off=$i
i='󰶖' i_md_rewind_30=$i
i='󰶗' i_md_room_service_outline=$i
i='󰶘' i_md_rotate_orbit=$i
i='󰶙' i_md_rugby=$i
i='󰶚' i_md_shield_search=$i
i='󰶛' i_md_solar_panel=$i
i='󰶜' i_md_solar_panel_large=$i
i='󰶝' i_md_subway_alert_variant=$i
i='󰶞' i_md_tea=$i
i='󰶟' i_md_tea_outline=$i
i='󰶠' i_md_tennis=$i
i='󰶡' i_md_transfer_down=$i
i='󰶢' i_md_transfer_left=$i
i='󰶣' i_md_transfer_up=$i
i='󰶤' i_md_trophy_broken=$i
i='󰶥' i_md_wind_turbine=$i
i='󰶦' i_md_wiper_wash=$i
i='󰶧' i_md_badge_account=$i
i='󰶨' i_md_badge_account_alert=$i
i='󰶩' i_md_badge_account_alert_outline=$i
i='󰶪' i_md_badge_account_outline=$i
i='󰶫' i_md_card_account_details_outline=$i
i='󰶬' i_md_air_horn=$i
i='󰶭' i_md_application_export=$i
i='󰶮' i_md_application_import=$i
i='󰶯' i_md_bandage=$i
i='󰶰' i_md_bank_minus=$i
i='󰶱' i_md_bank_plus=$i
i='󰶲' i_md_bank_remove=$i
i='󰶳' i_md_bolt=$i
i='󰶴' i_md_bugle=$i
i='󰶵' i_md_cactus=$i
i='󰶶' i_md_camera_wireless=$i
i='󰶷' i_md_camera_wireless_outline=$i
i='󰶸' i_md_cash_marker=$i
i='󰶹' i_md_chevron_triple_down=$i
i='󰶺' i_md_chevron_triple_left=$i
i='󰶻' i_md_chevron_triple_right=$i
i='󰶼' i_md_chevron_triple_up=$i
i='󰶽' i_md_closed_caption_outline=$i
i='󰶾' i_md_credit_card_marker_outline=$i
i='󰶿' i_md_diving_flippers=$i
i='󰷀' i_md_diving_helmet=$i
i='󰷁' i_md_diving_scuba=$i
i='󰷂' i_md_diving_scuba_flag=$i
i='󰷃' i_md_diving_scuba_tank=$i
i='󰷄' i_md_diving_scuba_tank_multiple=$i
i='󰷅' i_md_diving_snorkel=$i
i='󰷆' i_md_file_cancel=$i
i='󰷇' i_md_file_cancel_outline=$i
i='󰷈' i_md_file_document_edit=$i
i='󰷉' i_md_file_document_edit_outline=$i
i='󰷊' i_md_file_eye=$i
i='󰷋' i_md_file_eye_outline=$i
i='󰷌' i_md_folder_alert=$i
i='󰷍' i_md_folder_alert_outline=$i
i='󰷎' i_md_folder_edit_outline=$i
i='󰷏' i_md_folder_open_outline=$i
i='󰷐' i_md_format_list_bulleted_square=$i
i='󰷑' i_md_gantry_crane=$i
i='󰷒' i_md_home_floor_0=$i
i='󰷓' i_md_home_floor_negative_1=$i
i='󰷔' i_md_home_group=$i
i='󰷕' i_md_jabber=$i
i='󰷖' i_md_key_outline=$i
i='󰷗' i_md_leak=$i
i='󰷘' i_md_leak_off=$i
i='󰷙' i_md_marker_cancel=$i
i='󰷚' i_md_mine=$i
i='󰷛' i_md_monitor_lock=$i
i='󰷜' i_md_monitor_star=$i
i='󰷝' i_md_movie_outline=$i
i='󰷞' i_md_music_note_plus=$i
i='󰷟' i_md_nail=$i
i='󰷠' i_md_ocarina=$i
i='󰷡' i_md_passport_biometric=$i
i='󰷢' i_md_pen_lock=$i
i='󰷣' i_md_pen_minus=$i
i='󰷤' i_md_pen_off=$i
i='󰷥' i_md_pen_plus=$i
i='󰷦' i_md_pen_remove=$i
i='󰷧' i_md_pencil_lock_outline=$i
i='󰷨' i_md_pencil_minus=$i
i='󰷩' i_md_pencil_minus_outline=$i
i='󰷪' i_md_pencil_off_outline=$i
i='󰷫' i_md_pencil_plus=$i
i='󰷬' i_md_pencil_plus_outline=$i
i='󰷭' i_md_pencil_remove=$i
i='󰷮' i_md_pencil_remove_outline=$i
i='󰷯' i_md_phone_off=$i
i='󰷰' i_md_phone_outline=$i
i='󰷱' i_md_pi_hole=$i
i='󰷲' i_md_playlist_star=$i
i='󰷳' i_md_screw_flat_top=$i
i='󰷴' i_md_screw_lag=$i
i='󰷵' i_md_screw_machine_flat_top=$i
i='󰷶' i_md_screw_machine_round_top=$i
i='󰷷' i_md_screw_round_top=$i
i='󰷸' i_md_send_circle=$i
i='󰷹' i_md_send_circle_outline=$i
i='󰷺' i_md_shoe_print=$i
i='󰷻' i_md_signature=$i
i='󰷼' i_md_signature_freehand=$i
i='󰷽' i_md_signature_image=$i
i='󰷾' i_md_signature_text=$i
i='󰷿' i_md_slope_downhill=$i
i='󰸀' i_md_slope_uphill=$i
i='󰸁' i_md_thermometer_alert=$i
i='󰸂' i_md_thermometer_chevron_down=$i
i='󰸃' i_md_thermometer_chevron_up=$i
i='󰸄' i_md_thermometer_minus=$i
i='󰸅' i_md_thermometer_plus=$i
i='󰸆' i_md_translate_off=$i
i='󰸇' i_md_upload_outline=$i
i='󰸈' i_md_volume_variant_off=$i
i='󰸉' i_md_wallpaper=$i
i='󰸊' i_md_water_outline=$i
i='󰸋' i_md_wifi_star=$i
i='󰸌' i_md_palette_outline=$i
i='󰸍' i_md_badge_account_horizontal=$i
i='󰸎' i_md_badge_account_horizontal_outline=$i
i='󰸏' i_md_aws=$i
i='󰸐' i_md_bag_personal=$i
i='󰸑' i_md_bag_personal_off=$i
i='󰸒' i_md_bag_personal_off_outline=$i
i='󰸓' i_md_bag_personal_outline=$i
i='󰸔' i_md_biathlon=$i
i='󰸕' i_md_bookmark_multiple=$i
i='󰸖' i_md_bookmark_multiple_outline=$i
i='󰸗' i_md_calendar_month=$i
i='󰸘' i_md_calendar_month_outline=$i
i='󰸙' i_md_camera_retake=$i
i='󰸚' i_md_camera_retake_outline=$i
i='󰸛' i_md_car_back=$i
i='󰸜' i_md_car_off=$i
i='󰸝' i_md_cast_education=$i
i='󰸞' i_md_check_bold=$i
i='󰸟' i_md_check_underline=$i
i='󰸠' i_md_check_underline_circle=$i
i='󰸡' i_md_check_underline_circle_outline=$i
i='󰸢' i_md_circular_saw=$i
i='󰸣' i_md_comma=$i
i='󰸤' i_md_comma_box_outline=$i
i='󰸥' i_md_comma_circle=$i
i='󰸦' i_md_comma_circle_outline=$i
i='󰸧' i_md_content_save_move=$i
i='󰸨' i_md_content_save_move_outline=$i
i='󰸩' i_md_file_check_outline=$i
i='󰸪' i_md_file_music_outline=$i
i='󰸫' i_md_comma_box=$i
i='󰸬' i_md_file_video_outline=$i
i='󰸭' i_md_file_png_box=$i
i='󰸮' i_md_fireplace=$i
i='󰸯' i_md_fireplace_off=$i
i='󰸰' i_md_firework=$i
i='󰸱' i_md_format_color_highlight=$i
i='󰸲' i_md_format_text_variant=$i
i='󰸳' i_md_gamepad_circle=$i
i='󰸴' i_md_gamepad_circle_down=$i
i='󰸵' i_md_gamepad_circle_left=$i
i='󰸶' i_md_gamepad_circle_outline=$i
i='󰸷' i_md_gamepad_circle_right=$i
i='󰸸' i_md_gamepad_circle_up=$i
i='󰸹' i_md_gamepad_down=$i
i='󰸺' i_md_gamepad_left=$i
i='󰸻' i_md_gamepad_right=$i
i='󰸼' i_md_gamepad_round=$i
i='󰸽' i_md_gamepad_round_down=$i
i='󰸾' i_md_gamepad_round_left=$i
i='󰸿' i_md_gamepad_round_outline=$i
i='󰹀' i_md_gamepad_round_right=$i
i='󰹁' i_md_gamepad_round_up=$i
i='󰹂' i_md_gamepad_up=$i
i='󰹃' i_md_gatsby=$i
i='󰹄' i_md_gift=$i
i='󰹅' i_md_grill=$i
i='󰹆' i_md_hand_back_left=$i
i='󰹇' i_md_hand_back_right=$i
i='󰹈' i_md_hand_saw=$i
i='󰹉' i_md_image_frame=$i
i='󰹊' i_md_invert_colors_off=$i
i='󰹋' i_md_keyboard_off_outline=$i
i='󰹌' i_md_layers_minus=$i
i='󰹍' i_md_layers_plus=$i
i='󰹎' i_md_layers_remove=$i
i='󰹏' i_md_lightbulb_off=$i
i='󰹐' i_md_lightbulb_off_outline=$i
i='󰹑' i_md_monitor_screenshot=$i
i='󰹒' i_md_ice_cream_off=$i
i='󰹓' i_md_nfc_search_variant=$i
i='󰹔' i_md_nfc_variant_off=$i
i='󰹕' i_md_notebook_multiple=$i
i='󰹖' i_md_hoop_house=$i
i='󰹗' i_md_picture_in_picture_bottom_right=$i
i='󰹘' i_md_picture_in_picture_bottom_right_outline=$i
i='󰹙' i_md_picture_in_picture_top_right=$i
i='󰹚' i_md_picture_in_picture_top_right_outline=$i
i='󰹛' i_md_printer_3d_nozzle=$i
i='󰹜' i_md_printer_3d_nozzle_outline=$i
i='󰹝' i_md_printer_off=$i
i='󰹞' i_md_rectangle=$i
i='󰹟' i_md_rectangle_outline=$i
i='󰹠' i_md_rivet=$i
i='󰹡' i_md_saw_blade=$i
i='󰹢' i_md_seed=$i
i='󰹣' i_md_seed_outline=$i
i='󰹤' i_md_signal_distance_variant=$i
i='󰹥' i_md_spade=$i
i='󰹦' i_md_sprout=$i
i='󰹧' i_md_sprout_outline=$i
i='󰹨' i_md_table_tennis=$i
i='󰹩' i_md_tree_outline=$i
i='󰹪' i_md_view_comfy=$i
i='󰹫' i_md_view_compact=$i
i='󰹬' i_md_view_compact_outline=$i
i='󰹭' i_md_vuetify=$i
i='󰹮' i_md_weather_cloudy_arrow_right=$i
i='󰹯' i_md_microsoft_xbox_controller_menu=$i
i='󰹰' i_md_microsoft_xbox_controller_view=$i
i='󰹱' i_md_alarm_note=$i
i='󰹲' i_md_alarm_note_off=$i
i='󰹳' i_md_arrow_left_right=$i
i='󰹴' i_md_arrow_left_right_bold=$i
i='󰹵' i_md_arrow_top_left_bottom_right=$i
i='󰹶' i_md_arrow_top_left_bottom_right_bold=$i
i='󰹷' i_md_arrow_top_right_bottom_left=$i
i='󰹸' i_md_arrow_top_right_bottom_left_bold=$i
i='󰹹' i_md_arrow_up_down=$i
i='󰹺' i_md_arrow_up_down_bold=$i
i='󰹻' i_md_atom_variant=$i
i='󰹼' i_md_baby_face=$i
i='󰹽' i_md_baby_face_outline=$i
i='󰹾' i_md_backspace_reverse=$i
i='󰹿' i_md_backspace_reverse_outline=$i
i='󰺀' i_md_bank_outline=$i
i='󰺁' i_md_bell_alert_outline=$i
i='󰺂' i_md_book_play=$i
i='󰺃' i_md_book_play_outline=$i
i='󰺄' i_md_book_search=$i
i='󰺅' i_md_book_search_outline=$i
i='󰺆' i_md_boom_gate=$i
i='󰺇' i_md_boom_gate_alert=$i
i='󰺈' i_md_boom_gate_alert_outline=$i
i='󰺉' i_md_boom_gate_arrow_down=$i
i='󰺊' i_md_boom_gate_arrow_down_outline=$i
i='󰺋' i_md_boom_gate_outline=$i
i='󰺌' i_md_boom_gate_arrow_up=$i
i='󰺍' i_md_boom_gate_arrow_up_outline=$i
i='󰺎' i_md_calendar_sync=$i
i='󰺏' i_md_calendar_sync_outline=$i
i='󰺐' i_md_cellphone_nfc=$i
i='󰺑' i_md_chart_areaspline_variant=$i
i='󰺒' i_md_chart_scatter_plot=$i
i='󰺓' i_md_chart_timeline_variant=$i
i='󰺔' i_md_chart_tree=$i
i='󰺕' i_md_circle_double=$i
i='󰺖' i_md_circle_expand=$i
i='󰺗' i_md_clock_digital=$i
i='󰺘' i_md_card_account_mail_outline=$i
i='󰺙' i_md_card_account_phone=$i
i='󰺚' i_md_card_account_phone_outline=$i
i='󰺛' i_md_account_cowboy_hat=$i
i='󰺜' i_md_currency_rial=$i
i='󰺝' i_md_delete_empty_outline=$i
i='󰺞' i_md_dolly=$i
i='󰺟' i_md_electric_switch=$i
i='󰺠' i_md_ellipse=$i
i='󰺡' i_md_ellipse_outline=$i
i='󰺢' i_md_equalizer=$i
i='󰺣' i_md_equalizer_outline=$i
i='󰺤' i_md_ferris_wheel=$i
i='󰺥' i_md_file_delimited_outline=$i
i='󰺦' i_md_text_box_check=$i
i='󰺧' i_md_text_box_check_outline=$i
i='󰺨' i_md_text_box_minus=$i
i='󰺩' i_md_text_box_minus_outline=$i
i='󰺪' i_md_text_box_plus=$i
i='󰺫' i_md_text_box_plus_outline=$i
i='󰺬' i_md_text_box_remove=$i
i='󰺭' i_md_text_box_remove_outline=$i
i='󰺮' i_md_text_box_search=$i
i='󰺯' i_md_text_box_search_outline=$i
i='󰺰' i_md_file_image_outline=$i
i='󰺱' i_md_fingerprint_off=$i
i='󰺲' i_md_format_list_bulleted_triangle=$i
i='󰺳' i_md_format_overline=$i
i='󰺴' i_md_frequently_asked_questions=$i
i='󰺵' i_md_gamepad_square=$i
i='󰺶' i_md_gamepad_square_outline=$i
i='󰺷' i_md_gamepad_variant_outline=$i
i='󰺸' i_md_gas_station_outline=$i
i='󰺹' i_md_google_podcast=$i
i='󰺺' i_md_home_analytics=$i
i='󰺻' i_md_mail=$i
i='󰺼' i_md_map_check=$i
i='󰺽' i_md_map_check_outline=$i
i='󰺾' i_md_ruler_square_compass=$i
i='󰺿' i_md_notebook_outline=$i
i='󰻀' i_md_penguin=$i
i='󰻁' i_md_radioactive_off=$i
i='󰻂' i_md_record_circle=$i
i='󰻃' i_md_record_circle_outline=$i
i='󰻄' i_md_remote_off=$i
i='󰻅' i_md_remote_tv=$i
i='󰻆' i_md_remote_tv_off=$i
i='󰻇' i_md_rotate_3d=$i
i='󰻈' i_md_sail_boat=$i
i='󰻉' i_md_scatter_plot=$i
i='󰻊' i_md_scatter_plot_outline=$i
i='󰻋' i_md_segment=$i
i='󰻌' i_md_shield_alert=$i
i='󰻍' i_md_shield_alert_outline=$i
i='󰻎' i_md_tablet_dashboard=$i
i='󰻏' i_md_television_play=$i
i='󰻐' i_md_unicode=$i
i='󰻑' i_md_video_3d_variant=$i
i='󰻒' i_md_video_wireless=$i
i='󰻓' i_md_video_wireless_outline=$i
i='󰻔' i_md_account_voice_off=$i
i='󰻕' i_md_bacteria=$i
i='󰻖' i_md_bacteria_outline=$i
i='󰻗' i_md_calendar_account=$i
i='󰻘' i_md_calendar_account_outline=$i
i='󰻙' i_md_calendar_weekend=$i
i='󰻚' i_md_calendar_weekend_outline=$i
i='󰻛' i_md_camera_plus=$i
i='󰻜' i_md_camera_plus_outline=$i
i='󰻝' i_md_campfire=$i
i='󰻞' i_md_chat_outline=$i
i='󰻟' i_md_cpu_32_bit=$i
i='󰻠' i_md_cpu_64_bit=$i
i='󰻡' i_md_credit_card_clock=$i
i='󰻢' i_md_credit_card_clock_outline=$i
i='󰻣' i_md_email_edit=$i
i='󰻤' i_md_email_edit_outline=$i
i='󰻥' i_md_email_minus=$i
i='󰻦' i_md_email_minus_outline=$i
i='󰻧' i_md_email_multiple=$i
i='󰻨' i_md_email_multiple_outline=$i
i='󰻩' i_md_email_open_multiple=$i
i='󰻪' i_md_email_open_multiple_outline=$i
i='󰻫' i_md_file_cad=$i
i='󰻬' i_md_file_cad_box=$i
i='󰻭' i_md_file_plus_outline=$i
i='󰻮' i_md_filter_minus=$i
i='󰻯' i_md_filter_minus_outline=$i
i='󰻰' i_md_filter_plus=$i
i='󰻱' i_md_filter_plus_outline=$i
i='󰻲' i_md_fire_extinguisher=$i
i='󰻳' i_md_fishbowl=$i
i='󰻴' i_md_fishbowl_outline=$i
i='󰻵' i_md_fit_to_page=$i
i='󰻶' i_md_fit_to_page_outline=$i
i='󰻷' i_md_flash_alert=$i
i='󰻸' i_md_flash_alert_outline=$i
i='󰻹' i_md_heart_flash=$i
i='󰻺' i_md_home_flood=$i
i='󰻻' i_md_human_male_height=$i
i='󰻼' i_md_human_male_height_variant=$i
i='󰻽' i_md_ice_pop=$i
i='󰻾' i_md_identifier=$i
i='󰻿' i_md_image_filter_center_focus_strong=$i
i='󰼀' i_md_image_filter_center_focus_strong_outline=$i
i='󰼁' i_md_jellyfish=$i
i='󰼂' i_md_jellyfish_outline=$i
i='󰼃' i_md_lasso=$i
i='󰼄' i_md_music_box_multiple_outline=$i
i='󰼅' i_md_map_marker_alert=$i
i='󰼆' i_md_map_marker_alert_outline=$i
i='󰼇' i_md_map_marker_question=$i
i='󰼈' i_md_map_marker_question_outline=$i
i='󰼉' i_md_map_marker_remove=$i
i='󰼊' i_md_map_marker_remove_variant=$i
i='󰼋' i_md_necklace=$i
i='󰼌' i_md_newspaper_minus=$i
i='󰼍' i_md_newspaper_plus=$i
i='󰼎' i_md_numeric_0_box_multiple=$i
i='󰼏' i_md_numeric_1_box_multiple=$i
i='󰼐' i_md_numeric_2_box_multiple=$i
i='󰼑' i_md_numeric_3_box_multiple=$i
i='󰼒' i_md_numeric_4_box_multiple=$i
i='󰼓' i_md_numeric_5_box_multiple=$i
i='󰼔' i_md_numeric_6_box_multiple=$i
i='󰼕' i_md_numeric_7_box_multiple=$i
i='󰼖' i_md_numeric_8_box_multiple=$i
i='󰼗' i_md_numeric_9_box_multiple=$i
i='󰼘' i_md_numeric_9_plus_box_multiple=$i
i='󰼙' i_md_oil_lamp=$i
i='󰼚' i_md_phone_alert=$i
i='󰼛' i_md_play_outline=$i
i='󰼜' i_md_purse=$i
i='󰼝' i_md_purse_outline=$i
i='󰼞' i_md_railroad_light=$i
i='󰼟' i_md_reply_all_outline=$i
i='󰼠' i_md_reply_outline=$i
i='󰼡' i_md_rss_off=$i
i='󰼢' i_md_selection_ellipse_arrow_inside=$i
i='󰼣' i_md_share_off=$i
i='󰼤' i_md_share_off_outline=$i
i='󰼥' i_md_skip_backward_outline=$i
i='󰼦' i_md_skip_forward_outline=$i
i='󰼧' i_md_skip_next_outline=$i
i='󰼨' i_md_skip_previous_outline=$i
i='󰼩' i_md_snowflake_alert=$i
i='󰼪' i_md_snowflake_variant=$i
i='󰼫' i_md_stretch_to_page=$i
i='󰼬' i_md_stretch_to_page_outline=$i
i='󰼭' i_md_typewriter=$i
i='󰼮' i_md_wave=$i
i='󰼯' i_md_weather_cloudy_alert=$i
i='󰼰' i_md_weather_hazy=$i
i='󰼱' i_md_weather_night_partly_cloudy=$i
i='󰼲' i_md_weather_partly_lightning=$i
i='󰼳' i_md_weather_partly_rainy=$i
i='󰼴' i_md_weather_partly_snowy=$i
i='󰼵' i_md_weather_partly_snowy_rainy=$i
i='󰼶' i_md_weather_snowy_heavy=$i
i='󰼷' i_md_weather_sunny_alert=$i
i='󰼸' i_md_weather_tornado=$i
i='󰼹' i_md_baby_bottle=$i
i='󰼺' i_md_baby_bottle_outline=$i
i='󰼻' i_md_bag_carry_on=$i
i='󰼼' i_md_bag_carry_on_off=$i
i='󰼽' i_md_bag_checked=$i
i='󰼾' i_md_baguette=$i
i='󰼿' i_md_bus_multiple=$i
i='󰽀' i_md_car_shift_pattern=$i
i='󰽁' i_md_cellphone_information=$i
i='󰽂' i_md_content_save_alert=$i
i='󰽃' i_md_content_save_alert_outline=$i
i='󰽄' i_md_content_save_all_outline=$i
i='󰽅' i_md_crosshairs_off=$i
i='󰽆' i_md_cupboard=$i
i='󰽇' i_md_cupboard_outline=$i
i='󰽈' i_md_chair_rolling=$i
i='󰽉' i_md_draw=$i
i='󰽊' i_md_dresser=$i
i='󰽋' i_md_dresser_outline=$i
i='󰽌' i_md_emoticon_frown=$i
i='󰽍' i_md_emoticon_frown_outline=$i
i='󰽎' i_md_focus_auto=$i
i='󰽏' i_md_focus_field=$i
i='󰽐' i_md_focus_field_horizontal=$i
i='󰽑' i_md_focus_field_vertical=$i
i='󰽒' i_md_foot_print=$i
i='󰽓' i_md_handball=$i
i='󰽔' i_md_home_thermometer=$i
i='󰽕' i_md_home_thermometer_outline=$i
i='󰽖' i_md_kettle_outline=$i
i='󰽗' i_md_latitude=$i
i='󰽘' i_md_layers_triple=$i
i='󰽙' i_md_layers_triple_outline=$i
i='󰽚' i_md_longitude=$i
i='󰽛' i_md_language_markdown_outline=$i
i='󰽜' i_md_merge=$i
i='󰽝' i_md_middleware=$i
i='󰽞' i_md_middleware_outline=$i
i='󰽟' i_md_monitor_speaker=$i
i='󰽠' i_md_monitor_speaker_off=$i
i='󰽡' i_md_moon_first_quarter=$i
i='󰽢' i_md_moon_full=$i
i='󰽣' i_md_moon_last_quarter=$i
i='󰽤' i_md_moon_new=$i
i='󰽥' i_md_moon_waning_crescent=$i
i='󰽦' i_md_moon_waning_gibbous=$i
i='󰽧' i_md_moon_waxing_crescent=$i
i='󰽨' i_md_moon_waxing_gibbous=$i
i='󰽩' i_md_music_accidental_double_flat=$i
i='󰽪' i_md_music_accidental_double_sharp=$i
i='󰽫' i_md_music_accidental_flat=$i
i='󰽬' i_md_music_accidental_natural=$i
i='󰽭' i_md_music_accidental_sharp=$i
i='󰽮' i_md_music_clef_alto=$i
i='󰽯' i_md_music_clef_bass=$i
i='󰽰' i_md_music_clef_treble=$i
i='󰽱' i_md_music_note_eighth_dotted=$i
i='󰽲' i_md_music_note_half_dotted=$i
i='󰽳' i_md_music_note_off_outline=$i
i='󰽴' i_md_music_note_outline=$i
i='󰽵' i_md_music_note_quarter_dotted=$i
i='󰽶' i_md_music_note_sixteenth_dotted=$i
i='󰽷' i_md_music_note_whole_dotted=$i
i='󰽸' i_md_music_rest_eighth=$i
i='󰽹' i_md_music_rest_half=$i
i='󰽺' i_md_music_rest_quarter=$i
i='󰽻' i_md_music_rest_sixteenth=$i
i='󰽼' i_md_music_rest_whole=$i
i='󰽽' i_md_numeric_10_box=$i
i='󰽾' i_md_numeric_10_box_outline=$i
i='󰽿' i_md_page_layout_header_footer=$i
i='󰾀' i_md_patio_heater=$i
i='󰾁' i_md_warehouse=$i
i='󰾂' i_md_select_group=$i
i='󰾃' i_md_shield_car=$i
i='󰾄' i_md_shopping_search=$i
i='󰾅' i_md_speedometer_medium=$i
i='󰾆' i_md_speedometer_slow=$i
i='󰾇' i_md_table_large_plus=$i
i='󰾈' i_md_table_large_remove=$i
i='󰾉' i_md_television_pause=$i
i='󰾊' i_md_television_stop=$i
i='󰾋' i_md_transit_detour=$i
i='󰾌' i_md_video_input_scart=$i
i='󰾍' i_md_view_grid_plus=$i
i='󰾎' i_md_wallet_plus=$i
i='󰾏' i_md_wallet_plus_outline=$i
i='󰾐' i_md_wardrobe=$i
i='󰾑' i_md_wardrobe_outline=$i
i='󰾒' i_md_water_boiler=$i
i='󰾓' i_md_water_pump_off=$i
i='󰾔' i_md_web_box=$i
i='󰾕' i_md_timeline_alert=$i
i='󰾖' i_md_timeline_plus=$i
i='󰾗' i_md_timeline_plus_outline=$i
i='󰾘' i_md_timeline_alert_outline=$i
i='󰾙' i_md_timeline_help=$i
i='󰾚' i_md_timeline_help_outline=$i
i='󰾛' i_md_home_export_outline=$i
i='󰾜' i_md_home_import_outline=$i
i='󰾝' i_md_account_filter_outline=$i
i='󰾞' i_md_approximately_equal=$i
i='󰾟' i_md_approximately_equal_box=$i
i='󰾠' i_md_baby_carriage_off=$i
i='󰾡' i_md_bee=$i
i='󰾢' i_md_bee_flower=$i
i='󰾣' i_md_car_child_seat=$i
i='󰾤' i_md_car_seat=$i
i='󰾥' i_md_car_seat_cooler=$i
i='󰾦' i_md_car_seat_heater=$i
i='󰾧' i_md_chart_bell_curve_cumulative=$i
i='󰾨' i_md_clock_check=$i
i='󰾩' i_md_clock_check_outline=$i
i='󰾪' i_md_coffee_off=$i
i='󰾫' i_md_coffee_off_outline=$i
i='󰾬' i_md_credit_card_minus=$i
i='󰾭' i_md_credit_card_minus_outline=$i
i='󰾮' i_md_credit_card_remove=$i
i='󰾯' i_md_credit_card_remove_outline=$i
i='󰾰' i_md_devices=$i
i='󰾱' i_md_email_newsletter=$i
i='󰾲' i_md_expansion_card_variant=$i
i='󰾳' i_md_power_socket_ch=$i
i='󰾴' i_md_file_swap=$i
i='󰾵' i_md_file_swap_outline=$i
i='󰾶' i_md_folder_swap=$i
i='󰾷' i_md_folder_swap_outline=$i
i='󰾸' i_md_format_letter_ends_with=$i
i='󰾹' i_md_format_letter_matches=$i
i='󰾺' i_md_format_letter_starts_with=$i
i='󰾻' i_md_format_text_rotation_angle_down=$i
i='󰾼' i_md_format_text_rotation_angle_up=$i
i='󰾽' i_md_format_text_rotation_down_vertical=$i
i='󰾾' i_md_format_text_rotation_up=$i
i='󰾿' i_md_format_text_rotation_vertical=$i
i='󰿀' i_md_id_card=$i
i='󰿁' i_md_image_auto_adjust=$i
i='󰿂' i_md_key_wireless=$i
i='󰿃' i_md_license=$i
i='󰿄' i_md_location_enter=$i
i='󰿅' i_md_location_exit=$i
i='󰿆' i_md_lock_open_variant=$i
i='󰿇' i_md_lock_open_variant_outline=$i
i='󰿈' i_md_math_integral=$i
i='󰿉' i_md_math_integral_box=$i
i='󰿊' i_md_math_norm=$i
i='󰿋' i_md_math_norm_box=$i
i='󰿌' i_md_message_lock=$i
i='󰿍' i_md_message_text_lock=$i
i='󰿎' i_md_movie_open=$i
i='󰿏' i_md_movie_open_outline=$i
i='󰿐' i_md_bed_queen=$i
i='󰿑' i_md_bed_king_outline=$i
i='󰿒' i_md_bed_king=$i
i='󰿓' i_md_bed_double_outline=$i
i='󰿔' i_md_bed_double=$i
i='󰿕' i_md_microsoft_azure_devops=$i
i='󰿖' i_md_arm_flex_outline=$i
i='󰿗' i_md_arm_flex=$i
i='󰿘' i_md_protocol=$i
i='󰿙' i_md_seal_variant=$i
i='󰿚' i_md_select_place=$i
i='󰿛' i_md_bed_queen_outline=$i
i='󰿜' i_md_sign_direction_plus=$i
i='󰿝' i_md_sign_direction_remove=$i
i='󰿞' i_md_silverware_clean=$i
i='󰿟' i_md_slash_forward=$i
i='󰿠' i_md_slash_forward_box=$i
i='󰿡' i_md_swap_horizontal_circle=$i
i='󰿢' i_md_swap_horizontal_circle_outline=$i
i='󰿣' i_md_swap_vertical_circle=$i
i='󰿤' i_md_swap_vertical_circle_outline=$i
i='󰿥' i_md_tanker_truck=$i
i='󰿦' i_md_texture_box=$i
i='󰿧' i_md_tram_side=$i
i='󰿨' i_md_vector_link=$i
i='󰿩' i_md_numeric_10=$i
i='󰿪' i_md_numeric_10_box_multiple=$i
i='󰿫' i_md_numeric_10_box_multiple_outline=$i
i='󰿬' i_md_numeric_10_circle=$i
i='󰿭' i_md_numeric_10_circle_outline=$i
i='󰿮' i_md_numeric_9_plus=$i
i='󰿯' i_md_credit_card=$i
i='󰿰' i_md_credit_card_multiple=$i
i='󰿱' i_md_credit_card_off=$i
i='󰿲' i_md_credit_card_plus=$i
i='󰿳' i_md_credit_card_refund=$i
i='󰿴' i_md_credit_card_scan=$i
i='󰿵' i_md_credit_card_settings=$i
i='󰿶' i_md_hospital=$i
i='󰿷' i_md_hospital_box_outline=$i
i='󰿸' i_md_oil_temperature=$i
i='󰿹' i_md_stadium=$i
i='󰿺' i_md_zip_box_outline=$i
i='󰿻' i_md_account_edit_outline=$i
i='󰿼' i_md_peanut=$i
i='󰿽' i_md_peanut_off=$i
i='󰿾' i_md_peanut_outline=$i
i='󰿿' i_md_peanut_off_outline=$i
i='󱀀' i_md_sign_direction_minus=$i
i='󱀁' i_md_newspaper_variant=$i
i='󱀂' i_md_newspaper_variant_multiple=$i
i='󱀃' i_md_newspaper_variant_multiple_outline=$i
i='󱀄' i_md_newspaper_variant_outline=$i
i='󱀅' i_md_overscan=$i
i='󱀆' i_md_pig_variant=$i
i='󱀇' i_md_piggy_bank=$i
i='󱀈' i_md_post=$i
i='󱀉' i_md_post_outline=$i
i='󱀊' i_md_account_box_multiple_outline=$i
i='󱀋' i_md_airballoon_outline=$i
i='󱀌' i_md_alphabetical_off=$i
i='󱀍' i_md_alphabetical_variant=$i
i='󱀎' i_md_alphabetical_variant_off=$i
i='󱀏' i_md_apache_kafka=$i
i='󱀐' i_md_billboard=$i
i='󱀑' i_md_blinds_open=$i
i='󱀒' i_md_bus_stop=$i
i='󱀓' i_md_bus_stop_covered=$i
i='󱀔' i_md_bus_stop_uncovered=$i
i='󱀕' i_md_car_2_plus=$i
i='󱀖' i_md_car_3_plus=$i
i='󱀗' i_md_car_brake_retarder=$i
i='󱀘' i_md_car_clutch=$i
i='󱀙' i_md_car_coolant_level=$i
i='󱀚' i_md_car_turbocharger=$i
i='󱀛' i_md_car_windshield=$i
i='󱀜' i_md_car_windshield_outline=$i
i='󱀝' i_md_cards_diamond_outline=$i
i='󱀞' i_md_cast_audio=$i
i='󱀟' i_md_cellphone_play=$i
i='󱀠' i_md_coach_lamp=$i
i='󱀡' i_md_comment_quote=$i
i='󱀢' i_md_comment_quote_outline=$i
i='󱀣' i_md_domino_mask=$i
i='󱀤' i_md_electron_framework=$i
i='󱀥' i_md_excavator=$i
i='󱀦' i_md_eye_minus=$i
i='󱀧' i_md_eye_minus_outline=$i
i='󱀨' i_md_file_account_outline=$i
i='󱀩' i_md_file_chart_outline=$i
i='󱀪' i_md_file_cloud_outline=$i
i='󱀫' i_md_file_code_outline=$i
i='󱀬' i_md_file_excel_box_outline=$i
i='󱀭' i_md_file_excel_outline=$i
i='󱀮' i_md_file_export_outline=$i
i='󱀯' i_md_file_import_outline=$i
i='󱀰' i_md_file_lock_outline=$i
i='󱀱' i_md_file_move_outline=$i
i='󱀲' i_md_file_multiple_outline=$i
i='󱀳' i_md_file_percent_outline=$i
i='󱀴' i_md_file_powerpoint_box_outline=$i
i='󱀵' i_md_file_powerpoint_outline=$i
i='󱀶' i_md_file_question_outline=$i
i='󱀷' i_md_file_remove_outline=$i
i='󱀸' i_md_file_restore_outline=$i
i='󱀹' i_md_file_send_outline=$i
i='󱀺' i_md_file_star=$i
i='󱀻' i_md_file_star_outline=$i
i='󱀼' i_md_file_undo_outline=$i
i='󱀽' i_md_file_word_box_outline=$i
i='󱀾' i_md_file_word_outline=$i
i='󱀿' i_md_filter_variant_remove=$i
i='󱁀' i_md_floor_lamp_dual=$i
i='󱁁' i_md_floor_lamp_torchiere_variant=$i
i='󱁂' i_md_fruit_cherries=$i
i='󱁃' i_md_fruit_citrus=$i
i='󱁄' i_md_fruit_grapes=$i
i='󱁅' i_md_fruit_grapes_outline=$i
i='󱁆' i_md_fruit_pineapple=$i
i='󱁇' i_md_fruit_watermelon=$i
i='󱁈' i_md_google_my_business=$i
i='󱁉' i_md_graph=$i
i='󱁊' i_md_graph_outline=$i
i='󱁋' i_md_harddisk_plus=$i
i='󱁌' i_md_harddisk_remove=$i
i='󱁍' i_md_home_circle_outline=$i
i='󱁎' i_md_instrument_triangle=$i
i='󱁏' i_md_island=$i
i='󱁐' i_md_keyboard_space=$i
i='󱁑' i_md_led_strip_variant=$i
i='󱁒' i_md_numeric_negative_1=$i
i='󱁓' i_md_oil_level=$i
i='󱁔' i_md_outdoor_lamp=$i
i='󱁕' i_md_palm_tree=$i
i='󱁖' i_md_party_popper=$i
i='󱁗' i_md_printer_pos=$i
i='󱁘' i_md_robber=$i
i='󱁙' i_md_routes_clock=$i
i='󱁚' i_md_scale_off=$i
i='󱁛' i_md_cog_transfer=$i
i='󱁜' i_md_cog_transfer_outline=$i
i='󱁝' i_md_shield_sun=$i
i='󱁞' i_md_shield_sun_outline=$i
i='󱁟' i_md_sprinkler=$i
i='󱁠' i_md_sprinkler_variant=$i
i='󱁡' i_md_table_chair=$i
i='󱁢' i_md_terraform=$i
i='󱁣' i_md_toaster=$i
i='󱁤' i_md_tools=$i
i='󱁥' i_md_transfer=$i
i='󱁦' i_md_valve=$i
i='󱁧' i_md_valve_closed=$i
i='󱁨' i_md_valve_open=$i
i='󱁩' i_md_video_check=$i
i='󱁪' i_md_video_check_outline=$i
i='󱁫' i_md_water_well=$i
i='󱁬' i_md_water_well_outline=$i
i='󱁭' i_md_bed_single=$i
i='󱁮' i_md_bed_single_outline=$i
i='󱁯' i_md_book_information_variant=$i
i='󱁰' i_md_bottle_soda=$i
i='󱁱' i_md_bottle_soda_classic=$i
i='󱁲' i_md_bottle_soda_outline=$i
i='󱁳' i_md_calendar_blank_multiple=$i
i='󱁴' i_md_card_search=$i
i='󱁵' i_md_card_search_outline=$i
i='󱁶' i_md_face_woman_profile=$i
i='󱁷' i_md_face_woman=$i
i='󱁸' i_md_face_woman_outline=$i
i='󱁹' i_md_file_settings=$i
i='󱁺' i_md_file_settings_outline=$i
i='󱁻' i_md_file_cog=$i
i='󱁼' i_md_file_cog_outline=$i
i='󱁽' i_md_folder_settings=$i
i='󱁾' i_md_folder_settings_outline=$i
i='󱁿' i_md_folder_cog=$i
i='󱂀' i_md_folder_cog_outline=$i
i='󱂁' i_md_furigana_horizontal=$i
i='󱂂' i_md_furigana_vertical=$i
i='󱂃' i_md_golf_tee=$i
i='󱂄' i_md_lungs=$i
i='󱂅' i_md_math_log=$i
i='󱂆' i_md_moped=$i
i='󱂇' i_md_router_network=$i
i='󱂉' i_md_roman_numeral_2=$i
i='󱂊' i_md_roman_numeral_3=$i
i='󱂋' i_md_roman_numeral_4=$i
i='󱂍' i_md_roman_numeral_6=$i
i='󱂎' i_md_roman_numeral_7=$i
i='󱂏' i_md_roman_numeral_8=$i
i='󱂐' i_md_roman_numeral_9=$i
i='󱂒' i_md_soldering_iron=$i
i='󱂓' i_md_stomach=$i
i='󱂔' i_md_table_eye=$i
i='󱂕' i_md_form_textarea=$i
i='󱂖' i_md_trumpet=$i
i='󱂗' i_md_account_cash=$i
i='󱂘' i_md_account_cash_outline=$i
i='󱂙' i_md_air_humidifier=$i
i='󱂚' i_md_ansible=$i
i='󱂛' i_md_api=$i
i='󱂜' i_md_bicycle=$i
i='󱂝' i_md_car_door_lock=$i
i='󱂞' i_md_coat_rack=$i
i='󱂟' i_md_coffee_maker=$i
i='󱂠' i_md_web_minus=$i
i='󱂡' i_md_decimal=$i
i='󱂢' i_md_decimal_comma=$i
i='󱂣' i_md_decimal_comma_decrease=$i
i='󱂤' i_md_decimal_comma_increase=$i
i='󱂥' i_md_delete_alert=$i
i='󱂦' i_md_delete_alert_outline=$i
i='󱂧' i_md_delete_off=$i
i='󱂨' i_md_delete_off_outline=$i
i='󱂩' i_md_dock_bottom=$i
i='󱂪' i_md_dock_left=$i
i='󱂫' i_md_dock_right=$i
i='󱂬' i_md_dock_window=$i
i='󱂭' i_md_domain_plus=$i
i='󱂮' i_md_domain_remove=$i
i='󱂯' i_md_door_closed_lock=$i
i='󱂰' i_md_download_off=$i
i='󱂱' i_md_download_off_outline=$i
i='󱂲' i_md_flag_minus_outline=$i
i='󱂳' i_md_flag_plus_outline=$i
i='󱂴' i_md_flag_remove_outline=$i
i='󱂵' i_md_folder_home=$i
i='󱂶' i_md_folder_home_outline=$i
i='󱂷' i_md_folder_information=$i
i='󱂸' i_md_folder_information_outline=$i
i='󱂹' i_md_iv_bag=$i
i='󱂺' i_md_link_lock=$i
i='󱂻' i_md_message_plus_outline=$i
i='󱂼' i_md_phone_cancel=$i
i='󱂽' i_md_smart_card=$i
i='󱂾' i_md_smart_card_outline=$i
i='󱂿' i_md_smart_card_reader=$i
i='󱃀' i_md_smart_card_reader_outline=$i
i='󱃁' i_md_storefront_outline=$i
i='󱃂' i_md_thermometer_high=$i
i='󱃃' i_md_thermometer_low=$i
i='󱃄' i_md_ufo=$i
i='󱃅' i_md_ufo_outline=$i
i='󱃆' i_md_upload_off=$i
i='󱃇' i_md_upload_off_outline=$i
i='󱃈' i_md_account_child_outline=$i
i='󱃉' i_md_account_settings_outline=$i
i='󱃊' i_md_account_tie_outline=$i
i='󱃋' i_md_alien_outline=$i
i='󱃌' i_md_battery_alert_variant=$i
i='󱃍' i_md_battery_alert_variant_outline=$i
i='󱃎' i_md_beehive_outline=$i
i='󱃏' i_md_boomerang=$i
i='󱃐' i_md_briefcase_clock=$i
i='󱃑' i_md_briefcase_clock_outline=$i
i='󱃒' i_md_cellphone_message_off=$i
i='󱃓' i_md_circle_off_outline=$i
i='󱃔' i_md_clipboard_list=$i
i='󱃕' i_md_clipboard_list_outline=$i
i='󱃖' i_md_code_braces_box=$i
i='󱃗' i_md_code_parentheses_box=$i
i='󱃘' i_md_consolidate=$i
i='󱃙' i_md_electric_switch_closed=$i
i='󱃚' i_md_email_receive=$i
i='󱃛' i_md_email_receive_outline=$i
i='󱃜' i_md_email_send=$i
i='󱃝' i_md_email_send_outline=$i
i='󱃞' i_md_emoticon_confused=$i
i='󱃟' i_md_emoticon_confused_outline=$i
i='󱃠' i_md_epsilon=$i
i='󱃡' i_md_file_table_box=$i
i='󱃢' i_md_file_table_box_multiple=$i
i='󱃣' i_md_file_table_box_multiple_outline=$i
i='󱃤' i_md_file_table_box_outline=$i
i='󱃥' i_md_filter_menu=$i
i='󱃦' i_md_filter_menu_outline=$i
i='󱃧' i_md_flip_horizontal=$i
i='󱃨' i_md_flip_vertical=$i
i='󱃩' i_md_folder_download_outline=$i
i='󱃪' i_md_folder_heart=$i
i='󱃫' i_md_folder_heart_outline=$i
i='󱃬' i_md_folder_key_outline=$i
i='󱃭' i_md_folder_upload_outline=$i
i='󱃮' i_md_gamma=$i
i='󱃯' i_md_hair_dryer=$i
i='󱃰' i_md_hair_dryer_outline=$i
i='󱃱' i_md_hand_heart=$i
i='󱃲' i_md_hexagon_multiple_outline=$i
i='󱃳' i_md_horizontal_rotate_clockwise=$i
i='󱃴' i_md_horizontal_rotate_counterclockwise=$i
i='󱃵' i_md_application_array=$i
i='󱃶' i_md_application_array_outline=$i
i='󱃷' i_md_application_braces=$i
i='󱃸' i_md_application_braces_outline=$i
i='󱃹' i_md_application_parentheses=$i
i='󱃺' i_md_application_parentheses_outline=$i
i='󱃻' i_md_application_variable=$i
i='󱃼' i_md_application_variable_outline=$i
i='󱃽' i_md_khanda=$i
i='󱃾' i_md_kubernetes=$i
i='󱃿' i_md_link_variant_minus=$i
i='󱄀' i_md_link_variant_plus=$i
i='󱄁' i_md_link_variant_remove=$i
i='󱄂' i_md_map_marker_down=$i
i='󱄃' i_md_map_marker_up=$i
i='󱄄' i_md_monitor_shimmer=$i
i='󱄅' i_md_nix=$i
i='󱄆' i_md_nuxt=$i
i='󱄇' i_md_power_socket_de=$i
i='󱄈' i_md_power_socket_fr=$i
i='󱄉' i_md_power_socket_jp=$i
i='󱄊' i_md_progress_close=$i
i='󱄋' i_md_reload_alert=$i
i='󱄌' i_md_restart_alert=$i
i='󱄍' i_md_restore_alert=$i
i='󱄎' i_md_shaker=$i
i='󱄏' i_md_shaker_outline=$i
i='󱄐' i_md_television_shimmer=$i
i='󱄑' i_md_variable_box=$i
i='󱄒' i_md_filter_variant_minus=$i
i='󱄓' i_md_filter_variant_plus=$i
i='󱄔' i_md_slot_machine=$i
i='󱄕' i_md_slot_machine_outline=$i
i='󱄖' i_md_glass_mug_variant=$i
i='󱄗' i_md_clipboard_flow_outline=$i
i='󱄘' i_md_sign_real_estate=$i
i='󱄙' i_md_antenna=$i
i='󱄚' i_md_centos=$i
i='󱄛' i_md_redhat=$i
i='󱄜' i_md_window_shutter=$i
i='󱄝' i_md_window_shutter_alert=$i
i='󱄞' i_md_window_shutter_open=$i
i='󱄟' i_md_bike_fast=$i
i='󱄠' i_md_volume_source=$i
i='󱄡' i_md_volume_vibrate=$i
i='󱄢' i_md_movie_edit=$i
i='󱄣' i_md_movie_edit_outline=$i
i='󱄤' i_md_movie_filter=$i
i='󱄥' i_md_movie_filter_outline=$i
i='󱄦' i_md_diabetes=$i
i='󱄧' i_md_cursor_default_gesture=$i
i='󱄨' i_md_cursor_default_gesture_outline=$i
i='󱄩' i_md_toothbrush=$i
i='󱄪' i_md_toothbrush_paste=$i
i='󱄫' i_md_home_roof=$i
i='󱄬' i_md_toothbrush_electric=$i
i='󱄭' i_md_account_supervisor_outline=$i
i='󱄮' i_md_bottle_tonic=$i
i='󱄯' i_md_bottle_tonic_outline=$i
i='󱄰' i_md_bottle_tonic_plus=$i
i='󱄱' i_md_bottle_tonic_plus_outline=$i
i='󱄲' i_md_bottle_tonic_skull=$i
i='󱄳' i_md_bottle_tonic_skull_outline=$i
i='󱄴' i_md_calendar_arrow_left=$i
i='󱄵' i_md_calendar_arrow_right=$i
i='󱄶' i_md_crosshairs_question=$i
i='󱄷' i_md_fire_hydrant=$i
i='󱄸' i_md_fire_hydrant_alert=$i
i='󱄹' i_md_fire_hydrant_off=$i
i='󱄺' i_md_ocr=$i
i='󱄻' i_md_shield_star=$i
i='󱄼' i_md_shield_star_outline=$i
i='󱄽' i_md_text_recognition=$i
i='󱄾' i_md_handcuffs=$i
i='󱄿' i_md_gender_male_female_variant=$i
i='󱅀' i_md_gender_non_binary=$i
i='󱅁' i_md_minus_box_multiple=$i
i='󱅂' i_md_minus_box_multiple_outline=$i
i='󱅃' i_md_plus_box_multiple_outline=$i
i='󱅄' i_md_pencil_box_multiple=$i
i='󱅅' i_md_pencil_box_multiple_outline=$i
i='󱅆' i_md_printer_check=$i
i='󱅇' i_md_sort_variant_remove=$i
i='󱅈' i_md_sort_alphabetical_ascending_variant=$i
i='󱅉' i_md_sort_alphabetical_descending_variant=$i
i='󱅊' i_md_dice_1_outline=$i
i='󱅋' i_md_dice_2_outline=$i
i='󱅌' i_md_dice_3_outline=$i
i='󱅍' i_md_dice_4_outline=$i
i='󱅎' i_md_dice_5_outline=$i
i='󱅏' i_md_dice_6_outline=$i
i='󱅐' i_md_dice_d4=$i
i='󱅑' i_md_dice_d6=$i
i='󱅒' i_md_dice_d8=$i
i='󱅓' i_md_dice_d10=$i
i='󱅔' i_md_dice_d12=$i
i='󱅕' i_md_dice_d20=$i
i='󱅖' i_md_dice_multiple_outline=$i
i='󱅗' i_md_paper_roll=$i
i='󱅘' i_md_paper_roll_outline=$i
i='󱅙' i_md_home_edit=$i
i='󱅚' i_md_home_edit_outline=$i
i='󱅛' i_md_arrow_horizontal_lock=$i
i='󱅜' i_md_arrow_vertical_lock=$i
i='󱅝' i_md_weight_lifter=$i
i='󱅞' i_md_account_lock=$i
i='󱅟' i_md_account_lock_outline=$i
i='󱅠' i_md_pasta=$i
i='󱅡' i_md_send_check=$i
i='󱅢' i_md_send_check_outline=$i
i='󱅣' i_md_send_clock=$i
i='󱅤' i_md_send_clock_outline=$i
i='󱅥' i_md_send_outline=$i
i='󱅦' i_md_send_lock_outline=$i
i='󱅧' i_md_police_badge=$i
i='󱅨' i_md_police_badge_outline=$i
i='󱅩' i_md_gate_arrow_right=$i
i='󱅪' i_md_gate_open=$i
i='󱅫' i_md_bell_badge=$i
i='󱅬' i_md_message_image_outline=$i
i='󱅭' i_md_message_lock_outline=$i
i='󱅮' i_md_message_minus=$i
i='󱅯' i_md_message_minus_outline=$i
i='󱅰' i_md_message_processing_outline=$i
i='󱅱' i_md_message_settings_outline=$i
i='󱅲' i_md_message_cog_outline=$i
i='󱅳' i_md_message_text_clock=$i
i='󱅴' i_md_message_text_clock_outline=$i
i='󱅵' i_md_message_text_lock_outline=$i
i='󱅶' i_md_checkbox_blank_badge=$i
i='󱅷' i_md_file_link=$i
i='󱅸' i_md_file_link_outline=$i
i='󱅹' i_md_file_phone=$i
i='󱅺' i_md_file_phone_outline=$i
i='󱅻' i_md_meditation=$i
i='󱅼' i_md_yoga=$i
i='󱅽' i_md_leek=$i
i='󱅾' i_md_noodles=$i
i='󱅿' i_md_pound_box_outline=$i
i='󱆀' i_md_school_outline=$i
i='󱆁' i_md_basket_outline=$i
i='󱆂' i_md_phone_in_talk_outline=$i
i='󱆃' i_md_bash=$i
i='󱆄' i_md_file_key=$i
i='󱆅' i_md_file_key_outline=$i
i='󱆆' i_md_file_certificate=$i
i='󱆇' i_md_file_certificate_outline=$i
i='󱆈' i_md_certificate_outline=$i
i='󱆉' i_md_cigar=$i
i='󱆊' i_md_grill_outline=$i
i='󱆋' i_md_qrcode_plus=$i
i='󱆌' i_md_qrcode_minus=$i
i='󱆍' i_md_qrcode_remove=$i
i='󱆎' i_md_phone_alert_outline=$i
i='󱆏' i_md_phone_bluetooth_outline=$i
i='󱆐' i_md_phone_cancel_outline=$i
i='󱆑' i_md_phone_forward_outline=$i
i='󱆒' i_md_phone_hangup_outline=$i
i='󱆓' i_md_phone_incoming_outline=$i
i='󱆔' i_md_phone_lock_outline=$i
i='󱆕' i_md_phone_log_outline=$i
i='󱆖' i_md_phone_message=$i
i='󱆗' i_md_phone_message_outline=$i
i='󱆘' i_md_phone_minus_outline=$i
i='󱆙' i_md_phone_outgoing_outline=$i
i='󱆚' i_md_phone_paused_outline=$i
i='󱆛' i_md_phone_plus_outline=$i
i='󱆜' i_md_phone_return_outline=$i
i='󱆝' i_md_phone_settings_outline=$i
i='󱆞' i_md_key_star=$i
i='󱆟' i_md_key_link=$i
i='󱆠' i_md_shield_edit=$i
i='󱆡' i_md_shield_edit_outline=$i
i='󱆢' i_md_shield_sync=$i
i='󱆣' i_md_shield_sync_outline=$i
i='󱆤' i_md_golf_cart=$i
i='󱆥' i_md_phone_missed_outline=$i
i='󱆦' i_md_phone_off_outline=$i
i='󱆧' i_md_format_quote_open_outline=$i
i='󱆨' i_md_format_quote_close_outline=$i
i='󱆩' i_md_phone_check=$i
i='󱆪' i_md_phone_check_outline=$i
i='󱆫' i_md_phone_ring=$i
i='󱆬' i_md_phone_ring_outline=$i
i='󱆭' i_md_share_circle=$i
i='󱆮' i_md_reply_circle=$i
i='󱆯' i_md_fridge_off=$i
i='󱆰' i_md_fridge_off_outline=$i
i='󱆱' i_md_fridge_alert=$i
i='󱆲' i_md_fridge_alert_outline=$i
i='󱆳' i_md_water_boiler_alert=$i
i='󱆴' i_md_water_boiler_off=$i
i='󱆵' i_md_amplifier_off=$i
i='󱆶' i_md_audio_video_off=$i
i='󱆷' i_md_toaster_off=$i
i='󱆸' i_md_dishwasher_alert=$i
i='󱆹' i_md_dishwasher_off=$i
i='󱆺' i_md_tumble_dryer_alert=$i
i='󱆻' i_md_tumble_dryer_off=$i
i='󱆼' i_md_washing_machine_alert=$i
i='󱆽' i_md_washing_machine_off=$i
i='󱆾' i_md_car_info=$i
i='󱆿' i_md_comment_edit=$i
i='󱇀' i_md_printer_3d_nozzle_alert=$i
i='󱇁' i_md_printer_3d_nozzle_alert_outline=$i
i='󱇂' i_md_align_horizontal_left=$i
i='󱇃' i_md_align_horizontal_center=$i
i='󱇄' i_md_align_horizontal_right=$i
i='󱇅' i_md_align_vertical_bottom=$i
i='󱇆' i_md_align_vertical_center=$i
i='󱇇' i_md_align_vertical_top=$i
i='󱇈' i_md_distribute_horizontal_left=$i
i='󱇉' i_md_distribute_horizontal_center=$i
i='󱇊' i_md_distribute_horizontal_right=$i
i='󱇋' i_md_distribute_vertical_bottom=$i
i='󱇌' i_md_distribute_vertical_center=$i
i='󱇍' i_md_distribute_vertical_top=$i
i='󱇎' i_md_alert_rhombus=$i
i='󱇏' i_md_alert_rhombus_outline=$i
i='󱇐' i_md_crown_outline=$i
i='󱇑' i_md_image_off_outline=$i
i='󱇒' i_md_movie_search=$i
i='󱇓' i_md_movie_search_outline=$i
i='󱇔' i_md_rv_truck=$i
i='󱇕' i_md_shopping_outline=$i
i='󱇖' i_md_strategy=$i
i='󱇗' i_md_note_text_outline=$i
i='󱇘' i_md_view_agenda_outline=$i
i='󱇙' i_md_view_grid_outline=$i
i='󱇚' i_md_view_grid_plus_outline=$i
i='󱇛' i_md_window_closed_variant=$i
i='󱇜' i_md_window_open_variant=$i
i='󱇝' i_md_cog_clockwise=$i
i='󱇞' i_md_cog_counterclockwise=$i
i='󱇟' i_md_chart_sankey=$i
i='󱇠' i_md_chart_sankey_variant=$i
i='󱇡' i_md_vanity_light=$i
i='󱇢' i_md_router=$i
i='󱇣' i_md_image_edit=$i
i='󱇤' i_md_image_edit_outline=$i
i='󱇥' i_md_bell_check=$i
i='󱇦' i_md_bell_check_outline=$i
i='󱇧' i_md_file_edit=$i
i='󱇨' i_md_file_edit_outline=$i
i='󱇩' i_md_human_scooter=$i
i='󱇪' i_md_spider=$i
i='󱇫' i_md_spider_thread=$i
i='󱇬' i_md_plus_thick=$i
i='󱇭' i_md_alert_circle_check=$i
i='󱇮' i_md_alert_circle_check_outline=$i
i='󱇯' i_md_state_machine=$i
i='󱇰' i_md_usb_port=$i
i='󱇱' i_md_cloud_lock=$i
i='󱇲' i_md_cloud_lock_outline=$i
i='󱇳' i_md_robot_mower_outline=$i
i='󱇴' i_md_share_all=$i
i='󱇵' i_md_share_all_outline=$i
i='󱇶' i_md_google_cloud=$i
i='󱇷' i_md_robot_mower=$i
i='󱇸' i_md_fast_forward_5=$i
i='󱇹' i_md_rewind_5=$i
i='󱇺' i_md_shape_oval_plus=$i
i='󱇻' i_md_timeline_clock=$i
i='󱇼' i_md_timeline_clock_outline=$i
i='󱇽' i_md_mirror=$i
i='󱇾' i_md_account_multiple_check_outline=$i
i='󱇿' i_md_card_plus=$i
i='󱈀' i_md_card_plus_outline=$i
i='󱈁' i_md_checkerboard_plus=$i
i='󱈂' i_md_checkerboard_minus=$i
i='󱈃' i_md_checkerboard_remove=$i
i='󱈄' i_md_select_search=$i
i='󱈅' i_md_selection_search=$i
i='󱈆' i_md_layers_search=$i
i='󱈇' i_md_layers_search_outline=$i
i='󱈈' i_md_lightbulb_cfl=$i
i='󱈉' i_md_lightbulb_cfl_off=$i
i='󱈊' i_md_account_multiple_remove=$i
i='󱈋' i_md_account_multiple_remove_outline=$i
i='󱈌' i_md_magnify_remove_cursor=$i
i='󱈍' i_md_magnify_remove_outline=$i
i='󱈎' i_md_archive_outline=$i
i='󱈏' i_md_battery_heart=$i
i='󱈐' i_md_battery_heart_outline=$i
i='󱈑' i_md_battery_heart_variant=$i
i='󱈒' i_md_bus_marker=$i
i='󱈓' i_md_chart_multiple=$i
i='󱈔' i_md_emoticon_lol=$i
i='󱈕' i_md_emoticon_lol_outline=$i
i='󱈖' i_md_file_sync=$i
i='󱈗' i_md_file_sync_outline=$i
i='󱈘' i_md_handshake=$i
i='󱈙' i_md_language_kotlin=$i
i='󱈚' i_md_language_fortran=$i
i='󱈛' i_md_offer=$i
i='󱈜' i_md_radio_off=$i
i='󱈝' i_md_table_headers_eye=$i
i='󱈞' i_md_table_headers_eye_off=$i
i='󱈟' i_md_tag_minus_outline=$i
i='󱈠' i_md_tag_off=$i
i='󱈡' i_md_tag_off_outline=$i
i='󱈢' i_md_tag_plus_outline=$i
i='󱈣' i_md_tag_remove_outline=$i
i='󱈤' i_md_tag_text=$i
i='󱈥' i_md_vector_polyline_edit=$i
i='󱈦' i_md_vector_polyline_minus=$i
i='󱈧' i_md_vector_polyline_plus=$i
i='󱈨' i_md_vector_polyline_remove=$i
i='󱈩' i_md_beaker_alert=$i
i='󱈪' i_md_beaker_alert_outline=$i
i='󱈫' i_md_beaker_check=$i
i='󱈬' i_md_beaker_check_outline=$i
i='󱈭' i_md_beaker_minus=$i
i='󱈮' i_md_beaker_minus_outline=$i
i='󱈯' i_md_beaker_plus=$i
i='󱈰' i_md_beaker_plus_outline=$i
i='󱈱' i_md_beaker_question=$i
i='󱈲' i_md_beaker_question_outline=$i
i='󱈳' i_md_beaker_remove=$i
i='󱈴' i_md_beaker_remove_outline=$i
i='󱈵' i_md_bicycle_basket=$i
i='󱈶' i_md_barcode_off=$i
i='󱈷' i_md_digital_ocean=$i
i='󱈸' i_md_exclamation_thick=$i
i='󱈹' i_md_desk=$i
i='󱈺' i_md_flask_empty_minus=$i
i='󱈻' i_md_flask_empty_minus_outline=$i
i='󱈼' i_md_flask_empty_plus=$i
i='󱈽' i_md_flask_empty_plus_outline=$i
i='󱈾' i_md_flask_empty_remove=$i
i='󱈿' i_md_flask_empty_remove_outline=$i
i='󱉀' i_md_flask_minus=$i
i='󱉁' i_md_flask_minus_outline=$i
i='󱉂' i_md_flask_plus=$i
i='󱉃' i_md_flask_plus_outline=$i
i='󱉄' i_md_flask_remove=$i
i='󱉅' i_md_flask_remove_outline=$i
i='󱉆' i_md_folder_move_outline=$i
i='󱉇' i_md_home_remove=$i
i='󱉈' i_md_webrtc=$i
i='󱉉' i_md_seat_passenger=$i
i='󱉊' i_md_web_clock=$i
i='󱉋' i_md_flask_round_bottom=$i
i='󱉌' i_md_flask_round_bottom_empty=$i
i='󱉍' i_md_flask_round_bottom_empty_outline=$i
i='󱉎' i_md_flask_round_bottom_outline=$i
i='󱉏' i_md_gold=$i
i='󱉐' i_md_message_star_outline=$i
i='󱉑' i_md_home_lightbulb=$i
i='󱉒' i_md_home_lightbulb_outline=$i
i='󱉓' i_md_lightbulb_group=$i
i='󱉔' i_md_lightbulb_group_outline=$i
i='󱉕' i_md_lightbulb_multiple=$i
i='󱉖' i_md_lightbulb_multiple_outline=$i
i='󱉗' i_md_api_off=$i
i='󱉘' i_md_allergy=$i
i='󱉙' i_md_archive_arrow_down=$i
i='󱉚' i_md_archive_arrow_down_outline=$i
i='󱉛' i_md_archive_arrow_up=$i
i='󱉜' i_md_archive_arrow_up_outline=$i
i='󱉝' i_md_battery_off=$i
i='󱉞' i_md_battery_off_outline=$i
i='󱉟' i_md_bookshelf=$i
i='󱉠' i_md_cash_minus=$i
i='󱉡' i_md_cash_plus=$i
i='󱉢' i_md_cash_remove=$i
i='󱉣' i_md_clipboard_check_multiple=$i
i='󱉤' i_md_clipboard_check_multiple_outline=$i
i='󱉥' i_md_clipboard_file=$i
i='󱉦' i_md_clipboard_file_outline=$i
i='󱉧' i_md_clipboard_multiple=$i
i='󱉨' i_md_clipboard_multiple_outline=$i
i='󱉩' i_md_clipboard_play_multiple=$i
i='󱉪' i_md_clipboard_play_multiple_outline=$i
i='󱉫' i_md_clipboard_text_multiple=$i
i='󱉬' i_md_clipboard_text_multiple_outline=$i
i='󱉭' i_md_folder_marker=$i
i='󱉮' i_md_folder_marker_outline=$i
i='󱉯' i_md_format_list_text=$i
i='󱉰' i_md_inbox_arrow_down_outline=$i
i='󱉱' i_md_inbox_arrow_up_outline=$i
i='󱉲' i_md_inbox_full=$i
i='󱉳' i_md_inbox_full_outline=$i
i='󱉴' i_md_inbox_outline=$i
i='󱉵' i_md_lightbulb_cfl_spiral=$i
i='󱉶' i_md_magnify_scan=$i
i='󱉷' i_md_map_marker_multiple_outline=$i
i='󱉸' i_md_percent_outline=$i
i='󱉹' i_md_phone_classic_off=$i
i='󱉺' i_md_play_box=$i
i='󱉻' i_md_account_eye_outline=$i
i='󱉼' i_md_safe_square=$i
i='󱉽' i_md_safe_square_outline=$i
i='󱉾' i_md_scoreboard=$i
i='󱉿' i_md_scoreboard_outline=$i
i='󱊀' i_md_select_marker=$i
i='󱊁' i_md_select_multiple=$i
i='󱊂' i_md_select_multiple_marker=$i
i='󱊃' i_md_selection_marker=$i
i='󱊄' i_md_selection_multiple_marker=$i
i='󱊅' i_md_selection_multiple=$i
i='󱊆' i_md_star_box_multiple=$i
i='󱊇' i_md_star_box_multiple_outline=$i
i='󱊈' i_md_toy_brick=$i
i='󱊉' i_md_toy_brick_marker=$i
i='󱊊' i_md_toy_brick_marker_outline=$i
i='󱊋' i_md_toy_brick_minus=$i
i='󱊌' i_md_toy_brick_minus_outline=$i
i='󱊍' i_md_toy_brick_outline=$i
i='󱊎' i_md_toy_brick_plus=$i
i='󱊏' i_md_toy_brick_plus_outline=$i
i='󱊐' i_md_toy_brick_remove=$i
i='󱊑' i_md_toy_brick_remove_outline=$i
i='󱊒' i_md_toy_brick_search=$i
i='󱊓' i_md_toy_brick_search_outline=$i
i='󱊔' i_md_tray=$i
i='󱊕' i_md_tray_alert=$i
i='󱊖' i_md_tray_full=$i
i='󱊗' i_md_tray_minus=$i
i='󱊘' i_md_tray_plus=$i
i='󱊙' i_md_tray_remove=$i
i='󱊚' i_md_truck_check_outline=$i
i='󱊛' i_md_truck_delivery_outline=$i
i='󱊜' i_md_truck_fast_outline=$i
i='󱊝' i_md_truck_outline=$i
i='󱊞' i_md_usb_flash_drive=$i
i='󱊟' i_md_usb_flash_drive_outline=$i
i='󱊠' i_md_water_polo=$i
i='󱊡' i_md_battery_low=$i
i='󱊢' i_md_battery_medium=$i
i='󱊣' i_md_battery_high=$i
i='󱊤' i_md_battery_charging_low=$i
i='󱊥' i_md_battery_charging_medium=$i
i='󱊦' i_md_battery_charging_high=$i
i='󱊧' i_md_hexadecimal=$i
i='󱊨' i_md_gesture_tap_button=$i
i='󱊩' i_md_gesture_tap_box=$i
i='󱊪' i_md_lan_check=$i
i='󱊫' i_md_keyboard_f1=$i
i='󱊬' i_md_keyboard_f2=$i
i='󱊭' i_md_keyboard_f3=$i
i='󱊮' i_md_keyboard_f4=$i
i='󱊯' i_md_keyboard_f5=$i
i='󱊰' i_md_keyboard_f6=$i
i='󱊱' i_md_keyboard_f7=$i
i='󱊲' i_md_keyboard_f8=$i
i='󱊳' i_md_keyboard_f9=$i
i='󱊴' i_md_keyboard_f10=$i
i='󱊵' i_md_keyboard_f11=$i
i='󱊶' i_md_keyboard_f12=$i
i='󱊷' i_md_keyboard_esc=$i
i='󱊸' i_md_toslink=$i
i='󱊹' i_md_cheese=$i
i='󱊺' i_md_string_lights=$i
i='󱊻' i_md_string_lights_off=$i
i='󱊼' i_md_whistle_outline=$i
i='󱊽' i_md_stairs_up=$i
i='󱊾' i_md_stairs_down=$i
i='󱊿' i_md_escalator_up=$i
i='󱋀' i_md_escalator_down=$i
i='󱋁' i_md_elevator_up=$i
i='󱋂' i_md_elevator_down=$i
i='󱋃' i_md_lightbulb_cfl_spiral_off=$i
i='󱋄' i_md_comment_edit_outline=$i
i='󱋅' i_md_tooltip_edit_outline=$i
i='󱋆' i_md_monitor_edit=$i
i='󱋇' i_md_email_sync=$i
i='󱋈' i_md_email_sync_outline=$i
i='󱋉' i_md_chat_alert_outline=$i
i='󱋊' i_md_chat_processing_outline=$i
i='󱋋' i_md_snowflake_melt=$i
i='󱋌' i_md_cloud_check_outline=$i
i='󱋍' i_md_lightbulb_group_off=$i
i='󱋎' i_md_lightbulb_group_off_outline=$i
i='󱋏' i_md_lightbulb_multiple_off=$i
i='󱋐' i_md_lightbulb_multiple_off_outline=$i
i='󱋑' i_md_chat_sleep=$i
i='󱋒' i_md_chat_sleep_outline=$i
i='󱋓' i_md_garage_variant=$i
i='󱋔' i_md_garage_open_variant=$i
i='󱋕' i_md_garage_alert_variant=$i
i='󱋖' i_md_cloud_sync_outline=$i
i='󱋗' i_md_globe_light=$i
i='󱋘' i_md_cellphone_nfc_off=$i
i='󱋙' i_md_leaf_off=$i
i='󱋚' i_md_leaf_maple_off=$i
i='󱋛' i_md_map_marker_left=$i
i='󱋜' i_md_map_marker_right=$i
i='󱋝' i_md_map_marker_left_outline=$i
i='󱋞' i_md_map_marker_right_outline=$i
i='󱋟' i_md_account_cancel=$i
i='󱋠' i_md_account_cancel_outline=$i
i='󱋡' i_md_file_clock=$i
i='󱋢' i_md_file_clock_outline=$i
i='󱋣' i_md_folder_table=$i
i='󱋤' i_md_folder_table_outline=$i
i='󱋥' i_md_hydro_power=$i
i='󱋦' i_md_doorbell=$i
i='󱋧' i_md_bulma=$i
i='󱋨' i_md_iobroker=$i
i='󱋩' i_md_oci=$i
i='󱋪' i_md_label_percent=$i
i='󱋫' i_md_label_percent_outline=$i
i='󱋬' i_md_checkbox_blank_off=$i
i='󱋭' i_md_checkbox_blank_off_outline=$i
i='󱋮' i_md_square_off=$i
i='󱋯' i_md_square_off_outline=$i
i='󱋰' i_md_drag_horizontal_variant=$i
i='󱋱' i_md_drag_vertical_variant=$i
i='󱋲' i_md_message_arrow_left=$i
i='󱋳' i_md_message_arrow_left_outline=$i
i='󱋴' i_md_message_arrow_right=$i
i='󱋵' i_md_message_arrow_right_outline=$i
i='󱋶' i_md_database_marker=$i
i='󱋷' i_md_tag_multiple_outline=$i
i='󱋸' i_md_map_marker_plus_outline=$i
i='󱋹' i_md_map_marker_minus_outline=$i
i='󱋺' i_md_map_marker_remove_outline=$i
i='󱋻' i_md_map_marker_check_outline=$i
i='󱋼' i_md_map_marker_radius_outline=$i
i='󱋽' i_md_map_marker_off_outline=$i
i='󱋾' i_md_molecule_co=$i
i='󱋿' i_md_jump_rope=$i
i='󱌀' i_md_kettlebell=$i
i='󱌁' i_md_account_convert_outline=$i
i='󱌂' i_md_bunk_bed=$i
i='󱌃' i_md_fleur_de_lis=$i
i='󱌄' i_md_ski=$i
i='󱌅' i_md_ski_cross_country=$i
i='󱌆' i_md_ski_water=$i
i='󱌇' i_md_snowboard=$i
i='󱌈' i_md_account_tie_voice=$i
i='󱌉' i_md_account_tie_voice_outline=$i
i='󱌊' i_md_account_tie_voice_off=$i
i='󱌋' i_md_account_tie_voice_off_outline=$i
i='󱌌' i_md_beer_outline=$i
i='󱌍' i_md_glass_pint_outline=$i
i='󱌎' i_md_coffee_to_go_outline=$i
i='󱌏' i_md_cup_outline=$i
i='󱌐' i_md_bottle_wine_outline=$i
i='󱌑' i_md_earth_arrow_right=$i
i='󱌒' i_md_key_arrow_right=$i
i='󱌓' i_md_format_color_marker_cancel=$i
i='󱌔' i_md_mother_heart=$i
i='󱌕' i_md_currency_eur_off=$i
i='󱌖' i_md_semantic_web=$i
i='󱌗' i_md_kettle_alert=$i
i='󱌘' i_md_kettle_alert_outline=$i
i='󱌙' i_md_kettle_steam=$i
i='󱌚' i_md_kettle_steam_outline=$i
i='󱌛' i_md_kettle_off=$i
i='󱌜' i_md_kettle_off_outline=$i
i='󱌝' i_md_simple_icons=$i
i='󱌞' i_md_briefcase_check_outline=$i
i='󱌟' i_md_clipboard_plus_outline=$i
i='󱌠' i_md_download_lock=$i
i='󱌡' i_md_download_lock_outline=$i
i='󱌢' i_md_hammer_screwdriver=$i
i='󱌣' i_md_hammer_wrench=$i
i='󱌤' i_md_hydraulic_oil_level=$i
i='󱌥' i_md_hydraulic_oil_temperature=$i
i='󱌦' i_md_medal_outline=$i
i='󱌧' i_md_rodent=$i
i='󱌨' i_md_abjad_arabic=$i
i='󱌩' i_md_abjad_hebrew=$i
i='󱌪' i_md_abugida_devanagari=$i
i='󱌫' i_md_abugida_thai=$i
i='󱌬' i_md_alphabet_aurebesh=$i
i='󱌭' i_md_alphabet_cyrillic=$i
i='󱌮' i_md_alphabet_greek=$i
i='󱌯' i_md_alphabet_latin=$i
i='󱌰' i_md_alphabet_piqad=$i
i='󱌱' i_md_ideogram_cjk=$i
i='󱌲' i_md_ideogram_cjk_variant=$i
i='󱌳' i_md_syllabary_hangul=$i
i='󱌴' i_md_syllabary_hiragana=$i
i='󱌵' i_md_syllabary_katakana=$i
i='󱌶' i_md_syllabary_katakana_halfwidth=$i
i='󱌷' i_md_alphabet_tengwar=$i
i='󱌸' i_md_head_alert=$i
i='󱌹' i_md_head_alert_outline=$i
i='󱌺' i_md_head_check=$i
i='󱌻' i_md_head_check_outline=$i
i='󱌼' i_md_head_cog=$i
i='󱌽' i_md_head_cog_outline=$i
i='󱌾' i_md_head_dots_horizontal=$i
i='󱌿' i_md_head_dots_horizontal_outline=$i
i='󱍀' i_md_head_flash=$i
i='󱍁' i_md_head_flash_outline=$i
i='󱍂' i_md_head_heart=$i
i='󱍃' i_md_head_heart_outline=$i
i='󱍄' i_md_head_lightbulb=$i
i='󱍅' i_md_head_lightbulb_outline=$i
i='󱍆' i_md_head_minus=$i
i='󱍇' i_md_head_minus_outline=$i
i='󱍈' i_md_head_plus=$i
i='󱍉' i_md_head_plus_outline=$i
i='󱍊' i_md_head_question=$i
i='󱍋' i_md_head_question_outline=$i
i='󱍌' i_md_head_remove=$i
i='󱍍' i_md_head_remove_outline=$i
i='󱍎' i_md_head_snowflake=$i
i='󱍏' i_md_head_snowflake_outline=$i
i='󱍐' i_md_head_sync=$i
i='󱍑' i_md_head_sync_outline=$i
i='󱍒' i_md_hvac=$i
i='󱍓' i_md_pencil_ruler=$i
i='󱍔' i_md_pipe_wrench=$i
i='󱍕' i_md_widgets_outline=$i
i='󱍖' i_md_television_ambient_light=$i
i='󱍗' i_md_propane_tank=$i
i='󱍘' i_md_propane_tank_outline=$i
i='󱍙' i_md_folder_music=$i
i='󱍚' i_md_folder_music_outline=$i
i='󱍛' i_md_klingon=$i
i='󱍜' i_md_palette_swatch_outline=$i
i='󱍝' i_md_form_textbox_lock=$i
i='󱍞' i_md_head=$i
i='󱍟' i_md_head_outline=$i
i='󱍠' i_md_shield_half=$i
i='󱍡' i_md_store_outline=$i
i='󱍢' i_md_google_downasaur=$i
i='󱍣' i_md_bottle_soda_classic_outline=$i
i='󱍤' i_md_sticker=$i
i='󱍥' i_md_sticker_alert=$i
i='󱍦' i_md_sticker_alert_outline=$i
i='󱍧' i_md_sticker_check=$i
i='󱍨' i_md_sticker_check_outline=$i
i='󱍩' i_md_sticker_minus=$i
i='󱍪' i_md_sticker_minus_outline=$i
i='󱍫' i_md_sticker_outline=$i
i='󱍬' i_md_sticker_plus=$i
i='󱍭' i_md_sticker_plus_outline=$i
i='󱍮' i_md_sticker_remove=$i
i='󱍯' i_md_sticker_remove_outline=$i
i='󱍰' i_md_account_cog=$i
i='󱍱' i_md_account_cog_outline=$i
i='󱍲' i_md_account_details_outline=$i
i='󱍳' i_md_upload_lock=$i
i='󱍴' i_md_upload_lock_outline=$i
i='󱍵' i_md_label_multiple=$i
i='󱍶' i_md_label_multiple_outline=$i
i='󱍷' i_md_refresh_circle=$i
i='󱍸' i_md_sync_circle=$i
i='󱍹' i_md_bookmark_music_outline=$i
i='󱍺' i_md_bookmark_remove_outline=$i
i='󱍻' i_md_bookmark_check_outline=$i
i='󱍼' i_md_traffic_cone=$i
i='󱍽' i_md_cup_off_outline=$i
i='󱍾' i_md_auto_download=$i
i='󱍿' i_md_shuriken=$i
i='󱎀' i_md_chart_ppf=$i
i='󱎁' i_md_elevator_passenger=$i
i='󱎂' i_md_compass_rose=$i
i='󱎃' i_md_space_station=$i
i='󱎄' i_md_order_bool_descending=$i
i='󱎅' i_md_sort_bool_ascending=$i
i='󱎆' i_md_sort_bool_ascending_variant=$i
i='󱎇' i_md_sort_bool_descending=$i
i='󱎈' i_md_sort_bool_descending_variant=$i
i='󱎉' i_md_sort_numeric_ascending=$i
i='󱎊' i_md_sort_numeric_descending=$i
i='󱎋' i_md_human_baby_changing_table=$i
i='󱎌' i_md_human_male_child=$i
i='󱎍' i_md_human_wheelchair=$i
i='󱎎' i_md_microsoft_access=$i
i='󱎏' i_md_microsoft_excel=$i
i='󱎐' i_md_microsoft_powerpoint=$i
i='󱎑' i_md_microsoft_sharepoint=$i
i='󱎒' i_md_microsoft_word=$i
i='󱎓' i_md_nintendo_game_boy=$i
i='󱎔' i_md_cable_data=$i
i='󱎕' i_md_circle_half=$i
i='󱎖' i_md_circle_half_full=$i
i='󱎗' i_md_cellphone_charging=$i
i='󱎘' i_md_close_thick=$i
i='󱎙' i_md_escalator_box=$i
i='󱎚' i_md_lock_check=$i
i='󱎛' i_md_lock_open_alert=$i
i='󱎜' i_md_lock_open_check=$i
i='󱎝' i_md_recycle_variant=$i
i='󱎞' i_md_stairs_box=$i
i='󱎟' i_md_hand_water=$i
i='󱎠' i_md_table_refresh=$i
i='󱎡' i_md_table_sync=$i
i='󱎢' i_md_size_xxs=$i
i='󱎣' i_md_size_xs=$i
i='󱎤' i_md_size_s=$i
i='󱎥' i_md_size_m=$i
i='󱎧' i_md_size_xl=$i
i='󱎨' i_md_size_xxl=$i
i='󱎩' i_md_size_xxxl=$i
i='󱎪' i_md_ticket_confirmation_outline=$i
i='󱎫' i_md_timer=$i
i='󱎬' i_md_timer_off=$i
i='󱎭' i_md_book_account=$i
i='󱎮' i_md_book_account_outline=$i
i='󱎯' i_md_rocket_outline=$i
i='󱎰' i_md_home_search=$i
i='󱎱' i_md_home_search_outline=$i
i='󱎲' i_md_car_arrow_left=$i
i='󱎳' i_md_car_arrow_right=$i
i='󱎴' i_md_monitor_eye=$i
i='󱎵' i_md_lipstick=$i
i='󱎶' i_md_virus=$i
i='󱎷' i_md_virus_outline=$i
i='󱎸' i_md_text_search=$i
i='󱎹' i_md_table_account=$i
i='󱎺' i_md_table_alert=$i
i='󱎻' i_md_table_arrow_down=$i
i='󱎼' i_md_table_arrow_left=$i
i='󱎽' i_md_table_arrow_right=$i
i='󱎾' i_md_table_arrow_up=$i
i='󱎿' i_md_table_cancel=$i
i='󱏀' i_md_table_check=$i
i='󱏁' i_md_table_clock=$i
i='󱏂' i_md_table_cog=$i
i='󱏃' i_md_table_eye_off=$i
i='󱏄' i_md_table_heart=$i
i='󱏅' i_md_table_key=$i
i='󱏆' i_md_table_lock=$i
i='󱏇' i_md_table_minus=$i
i='󱏈' i_md_table_multiple=$i
i='󱏉' i_md_table_network=$i
i='󱏊' i_md_table_off=$i
i='󱏋' i_md_table_star=$i
i='󱏌' i_md_car_cog=$i
i='󱏍' i_md_car_settings=$i
i='󱏎' i_md_cog_off=$i
i='󱏏' i_md_cog_off_outline=$i
i='󱏐' i_md_credit_card_check=$i
i='󱏑' i_md_credit_card_check_outline=$i
i='󱏒' i_md_file_tree_outline=$i
i='󱏓' i_md_folder_star_multiple=$i
i='󱏔' i_md_folder_star_multiple_outline=$i
i='󱏕' i_md_home_minus_outline=$i
i='󱏖' i_md_home_plus_outline=$i
i='󱏗' i_md_home_remove_outline=$i
i='󱏘' i_md_scan_helper=$i
i='󱏙' i_md_video_3d_off=$i
i='󱏚' i_md_shield_bug=$i
i='󱏛' i_md_shield_bug_outline=$i
i='󱏜' i_md_eyedropper_plus=$i
i='󱏝' i_md_eyedropper_minus=$i
i='󱏞' i_md_eyedropper_remove=$i
i='󱏟' i_md_eyedropper_off=$i
i='󱏠' i_md_baby_buggy=$i
i='󱏡' i_md_umbrella_closed_variant=$i
i='󱏢' i_md_umbrella_closed_outline=$i
i='󱏣' i_md_email_off=$i
i='󱏤' i_md_email_off_outline=$i
i='󱏥' i_md_food_variant_off=$i
i='󱏦' i_md_play_box_multiple_outline=$i
i='󱏧' i_md_bell_cancel=$i
i='󱏨' i_md_bell_cancel_outline=$i
i='󱏩' i_md_bell_minus=$i
i='󱏪' i_md_bell_minus_outline=$i
i='󱏫' i_md_bell_remove=$i
i='󱏬' i_md_bell_remove_outline=$i
i='󱏭' i_md_beehive_off_outline=$i
i='󱏮' i_md_cheese_off=$i
i='󱏯' i_md_corn_off=$i
i='󱏰' i_md_egg_off=$i
i='󱏱' i_md_egg_off_outline=$i
i='󱏲' i_md_egg_outline=$i
i='󱏳' i_md_fish_off=$i
i='󱏴' i_md_flask_empty_off=$i
i='󱏵' i_md_flask_empty_off_outline=$i
i='󱏶' i_md_flask_off=$i
i='󱏷' i_md_flask_off_outline=$i
i='󱏸' i_md_fruit_cherries_off=$i
i='󱏹' i_md_fruit_citrus_off=$i
i='󱏺' i_md_mushroom_off=$i
i='󱏻' i_md_mushroom_off_outline=$i
i='󱏼' i_md_soy_sauce_off=$i
i='󱏽' i_md_seed_off=$i
i='󱏾' i_md_seed_off_outline=$i
i='󱏿' i_md_tailwind=$i
i='󱐀' i_md_form_dropdown=$i
i='󱐁' i_md_form_select=$i
i='󱐂' i_md_pump=$i
i='󱐃' i_md_earth_plus=$i
i='󱐄' i_md_earth_minus=$i
i='󱐅' i_md_earth_remove=$i
i='󱐆' i_md_earth_box_plus=$i
i='󱐇' i_md_earth_box_minus=$i
i='󱐈' i_md_earth_box_remove=$i
i='󱐉' i_md_gas_station_off=$i
i='󱐊' i_md_gas_station_off_outline=$i
i='󱐋' i_md_lightning_bolt=$i
i='󱐌' i_md_lightning_bolt_outline=$i
i='󱐍' i_md_smoking_pipe=$i
i='󱐎' i_md_axis_arrow_info=$i
i='󱐏' i_md_chat_plus=$i
i='󱐐' i_md_chat_minus=$i
i='󱐑' i_md_chat_remove=$i
i='󱐒' i_md_chat_plus_outline=$i
i='󱐓' i_md_chat_minus_outline=$i
i='󱐔' i_md_chat_remove_outline=$i
i='󱐕' i_md_bucket=$i
i='󱐖' i_md_bucket_outline=$i
i='󱐗' i_md_pail=$i
i='󱐘' i_md_image_remove=$i
i='󱐙' i_md_image_minus=$i
i='󱐚' i_md_pine_tree_fire=$i
i='󱐛' i_md_cigar_off=$i
i='󱐜' i_md_cube_off=$i
i='󱐝' i_md_cube_off_outline=$i
i='󱐞' i_md_dome_light=$i
i='󱐟' i_md_food_drumstick=$i
i='󱐠' i_md_food_drumstick_outline=$i
i='󱐡' i_md_incognito_circle=$i
i='󱐢' i_md_incognito_circle_off=$i
i='󱐣' i_md_microwave_off=$i
i='󱐤' i_md_power_plug_off_outline=$i
i='󱐥' i_md_power_plug_outline=$i
i='󱐦' i_md_puzzle_check=$i
i='󱐧' i_md_puzzle_check_outline=$i
i='󱐨' i_md_smoking_pipe_off=$i
i='󱐩' i_md_spoon_sugar=$i
i='󱐪' i_md_table_split_cell=$i
i='󱐫' i_md_ticket_percent_outline=$i
i='󱐬' i_md_fuse_off=$i
i='󱐭' i_md_fuse_alert=$i
i='󱐮' i_md_heart_plus=$i
i='󱐯' i_md_heart_minus=$i
i='󱐰' i_md_heart_remove=$i
i='󱐱' i_md_heart_plus_outline=$i
i='󱐲' i_md_heart_minus_outline=$i
i='󱐳' i_md_heart_remove_outline=$i
i='󱐴' i_md_heart_off_outline=$i
i='󱐵' i_md_motion_sensor_off=$i
i='󱐶' i_md_pail_plus=$i
i='󱐷' i_md_pail_minus=$i
i='󱐸' i_md_pail_remove=$i
i='󱐹' i_md_pail_off=$i
i='󱐺' i_md_pail_outline=$i
i='󱐻' i_md_pail_plus_outline=$i
i='󱐼' i_md_pail_minus_outline=$i
i='󱐽' i_md_pail_remove_outline=$i
i='󱐾' i_md_pail_off_outline=$i
i='󱐿' i_md_clock_time_one=$i
i='󱑀' i_md_clock_time_two=$i
i='󱑁' i_md_clock_time_three=$i
i='󱑂' i_md_clock_time_four=$i
i='󱑃' i_md_clock_time_five=$i
i='󱑄' i_md_clock_time_six=$i
i='󱑅' i_md_clock_time_seven=$i
i='󱑆' i_md_clock_time_eight=$i
i='󱑇' i_md_clock_time_nine=$i
i='󱑈' i_md_clock_time_ten=$i
i='󱑉' i_md_clock_time_eleven=$i
i='󱑊' i_md_clock_time_twelve=$i
i='󱑋' i_md_clock_time_one_outline=$i
i='󱑌' i_md_clock_time_two_outline=$i
i='󱑍' i_md_clock_time_three_outline=$i
i='󱑎' i_md_clock_time_four_outline=$i
i='󱑏' i_md_clock_time_five_outline=$i
i='󱑐' i_md_clock_time_six_outline=$i
i='󱑑' i_md_clock_time_seven_outline=$i
i='󱑒' i_md_clock_time_eight_outline=$i
i='󱑓' i_md_clock_time_nine_outline=$i
i='󱑔' i_md_clock_time_ten_outline=$i
i='󱑕' i_md_clock_time_eleven_outline=$i
i='󱑖' i_md_clock_time_twelve_outline=$i
i='󱑗' i_md_printer_search=$i
i='󱑘' i_md_printer_eye=$i
i='󱑙' i_md_minus_circle_off=$i
i='󱑚' i_md_minus_circle_off_outline=$i
i='󱑛' i_md_content_save_cog=$i
i='󱑜' i_md_content_save_cog_outline=$i
i='󱑝' i_md_set_square=$i
i='󱑞' i_md_cog_refresh=$i
i='󱑟' i_md_cog_refresh_outline=$i
i='󱑠' i_md_cog_sync=$i
i='󱑡' i_md_cog_sync_outline=$i
i='󱑢' i_md_download_box=$i
i='󱑣' i_md_download_box_outline=$i
i='󱑤' i_md_download_circle=$i
i='󱑥' i_md_download_circle_outline=$i
i='󱑦' i_md_air_humidifier_off=$i
i='󱑧' i_md_chili_off=$i
i='󱑨' i_md_food_drumstick_off=$i
i='󱑩' i_md_food_drumstick_off_outline=$i
i='󱑪' i_md_food_steak=$i
i='󱑫' i_md_food_steak_off=$i
i='󱑬' i_md_fan_alert=$i
i='󱑭' i_md_fan_chevron_down=$i
i='󱑮' i_md_fan_chevron_up=$i
i='󱑯' i_md_fan_plus=$i
i='󱑰' i_md_fan_minus=$i
i='󱑱' i_md_fan_remove=$i
i='󱑲' i_md_fan_speed_1=$i
i='󱑳' i_md_fan_speed_2=$i
i='󱑴' i_md_fan_speed_3=$i
i='󱑵' i_md_rug=$i
i='󱑶' i_md_lingerie=$i
i='󱑷' i_md_wizard_hat=$i
i='󱑸' i_md_hours_24=$i
i='󱑹' i_md_cosine_wave=$i
i='󱑺' i_md_sawtooth_wave=$i
i='󱑻' i_md_square_wave=$i
i='󱑼' i_md_triangle_wave=$i
i='󱑽' i_md_waveform=$i
i='󱑾' i_md_folder_multiple_plus=$i
i='󱑿' i_md_folder_multiple_plus_outline=$i
i='󱒀' i_md_current_ac=$i
i='󱒁' i_md_watering_can=$i
i='󱒂' i_md_watering_can_outline=$i
i='󱒃' i_md_monitor_share=$i
i='󱒄' i_md_laser_pointer=$i
i='󱒅' i_md_view_array_outline=$i
i='󱒆' i_md_view_carousel_outline=$i
i='󱒇' i_md_view_column_outline=$i
i='󱒈' i_md_view_comfy_outline=$i
i='󱒉' i_md_view_dashboard_variant_outline=$i
i='󱒊' i_md_view_day_outline=$i
i='󱒋' i_md_view_list_outline=$i
i='󱒌' i_md_view_module_outline=$i
i='󱒍' i_md_view_parallel_outline=$i
i='󱒎' i_md_view_quilt_outline=$i
i='󱒏' i_md_view_sequential_outline=$i
i='󱒐' i_md_view_stream_outline=$i
i='󱒑' i_md_view_week_outline=$i
i='󱒒' i_md_compare_horizontal=$i
i='󱒓' i_md_compare_vertical=$i
i='󱒔' i_md_briefcase_variant=$i
i='󱒕' i_md_briefcase_variant_outline=$i
i='󱒖' i_md_relation_many_to_many=$i
i='󱒗' i_md_relation_many_to_one=$i
i='󱒘' i_md_relation_many_to_one_or_many=$i
i='󱒙' i_md_relation_many_to_only_one=$i
i='󱒚' i_md_relation_many_to_zero_or_many=$i
i='󱒛' i_md_relation_many_to_zero_or_one=$i
i='󱒜' i_md_relation_one_or_many_to_many=$i
i='󱒝' i_md_relation_one_or_many_to_one=$i
i='󱒞' i_md_relation_one_or_many_to_one_or_many=$i
i='󱒟' i_md_relation_one_or_many_to_only_one=$i
i='󱒠' i_md_relation_one_or_many_to_zero_or_many=$i
i='󱒡' i_md_relation_one_or_many_to_zero_or_one=$i
i='󱒢' i_md_relation_one_to_many=$i
i='󱒣' i_md_relation_one_to_one=$i
i='󱒤' i_md_relation_one_to_one_or_many=$i
i='󱒥' i_md_relation_one_to_only_one=$i
i='󱒦' i_md_relation_one_to_zero_or_many=$i
i='󱒧' i_md_relation_one_to_zero_or_one=$i
i='󱒨' i_md_relation_only_one_to_many=$i
i='󱒩' i_md_relation_only_one_to_one=$i
i='󱒪' i_md_relation_only_one_to_one_or_many=$i
i='󱒫' i_md_relation_only_one_to_only_one=$i
i='󱒬' i_md_relation_only_one_to_zero_or_many=$i
i='󱒭' i_md_relation_only_one_to_zero_or_one=$i
i='󱒮' i_md_relation_zero_or_many_to_many=$i
i='󱒯' i_md_relation_zero_or_many_to_one=$i
i='󱒰' i_md_relation_zero_or_many_to_one_or_many=$i
i='󱒱' i_md_relation_zero_or_many_to_only_one=$i
i='󱒲' i_md_relation_zero_or_many_to_zero_or_many=$i
i='󱒳' i_md_relation_zero_or_many_to_zero_or_one=$i
i='󱒴' i_md_relation_zero_or_one_to_many=$i
i='󱒵' i_md_relation_zero_or_one_to_one=$i
i='󱒶' i_md_relation_zero_or_one_to_one_or_many=$i
i='󱒷' i_md_relation_zero_or_one_to_only_one=$i
i='󱒸' i_md_relation_zero_or_one_to_zero_or_many=$i
i='󱒹' i_md_relation_zero_or_one_to_zero_or_one=$i
i='󱒺' i_md_alert_plus=$i
i='󱒻' i_md_alert_minus=$i
i='󱒼' i_md_alert_remove=$i
i='󱒽' i_md_alert_plus_outline=$i
i='󱒾' i_md_alert_minus_outline=$i
i='󱒿' i_md_alert_remove_outline=$i
i='󱓀' i_md_carabiner=$i
i='󱓁' i_md_fencing=$i
i='󱓂' i_md_skateboard=$i
i='󱓃' i_md_polo=$i
i='󱓄' i_md_tractor_variant=$i
i='󱓅' i_md_radiology_box=$i
i='󱓆' i_md_radiology_box_outline=$i
i='󱓇' i_md_skull_scan=$i
i='󱓈' i_md_skull_scan_outline=$i
i='󱓉' i_md_plus_minus_variant=$i
i='󱓊' i_md_source_branch_plus=$i
i='󱓋' i_md_source_branch_minus=$i
i='󱓌' i_md_source_branch_remove=$i
i='󱓍' i_md_source_branch_refresh=$i
i='󱓎' i_md_source_branch_sync=$i
i='󱓏' i_md_source_branch_check=$i
i='󱓐' i_md_puzzle_plus=$i
i='󱓑' i_md_puzzle_minus=$i
i='󱓒' i_md_puzzle_remove=$i
i='󱓓' i_md_puzzle_edit=$i
i='󱓔' i_md_puzzle_heart=$i
i='󱓕' i_md_puzzle_star=$i
i='󱓖' i_md_puzzle_plus_outline=$i
i='󱓗' i_md_puzzle_minus_outline=$i
i='󱓘' i_md_puzzle_remove_outline=$i
i='󱓙' i_md_puzzle_edit_outline=$i
i='󱓚' i_md_puzzle_heart_outline=$i
i='󱓛' i_md_puzzle_star_outline=$i
i='󱓜' i_md_rhombus_medium_outline=$i
i='󱓝' i_md_rhombus_split_outline=$i
i='󱓞' i_md_rocket_launch=$i
i='󱓟' i_md_rocket_launch_outline=$i
i='󱓠' i_md_set_merge=$i
i='󱓡' i_md_set_split=$i
i='󱓢' i_md_beekeeper=$i
i='󱓣' i_md_snowflake_off=$i
i='󱓤' i_md_weather_sunny_off=$i
i='󱓥' i_md_clipboard_edit=$i
i='󱓦' i_md_clipboard_edit_outline=$i
i='󱓧' i_md_notebook_edit=$i
i='󱓨' i_md_human_edit=$i
i='󱓩' i_md_notebook_edit_outline=$i
i='󱓪' i_md_cash_lock=$i
i='󱓫' i_md_cash_lock_open=$i
i='󱓬' i_md_account_supervisor_circle_outline=$i
i='󱓭' i_md_car_outline=$i
i='󱓮' i_md_cash_check=$i
i='󱓯' i_md_filter_off=$i
i='󱓰' i_md_filter_off_outline=$i
i='󱓱' i_md_spirit_level=$i
i='󱓲' i_md_wheel_barrow=$i
i='󱓳' i_md_book_check=$i
i='󱓴' i_md_book_check_outline=$i
i='󱓵' i_md_notebook_check=$i
i='󱓶' i_md_notebook_check_outline=$i
i='󱓷' i_md_book_open_variant=$i
i='󱓸' i_md_sign_pole=$i
i='󱓹' i_md_shore=$i
i='󱓺' i_md_shape_square_rounded_plus=$i
i='󱓻' i_md_square_rounded=$i
i='󱓼' i_md_square_rounded_outline=$i
i='󱓽' i_md_archive_alert=$i
i='󱓾' i_md_archive_alert_outline=$i
i='󱓿' i_md_power_socket_it=$i
i='󱔀' i_md_square_circle=$i
i='󱔁' i_md_symbol=$i
i='󱔂' i_md_water_alert=$i
i='󱔃' i_md_water_alert_outline=$i
i='󱔄' i_md_water_check=$i
i='󱔅' i_md_water_check_outline=$i
i='󱔆' i_md_water_minus=$i
i='󱔇' i_md_water_minus_outline=$i
i='󱔈' i_md_water_off_outline=$i
i='󱔉' i_md_water_percent_alert=$i
i='󱔊' i_md_water_plus=$i
i='󱔋' i_md_water_plus_outline=$i
i='󱔌' i_md_water_remove=$i
i='󱔍' i_md_water_remove_outline=$i
i='󱔎' i_md_snake=$i
i='󱔏' i_md_format_text_variant_outline=$i
i='󱔐' i_md_grass=$i
i='󱔑' i_md_access_point_off=$i
i='󱔒' i_md_currency_mnt=$i
i='󱔓' i_md_dock_top=$i
i='󱔔' i_md_share_variant_outline=$i
i='󱔕' i_md_transit_skip=$i
i='󱔖' i_md_yurt=$i
i='󱔗' i_md_file_document_multiple=$i
i='󱔘' i_md_file_document_multiple_outline=$i
i='󱔙' i_md_ev_plug_ccs1=$i
i='󱔚' i_md_ev_plug_ccs2=$i
i='󱔛' i_md_ev_plug_chademo=$i
i='󱔜' i_md_ev_plug_tesla=$i
i='󱔝' i_md_ev_plug_type1=$i
i='󱔞' i_md_ev_plug_type2=$i
i='󱔟' i_md_office_building_outline=$i
i='󱔠' i_md_office_building_marker=$i
i='󱔡' i_md_office_building_marker_outline=$i
i='󱔢' i_md_progress_question=$i
i='󱔣' i_md_basket_minus=$i
i='󱔤' i_md_basket_minus_outline=$i
i='󱔥' i_md_basket_off=$i
i='󱔦' i_md_basket_off_outline=$i
i='󱔧' i_md_basket_plus=$i
i='󱔨' i_md_basket_plus_outline=$i
i='󱔩' i_md_basket_remove=$i
i='󱔪' i_md_basket_remove_outline=$i
i='󱔫' i_md_account_reactivate=$i
i='󱔬' i_md_account_reactivate_outline=$i
i='󱔭' i_md_car_lifted_pickup=$i
i='󱔮' i_md_video_high_definition=$i
i='󱔯' i_md_phone_remove=$i
i='󱔰' i_md_phone_remove_outline=$i
i='󱔱' i_md_thermometer_off=$i
i='󱔲' i_md_timeline_check=$i
i='󱔳' i_md_timeline_check_outline=$i
i='󱔴' i_md_timeline_minus=$i
i='󱔵' i_md_timeline_minus_outline=$i
i='󱔶' i_md_timeline_remove=$i
i='󱔷' i_md_timeline_remove_outline=$i
i='󱔸' i_md_access_point_check=$i
i='󱔹' i_md_access_point_minus=$i
i='󱔺' i_md_access_point_plus=$i
i='󱔻' i_md_access_point_remove=$i
i='󱔼' i_md_data_matrix=$i
i='󱔽' i_md_data_matrix_edit=$i
i='󱔾' i_md_data_matrix_minus=$i
i='󱔿' i_md_data_matrix_plus=$i
i='󱕀' i_md_data_matrix_remove=$i
i='󱕁' i_md_data_matrix_scan=$i
i='󱕂' i_md_tune_variant=$i
i='󱕃' i_md_tune_vertical_variant=$i
i='󱕄' i_md_rake=$i
i='󱕅' i_md_shimmer=$i
i='󱕆' i_md_transit_connection_horizontal=$i
i='󱕇' i_md_sort_calendar_ascending=$i
i='󱕈' i_md_sort_calendar_descending=$i
i='󱕉' i_md_sort_clock_ascending=$i
i='󱕊' i_md_sort_clock_ascending_outline=$i
i='󱕋' i_md_sort_clock_descending=$i
i='󱕌' i_md_sort_clock_descending_outline=$i
i='󱕍' i_md_chart_box=$i
i='󱕎' i_md_chart_box_outline=$i
i='󱕏' i_md_chart_box_plus_outline=$i
i='󱕐' i_md_mouse_move_down=$i
i='󱕑' i_md_mouse_move_up=$i
i='󱕒' i_md_mouse_move_vertical=$i
i='󱕓' i_md_pitchfork=$i
i='󱕔' i_md_vanish_quarter=$i
i='󱕕' i_md_application_settings_outline=$i
i='󱕖' i_md_delete_clock=$i
i='󱕗' i_md_delete_clock_outline=$i
i='󱕘' i_md_kangaroo=$i
i='󱕙' i_md_phone_dial=$i
i='󱕚' i_md_phone_dial_outline=$i
i='󱕛' i_md_star_off_outline=$i
i='󱕜' i_md_tooltip_check=$i
i='󱕝' i_md_tooltip_check_outline=$i
i='󱕞' i_md_tooltip_minus=$i
i='󱕟' i_md_tooltip_minus_outline=$i
i='󱕠' i_md_tooltip_remove=$i
i='󱕡' i_md_tooltip_remove_outline=$i
i='󱕢' i_md_pretzel=$i
i='󱕣' i_md_star_plus=$i
i='󱕤' i_md_star_minus=$i
i='󱕥' i_md_star_remove=$i
i='󱕦' i_md_star_check=$i
i='󱕧' i_md_star_plus_outline=$i
i='󱕨' i_md_star_minus_outline=$i
i='󱕩' i_md_star_remove_outline=$i
i='󱕪' i_md_star_check_outline=$i
i='󱕫' i_md_eiffel_tower=$i
i='󱕬' i_md_submarine=$i
i='󱕭' i_md_sofa_outline=$i
i='󱕮' i_md_sofa_single=$i
i='󱕯' i_md_sofa_single_outline=$i
i='󱕰' i_md_text_account=$i
i='󱕱' i_md_human_queue=$i
i='󱕲' i_md_food_halal=$i
i='󱕳' i_md_food_kosher=$i
i='󱕴' i_md_key_chain=$i
i='󱕵' i_md_key_chain_variant=$i
i='󱕶' i_md_lamps=$i
i='󱕷' i_md_application_cog_outline=$i
i='󱕸' i_md_dance_pole=$i
i='󱕹' i_md_social_distance_2_meters=$i
i='󱕺' i_md_social_distance_6_feet=$i
i='󱕻' i_md_calendar_cursor=$i
i='󱕼' i_md_emoticon_sick=$i
i='󱕽' i_md_emoticon_sick_outline=$i
i='󱕾' i_md_hand_heart_outline=$i
i='󱕿' i_md_hand_wash=$i
i='󱖀' i_md_hand_wash_outline=$i
i='󱖁' i_md_human_cane=$i
i='󱖂' i_md_lotion=$i
i='󱖃' i_md_lotion_outline=$i
i='󱖄' i_md_lotion_plus=$i
i='󱖅' i_md_lotion_plus_outline=$i
i='󱖆' i_md_face_mask=$i
i='󱖇' i_md_face_mask_outline=$i
i='󱖈' i_md_reiterate=$i
i='󱖉' i_md_butterfly=$i
i='󱖊' i_md_butterfly_outline=$i
i='󱖋' i_md_bag_suitcase=$i
i='󱖌' i_md_bag_suitcase_outline=$i
i='󱖍' i_md_bag_suitcase_off=$i
i='󱖎' i_md_bag_suitcase_off_outline=$i
i='󱖏' i_md_motion_play=$i
i='󱖐' i_md_motion_pause=$i
i='󱖑' i_md_motion_play_outline=$i
i='󱖒' i_md_motion_pause_outline=$i
i='󱖓' i_md_arrow_top_left_thin_circle_outline=$i
i='󱖔' i_md_arrow_top_right_thin_circle_outline=$i
i='󱖕' i_md_arrow_bottom_right_thin_circle_outline=$i
i='󱖖' i_md_arrow_bottom_left_thin_circle_outline=$i
i='󱖗' i_md_arrow_up_thin_circle_outline=$i
i='󱖘' i_md_arrow_right_thin_circle_outline=$i
i='󱖙' i_md_arrow_down_thin_circle_outline=$i
i='󱖚' i_md_arrow_left_thin_circle_outline=$i
i='󱖛' i_md_human_capacity_decrease=$i
i='󱖜' i_md_human_capacity_increase=$i
i='󱖝' i_md_human_greeting_proximity=$i
i='󱖞' i_md_hvac_off=$i
i='󱖟' i_md_inbox_remove=$i
i='󱖠' i_md_inbox_remove_outline=$i
i='󱖡' i_md_handshake_outline=$i
i='󱖢' i_md_ladder=$i
i='󱖣' i_md_router_wireless_off=$i
i='󱖤' i_md_seesaw=$i
i='󱖥' i_md_slide=$i
i='󱖦' i_md_calculator_variant_outline=$i
i='󱖧' i_md_shield_account_variant=$i
i='󱖨' i_md_shield_account_variant_outline=$i
i='󱖩' i_md_message_flash=$i
i='󱖪' i_md_message_flash_outline=$i
i='󱖫' i_md_list_status=$i
i='󱖬' i_md_message_bookmark=$i
i='󱖭' i_md_message_bookmark_outline=$i
i='󱖮' i_md_comment_bookmark=$i
i='󱖯' i_md_comment_bookmark_outline=$i
i='󱖰' i_md_comment_flash=$i
i='󱖱' i_md_comment_flash_outline=$i
i='󱖲' i_md_motion=$i
i='󱖳' i_md_motion_outline=$i
i='󱖴' i_md_bicycle_electric=$i
i='󱖵' i_md_car_electric_outline=$i
i='󱖶' i_md_chart_timeline_variant_shimmer=$i
i='󱖷' i_md_moped_electric=$i
i='󱖸' i_md_moped_electric_outline=$i
i='󱖹' i_md_moped_outline=$i
i='󱖺' i_md_motorbike_electric=$i
i='󱖻' i_md_rickshaw=$i
i='󱖼' i_md_rickshaw_electric=$i
i='󱖽' i_md_scooter=$i
i='󱖾' i_md_scooter_electric=$i
i='󱖿' i_md_horse=$i
i='󱗀' i_md_horse_human=$i
i='󱗁' i_md_horse_variant=$i
i='󱗂' i_md_unicorn=$i
i='󱗃' i_md_unicorn_variant=$i
i='󱗄' i_md_alarm_panel=$i
i='󱗅' i_md_alarm_panel_outline=$i
i='󱗆' i_md_bird=$i
i='󱗇' i_md_shoe_cleat=$i
i='󱗈' i_md_shoe_sneaker=$i
i='󱗉' i_md_human_female_dance=$i
i='󱗊' i_md_shoe_ballet=$i
i='󱗋' i_md_numeric_positive_1=$i
i='󱗌' i_md_face_man_shimmer=$i
i='󱗍' i_md_face_man_shimmer_outline=$i
i='󱗎' i_md_face_woman_shimmer=$i
i='󱗏' i_md_face_woman_shimmer_outline=$i
i='󱗐' i_md_home_alert_outline=$i
i='󱗑' i_md_lock_alert_outline=$i
i='󱗒' i_md_lock_open_alert_outline=$i
i='󱗓' i_md_sim_alert_outline=$i
i='󱗔' i_md_sim_off_outline=$i
i='󱗕' i_md_sim_outline=$i
i='󱗖' i_md_book_open_page_variant_outline=$i
i='󱗗' i_md_fire_alert=$i
i='󱗘' i_md_ray_start_vertex_end=$i
i='󱗙' i_md_camera_flip=$i
i='󱗚' i_md_camera_flip_outline=$i
i='󱗛' i_md_orbit_variant=$i
i='󱗜' i_md_circle_box=$i
i='󱗝' i_md_circle_box_outline=$i
i='󱗞' i_md_mustache=$i
i='󱗟' i_md_comment_minus=$i
i='󱗠' i_md_comment_minus_outline=$i
i='󱗡' i_md_comment_off=$i
i='󱗢' i_md_comment_off_outline=$i
i='󱗣' i_md_eye_remove=$i
i='󱗤' i_md_eye_remove_outline=$i
i='󱗥' i_md_unicycle=$i
i='󱗦' i_md_glass_cocktail_off=$i
i='󱗧' i_md_glass_mug_off=$i
i='󱗨' i_md_glass_mug_variant_off=$i
i='󱗩' i_md_bicycle_penny_farthing=$i
i='󱗪' i_md_cart_check=$i
i='󱗫' i_md_cart_variant=$i
i='󱗬' i_md_baseball_diamond=$i
i='󱗭' i_md_baseball_diamond_outline=$i
i='󱗮' i_md_fridge_industrial=$i
i='󱗯' i_md_fridge_industrial_alert=$i
i='󱗰' i_md_fridge_industrial_alert_outline=$i
i='󱗱' i_md_fridge_industrial_off=$i
i='󱗲' i_md_fridge_industrial_off_outline=$i
i='󱗳' i_md_fridge_industrial_outline=$i
i='󱗴' i_md_fridge_variant=$i
i='󱗵' i_md_fridge_variant_alert=$i
i='󱗶' i_md_fridge_variant_alert_outline=$i
i='󱗷' i_md_fridge_variant_off=$i
i='󱗸' i_md_fridge_variant_off_outline=$i
i='󱗹' i_md_fridge_variant_outline=$i
i='󱗺' i_md_windsock=$i
i='󱗻' i_md_dance_ballroom=$i
i='󱗼' i_md_dots_grid=$i
i='󱗽' i_md_dots_square=$i
i='󱗾' i_md_dots_triangle=$i
i='󱗿' i_md_dots_hexagon=$i
i='󱘀' i_md_card_minus=$i
i='󱘁' i_md_card_minus_outline=$i
i='󱘂' i_md_card_off=$i
i='󱘃' i_md_card_off_outline=$i
i='󱘄' i_md_card_remove=$i
i='󱘅' i_md_card_remove_outline=$i
i='󱘆' i_md_torch=$i
i='󱘇' i_md_navigation_outline=$i
i='󱘈' i_md_map_marker_star=$i
i='󱘉' i_md_map_marker_star_outline=$i
i='󱘊' i_md_manjaro=$i
i='󱘋' i_md_fast_forward_60=$i
i='󱘌' i_md_rewind_60=$i
i='󱘍' i_md_image_text=$i
i='󱘎' i_md_family_tree=$i
i='󱘏' i_md_car_emergency=$i
i='󱘐' i_md_notebook_minus=$i
i='󱘑' i_md_notebook_minus_outline=$i
i='󱘒' i_md_notebook_plus=$i
i='󱘓' i_md_notebook_plus_outline=$i
i='󱘔' i_md_notebook_remove=$i
i='󱘕' i_md_notebook_remove_outline=$i
i='󱘖' i_md_connection=$i
i='󱘗' i_md_language_rust=$i
i='󱘘' i_md_clipboard_minus=$i
i='󱘙' i_md_clipboard_minus_outline=$i
i='󱘚' i_md_clipboard_off=$i
i='󱘛' i_md_clipboard_off_outline=$i
i='󱘜' i_md_clipboard_remove=$i
i='󱘝' i_md_clipboard_remove_outline=$i
i='󱘞' i_md_clipboard_search=$i
i='󱘟' i_md_clipboard_search_outline=$i
i='󱘠' i_md_clipboard_text_off=$i
i='󱘡' i_md_clipboard_text_off_outline=$i
i='󱘢' i_md_clipboard_text_search=$i
i='󱘣' i_md_clipboard_text_search_outline=$i
i='󱘤' i_md_database_alert_outline=$i
i='󱘥' i_md_database_arrow_down_outline=$i
i='󱘦' i_md_database_arrow_left_outline=$i
i='󱘧' i_md_database_arrow_right_outline=$i
i='󱘨' i_md_database_arrow_up_outline=$i
i='󱘩' i_md_database_check_outline=$i
i='󱘪' i_md_database_clock_outline=$i
i='󱘫' i_md_database_edit_outline=$i
i='󱘬' i_md_database_export_outline=$i
i='󱘭' i_md_database_import_outline=$i
i='󱘮' i_md_database_lock_outline=$i
i='󱘯' i_md_database_marker_outline=$i
i='󱘰' i_md_database_minus_outline=$i
i='󱘱' i_md_database_off_outline=$i
i='󱘲' i_md_database_outline=$i
i='󱘳' i_md_database_plus_outline=$i
i='󱘴' i_md_database_refresh_outline=$i
i='󱘵' i_md_database_remove_outline=$i
i='󱘶' i_md_database_search_outline=$i
i='󱘷' i_md_database_settings_outline=$i
i='󱘸' i_md_database_sync_outline=$i
i='󱘹' i_md_minus_thick=$i
i='󱘺' i_md_database_alert=$i
i='󱘻' i_md_database_arrow_down=$i
i='󱘼' i_md_database_arrow_left=$i
i='󱘽' i_md_database_arrow_right=$i
i='󱘾' i_md_database_arrow_up=$i
i='󱘿' i_md_database_clock=$i
i='󱙀' i_md_database_off=$i
i='󱙁' i_md_calendar_lock=$i
i='󱙂' i_md_calendar_lock_outline=$i
i='󱙃' i_md_content_save_off=$i
i='󱙄' i_md_content_save_off_outline=$i
i='󱙅' i_md_credit_card_refresh=$i
i='󱙆' i_md_credit_card_refresh_outline=$i
i='󱙇' i_md_credit_card_search=$i
i='󱙈' i_md_credit_card_search_outline=$i
i='󱙉' i_md_credit_card_sync=$i
i='󱙊' i_md_credit_card_sync_outline=$i
i='󱙋' i_md_database_cog=$i
i='󱙌' i_md_database_cog_outline=$i
i='󱙍' i_md_message_off=$i
i='󱙎' i_md_message_off_outline=$i
i='󱙏' i_md_note_minus=$i
i='󱙐' i_md_note_minus_outline=$i
i='󱙑' i_md_note_remove=$i
i='󱙒' i_md_note_remove_outline=$i
i='󱙓' i_md_note_search=$i
i='󱙔' i_md_note_search_outline=$i
i='󱙕' i_md_bank_check=$i
i='󱙖' i_md_bank_off=$i
i='󱙗' i_md_bank_off_outline=$i
i='󱙘' i_md_briefcase_off=$i
i='󱙙' i_md_briefcase_off_outline=$i
i='󱙚' i_md_briefcase_variant_off=$i
i='󱙛' i_md_briefcase_variant_off_outline=$i
i='󱙜' i_md_ghost_off_outline=$i
i='󱙝' i_md_ghost_outline=$i
i='󱙞' i_md_store_minus=$i
i='󱙟' i_md_store_plus=$i
i='󱙠' i_md_store_remove=$i
i='󱙡' i_md_email_remove=$i
i='󱙢' i_md_email_remove_outline=$i
i='󱙣' i_md_heart_cog=$i
i='󱙤' i_md_heart_cog_outline=$i
i='󱙥' i_md_heart_settings=$i
i='󱙦' i_md_heart_settings_outline=$i
i='󱙧' i_md_pentagram=$i
i='󱙨' i_md_star_cog=$i
i='󱙩' i_md_star_cog_outline=$i
i='󱙪' i_md_star_settings=$i
i='󱙫' i_md_star_settings_outline=$i
i='󱙬' i_md_calendar_end=$i
i='󱙭' i_md_calendar_start=$i
i='󱙮' i_md_cannabis_off=$i
i='󱙯' i_md_mower=$i
i='󱙰' i_md_mower_bag=$i
i='󱙱' i_md_lock_off=$i
i='󱙲' i_md_lock_off_outline=$i
i='󱙳' i_md_shark_fin=$i
i='󱙴' i_md_shark_fin_outline=$i
i='󱙵' i_md_paw_outline=$i
i='󱙶' i_md_paw_off_outline=$i
i='󱙷' i_md_snail=$i
i='󱙸' i_md_pig_variant_outline=$i
i='󱙹' i_md_piggy_bank_outline=$i
i='󱙺' i_md_robot_outline=$i
i='󱙻' i_md_robot_off_outline=$i
i='󱙼' i_md_book_alert=$i
i='󱙽' i_md_book_alert_outline=$i
i='󱙾' i_md_book_arrow_down=$i
i='󱙿' i_md_book_arrow_down_outline=$i
i='󱚀' i_md_book_arrow_left=$i
i='󱚁' i_md_book_arrow_left_outline=$i
i='󱚂' i_md_book_arrow_right=$i
i='󱚃' i_md_book_arrow_right_outline=$i
i='󱚄' i_md_book_arrow_up=$i
i='󱚅' i_md_book_arrow_up_outline=$i
i='󱚆' i_md_book_cancel=$i
i='󱚇' i_md_book_cancel_outline=$i
i='󱚈' i_md_book_clock=$i
i='󱚉' i_md_book_clock_outline=$i
i='󱚊' i_md_book_cog=$i
i='󱚋' i_md_book_cog_outline=$i
i='󱚌' i_md_book_edit=$i
i='󱚍' i_md_book_edit_outline=$i
i='󱚎' i_md_book_lock_open_outline=$i
i='󱚏' i_md_book_lock_outline=$i
i='󱚐' i_md_book_marker=$i
i='󱚑' i_md_book_marker_outline=$i
i='󱚒' i_md_book_minus_outline=$i
i='󱚓' i_md_book_music_outline=$i
i='󱚔' i_md_book_off=$i
i='󱚕' i_md_book_off_outline=$i
i='󱚖' i_md_book_plus_outline=$i
i='󱚗' i_md_book_refresh=$i
i='󱚘' i_md_book_refresh_outline=$i
i='󱚙' i_md_book_remove_outline=$i
i='󱚚' i_md_book_settings=$i
i='󱚛' i_md_book_settings_outline=$i
i='󱚜' i_md_book_sync=$i
i='󱚝' i_md_robot_angry=$i
i='󱚞' i_md_robot_angry_outline=$i
i='󱚟' i_md_robot_confused=$i
i='󱚠' i_md_robot_confused_outline=$i
i='󱚡' i_md_robot_dead=$i
i='󱚢' i_md_robot_dead_outline=$i
i='󱚣' i_md_robot_excited=$i
i='󱚤' i_md_robot_excited_outline=$i
i='󱚥' i_md_robot_love=$i
i='󱚦' i_md_robot_love_outline=$i
i='󱚧' i_md_robot_off=$i
i='󱚨' i_md_lock_check_outline=$i
i='󱚩' i_md_lock_minus=$i
i='󱚪' i_md_lock_minus_outline=$i
i='󱚫' i_md_lock_open_check_outline=$i
i='󱚬' i_md_lock_open_minus=$i
i='󱚭' i_md_lock_open_minus_outline=$i
i='󱚮' i_md_lock_open_plus=$i
i='󱚯' i_md_lock_open_plus_outline=$i
i='󱚰' i_md_lock_open_remove=$i
i='󱚱' i_md_lock_open_remove_outline=$i
i='󱚲' i_md_lock_plus_outline=$i
i='󱚳' i_md_lock_remove=$i
i='󱚴' i_md_lock_remove_outline=$i
i='󱚵' i_md_wifi_alert=$i
i='󱚶' i_md_wifi_arrow_down=$i
i='󱚷' i_md_wifi_arrow_left=$i
i='󱚸' i_md_wifi_arrow_left_right=$i
i='󱚹' i_md_wifi_arrow_right=$i
i='󱚺' i_md_wifi_arrow_up=$i
i='󱚻' i_md_wifi_arrow_up_down=$i
i='󱚼' i_md_wifi_cancel=$i
i='󱚽' i_md_wifi_check=$i
i='󱚾' i_md_wifi_cog=$i
i='󱚿' i_md_wifi_lock=$i
i='󱛀' i_md_wifi_lock_open=$i
i='󱛁' i_md_wifi_marker=$i
i='󱛂' i_md_wifi_minus=$i
i='󱛃' i_md_wifi_plus=$i
i='󱛄' i_md_wifi_refresh=$i
i='󱛅' i_md_wifi_remove=$i
i='󱛆' i_md_wifi_settings=$i
i='󱛇' i_md_wifi_sync=$i
i='󱛈' i_md_book_sync_outline=$i
i='󱛉' i_md_book_education=$i
i='󱛊' i_md_book_education_outline=$i
i='󱛋' i_md_wifi_strength_1_lock_open=$i
i='󱛌' i_md_wifi_strength_2_lock_open=$i
i='󱛍' i_md_wifi_strength_3_lock_open=$i
i='󱛎' i_md_wifi_strength_4_lock_open=$i
i='󱛏' i_md_wifi_strength_lock_open_outline=$i
i='󱛐' i_md_cookie_alert=$i
i='󱛑' i_md_cookie_alert_outline=$i
i='󱛒' i_md_cookie_check=$i
i='󱛓' i_md_cookie_check_outline=$i
i='󱛔' i_md_cookie_cog=$i
i='󱛕' i_md_cookie_cog_outline=$i
i='󱛖' i_md_cookie_plus=$i
i='󱛗' i_md_cookie_plus_outline=$i
i='󱛘' i_md_cookie_remove=$i
i='󱛙' i_md_cookie_remove_outline=$i
i='󱛚' i_md_cookie_minus=$i
i='󱛛' i_md_cookie_minus_outline=$i
i='󱛜' i_md_cookie_settings=$i
i='󱛝' i_md_cookie_settings_outline=$i
i='󱛞' i_md_cookie_outline=$i
i='󱛟' i_md_tape_drive=$i
i='󱛠' i_md_abacus=$i
i='󱛡' i_md_calendar_clock_outline=$i
i='󱛢' i_md_clipboard_clock=$i
i='󱛣' i_md_clipboard_clock_outline=$i
i='󱛤' i_md_cookie_clock=$i
i='󱛥' i_md_cookie_clock_outline=$i
i='󱛦' i_md_cookie_edit=$i
i='󱛧' i_md_cookie_edit_outline=$i
i='󱛨' i_md_cookie_lock=$i
i='󱛩' i_md_cookie_lock_outline=$i
i='󱛪' i_md_cookie_off=$i
i='󱛫' i_md_cookie_off_outline=$i
i='󱛬' i_md_cookie_refresh=$i
i='󱛭' i_md_cookie_refresh_outline=$i
i='󱛮' i_md_dog_side_off=$i
i='󱛯' i_md_gift_off=$i
i='󱛰' i_md_gift_off_outline=$i
i='󱛱' i_md_gift_open=$i
i='󱛲' i_md_gift_open_outline=$i
i='󱛳' i_md_movie_check=$i
i='󱛴' i_md_movie_check_outline=$i
i='󱛵' i_md_movie_cog=$i
i='󱛶' i_md_movie_cog_outline=$i
i='󱛷' i_md_movie_minus=$i
i='󱛸' i_md_movie_minus_outline=$i
i='󱛹' i_md_movie_off=$i
i='󱛺' i_md_movie_off_outline=$i
i='󱛻' i_md_movie_open_check=$i
i='󱛼' i_md_movie_open_check_outline=$i
i='󱛽' i_md_movie_open_cog=$i
i='󱛾' i_md_movie_open_cog_outline=$i
i='󱛿' i_md_movie_open_edit=$i
i='󱜀' i_md_movie_open_edit_outline=$i
i='󱜁' i_md_movie_open_minus=$i
i='󱜂' i_md_movie_open_minus_outline=$i
i='󱜃' i_md_movie_open_off=$i
i='󱜄' i_md_movie_open_off_outline=$i
i='󱜅' i_md_movie_open_play=$i
i='󱜆' i_md_movie_open_play_outline=$i
i='󱜇' i_md_movie_open_plus=$i
i='󱜈' i_md_movie_open_plus_outline=$i
i='󱜉' i_md_movie_open_remove=$i
i='󱜊' i_md_movie_open_remove_outline=$i
i='󱜋' i_md_movie_open_settings=$i
i='󱜌' i_md_movie_open_settings_outline=$i
i='󱜍' i_md_movie_open_star=$i
i='󱜎' i_md_movie_open_star_outline=$i
i='󱜏' i_md_movie_play=$i
i='󱜐' i_md_movie_play_outline=$i
i='󱜑' i_md_movie_plus=$i
i='󱜒' i_md_movie_plus_outline=$i
i='󱜓' i_md_movie_remove=$i
i='󱜔' i_md_movie_remove_outline=$i
i='󱜕' i_md_movie_settings=$i
i='󱜖' i_md_movie_settings_outline=$i
i='󱜗' i_md_movie_star=$i
i='󱜘' i_md_movie_star_outline=$i
i='󱜙' i_md_robot_happy=$i
i='󱜚' i_md_robot_happy_outline=$i
i='󱜛' i_md_turkey=$i
i='󱜜' i_md_food_turkey=$i
i='󱜝' i_md_fan_auto=$i
i='󱜞' i_md_alarm_light_off=$i
i='󱜟' i_md_alarm_light_off_outline=$i
i='󱜠' i_md_broadcast=$i
i='󱜡' i_md_broadcast_off=$i
i='󱜢' i_md_fire_off=$i
i='󱜣' i_md_firework_off=$i
i='󱜤' i_md_projector_screen_outline=$i
i='󱜥' i_md_script_text_key=$i
i='󱜦' i_md_script_text_key_outline=$i
i='󱜧' i_md_script_text_play=$i
i='󱜨' i_md_script_text_play_outline=$i
i='󱜩' i_md_surround_sound_2_1=$i
i='󱜪' i_md_surround_sound_5_1_2=$i
i='󱜫' i_md_tag_arrow_down=$i
i='󱜬' i_md_tag_arrow_down_outline=$i
i='󱜭' i_md_tag_arrow_left=$i
i='󱜮' i_md_tag_arrow_left_outline=$i
i='󱜯' i_md_tag_arrow_right=$i
i='󱜰' i_md_tag_arrow_right_outline=$i
i='󱜱' i_md_tag_arrow_up=$i
i='󱜲' i_md_tag_arrow_up_outline=$i
i='󱜳' i_md_train_car_passenger=$i
i='󱜴' i_md_train_car_passenger_door=$i
i='󱜵' i_md_train_car_passenger_door_open=$i
i='󱜶' i_md_train_car_passenger_variant=$i
i='󱜷' i_md_webcam_off=$i
i='󱜸' i_md_chat_question=$i
i='󱜹' i_md_chat_question_outline=$i
i='󱜺' i_md_message_question=$i
i='󱜻' i_md_message_question_outline=$i
i='󱜼' i_md_kettle_pour_over=$i
i='󱜽' i_md_message_reply_outline=$i
i='󱜾' i_md_message_reply_text_outline=$i
i='󱜿' i_md_koala=$i
i='󱝀' i_md_check_decagram_outline=$i
i='󱝁' i_md_star_shooting=$i
i='󱝂' i_md_star_shooting_outline=$i
i='󱝃' i_md_table_picnic=$i
i='󱝄' i_md_kitesurfing=$i
i='󱝅' i_md_paragliding=$i
i='󱝆' i_md_surfing=$i
i='󱝇' i_md_floor_lamp_torchiere=$i
i='󱝈' i_md_mortar_pestle=$i
i='󱝉' i_md_cast_audio_variant=$i
i='󱝊' i_md_gradient_horizontal=$i
i='󱝋' i_md_archive_cancel=$i
i='󱝌' i_md_archive_cancel_outline=$i
i='󱝍' i_md_archive_check=$i
i='󱝎' i_md_archive_check_outline=$i
i='󱝏' i_md_archive_clock=$i
i='󱝐' i_md_archive_clock_outline=$i
i='󱝑' i_md_archive_cog=$i
i='󱝒' i_md_archive_cog_outline=$i
i='󱝓' i_md_archive_edit=$i
i='󱝔' i_md_archive_edit_outline=$i
i='󱝕' i_md_archive_eye=$i
i='󱝖' i_md_archive_eye_outline=$i
i='󱝗' i_md_archive_lock=$i
i='󱝘' i_md_archive_lock_open=$i
i='󱝙' i_md_archive_lock_open_outline=$i
i='󱝚' i_md_archive_lock_outline=$i
i='󱝛' i_md_archive_marker=$i
i='󱝜' i_md_archive_marker_outline=$i
i='󱝝' i_md_archive_minus=$i
i='󱝞' i_md_archive_minus_outline=$i
i='󱝟' i_md_archive_music=$i
i='󱝠' i_md_archive_music_outline=$i
i='󱝡' i_md_archive_off=$i
i='󱝢' i_md_archive_off_outline=$i
i='󱝣' i_md_archive_plus=$i
i='󱝤' i_md_archive_plus_outline=$i
i='󱝥' i_md_archive_refresh=$i
i='󱝦' i_md_archive_refresh_outline=$i
i='󱝧' i_md_archive_remove=$i
i='󱝨' i_md_archive_remove_outline=$i
i='󱝩' i_md_archive_search=$i
i='󱝪' i_md_archive_search_outline=$i
i='󱝫' i_md_archive_settings=$i
i='󱝬' i_md_archive_settings_outline=$i
i='󱝭' i_md_archive_star=$i
i='󱝮' i_md_archive_star_outline=$i
i='󱝯' i_md_archive_sync=$i
i='󱝰' i_md_archive_sync_outline=$i
i='󱝱' i_md_brush_off=$i
i='󱝲' i_md_file_image_marker=$i
i='󱝳' i_md_file_image_marker_outline=$i
i='󱝴' i_md_file_marker=$i
i='󱝵' i_md_file_marker_outline=$i
i='󱝶' i_md_hamburger_check=$i
i='󱝷' i_md_hamburger_minus=$i
i='󱝸' i_md_hamburger_off=$i
i='󱝹' i_md_hamburger_plus=$i
i='󱝺' i_md_hamburger_remove=$i
i='󱝻' i_md_image_marker=$i
i='󱝼' i_md_image_marker_outline=$i
i='󱝽' i_md_note_alert=$i
i='󱝾' i_md_note_alert_outline=$i
i='󱝿' i_md_note_check=$i
i='󱞀' i_md_note_check_outline=$i
i='󱞁' i_md_note_edit=$i
i='󱞂' i_md_note_edit_outline=$i
i='󱞃' i_md_note_off=$i
i='󱞄' i_md_note_off_outline=$i
i='󱞅' i_md_printer_off_outline=$i
i='󱞆' i_md_printer_outline=$i
i='󱞇' i_md_progress_pencil=$i
i='󱞈' i_md_progress_star=$i
i='󱞉' i_md_sausage_off=$i
i='󱞊' i_md_folder_eye=$i
i='󱞋' i_md_folder_eye_outline=$i
i='󱞌' i_md_information_off=$i
i='󱞍' i_md_information_off_outline=$i
i='󱞎' i_md_sticker_text=$i
i='󱞏' i_md_sticker_text_outline=$i
i='󱞐' i_md_web_cancel=$i
i='󱞑' i_md_web_refresh=$i
i='󱞒' i_md_web_sync=$i
i='󱞓' i_md_chandelier=$i
i='󱞔' i_md_home_switch=$i
i='󱞕' i_md_home_switch_outline=$i
i='󱞖' i_md_sun_snowflake=$i
i='󱞗' i_md_ceiling_fan=$i
i='󱞘' i_md_ceiling_fan_light=$i
i='󱞙' i_md_smoke=$i
i='󱞚' i_md_fence=$i
i='󱞛' i_md_light_recessed=$i
i='󱞜' i_md_battery_lock=$i
i='󱞝' i_md_battery_lock_open=$i
i='󱞞' i_md_folder_hidden=$i
i='󱞟' i_md_mirror_rectangle=$i
i='󱞠' i_md_mirror_variant=$i
i='󱞡' i_md_arrow_down_left=$i
i='󱞢' i_md_arrow_down_left_bold=$i
i='󱞣' i_md_arrow_down_right=$i
i='󱞤' i_md_arrow_down_right_bold=$i
i='󱞥' i_md_arrow_left_bottom=$i
i='󱞦' i_md_arrow_left_bottom_bold=$i
i='󱞧' i_md_arrow_left_top=$i
i='󱞨' i_md_arrow_left_top_bold=$i
i='󱞩' i_md_arrow_right_bottom=$i
i='󱞪' i_md_arrow_right_bottom_bold=$i
i='󱞫' i_md_arrow_right_top=$i
i='󱞬' i_md_arrow_right_top_bold=$i
i='󱞭' i_md_arrow_u_down_left=$i
i='󱞮' i_md_arrow_u_down_left_bold=$i
i='󱞯' i_md_arrow_u_down_right=$i
i='󱞰' i_md_arrow_u_down_right_bold=$i
i='󱞱' i_md_arrow_u_left_bottom=$i
i='󱞲' i_md_arrow_u_left_bottom_bold=$i
i='󱞳' i_md_arrow_u_left_top=$i
i='󱞴' i_md_arrow_u_left_top_bold=$i
i='󱞵' i_md_arrow_u_right_bottom=$i
i='󱞶' i_md_arrow_u_right_bottom_bold=$i
i='󱞷' i_md_arrow_u_right_top=$i
i='󱞸' i_md_arrow_u_right_top_bold=$i
i='󱞹' i_md_arrow_u_up_left=$i
i='󱞺' i_md_arrow_u_up_left_bold=$i
i='󱞻' i_md_arrow_u_up_right=$i
i='󱞼' i_md_arrow_u_up_right_bold=$i
i='󱞽' i_md_arrow_up_left=$i
i='󱞾' i_md_arrow_up_left_bold=$i
i='󱞿' i_md_arrow_up_right=$i
i='󱟀' i_md_arrow_up_right_bold=$i
i='󱟁' i_md_select_remove=$i
i='󱟂' i_md_selection_ellipse_remove=$i
i='󱟃' i_md_selection_remove=$i
i='󱟄' i_md_human_greeting=$i
i='󱟅' i_md_ph=$i
i='󱟆' i_md_water_sync=$i
i='󱟇' i_md_ceiling_light_outline=$i
i='󱟈' i_md_floor_lamp_outline=$i
i='󱟉' i_md_wall_sconce_flat_outline=$i
i='󱟊' i_md_wall_sconce_flat_variant_outline=$i
i='󱟋' i_md_wall_sconce_outline=$i
i='󱟌' i_md_wall_sconce_round_outline=$i
i='󱟍' i_md_wall_sconce_round_variant_outline=$i
i='󱟎' i_md_floor_lamp_dual_outline=$i
i='󱟏' i_md_floor_lamp_torchiere_variant_outline=$i
i='󱟐' i_md_lamp_outline=$i
i='󱟑' i_md_lamps_outline=$i
i='󱟒' i_md_candelabra=$i
i='󱟓' i_md_candelabra_fire=$i
i='󱟔' i_md_menorah=$i
i='󱟕' i_md_menorah_fire=$i
i='󱟖' i_md_floor_lamp_torchiere_outline=$i
i='󱟗' i_md_credit_card_edit=$i
i='󱟘' i_md_credit_card_edit_outline=$i
i='󱟙' i_md_briefcase_eye=$i
i='󱟚' i_md_briefcase_eye_outline=$i
i='󱟛' i_md_soundbar=$i
i='󱟜' i_md_crown_circle=$i
i='󱟝' i_md_crown_circle_outline=$i
i='󱟞' i_md_battery_arrow_down=$i
i='󱟟' i_md_battery_arrow_down_outline=$i
i='󱟠' i_md_battery_arrow_up=$i
i='󱟡' i_md_battery_arrow_up_outline=$i
i='󱟢' i_md_battery_check=$i
i='󱟣' i_md_battery_check_outline=$i
i='󱟤' i_md_battery_minus=$i
i='󱟥' i_md_battery_minus_outline=$i
i='󱟦' i_md_battery_plus=$i
i='󱟧' i_md_battery_plus_outline=$i
i='󱟨' i_md_battery_remove=$i
i='󱟩' i_md_battery_remove_outline=$i
i='󱟪' i_md_chili_alert=$i
i='󱟫' i_md_chili_alert_outline=$i
i='󱟬' i_md_chili_hot_outline=$i
i='󱟭' i_md_chili_medium_outline=$i
i='󱟮' i_md_chili_mild_outline=$i
i='󱟯' i_md_chili_off_outline=$i
i='󱟰' i_md_cake_variant_outline=$i
i='󱟱' i_md_card_multiple=$i
i='󱟲' i_md_card_multiple_outline=$i
i='󱟳' i_md_account_cowboy_hat_outline=$i
i='󱟴' i_md_lightbulb_spot=$i
i='󱟵' i_md_lightbulb_spot_off=$i
i='󱟶' i_md_fence_electric=$i
i='󱟷' i_md_gate_arrow_left=$i
i='󱟸' i_md_gate_alert=$i
i='󱟹' i_md_boom_gate_up=$i
i='󱟺' i_md_boom_gate_up_outline=$i
i='󱟻' i_md_garage_lock=$i
i='󱟼' i_md_garage_variant_lock=$i
i='󱟽' i_md_cellphone_check=$i
i='󱟾' i_md_sun_wireless=$i
i='󱟿' i_md_sun_wireless_outline=$i
i='󱠀' i_md_lightbulb_auto=$i
i='󱠁' i_md_lightbulb_auto_outline=$i
i='󱠂' i_md_lightbulb_variant=$i
i='󱠃' i_md_lightbulb_variant_outline=$i
i='󱠄' i_md_lightbulb_fluorescent_tube=$i
i='󱠅' i_md_lightbulb_fluorescent_tube_outline=$i
i='󱠆' i_md_water_circle=$i
i='󱠇' i_md_fire_circle=$i
i='󱠈' i_md_smoke_detector_outline=$i
i='󱠉' i_md_smoke_detector_off=$i
i='󱠊' i_md_smoke_detector_off_outline=$i
i='󱠋' i_md_smoke_detector_variant=$i
i='󱠌' i_md_smoke_detector_variant_off=$i
i='󱠍' i_md_projector_screen_off=$i
i='󱠎' i_md_projector_screen_off_outline=$i
i='󱠏' i_md_projector_screen_variant=$i
i='󱠐' i_md_projector_screen_variant_off=$i
i='󱠑' i_md_projector_screen_variant_off_outline=$i
i='󱠒' i_md_projector_screen_variant_outline=$i
i='󱠓' i_md_brush_variant=$i
i='󱠔' i_md_car_wrench=$i
i='󱠕' i_md_account_injury=$i
i='󱠖' i_md_account_injury_outline=$i
i='󱠗' i_md_balcony=$i
i='󱠘' i_md_bathtub=$i
i='󱠙' i_md_bathtub_outline=$i
i='󱠚' i_md_blender_outline=$i
i='󱠛' i_md_coffee_maker_outline=$i
i='󱠜' i_md_countertop=$i
i='󱠝' i_md_countertop_outline=$i
i='󱠞' i_md_door_sliding=$i
i='󱠟' i_md_door_sliding_lock=$i
i='󱠠' i_md_door_sliding_open=$i
i='󱠡' i_md_hand_wave=$i
i='󱠢' i_md_hand_wave_outline=$i
i='󱠣' i_md_human_male_female_child=$i
i='󱠤' i_md_iron=$i
i='󱠥' i_md_iron_outline=$i
i='󱠦' i_md_liquid_spot=$i
i='󱠧' i_md_mosque=$i
i='󱠨' i_md_shield_moon=$i
i='󱠩' i_md_shield_moon_outline=$i
i='󱠪' i_md_traffic_light_outline=$i
i='󱠫' i_md_hand_front_left=$i
i='󱠬' i_md_hand_back_left_outline=$i
i='󱠭' i_md_hand_back_right_outline=$i
i='󱠮' i_md_hand_front_left_outline=$i
i='󱠯' i_md_hand_front_right_outline=$i
i='󱠰' i_md_hand_back_left_off=$i
i='󱠱' i_md_hand_back_right_off=$i
i='󱠲' i_md_hand_back_left_off_outline=$i
i='󱠳' i_md_hand_back_right_off_outline=$i
i='󱠴' i_md_battery_sync=$i
i='󱠵' i_md_battery_sync_outline=$i
i='󱠶' i_md_food_takeout_box=$i
i='󱠷' i_md_food_takeout_box_outline=$i
i='󱠸' i_md_iron_board=$i
i='󱠹' i_md_police_station=$i
i='󱠺' i_md_cellphone_marker=$i
i='󱠻' i_md_tooltip_cellphone=$i
i='󱠼' i_md_table_pivot=$i
i='󱠽' i_md_tunnel=$i
i='󱠾' i_md_tunnel_outline=$i
i='󱠿' i_md_arrow_projectile_multiple=$i
i='󱡀' i_md_arrow_projectile=$i
i='󱡁' i_md_bow_arrow=$i
i='󱡂' i_md_axe_battle=$i
i='󱡃' i_md_mace=$i
i='󱡄' i_md_magic_staff=$i
i='󱡅' i_md_spear=$i
i='󱡆' i_md_curtains=$i
i='󱡇' i_md_curtains_closed=$i
i='󱡈' i_md_human_non_binary=$i
i='󱡉' i_md_waterfall=$i
i='󱡊' i_md_egg_fried=$i
i='󱡋' i_md_food_hot_dog=$i
i='󱡌' i_md_induction=$i
i='󱡍' i_md_pipe_valve=$i
i='󱡎' i_md_shipping_pallet=$i
i='󱡏' i_md_earbuds=$i
i='󱡐' i_md_earbuds_off=$i
i='󱡑' i_md_earbuds_off_outline=$i
i='󱡒' i_md_earbuds_outline=$i
i='󱡓' i_md_circle_opacity=$i
i='󱡔' i_md_square_opacity=$i
i='󱡕' i_md_water_opacity=$i
i='󱡖' i_md_vector_polygon_variant=$i
i='󱡗' i_md_vector_square_close=$i
i='󱡘' i_md_vector_square_open=$i
i='󱡙' i_md_waves_arrow_left=$i
i='󱡚' i_md_waves_arrow_right=$i
i='󱡛' i_md_waves_arrow_up=$i
i='󱡜' i_md_cash_fast=$i
i='󱡝' i_md_radioactive_circle=$i
i='󱡞' i_md_radioactive_circle_outline=$i
i='󱡟' i_md_cctv_off=$i
i='󱡠' i_md_format_list_group=$i
i='󱡡' i_md_clock_plus=$i
i='󱡢' i_md_clock_plus_outline=$i
i='󱡣' i_md_clock_minus=$i
i='󱡤' i_md_clock_minus_outline=$i
i='󱡥' i_md_clock_remove=$i
i='󱡦' i_md_clock_remove_outline=$i
i='󱡧' i_md_account_arrow_up=$i
i='󱡨' i_md_account_arrow_down=$i
i='󱡩' i_md_account_arrow_down_outline=$i
i='󱡪' i_md_account_arrow_up_outline=$i
i='󱡫' i_md_audio_input_rca=$i
i='󱡬' i_md_audio_input_stereo_minijack=$i
i='󱡭' i_md_audio_input_xlr=$i
i='󱡮' i_md_horse_variant_fast=$i
i='󱡯' i_md_email_fast=$i
i='󱡰' i_md_email_fast_outline=$i
i='󱡱' i_md_camera_document=$i
i='󱡲' i_md_camera_document_off=$i
i='󱡳' i_md_glass_fragile=$i
i='󱡴' i_md_magnify_expand=$i
i='󱡵' i_md_town_hall=$i
i='󱡶' i_md_monitor_small=$i
i='󱡷' i_md_diversify=$i
i='󱡸' i_md_car_wireless=$i
i='󱡹' i_md_car_select=$i
i='󱡺' i_md_airplane_alert=$i
i='󱡻' i_md_airplane_check=$i
i='󱡼' i_md_airplane_clock=$i
i='󱡽' i_md_airplane_cog=$i
i='󱡾' i_md_airplane_edit=$i
i='󱡿' i_md_airplane_marker=$i
i='󱢀' i_md_airplane_minus=$i
i='󱢁' i_md_airplane_plus=$i
i='󱢂' i_md_airplane_remove=$i
i='󱢃' i_md_airplane_search=$i
i='󱢄' i_md_airplane_settings=$i
i='󱢅' i_md_flower_pollen=$i
i='󱢆' i_md_flower_pollen_outline=$i
i='󱢇' i_md_hammer_sickle=$i
i='󱢈' i_md_view_gallery=$i
i='󱢉' i_md_view_gallery_outline=$i
i='󱢊' i_md_umbrella_beach=$i
i='󱢋' i_md_umbrella_beach_outline=$i
i='󱢌' i_md_cabin_a_frame=$i
i='󱢍' i_md_all_inclusive_box=$i
i='󱢎' i_md_all_inclusive_box_outline=$i
i='󱢏' i_md_hand_coin=$i
i='󱢐' i_md_hand_coin_outline=$i
i='󱢑' i_md_truck_flatbed=$i
i='󱢒' i_md_layers_edit=$i
i='󱢓' i_md_multicast=$i
i='󱢔' i_md_hydrogen_station=$i
i='󱢕' i_md_thermometer_bluetooth=$i
i='󱢖' i_md_tire=$i
i='󱢗' i_md_forest=$i
i='󱢘' i_md_account_tie_hat=$i
i='󱢙' i_md_account_tie_hat_outline=$i
i='󱢚' i_md_account_wrench=$i
i='󱢛' i_md_account_wrench_outline=$i
i='󱢜' i_md_bicycle_cargo=$i
i='󱢝' i_md_calendar_collapse_horizontal=$i
i='󱢞' i_md_calendar_expand_horizontal=$i
i='󱢟' i_md_cards_club_outline=$i
i='󱢡' i_md_cards_playing=$i
i='󱢢' i_md_cards_playing_club=$i
i='󱢣' i_md_cards_playing_club_multiple=$i
i='󱢤' i_md_cards_playing_club_multiple_outline=$i
i='󱢥' i_md_cards_playing_club_outline=$i
i='󱢦' i_md_cards_playing_diamond=$i
i='󱢧' i_md_cards_playing_diamond_multiple=$i
i='󱢨' i_md_cards_playing_diamond_multiple_outline=$i
i='󱢩' i_md_cards_playing_diamond_outline=$i
i='󱢪' i_md_cards_playing_heart=$i
i='󱢫' i_md_cards_playing_heart_multiple=$i
i='󱢬' i_md_cards_playing_heart_multiple_outline=$i
i='󱢭' i_md_cards_playing_heart_outline=$i
i='󱢮' i_md_cards_playing_spade=$i
i='󱢯' i_md_cards_playing_spade_multiple=$i
i='󱢰' i_md_cards_playing_spade_multiple_outline=$i
i='󱢱' i_md_cards_playing_spade_outline=$i
i='󱢲' i_md_cards_spade_outline=$i
i='󱢳' i_md_compare_remove=$i
i='󱢴' i_md_dolphin=$i
i='󱢵' i_md_fuel_cell=$i
i='󱢶' i_md_hand_extended=$i
i='󱢷' i_md_hand_extended_outline=$i
i='󱢸' i_md_printer_3d_nozzle_heat=$i
i='󱢹' i_md_printer_3d_nozzle_heat_outline=$i
i='󱢺' i_md_shark=$i
i='󱢻' i_md_shark_off=$i
i='󱢼' i_md_shield_crown=$i
i='󱢽' i_md_shield_crown_outline=$i
i='󱢾' i_md_shield_sword=$i
i='󱢿' i_md_shield_sword_outline=$i
i='󱣀' i_md_sickle=$i
i='󱣁' i_md_store_alert=$i
i='󱣂' i_md_store_alert_outline=$i
i='󱣃' i_md_store_check=$i
i='󱣄' i_md_store_check_outline=$i
i='󱣅' i_md_store_clock=$i
i='󱣆' i_md_store_clock_outline=$i
i='󱣇' i_md_store_cog=$i
i='󱣈' i_md_store_cog_outline=$i
i='󱣉' i_md_store_edit=$i
i='󱣊' i_md_store_edit_outline=$i
i='󱣋' i_md_store_marker=$i
i='󱣌' i_md_store_marker_outline=$i
i='󱣍' i_md_store_minus_outline=$i
i='󱣎' i_md_store_off=$i
i='󱣏' i_md_store_off_outline=$i
i='󱣐' i_md_store_plus_outline=$i
i='󱣑' i_md_store_remove_outline=$i
i='󱣒' i_md_store_search=$i
i='󱣓' i_md_store_search_outline=$i
i='󱣔' i_md_store_settings=$i
i='󱣕' i_md_store_settings_outline=$i
i='󱣖' i_md_sun_thermometer=$i
i='󱣗' i_md_sun_thermometer_outline=$i
i='󱣘' i_md_truck_cargo_container=$i
i='󱣙' i_md_vector_square_edit=$i
i='󱣚' i_md_vector_square_minus=$i
i='󱣛' i_md_vector_square_plus=$i
i='󱣜' i_md_vector_square_remove=$i
i='󱣝' i_md_ceiling_light_multiple=$i
i='󱣞' i_md_ceiling_light_multiple_outline=$i
i='󱣟' i_md_wiper_wash_alert=$i
i='󱣠' i_md_cart_heart=$i
i='󱣡' i_md_virus_off=$i
i='󱣢' i_md_virus_off_outline=$i
i='󱣣' i_md_map_marker_account=$i
i='󱣤' i_md_map_marker_account_outline=$i
i='󱣥' i_md_basket_check=$i
i='󱣦' i_md_basket_check_outline=$i
i='󱣧' i_md_credit_card_lock=$i
i='󱣨' i_md_credit_card_lock_outline=$i
i='󱣩' i_md_format_underline_wavy=$i
i='󱣪' i_md_content_save_check=$i
i='󱣫' i_md_content_save_check_outline=$i
i='󱣬' i_md_filter_check=$i
i='󱣭' i_md_filter_check_outline=$i
i='󱣮' i_md_flag_off=$i
i='󱣯' i_md_flag_off_outline=$i
i='󱣱' i_md_navigation_variant_outline=$i
i='󱣲' i_md_refresh_auto=$i
i='󱣳' i_md_tilde_off=$i
i='󱣴' i_md_fit_to_screen=$i
i='󱣵' i_md_fit_to_screen_outline=$i
i='󱣶' i_md_weather_cloudy_clock=$i
i='󱣷' i_md_smart_card_off=$i
i='󱣸' i_md_smart_card_off_outline=$i
i='󱣹' i_md_clipboard_text_clock=$i
i='󱣺' i_md_clipboard_text_clock_outline=$i
i='󱣻' i_md_teddy_bear=$i
i='󱣼' i_md_cow_off=$i
i='󱣽' i_md_eye_arrow_left=$i
i='󱣾' i_md_eye_arrow_left_outline=$i
i='󱣿' i_md_eye_arrow_right=$i
i='󱤀' i_md_eye_arrow_right_outline=$i
i='󱤁' i_md_home_battery=$i
i='󱤂' i_md_home_battery_outline=$i
i='󱤃' i_md_home_lightning_bolt=$i
i='󱤄' i_md_home_lightning_bolt_outline=$i
i='󱤅' i_md_leaf_circle=$i
i='󱤆' i_md_leaf_circle_outline=$i
i='󱤇' i_md_tag_search=$i
i='󱤈' i_md_tag_search_outline=$i
i='󱤉' i_md_car_brake_fluid_level=$i
i='󱤊' i_md_car_brake_low_pressure=$i
i='󱤋' i_md_car_brake_temperature=$i
i='󱤌' i_md_car_brake_worn_linings=$i
i='󱤍' i_md_car_light_alert=$i
i='󱤎' i_md_car_speed_limiter=$i
i='󱤏' i_md_credit_card_chip=$i
i='󱤐' i_md_credit_card_chip_outline=$i
i='󱤑' i_md_credit_card_fast=$i
i='󱤒' i_md_credit_card_fast_outline=$i
i='󱤓' i_md_integrated_circuit_chip=$i
i='󱤔' i_md_thumbs_up_down_outline=$i
i='󱤕' i_md_food_off_outline=$i
i='󱤖' i_md_food_outline=$i
i='󱤗' i_md_format_page_split=$i
i='󱤘' i_md_chart_waterfall=$i
i='󱤙' i_md_gamepad_outline=$i
i='󱤚' i_md_network_strength_4_cog=$i
i='󱤛' i_md_account_sync=$i
i='󱤜' i_md_account_sync_outline=$i
i='󱤝' i_md_bus_electric=$i
i='󱤞' i_md_liquor=$i
i='󱤟' i_md_database_eye=$i
i='󱤠' i_md_database_eye_off=$i
i='󱤡' i_md_database_eye_off_outline=$i
i='󱤢' i_md_database_eye_outline=$i
i='󱤣' i_md_timer_settings=$i
i='󱤤' i_md_timer_settings_outline=$i
i='󱤥' i_md_timer_cog=$i
i='󱤦' i_md_timer_cog_outline=$i
i='󱤧' i_md_checkbox_marked_circle_plus_outline=$i
i='󱤨' i_md_panorama_horizontal=$i
i='󱤩' i_md_panorama_vertical=$i
i='󱤪' i_md_advertisements=$i
i='󱤫' i_md_advertisements_off=$i
i='󱤬' i_md_transmission_tower_export=$i
i='󱤭' i_md_transmission_tower_import=$i
i='󱤮' i_md_smoke_detector_alert=$i
i='󱤯' i_md_smoke_detector_alert_outline=$i
i='󱤰' i_md_smoke_detector_variant_alert=$i
i='󱤱' i_md_coffee_maker_check=$i
i='󱤲' i_md_coffee_maker_check_outline=$i
i='󱤳' i_md_cog_pause=$i
i='󱤴' i_md_cog_pause_outline=$i
i='󱤵' i_md_cog_play=$i
i='󱤶' i_md_cog_play_outline=$i
i='󱤷' i_md_cog_stop=$i
i='󱤸' i_md_cog_stop_outline=$i
i='󱤹' i_md_copyleft=$i
i='󱤺' i_md_fast_forward_15=$i
i='󱤻' i_md_file_image_minus=$i
i='󱤼' i_md_file_image_minus_outline=$i
i='󱤽' i_md_file_image_plus=$i
i='󱤾' i_md_file_image_plus_outline=$i
i='󱤿' i_md_file_image_remove=$i
i='󱥀' i_md_file_image_remove_outline=$i
i='󱥁' i_md_message_badge=$i
i='󱥂' i_md_message_badge_outline=$i
i='󱥃' i_md_newspaper_check=$i
i='󱥄' i_md_newspaper_remove=$i
i='󱥅' i_md_publish_off=$i
i='󱥆' i_md_rewind_15=$i
i='󱥇' i_md_view_dashboard_edit=$i
i='󱥈' i_md_view_dashboard_edit_outline=$i
i='󱥉' i_md_office_building_cog=$i
i='󱥊' i_md_office_building_cog_outline=$i
i='󱥋' i_md_hand_clap=$i
i='󱥌' i_md_cone=$i
i='󱥍' i_md_cone_off=$i
i='󱥎' i_md_cylinder=$i
i='󱥏' i_md_cylinder_off=$i
i='󱥐' i_md_octahedron=$i
i='󱥑' i_md_octahedron_off=$i
i='󱥒' i_md_pyramid=$i
i='󱥓' i_md_pyramid_off=$i
i='󱥔' i_md_sphere=$i
i='󱥕' i_md_sphere_off=$i
i='󱥖' i_md_format_letter_spacing=$i
i='󱥗' i_md_french_fries=$i
i='󱥘' i_md_scent=$i
i='󱥙' i_md_scent_off=$i
i='󱥚' i_md_palette_swatch_variant=$i
i='󱥛' i_md_email_seal=$i
i='󱥜' i_md_email_seal_outline=$i
i='󱥝' i_md_stool=$i
i='󱥞' i_md_stool_outline=$i
i='󱥟' i_md_panorama_wide_angle=$i
i='󱥠' i_md_account_lock_open=$i
i='󱥡' i_md_account_lock_open_outline=$i
i='󱥢' i_md_align_horizontal_distribute=$i
i='󱥣' i_md_align_vertical_distribute=$i
i='󱥤' i_md_arrow_bottom_left_bold_box=$i
i='󱥥' i_md_arrow_bottom_left_bold_box_outline=$i
i='󱥦' i_md_arrow_bottom_right_bold_box=$i
i='󱥧' i_md_arrow_bottom_right_bold_box_outline=$i
i='󱥨' i_md_arrow_top_left_bold_box=$i
i='󱥩' i_md_arrow_top_left_bold_box_outline=$i
i='󱥪' i_md_arrow_top_right_bold_box=$i
i='󱥫' i_md_arrow_top_right_bold_box_outline=$i
i='󱥬' i_md_bookmark_box_multiple=$i
i='󱥭' i_md_bookmark_box_multiple_outline=$i
i='󱥮' i_md_bullhorn_variant=$i
i='󱥯' i_md_bullhorn_variant_outline=$i
i='󱥰' i_md_candy=$i
i='󱥱' i_md_candy_off=$i
i='󱥲' i_md_candy_off_outline=$i
i='󱥳' i_md_candy_outline=$i
i='󱥴' i_md_car_clock=$i
i='󱥵' i_md_crowd=$i
i='󱥶' i_md_currency_rupee=$i
i='󱥷' i_md_diving=$i
i='󱥸' i_md_dots_circle=$i
i='󱥹' i_md_elevator_passenger_off=$i
i='󱥺' i_md_elevator_passenger_off_outline=$i
i='󱥻' i_md_elevator_passenger_outline=$i
i='󱥼' i_md_eye_refresh=$i
i='󱥽' i_md_eye_refresh_outline=$i
i='󱥾' i_md_folder_check=$i
i='󱥿' i_md_folder_check_outline=$i
i='󱦀' i_md_human_dolly=$i
i='󱦁' i_md_human_white_cane=$i
i='󱦂' i_md_ip_outline=$i
i='󱦃' i_md_key_alert=$i
i='󱦄' i_md_key_alert_outline=$i
i='󱦅' i_md_kite=$i
i='󱦆' i_md_kite_outline=$i
i='󱦇' i_md_light_flood_down=$i
i='󱦈' i_md_light_flood_up=$i
i='󱦉' i_md_microphone_question=$i
i='󱦊' i_md_microphone_question_outline=$i
i='󱦋' i_md_cradle=$i
i='󱦌' i_md_panorama_outline=$i
i='󱦍' i_md_panorama_sphere=$i
i='󱦎' i_md_panorama_sphere_outline=$i
i='󱦏' i_md_panorama_variant=$i
i='󱦐' i_md_panorama_variant_outline=$i
i='󱦑' i_md_cradle_outline=$i
i='󱦒' i_md_fraction_one_half=$i
i='󱦓' i_md_phone_refresh=$i
i='󱦔' i_md_phone_refresh_outline=$i
i='󱦕' i_md_phone_sync=$i
i='󱦖' i_md_phone_sync_outline=$i
i='󱦗' i_md_razor_double_edge=$i
i='󱦘' i_md_razor_single_edge=$i
i='󱦙' i_md_rotate_360=$i
i='󱦚' i_md_shield_lock_open=$i
i='󱦛' i_md_shield_lock_open_outline=$i
i='󱦜' i_md_sitemap_outline=$i
i='󱦝' i_md_sprinkler_fire=$i
i='󱦞' i_md_tab_search=$i
i='󱦟' i_md_timer_sand_complete=$i
i='󱦠' i_md_timer_sand_paused=$i
i='󱦡' i_md_vacuum=$i
i='󱦢' i_md_vacuum_outline=$i
i='󱦣' i_md_wrench_clock=$i
i='󱦤' i_md_pliers=$i
i='󱦥' i_md_sun_compass=$i
i='󱦦' i_md_truck_snowflake=$i
i='󱦧' i_md_camera_marker=$i
i='󱦨' i_md_camera_marker_outline=$i
i='󱦩' i_md_video_marker=$i
i='󱦪' i_md_video_marker_outline=$i
i='󱦫' i_md_wind_turbine_alert=$i
i='󱦬' i_md_wind_turbine_check=$i
i='󱦭' i_md_truck_plus=$i
i='󱦮' i_md_truck_minus=$i
i='󱦯' i_md_truck_remove=$i
i='󱦰' i_md_arrow_right_thin=$i
i='󱦱' i_md_arrow_left_thin=$i
i='󱦲' i_md_arrow_up_thin=$i
i='󱦳' i_md_arrow_down_thin=$i
i='󱦴' i_md_arrow_top_right_thin=$i
i='󱦵' i_md_arrow_top_left_thin=$i
i='󱦶' i_md_arrow_bottom_left_thin=$i
i='󱦷' i_md_arrow_bottom_right_thin=$i
i='󱦸' i_md_scale_unbalanced=$i
i='󱦹' i_md_draw_pen=$i
i='󱦺' i_md_clock_edit=$i
i='󱦻' i_md_clock_edit_outline=$i
i='󱦼' i_md_truck_plus_outline=$i
i='󱦽' i_md_truck_minus_outline=$i
i='󱦾' i_md_truck_remove_outline=$i
i='󱦿' i_md_camera_off_outline=$i
i='󱧀' i_md_home_group_plus=$i
i='󱧁' i_md_home_group_minus=$i
i='󱧂' i_md_home_group_remove=$i
i='󱧃' i_md_file_sign=$i
i='󱧄' i_md_attachment_lock=$i
i='󱧅' i_md_cellphone_arrow_down_variant=$i
i='󱧆' i_md_file_chart_check=$i
i='󱧇' i_md_file_chart_check_outline=$i
i='󱧈' i_md_file_lock_open=$i
i='󱧉' i_md_file_lock_open_outline=$i
i='󱧊' i_md_folder_question=$i
i='󱧋' i_md_folder_question_outline=$i
i='󱧌' i_md_message_fast=$i
i='󱧍' i_md_message_fast_outline=$i
i='󱧎' i_md_message_text_fast=$i
i='󱧏' i_md_message_text_fast_outline=$i
i='󱧐' i_md_monitor_arrow_down=$i
i='󱧑' i_md_monitor_arrow_down_variant=$i
i='󱧒' i_md_needle_off=$i
i='󱧓' i_md_numeric_off=$i
i='󱧔' i_md_package_variant_closed_minus=$i
i='󱧕' i_md_package_variant_closed_plus=$i
i='󱧖' i_md_package_variant_closed_remove=$i
i='󱧗' i_md_package_variant_minus=$i
i='󱧘' i_md_package_variant_plus=$i
i='󱧙' i_md_package_variant_remove=$i
i='󱧚' i_md_paperclip_lock=$i
i='󱧛' i_md_phone_clock=$i
i='󱧜' i_md_receipt_outline=$i
i='󱧝' i_md_transmission_tower_off=$i
i='󱧞' i_md_truck_alert=$i
i='󱧟' i_md_truck_alert_outline=$i
i='󱧠' i_md_bone_off=$i
i='󱧡' i_md_lightbulb_alert=$i
i='󱧢' i_md_lightbulb_alert_outline=$i
i='󱧣' i_md_lightbulb_question=$i
i='󱧤' i_md_lightbulb_question_outline=$i
i='󱧥' i_md_battery_clock=$i
i='󱧦' i_md_battery_clock_outline=$i
i='󱧧' i_md_autorenew_off=$i
i='󱧨' i_md_folder_arrow_down=$i
i='󱧩' i_md_folder_arrow_down_outline=$i
i='󱧪' i_md_folder_arrow_left=$i
i='󱧫' i_md_folder_arrow_left_outline=$i
i='󱧬' i_md_folder_arrow_left_right=$i
i='󱧭' i_md_folder_arrow_left_right_outline=$i
i='󱧮' i_md_folder_arrow_right=$i
i='󱧯' i_md_folder_arrow_right_outline=$i
i='󱧰' i_md_folder_arrow_up=$i
i='󱧱' i_md_folder_arrow_up_down=$i
i='󱧲' i_md_folder_arrow_up_down_outline=$i
i='󱧳' i_md_folder_arrow_up_outline=$i
i='󱧴' i_md_folder_cancel=$i
i='󱧵' i_md_folder_cancel_outline=$i
i='󱧶' i_md_folder_file=$i
i='󱧷' i_md_folder_file_outline=$i
i='󱧸' i_md_folder_off=$i
i='󱧹' i_md_folder_off_outline=$i
i='󱧺' i_md_folder_play=$i
i='󱧻' i_md_folder_play_outline=$i
i='󱧼' i_md_folder_wrench=$i
i='󱧽' i_md_folder_wrench_outline=$i
i='󱧾' i_md_image_refresh=$i
i='󱧿' i_md_image_refresh_outline=$i
i='󱨀' i_md_image_sync=$i
i='󱨁' i_md_image_sync_outline=$i
i='󱨂' i_md_percent_box=$i
i='󱨃' i_md_percent_box_outline=$i
i='󱨄' i_md_percent_circle=$i
i='󱨅' i_md_percent_circle_outline=$i
i='󱨆' i_md_sale_outline=$i
i='󱨇' i_md_square_rounded_badge=$i
i='󱨈' i_md_square_rounded_badge_outline=$i
i='󱨉' i_md_triangle_small_down=$i
i='󱨊' i_md_triangle_small_up=$i
i='󱨋' i_md_notebook_heart=$i
i='󱨌' i_md_notebook_heart_outline=$i
i='󱨍' i_md_brush_outline=$i
i='󱨎' i_md_fruit_pear=$i
i='󱨏' i_md_raw=$i
i='󱨐' i_md_raw_off=$i
i='󱨑' i_md_wall_fire=$i
i='󱨒' i_md_home_clock=$i
i='󱨓' i_md_home_clock_outline=$i
i='󱨔' i_md_camera_lock=$i
i='󱨕' i_md_camera_lock_outline=$i
i='󱨖' i_md_play_box_lock=$i
i='󱨗' i_md_play_box_lock_open=$i
i='󱨘' i_md_play_box_lock_open_outline=$i
i='󱨙' i_md_play_box_lock_outline=$i
i='󱨚' i_md_robot_industrial_outline=$i
i='󱨛' i_md_gas_burner=$i
i='󱨜' i_md_video_2d=$i
i='󱨝' i_md_book_heart=$i
i='󱨞' i_md_book_heart_outline=$i
i='󱨟' i_md_account_hard_hat_outline=$i
i='󱨠' i_md_account_school=$i
i='󱨡' i_md_account_school_outline=$i
i='󱨢' i_md_library_outline=$i
i='󱨣' i_md_projector_off=$i
i='󱨤' i_md_light_switch_off=$i
i='󱨥' i_md_toggle_switch_variant=$i
i='󱨦' i_md_toggle_switch_variant_off=$i
i='󱨧' i_md_asterisk_circle_outline=$i
i='󱨨' i_md_barrel_outline=$i
i='󱨩' i_md_bell_cog=$i
i='󱨪' i_md_bell_cog_outline=$i
i='󱨫' i_md_blinds_horizontal=$i
i='󱨬' i_md_blinds_horizontal_closed=$i
i='󱨭' i_md_blinds_vertical=$i
i='󱨮' i_md_blinds_vertical_closed=$i
i='󱨯' i_md_bulkhead_light=$i
i='󱨰' i_md_calendar_today_outline=$i
i='󱨱' i_md_calendar_week_begin_outline=$i
i='󱨲' i_md_calendar_week_end=$i
i='󱨳' i_md_calendar_week_end_outline=$i
i='󱨴' i_md_calendar_week_outline=$i
i='󱨵' i_md_cloud_percent=$i
i='󱨶' i_md_cloud_percent_outline=$i
i='󱨷' i_md_coach_lamp_variant=$i
i='󱨸' i_md_compost=$i
i='󱨹' i_md_currency_fra=$i
i='󱨺' i_md_fan_clock=$i
i='󱨻' i_md_file_rotate_left=$i
i='󱨼' i_md_file_rotate_left_outline=$i
i='󱨽' i_md_file_rotate_right=$i
i='󱨾' i_md_file_rotate_right_outline=$i
i='󱨿' i_md_filter_multiple=$i
i='󱩀' i_md_filter_multiple_outline=$i
i='󱩁' i_md_gymnastics=$i
i='󱩂' i_md_hand_clap_off=$i
i='󱩃' i_md_heat_pump=$i
i='󱩄' i_md_heat_pump_outline=$i
i='󱩅' i_md_heat_wave=$i
i='󱩆' i_md_home_off=$i
i='󱩇' i_md_home_off_outline=$i
i='󱩈' i_md_landslide=$i
i='󱩉' i_md_landslide_outline=$i
i='󱩊' i_md_laptop_account=$i
i='󱩋' i_md_led_strip_variant_off=$i
i='󱩌' i_md_lightbulb_night=$i
i='󱩍' i_md_lightbulb_night_outline=$i
i='󱩎' i_md_lightbulb_on_10=$i
i='󱩏' i_md_lightbulb_on_20=$i
i='󱩐' i_md_lightbulb_on_30=$i
i='󱩑' i_md_lightbulb_on_40=$i
i='󱩒' i_md_lightbulb_on_50=$i
i='󱩓' i_md_lightbulb_on_60=$i
i='󱩔' i_md_lightbulb_on_70=$i
i='󱩕' i_md_lightbulb_on_80=$i
i='󱩖' i_md_lightbulb_on_90=$i
i='󱩗' i_md_meter_electric=$i
i='󱩘' i_md_meter_electric_outline=$i
i='󱩙' i_md_meter_gas=$i
i='󱩚' i_md_meter_gas_outline=$i
i='󱩛' i_md_monitor_account=$i
i='󱩜' i_md_pill_off=$i
i='󱩝' i_md_plus_lock=$i
i='󱩞' i_md_plus_lock_open=$i
i='󱩟' i_md_pool_thermometer=$i
i='󱩠' i_md_post_lamp=$i
i='󱩡' i_md_rabbit_variant=$i
i='󱩢' i_md_rabbit_variant_outline=$i
i='󱩣' i_md_receipt_text_check=$i
i='󱩤' i_md_receipt_text_check_outline=$i
i='󱩥' i_md_receipt_text_minus=$i
i='󱩦' i_md_receipt_text_minus_outline=$i
i='󱩧' i_md_receipt_text_plus=$i
i='󱩨' i_md_receipt_text_plus_outline=$i
i='󱩩' i_md_receipt_text_remove=$i
i='󱩪' i_md_receipt_text_remove_outline=$i
i='󱩫' i_md_roller_shade=$i
i='󱩬' i_md_roller_shade_closed=$i
i='󱩭' i_md_seed_plus=$i
i='󱩮' i_md_seed_plus_outline=$i
i='󱩯' i_md_shopping_search_outline=$i
i='󱩰' i_md_snowflake_check=$i
i='󱩱' i_md_snowflake_thermometer=$i
i='󱩲' i_md_snowshoeing=$i
i='󱩳' i_md_solar_power_variant=$i
i='󱩴' i_md_solar_power_variant_outline=$i
i='󱩵' i_md_storage_tank=$i
i='󱩶' i_md_storage_tank_outline=$i
i='󱩷' i_md_sun_clock=$i
i='󱩸' i_md_sun_clock_outline=$i
i='󱩹' i_md_sun_snowflake_variant=$i
i='󱩺' i_md_tag_check=$i
i='󱩻' i_md_tag_check_outline=$i
i='󱩼' i_md_text_box_edit=$i
i='󱩽' i_md_text_box_edit_outline=$i
i='󱩾' i_md_text_search_variant=$i
i='󱩿' i_md_thermometer_check=$i
i='󱪀' i_md_thermometer_water=$i
i='󱪁' i_md_tsunami=$i
i='󱪂' i_md_turbine=$i
i='󱪃' i_md_volcano=$i
i='󱪄' i_md_volcano_outline=$i
i='󱪅' i_md_water_thermometer=$i
i='󱪆' i_md_water_thermometer_outline=$i
i='󱪇' i_md_wheelchair=$i
i='󱪈' i_md_wind_power=$i
i='󱪉' i_md_wind_power_outline=$i
i='󱪊' i_md_window_shutter_cog=$i
i='󱪋' i_md_window_shutter_settings=$i
i='󱪌' i_md_account_tie_woman=$i
i='󱪍' i_md_briefcase_arrow_left_right=$i
i='󱪎' i_md_briefcase_arrow_left_right_outline=$i
i='󱪏' i_md_briefcase_arrow_up_down=$i
i='󱪐' i_md_briefcase_arrow_up_down_outline=$i
i='󱪑' i_md_cash_clock=$i
i='󱪒' i_md_cash_sync=$i
i='󱪓' i_md_file_arrow_left_right=$i
i='󱪔' i_md_file_arrow_left_right_outline=$i
i='󱪕' i_md_file_arrow_up_down=$i
i='󱪖' i_md_file_arrow_up_down_outline=$i
i='󱪗' i_md_file_document_alert=$i
i='󱪘' i_md_file_document_alert_outline=$i
i='󱪙' i_md_file_document_check=$i
i='󱪚' i_md_file_document_check_outline=$i
i='󱪛' i_md_file_document_minus=$i
i='󱪜' i_md_file_document_minus_outline=$i
i='󱪝' i_md_file_document_plus=$i
i='󱪞' i_md_file_document_plus_outline=$i
i='󱪟' i_md_file_document_remove=$i
i='󱪠' i_md_file_document_remove_outline=$i
i='󱪡' i_md_file_minus=$i
i='󱪢' i_md_file_minus_outline=$i
i='󱪣' i_md_filter_cog=$i
i='󱪤' i_md_filter_cog_outline=$i
i='󱪥' i_md_filter_settings=$i
i='󱪦' i_md_filter_settings_outline=$i
i='󱪧' i_md_folder_lock_open_outline=$i
i='󱪨' i_md_folder_lock_outline=$i
i='󱪩' i_md_forum_minus=$i
i='󱪪' i_md_forum_minus_outline=$i
i='󱪫' i_md_forum_plus=$i
i='󱪬' i_md_forum_plus_outline=$i
i='󱪭' i_md_forum_remove=$i
i='󱪮' i_md_forum_remove_outline=$i
i='󱪯' i_md_heating_coil=$i
i='󱪰' i_md_image_lock=$i
i='󱪱' i_md_image_lock_outline=$i
i='󱪲' i_md_land_fields=$i
i='󱪳' i_md_land_plots=$i
i='󱪴' i_md_land_plots_circle=$i
i='󱪵' i_md_land_plots_circle_variant=$i
i='󱪶' i_md_land_rows_horizontal=$i
i='󱪷' i_md_land_rows_vertical=$i
i='󱪸' i_md_medical_cotton_swab=$i
i='󱪹' i_md_rolodex=$i
i='󱪺' i_md_rolodex_outline=$i
i='󱪻' i_md_sort_variant_off=$i
i='󱪼' i_md_tally_mark_1=$i
i='󱪽' i_md_tally_mark_2=$i
i='󱪾' i_md_tally_mark_3=$i
i='󱪿' i_md_tally_mark_4=$i
i='󱫀' i_md_tally_mark_5=$i
i='󱫁' i_md_attachment_check=$i
i='󱫂' i_md_attachment_minus=$i
i='󱫃' i_md_attachment_off=$i
i='󱫄' i_md_attachment_plus=$i
i='󱫅' i_md_attachment_remove=$i
i='󱫆' i_md_paperclip_check=$i
i='󱫇' i_md_paperclip_minus=$i
i='󱫈' i_md_paperclip_off=$i
i='󱫉' i_md_paperclip_plus=$i
i='󱫊' i_md_paperclip_remove=$i
i='󱫋' i_md_network_pos=$i
i='󱫌' i_md_timer_alert=$i
i='󱫍' i_md_timer_alert_outline=$i
i='󱫎' i_md_timer_cancel=$i
i='󱫏' i_md_timer_cancel_outline=$i
i='󱫐' i_md_timer_check=$i
i='󱫑' i_md_timer_check_outline=$i
i='󱫒' i_md_timer_edit=$i
i='󱫓' i_md_timer_edit_outline=$i
i='󱫔' i_md_timer_lock=$i
i='󱫕' i_md_timer_lock_open=$i
i='󱫖' i_md_timer_lock_open_outline=$i
i='󱫗' i_md_timer_lock_outline=$i
i='󱫘' i_md_timer_marker=$i
i='󱫙' i_md_timer_marker_outline=$i
i='󱫚' i_md_timer_minus=$i
i='󱫛' i_md_timer_minus_outline=$i
i='󱫜' i_md_timer_music=$i
i='󱫝' i_md_timer_music_outline=$i
i='󱫞' i_md_timer_pause=$i
i='󱫟' i_md_timer_pause_outline=$i
i='󱫠' i_md_timer_play=$i
i='󱫡' i_md_timer_play_outline=$i
i='󱫢' i_md_timer_plus=$i
i='󱫣' i_md_timer_plus_outline=$i
i='󱫤' i_md_timer_refresh=$i
i='󱫥' i_md_timer_refresh_outline=$i
i='󱫦' i_md_timer_remove=$i
i='󱫧' i_md_timer_remove_outline=$i
i='󱫨' i_md_timer_star=$i
i='󱫩' i_md_timer_star_outline=$i
i='󱫪' i_md_timer_stop=$i
i='󱫫' i_md_timer_stop_outline=$i
i='󱫬' i_md_timer_sync=$i
i='󱫭' i_md_timer_sync_outline=$i
i='󱫮' i_md_ear_hearing_loop=$i
i='󱫯' i_md_sail_boat_sink=$i
i='󱫰' i_md_lecturn=$i
unset i
